@@ -18,43 +18,39 @@
  http://www.verisign.com/nds/naming/namestore/techdocs.html
  ***********************************************************/
 package com.verisign.epp.namestore.interfaces;
-
-//----------------------------------------------
-//
-// imports...
-//
-//----------------------------------------------
-// Java Core Imports
-
 import java.util.Random;
 
-import junit.extensions.TestSetup;
-import junit.framework.*;
-
 // Log4j imports
-import org.apache.log4j.*;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
+import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.gen.EPPResult;
 // EPP Imports
 import com.verisign.epp.codec.host.EPPHostAddress;
 import com.verisign.epp.codec.host.EPPHostCheckResp;
 import com.verisign.epp.codec.host.EPPHostCheckResult;
 import com.verisign.epp.codec.host.EPPHostInfoResp;
-import com.verisign.epp.codec.gen.*;
+import com.verisign.epp.codec.orgext.EPPOrgExtId;
 import com.verisign.epp.interfaces.EPPApplicationSingle;
 import com.verisign.epp.interfaces.EPPCommandException;
 import com.verisign.epp.interfaces.EPPHost;
 import com.verisign.epp.interfaces.EPPSession;
-import com.verisign.epp.util.EPPCatFactory;
+import com.verisign.epp.pool.EPPSessionPool;
 import com.verisign.epp.util.InvalidateSessionException;
 import com.verisign.epp.util.TestThread;
 import com.verisign.epp.util.TestUtil;
-import com.verisign.epp.pool.*;
+
+import junit.extensions.TestSetup;
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
 
 /**
- * Test of the use of the <code>NSHost</code> interface.  This
- * test utilizes the EPP session pool and exercises all of the 
- * operations defined in <code>NSHost</code> and the base
- * class <code>EPPHost</code>.  
+ * Test of the use of the <code>NSHost</code> interface. This test utilizes the
+ * EPP session pool and exercises all of the operations defined in
+ * <code>NSHost</code> and the base class <code>EPPHost</code>.
  * 
  * @see com.verisign.epp.namestore.interfaces.NSHost
  * @see com.verisign.epp.interfaces.EPPHost
@@ -62,34 +58,33 @@ import com.verisign.epp.pool.*;
 public class NSHostTst extends TestCase {
 
 	/**
-	 * Handle to the Singleton EPP Application instance
-	 * (<code>EPPApplicationSingle</code>)
+	 * Handle to the Singleton EPP Application instance (
+	 * <code>EPPApplicationSingle</code>)
 	 */
-	private static EPPApplicationSingle app = EPPApplicationSingle
-			.getInstance();
+	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
 	/** Name of configuration file to use for test (default = epp.config). */
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(NSHostTst.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(NSHostTst.class);
 
 	/** EPP Session pool associated with test */
 	private static EPPSessionPool sessionPool = null;
 
 	/**
-	 * Random instance for the generation of unique objects (hosts, IP
-	 * addresses, etc.).
+	 * Random instance for the generation of unique objects (hosts, IP addresses,
+	 * etc.).
 	 */
 	private Random rd = new Random(System.currentTimeMillis());
 
 	/**
-	 * Allocates an <code>NSHostTst</code> with a logical name.  The
-	 * constructor will initialize the base class <code>TestCase</code> with
-	 * the logical name.
+	 * Allocates an <code>NSHostTst</code> with a logical name. The constructor
+	 * will initialize the base class <code>TestCase</code> with the logical
+	 * name.
 	 *
-	 * @param name Logical name of the test
+	 * @param name
+	 *           Logical name of the test
 	 */
 	public NSHostTst(String name) {
 		super(name);
@@ -97,8 +92,6 @@ public class NSHostTst extends TestCase {
 
 	// End NSHostTst(String)
 
-
-
 	/**
 	 * Unit test of <code>NSHost.sendCreate</code> command.
 	 */
@@ -113,8 +106,7 @@ public class NSHostTst extends TestCase {
 			NSHost theHost = new NSHost(theSession);
 
 			try {
-				System.out
-						.println("\n----------------------------------------------------------------");
+				System.out.println("\n----------------------------------------------------------------");
 
 				String theHostName = this.makeInternalHost();
 
@@ -123,7 +115,7 @@ public class NSHostTst extends TestCase {
 				theHost.setTransId("ABC-12345-XYZ");
 
 				theHost.addHostName(theHostName);
-				theHost.setSubProductID(NSSubProduct.COM);
+				theHost.setSubProductID("COM");
 
 				theHost.addIPV4Address(this.makeIP());
 				theHost.addIPV6Address("1080:0:0:0:8:800:200C:417A");
@@ -131,9 +123,8 @@ public class NSHostTst extends TestCase {
 
 				theResponse = theHost.sendCreate();
 
-				//-- Output all of the response attributes
-				System.out.println("hostCreate: Response = [" + theResponse
-						+ "]\n\n");
+				// -- Output all of the response attributes
+				System.out.println("hostCreate: Response = [" + theResponse + "]\n\n");
 
 			}
 
@@ -142,24 +133,21 @@ public class NSHostTst extends TestCase {
 			}
 
 			try {
-				System.out
-						.println("\n----------------------------------------------------------------");
+				System.out.println("\n----------------------------------------------------------------");
 
 				theHost.setTransId("ABC-12345-XYZ");
 
 				String theHostName = this.makeExternalHost();
 
-				System.out.println("hostCreate: Create " + theHostName
-						+ " with all optional attributes");
+				System.out.println("hostCreate: Create " + theHostName + " with all optional attributes");
 
 				theHost.addHostName(theHostName);
-				theHost.setSubProductID(NSSubProduct.COM);
+				theHost.setSubProductID("COM");
 
 				theResponse = theHost.sendCreate();
 
-				//-- Output all of the response attributes
-				System.out.println("hostCreate: Response = [" + theResponse
-						+ "]\n\n");
+				// -- Output all of the response attributes
+				System.out.println("hostCreate: Response = [" + theResponse + "]\n\n");
 			}
 			catch (EPPCommandException ex) {
 				TestUtil.handleException(theSession, ex);
@@ -171,7 +159,8 @@ public class NSHostTst extends TestCase {
 			theSession = null;
 		}
 		finally {
-			if (theSession != null) this.returnSession(theSession);
+			if (theSession != null)
+				this.returnSession(theSession);
 		}
 
 		printEnd("testHostCreate");
@@ -191,44 +180,36 @@ public class NSHostTst extends TestCase {
 
 			try {
 
-				System.out
-						.println("\n----------------------------------------------------------------");
+				System.out.println("\n----------------------------------------------------------------");
 
 				String theHostName = this.makeInternalHost();
-				System.out.println("hostCheck: Check single host name ("
-						+ theHostName + ")");
+				System.out.println("hostCheck: Check single host name (" + theHostName + ")");
 
 				theHost.setTransId("ABC-12345-XYZ");
 
 				theHost.addHostName(theHostName);
-				theHost.setSubProductID(NSSubProduct.COM);
+				theHost.setSubProductID("COM");
 
 				theResponse = theHost.sendCheck();
 
 				System.out.println("Response Type = " + theResponse.getType());
 
-				System.out.println("Response.TransId.ServerTransId = "
-						+ theResponse.getTransId().getServerTransId());
+				System.out.println("Response.TransId.ServerTransId = " + theResponse.getTransId().getServerTransId());
 
-				System.out.println("Response.TransId.ServerTransId = "
-						+ theResponse.getTransId().getClientTransId());
+				System.out.println("Response.TransId.ServerTransId = " + theResponse.getTransId().getClientTransId());
 
 				// Output all of the response attributes
-				System.out.println("\nhostCheck: Response = [" + theResponse
-						+ "]");
+				System.out.println("\nhostCheck: Response = [" + theResponse + "]");
 
 				// For each result
 				for (int i = 0; i < theResponse.getCheckResults().size(); i++) {
-					EPPHostCheckResult currResult = (EPPHostCheckResult) theResponse
-							.getCheckResults().elementAt(i);
+					EPPHostCheckResult currResult = (EPPHostCheckResult) theResponse.getCheckResults().elementAt(i);
 
 					if (currResult.isAvailable()) {
-						System.out.println("hostCheck: Host "
-								+ currResult.getName() + " is available");
+						System.out.println("hostCheck: Host " + currResult.getName() + " is available");
 					}
 					else {
-						System.out.println("hostCheck: Host "
-								+ currResult.getName() + " is not available");
+						System.out.println("hostCheck: Host " + currResult.getName() + " is not available");
 					}
 				}
 
@@ -240,10 +221,9 @@ public class NSHostTst extends TestCase {
 
 			try {
 				// Check multiple host names
+				System.out.println("\n----------------------------------------------------------------");
 				System.out
-						.println("\n----------------------------------------------------------------");
-				System.out
-						.println("hostCheck: Check multiple host names (ns1.example.com, ns2.example.com, ns3.example.com)");
+				      .println("hostCheck: Check multiple host names (ns1.example.com, ns2.example.com, ns3.example.com)");
 				theHost.setTransId("ABC-12345-XYZ");
 
 				/**
@@ -252,7 +232,7 @@ public class NSHostTst extends TestCase {
 				theHost.addHostName("ns1.example.com");
 				theHost.addHostName("ns2.example.com");
 				theHost.addHostName("ns3.example.com");
-				theHost.setSubProductID(NSSubProduct.COM);
+				theHost.setSubProductID("COM");
 
 				for (int i = 0; i <= 10; i++) {
 					theHost.addHostName(this.makeInternalHost());
@@ -261,25 +241,19 @@ public class NSHostTst extends TestCase {
 				theResponse = theHost.sendCheck();
 
 				// Output all of the response attributes
-				System.out.println("\nhostCheck: Response = [" + theResponse
-						+ "]");
-				System.out.println("Client Transaction Id = "
-						+ theResponse.getTransId().getClientTransId());
-				System.out.println("Server Transaction Id = "
-						+ theResponse.getTransId().getServerTransId());
+				System.out.println("\nhostCheck: Response = [" + theResponse + "]");
+				System.out.println("Client Transaction Id = " + theResponse.getTransId().getClientTransId());
+				System.out.println("Server Transaction Id = " + theResponse.getTransId().getServerTransId());
 
 				// For each result
 				for (int i = 0; i < theResponse.getCheckResults().size(); i++) {
-					EPPHostCheckResult currResult = (EPPHostCheckResult) theResponse
-							.getCheckResults().elementAt(i);
+					EPPHostCheckResult currResult = (EPPHostCheckResult) theResponse.getCheckResults().elementAt(i);
 
 					if (currResult.isAvailable()) {
-						System.out.println("hostCheck: Host "
-								+ currResult.getName() + " is available");
+						System.out.println("hostCheck: Host " + currResult.getName() + " is available");
 					}
 					else {
-						System.out.println("hostCheck: Host "
-								+ currResult.getName() + " is not available");
+						System.out.println("hostCheck: Host " + currResult.getName() + " is not available");
 					}
 				}
 
@@ -295,7 +269,8 @@ public class NSHostTst extends TestCase {
 			theSession = null;
 		}
 		finally {
-			if (theSession != null) this.returnSession(theSession);
+			if (theSession != null)
+				this.returnSession(theSession);
 		}
 
 		printEnd("testHostCheck");
@@ -319,29 +294,25 @@ public class NSHostTst extends TestCase {
 				theHost.setTransId("ABC-12345-XYZ");
 
 				theHost.addHostName(this.makeInternalHost());
-				theHost.setSubProductID(NSSubProduct.COM);
+				theHost.setSubProductID("COM");
 
 				theResponse = theHost.sendInfo();
 
-				//-- Output all of the response attributes
+				// -- Output all of the response attributes
 				System.out.println("hostInfo: Response = [" + theResponse + "]\n\n");
 
-				//-- Output required response attributes using accessors
+				// -- Output required response attributes using accessors
 				System.out.println("hostInfo: name = " + theResponse.getName());
-				System.out.println("hostInfo: client id = "
-								   + theResponse.getClientId());
-				System.out.println("hostInfo: created by = "
-								   + theResponse.getCreatedBy());
-				System.out.println("hostInfo: create date = "
-								   + theResponse.getCreatedDate());
+				System.out.println("hostInfo: client id = " + theResponse.getClientId());
+				System.out.println("hostInfo: created by = " + theResponse.getCreatedBy());
+				System.out.println("hostInfo: create date = " + theResponse.getCreatedDate());
 
-				//-- Output optional response attributes using accessors
+				// -- Output optional response attributes using accessors
 				// Addresses
 				if (theResponse.getAddresses() != null) {
 					// For each Address
 					for (int i = 0; i < theResponse.getAddresses().size(); i++) {
-						EPPHostAddress currAddress =
-							(EPPHostAddress) theResponse.getAddresses().elementAt(i);
+						EPPHostAddress currAddress = (EPPHostAddress) theResponse.getAddresses().elementAt(i);
 
 						System.out.print("hostInfo: address " + (i + 1));
 
@@ -362,14 +333,12 @@ public class NSHostTst extends TestCase {
 
 				// Last Updated By
 				if (theResponse.getLastUpdatedBy() != null) {
-					System.out.println("hostInfo: last updated by = "
-									   + theResponse.getLastUpdatedBy());
+					System.out.println("hostInfo: last updated by = " + theResponse.getLastUpdatedBy());
 				}
 
 				// Last Updated Date
 				if (theResponse.getLastUpdatedDate() != null) {
-					System.out.println("hostInfo: last updated date = "
-									   + theResponse.getLastUpdatedDate());
+					System.out.println("hostInfo: last updated date = " + theResponse.getLastUpdatedDate());
 				}
 
 				this.handleResponse(theResponse);
@@ -385,7 +354,8 @@ public class NSHostTst extends TestCase {
 			theSession = null;
 		}
 		finally {
-			if (theSession != null) this.returnSession(theSession);
+			if (theSession != null)
+				this.returnSession(theSession);
 		}
 
 		printEnd("testHostInfo");
@@ -409,13 +379,12 @@ public class NSHostTst extends TestCase {
 				theHost.setTransId("ABC-12345-XYZ");
 
 				theHost.addHostName(this.makeInternalHost());
-				theHost.setSubProductID(NSSubProduct.COM);
+				theHost.setSubProductID("COM");
 
 				theResponse = theHost.sendDelete();
 
-				//-- Output all of the response attributes
-				System.out.println("hostDelete: Response = [" + theResponse
-						+ "]\n\n");
+				// -- Output all of the response attributes
+				System.out.println("hostDelete: Response = [" + theResponse + "]\n\n");
 
 				this.handleResponse(theResponse);
 
@@ -431,13 +400,13 @@ public class NSHostTst extends TestCase {
 			theSession = null;
 		}
 		finally {
-			if (theSession != null) this.returnSession(theSession);
+			if (theSession != null)
+				this.returnSession(theSession);
 		}
 
 		printEnd("testHostDelete");
 	}
 
-
 	/**
 	 * Unit test of <code>NSHost.sendUpdate</code> command.
 	 */
@@ -456,11 +425,10 @@ public class NSHostTst extends TestCase {
 
 				String theHostName = this.makeInternalHost();
 
-				System.out.println("\nhostUpdate: Host " + theHostName
-						+ " update");
+				System.out.println("\nhostUpdate: Host " + theHostName + " update");
 
 				theHost.addHostName(theHostName);
-				theHost.setSubProductID(NSSubProduct.COM);
+				theHost.setSubProductID("COM");
 
 				// Add attributes
 				theHost.addIPV4Address(this.makeIP());
@@ -468,19 +436,15 @@ public class NSHostTst extends TestCase {
 				// Remove attributes
 				theHost.removeIPV6Address("1080:0:0:0:8:800:200C:417A");
 
-				theHost.addStatus(
-							   EPPHost.STAT_OK, "Hello_World", EPPHost.DEFAULT_LANG);
+				theHost.addStatus(EPPHost.STAT_OK, "Hello_World", EPPHost.DEFAULT_LANG);
 
-				theHost.removeStatus(
-								  EPPHost.STAT_OK, "Hello World with spaces",
-								  EPPHost.DEFAULT_LANG);
+				theHost.removeStatus(EPPHost.STAT_OK, "Hello World with spaces", EPPHost.DEFAULT_LANG);
 
 				// Execute update
 				theResponse = theHost.sendUpdate();
 
-				//-- Output all of the response attributes
-				System.out.println("hostUpdate: Response = [" + theResponse
-						+ "]\n\n");
+				// -- Output all of the response attributes
+				System.out.println("hostUpdate: Response = [" + theResponse + "]\n\n");
 
 				this.handleResponse(theResponse);
 
@@ -495,12 +459,131 @@ public class NSHostTst extends TestCase {
 			theSession = null;
 		}
 		finally {
-			if (theSession != null) this.returnSession(theSession);
+			if (theSession != null)
+				this.returnSession(theSession);
 		}
 
 		printEnd("testHostUpdate");
 	}
-	
+
+	/**
+	 * Unit test using {@link NSHost#addOrgId(EPPOrgExtId)} to set the reseller
+	 * identifier on create and {@link NSHost#addUpdateOrgId(int, EPPOrgExtId)}
+	 * to update the reseller identifier of an existing host.
+	 */
+	public void testResellerId() {
+		printStart("testResellerId");
+
+		EPPSession theSession = null;
+		EPPResponse theResponse = null;
+		try {
+			theSession = this.borrowSession();
+			NSHost theHost = new NSHost(theSession);
+
+			// Reseller Identifier with Host Create
+			try {
+				System.out.println("\ntestResellerId: Host create with reseller identifier");
+
+				theHost.setTransId("ABC-12345");
+
+				theHost.addHostName("ns1.reseller.example");
+				theHost.setSubProductID("example");
+				theHost.addIPV4Address(this.makeIP());
+				theHost.addIPV6Address("1080:0:0:0:8:800:200C:417A");
+				theHost.addIPV6Address("::FFFF:129.144.52.38");
+				theHost.addOrgId(new EPPOrgExtId("reseller", "myreseller"));
+
+				theResponse = theHost.sendCreate();
+
+				// -- Output all of the response attributes
+				System.out.println("testResellerId: Create Response = [" + theResponse + "]\n\n");
+
+				this.handleResponse(theResponse);
+
+			}
+			catch (EPPCommandException ex) {
+				TestUtil.handleException(theSession, ex);
+			}
+
+			// Reseller Identifier with Host Update - ADD
+			try {
+				System.out.println("\ntestResellerId: Host update with reseller identifier - ADD");
+
+				theHost.setTransId("ABC-12345-XYZ");
+
+				theHost.addHostName("example1.tld");
+				theHost.setSubProductID("tld");
+
+				theHost.addUpdateOrgId(NSHost.ADD, new EPPOrgExtId("reseller", "myreseller"));
+
+				theResponse = theHost.sendUpdate();
+
+				// -- Output all of the response attributes
+				System.out.println("testResellerId: ADD Update Response = [" + theResponse + "]\n\n");
+
+				this.handleResponse(theResponse);
+			}
+			catch (EPPCommandException ex) {
+				TestUtil.handleException(theSession, ex);
+			}
+
+			// Reseller Identifier with Host Update - CHG
+			try {
+				System.out.println("\ntestResellerId: Host update with reseller identifier - CHG");
+
+				theHost.setTransId("ABC-12345-XYZ");
+
+				theHost.addHostName("example1.tld");
+				theHost.setSubProductID("tld");
+
+				theHost.addUpdateOrgId(NSHost.CHANGE, new EPPOrgExtId("reseller", "myreseller2"));
+
+				theResponse = theHost.sendUpdate();
+
+				// -- Output all of the response attributes
+				System.out.println("testResellerId: CHG Update Response = [" + theResponse + "]\n\n");
+
+				this.handleResponse(theResponse);
+			}
+			catch (EPPCommandException ex) {
+				TestUtil.handleException(theSession, ex);
+			}
+
+			// Reseller Identifier with Host Update - REM
+			try {
+				System.out.println("\ntestResellerId: Host update with reseller identifier - REM");
+
+				theHost.setTransId("ABC-12345-XYZ");
+
+				theHost.addHostName("example1.tld");
+				theHost.setSubProductID("tld");
+
+				theHost.addUpdateOrgId(NSHost.REMOVE, new EPPOrgExtId("reseller", "myreseller2"));
+
+				theResponse = theHost.sendUpdate();
+
+				// -- Output all of the response attributes
+				System.out.println("testResellerId: REM Update Response = [" + theResponse + "]\n\n");
+
+				this.handleResponse(theResponse);
+			}
+			catch (EPPCommandException ex) {
+				TestUtil.handleException(theSession, ex);
+			}
+
+		}
+		catch (InvalidateSessionException ex) {
+			this.invalidateSession(theSession);
+			theSession = null;
+		}
+		finally {
+			if (theSession != null)
+				this.returnSession(theSession);
+		}
+
+		printEnd("testResellerId");
+	}
+
 	/**
 	 * Unit test of <code>EPPSession.endSession</code>. One session in the
 	 * session pool wil be ended.
@@ -516,18 +599,16 @@ public class NSHostTst extends TestCase {
 		}
 		catch (Exception ex) {
 			ex.printStackTrace();
-			Assert.fail("testEndSession(): Exception invalidating session: "
-					+ ex);
+			Assert.fail("testEndSession(): Exception invalidating session: " + ex);
 		}
 		finally {
-			if (theSession != null) this.returnSession(theSession);
+			if (theSession != null)
+				this.returnSession(theSession);
 		}
 
 		printEnd("testEndSession");
 	}
 
-	// End NSHostTst.endSession()
-
 	/**
 	 * JUNIT <code>setUp</code> method
 	 */
@@ -535,8 +616,6 @@ public class NSHostTst extends TestCase {
 
 	}
 
-	// End NSHostTst.setUp();
-
 	/**
 	 * JUNIT <code>tearDown</code>, which currently does nothing.
 	 */
@@ -546,8 +625,8 @@ public class NSHostTst extends TestCase {
 	// End NSHostTst.tearDown();
 
 	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests
-	 * associated with <code>NSHostTst</code>.
+	 * JUNIT <code>suite</code> static method, which returns the tests associated
+	 * with <code>NSHostTst</code>.
 	 *
 	 * @return DOCUMENT ME!
 	 */
@@ -556,16 +635,17 @@ public class NSHostTst extends TestCase {
 	}
 
 	// End NSHostTst.suite()
-	
+
 	/**
 	 * Setup framework from running NSHostTst tests.
 	 */
 	private static class NSHostTstSetup extends TestSetup {
-		
+
 		/**
 		 * Creates setup instance for passed in tests.
 		 * 
-		 * @param aTest Tests to execute
+		 * @param aTest
+		 *           Tests to execute
 		 */
 		public NSHostTstSetup(Test aTest) {
 			super(aTest);
@@ -576,9 +656,10 @@ public class NSHostTst extends TestCase {
 		 */
 		protected void setUp() throws Exception {
 			super.setUp();
-			
+
 			String theConfigFileName = System.getProperty("EPP.ConfigFile");
-			if (theConfigFileName != null) configFileName = theConfigFileName;
+			if (theConfigFileName != null)
+				configFileName = theConfigFileName;
 
 			try {
 				app.initialize(configFileName);
@@ -621,7 +702,7 @@ public class NSHostTst extends TestCase {
 	 * 
 	 * 
 	 * @param args
-	 *            DOCUMENT ME!
+	 *           DOCUMENT ME!
 	 */
 	public static void main(String[] args) {
 		// Override the default configuration file name?
@@ -641,8 +722,7 @@ public class NSHostTst extends TestCase {
 		if (numThreads > 1) {
 			// Spawn each thread passing in the Test Suite
 			for (int i = 0; i < numThreads; i++) {
-				TestThread thread = new TestThread("NSHostTst Thread " + i,
-						NSHostTst.suite());
+				TestThread thread = new TestThread("NSHostTst Thread " + i, NSHostTst.suite());
 				thread.start();
 			}
 		}
@@ -661,24 +741,21 @@ public class NSHostTst extends TestCase {
 
 	// End NSHostTst.main(String [])
 
-
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the
-	 * current thread is a <code>TestThread</code>.
+	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 *
-	 * @param aTest name for the test
+	 * @param aTest
+	 *           name for the test
 	 */
 	public static void printStart(String aTest) {
 		if (Thread.currentThread() instanceof TestThread) {
 			System.out.print(Thread.currentThread().getName() + ": ");
-			cat
-					.info(Thread.currentThread().getName() + ": " + aTest
-							+ " Start");
+			cat.info(Thread.currentThread().getName() + ": " + aTest + " Start");
 		}
 
 		System.out.println("Start of " + aTest);
-		System.out
-				.println("****************************************************************\n");
+		System.out.println("****************************************************************\n");
 	}
 
 	// End NSHostTst.testStart(String)
@@ -687,11 +764,11 @@ public class NSHostTst extends TestCase {
 	 * Print the end of a test with the <code>Thread</code> name if the current
 	 * thread is a <code>TestThread</code>.
 	 *
-	 * @param aTest name for the test
+	 * @param aTest
+	 *           name for the test
 	 */
 	public static void printEnd(String aTest) {
-		System.out
-				.println("****************************************************************");
+		System.out.println("****************************************************************");
 
 		if (Thread.currentThread() instanceof TestThread) {
 			System.out.print(Thread.currentThread().getName() + ": ");
@@ -705,9 +782,9 @@ public class NSHostTst extends TestCase {
 	// End NSHostTst.testEnd(String)
 
 	/**
-	 * Utility method to borrow a session from the session pool.
-	 * All exceptions will result in the test failing.  This method
-	 * should only be used for positive session pool tests.
+	 * Utility method to borrow a session from the session pool. All exceptions
+	 * will result in the test failing. This method should only be used for
+	 * positive session pool tests.
 	 * 
 	 * @return Session from the session pool
 	 */
@@ -725,15 +802,16 @@ public class NSHostTst extends TestCase {
 	}
 
 	/**
-	 * Utility method to return a session to the session pool.  
-	 * This should be placed in a finally block.  All exceptions will
-	 * result in the test failing.
+	 * Utility method to return a session to the session pool. This should be
+	 * placed in a finally block. All exceptions will result in the test failing.
 	 * 
-	 * @param aSession Session to return to the pool
+	 * @param aSession
+	 *           Session to return to the pool
 	 */
 	private void returnSession(EPPSession aSession) {
 		try {
-			if (aSession != null) sessionPool.returnObject(aSession);
+			if (aSession != null)
+				sessionPool.returnObject(aSession);
 		}
 		catch (Exception ex) {
 			ex.printStackTrace();
@@ -742,33 +820,33 @@ public class NSHostTst extends TestCase {
 	}
 
 	/**
-	 * Utility method to invalidate a session in the session pool.  
-	 * This should be placed in an exception block.  
+	 * Utility method to invalidate a session in the session pool. This should be
+	 * placed in an exception block.
 	 * 
-	 * @param aSession Session to invalidate in the pool
+	 * @param aSession
+	 *           Session to invalidate in the pool
 	 */
 	private void invalidateSession(EPPSession aSession) {
 		try {
-			if (aSession != null) sessionPool.invalidateObject(aSession);
+			if (aSession != null)
+				sessionPool.invalidateObject(aSession);
 		}
 		catch (Exception ex) {
 			ex.printStackTrace();
 			Assert.fail("invalidateSession(): Exception invalidating session: " + ex);
 		}
 	}
-	
-	
 
 	/**
 	 * Handle a response by printing out the result details.
 	 * 
-	 * @param aResponse the response to handle
+	 * @param aResponse
+	 *           the response to handle
 	 */
 	private void handleResponse(EPPResponse aResponse) {
 
 		for (int i = 0; i < aResponse.getResults().size(); i++) {
-			EPPResult theResult = (EPPResult) aResponse.getResults().elementAt(
-					i);
+			EPPResult theResult = (EPPResult) aResponse.getResults().elementAt(i);
 
 			System.out.println("Result Code    : " + theResult.getCode());
 			System.out.println("Result Message : " + theResult.getMessage());
@@ -783,8 +861,7 @@ public class NSHostTst extends TestCase {
 
 			if (theResult.getAllValues() != null) {
 				for (int k = 0; k < theResult.getAllValues().size(); k++) {
-					System.out.println("Result Values  : "
-							+ theResult.getAllValues().elementAt(k));
+					System.out.println("Result Values  : " + theResult.getAllValues().elementAt(k));
 				}
 			}
 		}
@@ -798,9 +875,7 @@ public class NSHostTst extends TestCase {
 	public String makeDomainName() {
 		long tm = System.currentTimeMillis();
 
-		return new String(Thread.currentThread()
-						  + String.valueOf(tm + rd.nextInt(12)).substring(10)
-						  + ".com");
+		return new String(Thread.currentThread() + String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
 	}
 
 	/**
@@ -811,27 +886,24 @@ public class NSHostTst extends TestCase {
 	public String makeIP() {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10));
+		return new String(
+		      String.valueOf(tm + rd.nextInt(50)).substring(10) + "." + String.valueOf(tm + rd.nextInt(50)).substring(10)
+		            + "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
+		            + String.valueOf(tm + rd.nextInt(50)).substring(10));
 	}
 
 	/**
 	 * This method generates a unique internal Host Name for a given Domain Name
 	 *
-	 * @param newDomainName Domain name to based host name on
+	 * @param newDomainName
+	 *           Domain name to based host name on
 	 *
 	 * @return Unique host name
 	 */
 	public String makeInternalHost(String newDomainName) {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10)
-						  + "." + newDomainName);
+		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10) + "." + newDomainName);
 	}
 
 	/**
@@ -842,8 +914,7 @@ public class NSHostTst extends TestCase {
 	public String makeInternalHost() {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10)
-						  + "." + this.makeDomainName());
+		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10) + "." + this.makeDomainName());
 	}
 
 	/**
@@ -854,8 +925,7 @@ public class NSHostTst extends TestCase {
 	public String makeExternalHost() {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10)
-						  + ".sample.biz");
+		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10) + ".sample.biz");
 	}
 
 } // End class NSHostTst
