@@ -17,7 +17,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  ***********************************************************/
 package com.verisign.epp.codec.changepoll;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
@@ -27,22 +28,19 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
  * Transform operation executed on the object. The operation value should match
  * one of the <code>OPERATION</code> constants and the &quot;op&quot; attribute
- * can be set via the <code>{@link #setOp(String)} method
- * to handle specific cases.
+ * can be set via the {@link #setOp(String)} method to handle specific cases.
  */
 public class EPPChangeOperation implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPChangeOperation.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPChangeOperation.class);
 
 	/**
 	 * Create operation as defined in <code>RFC 5730</code>.
@@ -102,8 +100,7 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	/**
 	 * Constant for the phase qualified name (prefix and local name)
 	 */
-	public static final String ELM_NAME = EPPChangePollExtFactory.NS_PREFIX
-			+ ":" + ELM_LOCALNAME;
+	public static final String ELM_NAME = EPPChangePollExtFactory.NS_PREFIX + ":" + ELM_LOCALNAME;
 
 	/**
 	 * Name of XML attribute for the &quot;op&quot; attribute.
@@ -132,8 +129,8 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	 * value.
 	 * 
 	 * @param aValue
-	 *            Operation value using one of the <code>OPERATION</code>
-	 *            constants.
+	 *           Operation value using one of the <code>OPERATION</code>
+	 *           constants.
 	 */
 	public EPPChangeOperation(String aValue) {
 		this.value = aValue;
@@ -142,15 +139,15 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	/**
 	 * Create <code>EPPChangeOperation</code> instance with a defined operation
 	 * value and the optional &quot;op&quot; attribute that defines either the
-	 * sub-operation or the name of the operation when the operation value is
-	 * set to <code>OPERATION_CUSTOM</code>.
+	 * sub-operation or the name of the operation when the operation value is set
+	 * to <code>OPERATION_CUSTOM</code>.
 	 * 
 	 * @param aValue
-	 *            Operation value using one of the <code>OPERATION</code>
-	 *            constants.
+	 *           Operation value using one of the <code>OPERATION</code>
+	 *           constants.
 	 * @param aOp
-	 *            Sub-operation or name of operation when <code>aValue</code> is
-	 *            set to <code>OPERATION_CUSTOM</code>.
+	 *           Sub-operation or name of operation when <code>aValue</code> is
+	 *           set to <code>OPERATION_CUSTOM</code>.
 	 */
 	public EPPChangeOperation(String aValue, String aOp) {
 		this.value = aValue;
@@ -181,8 +178,8 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	 * Sets the operation value.
 	 * 
 	 * @param aValue
-	 *            Operation value, which should be one of the
-	 *            <code>OPERATION</code> constants.
+	 *           Operation value, which should be one of the
+	 *           <code>OPERATION</code> constants.
 	 */
 	public void setValue(String aValue) {
 		this.value = aValue;
@@ -214,9 +211,9 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	 * Sets the OPTIONAL &quot;op&quot; attribute value.
 	 * 
 	 * @param aOp
-	 *            &quot;op&quot; attribute value that defines the sub-operation
-	 *            or name of the operation when the operation value is set to
-	 *            <code>OPERATION_CUSTOM</code>.
+	 *           &quot;op&quot; attribute value that defines the sub-operation or
+	 *           name of the operation when the operation value is set to
+	 *           <code>OPERATION_CUSTOM</code>.
 	 */
 	public void setOp(String aOp) {
 		this.op = aOp;
@@ -228,7 +225,7 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	 * @return clone of <code>EPPChangeOperation</code>
 	 *
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPChangeOperation clone = null;
@@ -243,11 +240,11 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	 * tree.
 	 *
 	 * @param aElement
-	 *            - Root DOM Element to decode <code>EPPChangeOperation</code>
-	 *            from.
+	 *           - Root DOM Element to decode <code>EPPChangeOperation</code>
+	 *           from.
 	 *
 	 * @exception EPPDecodeException
-	 *                Unable to decode aElement
+	 *               Unable to decode aElement
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 		// Op
@@ -272,29 +269,24 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	 * <code>EPPChangeOperation</code> instance.
 	 *
 	 * @param aDocument
-	 *            - DOM Document that is being built. Used as an Element
-	 *            factory.
+	 *           - DOM Document that is being built. Used as an Element factory.
 	 *
 	 * @return Element - Root DOM Element representing the
 	 *         <code>EPPChangeOperation</code> instance.
 	 *
 	 * @exception EPPEncodeException
-	 *                - Unable to encode <code>EPPChangeOperation</code>
-	 *                instance.
+	 *               - Unable to encode <code>EPPChangeOperation</code> instance.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " on in EPPChangeOperation.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " on in EPPChangeOperation.encode(Document)");
 		}
 		if (this.value == null) {
-			throw new EPPEncodeException("value is null"
-					+ " on in EPPChangeOperation.encode(Document)");
+			throw new EPPEncodeException("value is null" + " on in EPPChangeOperation.encode(Document)");
 		}
 
-		Element root = aDocument.createElementNS(EPPChangePollExtFactory.NS,
-				ELM_NAME);
+		Element root = aDocument.createElementNS(EPPChangePollExtFactory.NS, ELM_NAME);
 
 		// Op
 		if (this.op != null) {
@@ -312,7 +304,7 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	 * Implements a deep <code>EPPChangeOperation</code> compare.
 	 *
 	 * @param aObject
-	 *            <code>EPPChangeOperation</code> instance to compare with
+	 *           <code>EPPChangeOperation</code> instance to compare with
 	 *
 	 * @return <code>true</code> if equal; <code>false</code> otherwise
 	 */
@@ -343,17 +335,18 @@ public class EPPChangeOperation implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
 	 */
 	@Override
 	public String getNamespace() {
