@@ -13,7 +13,8 @@
 
 package com.verisign.epp.codec.coaext;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -22,7 +23,7 @@ import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * EPPCodecComponent that encodes and decodes a COA Attr Tag.
@@ -32,9 +33,9 @@ import com.verisign.epp.util.EPPCatFactory;
  * <p>
  * Description: Each EPPCoaExtAttr object represents a single Client Object Attribute. As
  * such it contains a single key-value pair, represented by one EPPCoaExtKey and
- * one EPPCoaExtValue element. <br/>
- * As XML, is is represented by a <coa:attr> element
- * containing a single <coa:key> element and a single <coa:value> element.
+ * one EPPCoaExtValue element. <br>
+ * As XML, is is represented by a &lt;coa:attr&gt; element
+ * containing a single &lt;coa:key&gt; element and a single &lt;coa:value&gt; element.
  * </p>
  * <p>
  * Copyright: Copyright (c) 2011
@@ -54,12 +55,9 @@ public class EPPCoaExtAttr implements EPPCodecComponent {
 	private static final long serialVersionUID = 1L;
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat =
-			Logger.getLogger( EPPCoaExtAttr.class.getName(), EPPCatFactory
-					.getInstance()
-					.getFactory() );
+	private static Logger cat = LoggerFactory.getLogger(EPPCoaExtAttr.class);
 
 	/**
 	 * Constant for the key tag
@@ -87,8 +85,8 @@ public class EPPCoaExtAttr implements EPPCodecComponent {
 	/**
 	 * Convenience constructor specifying the key and value as arguments.
 	 * 
-	 * @param aKey
-	 * @param aValue
+	 * @param aKey Key of COA
+	 * @param aValue Value of COA
 	 */
 	public EPPCoaExtAttr ( String aKey, String aValue ) {
 		this.key = new EPPCoaExtKey( aKey );
@@ -151,7 +149,7 @@ public class EPPCoaExtAttr implements EPPCodecComponent {
 
 
 	/**
-	 * Decode the EPPCoaExtAttr element by decoding its <coa:key> and <coa:value>
+	 * Decode the EPPCoaExtAttr element by decoding its &lt;coa:key&gt; and &lt;coa:value&gt;
 	 * subelements.
 	 * 
 	 * @see com.verisign.epp.codec.gen.EPPCodecComponent#decode(org.w3c.dom.Element)
@@ -203,10 +201,10 @@ public class EPPCoaExtAttr implements EPPCodecComponent {
 
 
 	/**
-	 * Validate the state of the <code>EPPCoaExtAttr</code> instance. A valid
+	 * Validate the state of the {@code EPPCoaExtAttr} instance. A valid
 	 * state means that all of the required attributes have been set. If
 	 * validateState returns without an exception, the state is valid. If the
-	 * state is not valid, the <code>EPPCodecException</code> will contain a
+	 * state is not valid, the {@code EPPCodecException} will contain a
 	 * description of the error. throws EPPCodecException State error. This will
 	 * contain the name of the attribute that is not valid.
 	 * 
@@ -228,8 +226,8 @@ public class EPPCoaExtAttr implements EPPCodecComponent {
 
 
 	/**
-	 * Get method for the EPPCoaExtKey attribute.
-	 * @return EPPCoaExtKey
+	 * Gets the key of the COA.
+	 * @return Key of the COA
 	 */
 	public EPPCoaExtKey getKey () {
 		return key;
@@ -237,8 +235,9 @@ public class EPPCoaExtAttr implements EPPCodecComponent {
 
 
 	/**
-	 * Set method for the EPPCoaExtKey attribute.
-	 * @param aKey
+	 * Sets the key of the COA.
+	 * 
+	 * @param aKey Key of the COA
 	 */
 	public void setKey ( EPPCoaExtKey aKey ) {
 		this.key = aKey;
@@ -246,26 +245,28 @@ public class EPPCoaExtAttr implements EPPCodecComponent {
 
 
 	/**
-	 * Get method for the EPPCoaExtValue attribute.
-	 * @return EPPCoaExtValue
+	 * Gets the value of the COA.
+	 * 
+	 * @return Value of the COA 
 	 */
 	public EPPCoaExtValue getValue () {
-		return value;
+		return this.value;
 	}
 
 
 	/**
-	 * Set method for the EPPCoaExtValue attribute.
-	 * @param aValue
+	 * Sets the value of the COA.
+	 * 
+	 * @param aValue Value of the COA
 	 */
 	public void setValue ( EPPCoaExtValue aValue ) {
 		this.value = aValue;
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the {@code EPPCodecComponent}.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the {@code EPPCodecComponent}. 
 	 */
 	@Override
 	public String getNamespace() {
