@@ -21,7 +21,8 @@ package com.verisign.epp.codec.contact;
 
 import java.util.Vector;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
@@ -31,59 +32,50 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
-
 
 /**
  * Represents attributes to add, remove or change with a
- * <code>EPPContactUpdateCmd</code>. In <code>EPPContactUpdateCmd</code>,  an
- * instance of <code>EPPContactAddRemove</code> is used  to specify the
- * attributes to add, an instance of <code>EPPContactAddRemove</code> is used
- * to specify the attributes to remove and an instance of
- * <code>EPPContactAddRemove</code> is used  o specify the attributes to
- * change. <br>
+ * <code>EPPContactUpdateCmd</code>. In <code>EPPContactUpdateCmd</code>, an
+ * instance of <code>EPPContactAddRemove</code> is used to specify the
+ * attributes to add, an instance of <code>EPPContactAddRemove</code> is used to
+ * specify the attributes to remove and an instance of
+ * <code>EPPContactAddRemove</code> is used o specify the attributes to change.
+ * <br>
  * <br>
  * <br>
  * The &lt;contact:add&gt; and &lt;contact:rem&gt; elements SHALL contain the
  * following child elements: <br>
  * 
  * <ul>
- * <li>
- * One or more &lt;contact:status&gt; elements that contain status values to be
- * associated with or removed from the object.  When specifying a value to be
+ * <li>One or more &lt;contact:status&gt; elements that contain status values to
+ * be associated with or removed from the object. When specifying a value to be
  * removed, only the attribute value is significant; element text is not
- * required to match a value for removal.
- * </li>
+ * required to match a value for removal.</li>
  * </ul>
  * 
- * <br><br>
+ * <br>
+ * <br>
  * A &lt;contact:chg&gt; element SHALL contain the following OPTIONAL child
- * elements: <br><br>
+ * elements: <br>
+ * <br>
  * 
  * <ul>
- * <li>
- * A &lt;contact:postalInfo&gt; element that contains the postal contacts.  Use
- * <code>getPostalInfo</code>, <code>addPostalInfo</code> and
- * <code>setPostalInfo</code> to get, add and set the elements.
- * </li>
- * <li>
- * An &lt;contact:voice&gt; element that contains the contact's voice telephone
- * number. Use <code>getVoice</code> and <code>setVoice</code> to get and set
- * the elements.
- * </li>
- * <li>
- * An &lt;contact:fax&gt; element that contains the contact's facsimile
- * telephone number. Use <code>getFax</code> and <code>setFax</code> to get
- * and set the elements.
- * </li>
- * <li>
- * A &lt;contact:email&gt; element that contains the contact's e-mail address.
- * Use <code>getEmail</code> and <code>setEmail</code> to get and set the
- * elements.
- * </li>
+ * <li>A &lt;contact:postalInfo&gt; element that contains the postal contacts.
+ * Use <code>getPostalInfo</code>, <code>addPostalInfo</code> and
+ * <code>setPostalInfo</code> to get, add and set the elements.</li>
+ * <li>An &lt;contact:voice&gt; element that contains the contact's voice
+ * telephone number. Use <code>getVoice</code> and <code>setVoice</code> to get
+ * and set the elements.</li>
+ * <li>An &lt;contact:fax&gt; element that contains the contact's facsimile
+ * telephone number. Use <code>getFax</code> and <code>setFax</code> to get and
+ * set the elements.</li>
+ * <li>A &lt;contact:email&gt; element that contains the contact's e-mail
+ * address. Use <code>getEmail</code> and <code>setEmail</code> to get and set
+ * the elements.</li>
  * </ul>
  * 
- * <br><br>
+ * <br>
+ * <br>
  *
  * @author $Author: jim $
  * @version $Revision: 1.2 $
@@ -94,9 +86,9 @@ import com.verisign.epp.util.EPPCatFactory;
 public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_ADD</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_ADD</code>. This is a package constant, so
+	 * the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	/** mode of <code>EPPContactAddRemove</code> is not specified. */
 	final static short MODE_NONE = 0;
@@ -109,25 +101,25 @@ public class EPPContactAddChange implements EPPCodecComponent {
 
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_ADD</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_ADD</code>. This is a package constant, so
+	 * the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	final static String ELM_ADD = "contact:add";
 
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_REMOVE</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_REMOVE</code>. This is a package constant,
+	 * so the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	final static String ELM_REMOVE = "contact:rem";
 
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_REMOVE</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_REMOVE</code>. This is a package constant,
+	 * so the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	final static String ELM_CHANGE = "contact:chg";
 
@@ -136,17 +128,17 @@ public class EPPContactAddChange implements EPPCodecComponent {
 
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_REMOVE</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_REMOVE</code>. This is a package constant,
+	 * so the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	private final static String ELM_CONTACT_POSTAL_INFO = "contact:postalInfo";
 
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_REMOVE</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_REMOVE</code>. This is a package constant,
+	 * so the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	private final static String ELM_CONTACT_AUTHINFO = "contact:authInfo";
 
@@ -155,40 +147,36 @@ public class EPPContactAddChange implements EPPCodecComponent {
 
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_REMOVE</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_REMOVE</code>. This is a package constant,
+	 * so the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	private final static String ELM_CONTACT_EMAIL = "contact:email";
 
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_REMOVE</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_REMOVE</code>. This is a package constant,
+	 * so the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	private final static String ELM_CONTACT_FAX = "contact:fax";
 
 	/**
 	 * XML tag name when the <code>mode</code> attribute is
-	 * <code>EPPContactAddRemove.MODE_REMOVE</code>.  This     is a package
-	 * constant, so the container <code>EPPCodecComponent</code> can use it on
-	 * a decode operation.
+	 * <code>EPPContactAddRemove.MODE_REMOVE</code>. This is a package constant,
+	 * so the container <code>EPPCodecComponent</code> can use it on a decode
+	 * operation.
 	 */
 	private final static String ELM_CONTACT_VOICE = "contact:voice";
 
 	/**
-	 * XML Attribute Name for a phone extension, which applies to  fax and
-	 * voice numbers.
+	 * XML Attribute Name for a phone extension, which applies to fax and voice
+	 * numbers.
 	 */
 	private final static String ATTR_EXT = "x";
-	
-	/** Log4j category for logging */
-	private static Logger cat =
-		Logger.getLogger(
-						 EPPContactAddChange.class.getName(),
-						 EPPCatFactory.getInstance().getFactory());
 
+	/** Category for logging */
+	private static Logger cat = LoggerFactory.getLogger(EPPContactAddChange.class);
 
 	/** postal contacts */
 	private java.util.Vector postalContacts = new Vector();
@@ -218,9 +206,9 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	private String voiceExt = null;
 
 	/**
-	 * Mode of EPPContactAddRemove.  Must be <code>MODE_ADD</code> or
-	 * <code>MODE_REMOVE</code> to be valid.  This     attribute will be set
-	 * by the parent container <code>EPPCodecComponent</code>.  For example,
+	 * Mode of EPPContactAddRemove. Must be <code>MODE_ADD</code> or
+	 * <code>MODE_REMOVE</code> to be valid. This attribute will be set by the
+	 * parent container <code>EPPCodecComponent</code>. For example,
 	 * <code>EPPContactUpdateCmd</code> will set the mode for its
 	 * <code>EPPContactAddRemove</code> instances.
 	 */
@@ -237,7 +225,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Constructor for <code>EPPContactAddChange</code>.
 	 *
-	 * @param newStatuses Vector of statuses for contact add.
+	 * @param newStatuses
+	 *           Vector of statuses for contact add.
 	 */
 	public EPPContactAddChange(Vector newStatuses) {
 		statuses = newStatuses;
@@ -248,17 +237,18 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Constructor for <code>EPPContactAddChange</code>.
 	 *
-	 * @param aPostalInfo EPPContactPostalDefinition, defining a series objects
-	 * 		  for contact changes.
-	 * @param aVoice Voice number
-	 * @param aAuthInfo Authorization information for contact change.
+	 * @param aPostalInfo
+	 *           EPPContactPostalDefinition, defining a series objects for
+	 *           contact changes.
+	 * @param aVoice
+	 *           Voice number
+	 * @param aAuthInfo
+	 *           Authorization information for contact change.
 	 */
-	public EPPContactAddChange(
-							   EPPContactPostalDefinition aPostalInfo,
-							   String aVoice, EPPAuthInfo aAuthInfo) {
-		voice     = aVoice;
-		fax		  = null;
-		email     = null;
+	public EPPContactAddChange(EPPContactPostalDefinition aPostalInfo, String aVoice, EPPAuthInfo aAuthInfo) {
+		voice = aVoice;
+		fax = null;
+		email = null;
 
 		addPostalInfo(aPostalInfo);
 		setAuthInfo(aAuthInfo);
@@ -269,43 +259,49 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Constructor for <code>EPPContactAddChange</code>.
 	 *
-	 * @param aPostalInfo EPPContactPostalDefinition, defining a series objects
-	 * 		  for contact changes.
-	 * @param aVoice Voice number
-	 * @param aFax Fax number
-	 * @param aEmail Email
-	 * @param aAuthInfo Authorization information for contact change.
+	 * @param aPostalInfo
+	 *           EPPContactPostalDefinition, defining a series objects for
+	 *           contact changes.
+	 * @param aVoice
+	 *           Voice number
+	 * @param aFax
+	 *           Fax number
+	 * @param aEmail
+	 *           Email
+	 * @param aAuthInfo
+	 *           Authorization information for contact change.
 	 */
-	public EPPContactAddChange(
-							   EPPContactPostalDefinition aPostalInfo,
-							   String aVoice, String aFax, String aEmail,
-							   EPPAuthInfo aAuthInfo) {
-		voice     = aVoice;
-		fax		  = aFax;
-		email     = aEmail;
+	public EPPContactAddChange(EPPContactPostalDefinition aPostalInfo, String aVoice, String aFax, String aEmail,
+	      EPPAuthInfo aAuthInfo) {
+		voice = aVoice;
+		fax = aFax;
+		email = aEmail;
 
 		addPostalInfo(aPostalInfo);
 		setAuthInfo(aAuthInfo);
 	}
 
-	// End EPPContactAddChange(EPPContactPostalDefinition, String, String, String, EPPAuthInfo)
+	// End EPPContactAddChange(EPPContactPostalDefinition, String, String,
+	// String, EPPAuthInfo)
 
 	/**
 	 * Constructor for <code>EPPContactAddChange</code>.
 	 *
-	 * @param aPostalInfo Vector, defining a series objects for contact
-	 * 		  changes.
-	 * @param aVoice Voice number
-	 * @param aFax Fax number
-	 * @param aEmail Email
-	 * @param aAuthInfo Authorization information for contact change.
+	 * @param aPostalInfo
+	 *           Vector, defining a series objects for contact changes.
+	 * @param aVoice
+	 *           Voice number
+	 * @param aFax
+	 *           Fax number
+	 * @param aEmail
+	 *           Email
+	 * @param aAuthInfo
+	 *           Authorization information for contact change.
 	 */
-	public EPPContactAddChange(
-							   Vector aPostalInfo, String aVoice, String aFax,
-							   String aEmail, EPPAuthInfo aAuthInfo) {
-		voice     = aVoice;
-		fax		  = aFax;
-		email     = aEmail;
+	public EPPContactAddChange(Vector aPostalInfo, String aVoice, String aFax, String aEmail, EPPAuthInfo aAuthInfo) {
+		voice = aVoice;
+		fax = aFax;
+		email = aEmail;
 
 		setPostalInfo(aPostalInfo);
 		setAuthInfo(aAuthInfo);
@@ -317,18 +313,18 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	 * Encode a DOM Element tree from the attributes of the
 	 * <code>EPPContactAddChange</code> instance.
 	 *
-	 * @param aDocument DOM Document that is being built.  Used as an Element
-	 * 		  factory.
+	 * @param aDocument
+	 *           DOM Document that is being built. Used as an Element factory.
 	 *
-	 * @return Root DOM Element representing the
-	 * 		   <code>EPPContactAddChange</code> instance.
+	 * @return Root DOM Element representing the <code>EPPContactAddChange</code>
+	 *         instance.
 	 *
-	 * @exception EPPEncodeException Unable to encode
-	 * 			  <code>EPPContactAddChange</code> instance.
+	 * @exception EPPEncodeException
+	 *               Unable to encode <code>EPPContactAddChange</code> instance.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 		Element currElm = null;
-		Text    currVal = null;
+		Text currVal = null;
 
 		Element root;
 
@@ -337,16 +333,13 @@ public class EPPContactAddChange implements EPPCodecComponent {
 			root = aDocument.createElementNS(EPPContactMapFactory.NS, ELM_ADD);
 		}
 		else if (mode == MODE_REMOVE) {
-			root =
-				aDocument.createElementNS(EPPContactMapFactory.NS, ELM_REMOVE);
+			root = aDocument.createElementNS(EPPContactMapFactory.NS, ELM_REMOVE);
 		}
 		else if (mode == MODE_CHANGE) {
-			root =
-				aDocument.createElementNS(EPPContactMapFactory.NS, ELM_CHANGE);
+			root = aDocument.createElementNS(EPPContactMapFactory.NS, ELM_CHANGE);
 		}
 		else {
-			throw new EPPEncodeException("Invalid EPPContactAddRemove mode of "
-										 + mode);
+			throw new EPPEncodeException("Invalid EPPContactAddRemove mode of " + mode);
 		}
 
 		if (mode == MODE_CHANGE) {
@@ -355,10 +348,7 @@ public class EPPContactAddChange implements EPPCodecComponent {
 
 			// voice
 			if (voice != null) {
-				currElm =
-					aDocument.createElementNS(
-											  EPPContactMapFactory.NS,
-											  ELM_CONTACT_VOICE);
+				currElm = aDocument.createElementNS(EPPContactMapFactory.NS, ELM_CONTACT_VOICE);
 				currVal = aDocument.createTextNode(voice);
 
 				// voiceExt
@@ -372,10 +362,7 @@ public class EPPContactAddChange implements EPPCodecComponent {
 
 			// fax
 			if (fax != null) {
-				currElm =
-					aDocument.createElementNS(
-											  EPPContactMapFactory.NS,
-											  ELM_CONTACT_FAX);
+				currElm = aDocument.createElementNS(EPPContactMapFactory.NS, ELM_CONTACT_FAX);
 				currVal = aDocument.createTextNode(fax);
 
 				// faxExt
@@ -389,9 +376,7 @@ public class EPPContactAddChange implements EPPCodecComponent {
 
 			// email
 			if (email != null) {
-				EPPUtil.encodeString(
-									 aDocument, root, email,
-									 EPPContactMapFactory.NS, ELM_CONTACT_EMAIL);
+				EPPUtil.encodeString(aDocument, root, email, EPPContactMapFactory.NS, ELM_CONTACT_EMAIL);
 			}
 
 			// authInfo
@@ -420,10 +405,12 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	 * Decode the <code>EPPContactAddChange</code> attributes from the
 	 * <code>aElement</code> DOM Element tree.
 	 *
-	 * @param aElement Root DOM Element to decode
-	 * 		  <code>EPPContactAddChange</code> from.
+	 * @param aElement
+	 *           Root DOM Element to decode <code>EPPContactAddChange</code>
+	 *           from.
 	 *
-	 * @exception EPPDecodeException Unable to decode <code>aElement</code>.
+	 * @exception EPPDecodeException
+	 *               Unable to decode <code>aElement</code>.
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 		Element currElm = null;
@@ -438,28 +425,20 @@ public class EPPContactAddChange implements EPPCodecComponent {
 			mode = MODE_CHANGE;
 		}
 		else {
-			throw new EPPDecodeException("Invalid EPPContactAddRemove mode of "
-										 + aElement.getLocalName());
+			throw new EPPDecodeException("Invalid EPPContactAddRemove mode of " + aElement.getLocalName());
 		}
 
 		if (mode == MODE_CHANGE) {
 			// postalInfo
-			postalContacts =
-				EPPUtil.decodeCompVector(
-										 aElement, EPPContactMapFactory.NS,
-										 ELM_CONTACT_POSTAL_INFO,
-										 EPPContactPostalDefinition.class);
+			postalContacts = EPPUtil.decodeCompVector(aElement, EPPContactMapFactory.NS, ELM_CONTACT_POSTAL_INFO,
+			      EPPContactPostalDefinition.class);
 
 			// voice
-			voice =
-				EPPUtil.decodeString(
-									 aElement, EPPContactMapFactory.NS,
-									 ELM_CONTACT_VOICE);
+			voice = EPPUtil.decodeString(aElement, EPPContactMapFactory.NS, ELM_CONTACT_VOICE);
 
 			// voiceExt
 			if (voice != null) {
-				currElm =
-					EPPUtil.getElementByTagNameNS(aElement, EPPContactMapFactory.NS, ELM_CONTACT_VOICE);
+				currElm = EPPUtil.getElementByTagNameNS(aElement, EPPContactMapFactory.NS, ELM_CONTACT_VOICE);
 				voiceExt = currElm.getAttribute(ATTR_EXT);
 
 				if (voiceExt.length() == 0) {
@@ -471,14 +450,11 @@ public class EPPContactAddChange implements EPPCodecComponent {
 			}
 
 			// fax
-			fax = EPPUtil.decodeString(
-									   aElement, EPPContactMapFactory.NS,
-									   ELM_CONTACT_FAX);
+			fax = EPPUtil.decodeString(aElement, EPPContactMapFactory.NS, ELM_CONTACT_FAX);
 
 			// faxExt
 			if (fax != null) {
-				currElm =
-					EPPUtil.getElementByTagNameNS(aElement, EPPContactMapFactory.NS, ELM_CONTACT_FAX);
+				currElm = EPPUtil.getElementByTagNameNS(aElement, EPPContactMapFactory.NS, ELM_CONTACT_FAX);
 				faxExt = currElm.getAttribute(ATTR_EXT);
 
 				if (faxExt.length() == 0) {
@@ -490,34 +466,20 @@ public class EPPContactAddChange implements EPPCodecComponent {
 			}
 
 			// email
-			email =
-				EPPUtil.decodeString(
-									 aElement, EPPContactMapFactory.NS,
-									 ELM_CONTACT_EMAIL);
+			email = EPPUtil.decodeString(aElement, EPPContactMapFactory.NS, ELM_CONTACT_EMAIL);
 
 			// authInfo
-			authInfo =
-				(EPPAuthInfo) EPPUtil.decodeComp(
-												 aElement,
-												 EPPContactMapFactory.NS,
-												 ELM_CONTACT_AUTHINFO,
-												 EPPAuthInfo.class);
+			authInfo = (EPPAuthInfo) EPPUtil.decodeComp(aElement, EPPContactMapFactory.NS, ELM_CONTACT_AUTHINFO,
+			      EPPAuthInfo.class);
 
 			// disclose
-			disclose =
-				(EPPContactDisclose) EPPUtil.decodeComp(
-														aElement,
-														EPPContactMapFactory.NS,
-														ELM_CONTACT_DISCLOSE,
-														EPPContactDisclose.class);
+			disclose = (EPPContactDisclose) EPPUtil.decodeComp(aElement, EPPContactMapFactory.NS, ELM_CONTACT_DISCLOSE,
+			      EPPContactDisclose.class);
 		}
 		else {
 			// statuses
-			statuses =
-				EPPUtil.decodeCompVector(
-										 aElement, EPPContactMapFactory.NS,
-										 EPPContactStatus.ELM_NAME,
-										 EPPContactStatus.class);
+			statuses = EPPUtil.decodeCompVector(aElement, EPPContactMapFactory.NS, EPPContactStatus.ELM_NAME,
+			      EPPContactStatus.class);
 		}
 	}
 
@@ -526,13 +488,14 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * implements a deep <code>EPPContactAddChange</code> compare.
 	 *
-	 * @param aObject <code>EPPContactAddChange</code> instance to compare with
+	 * @param aObject
+	 *           <code>EPPContactAddChange</code> instance to compare with
 	 *
 	 * @return DOCUMENT ME!
 	 */
 	public boolean equals(Object aObject) {
 		cat.debug("equals(Object): enter");
-		
+
 		if (!(aObject instanceof EPPContactAddChange)) {
 			cat.error("equals(Object): aObject not EPPContactAddChange");
 			return false;
@@ -559,21 +522,13 @@ public class EPPContactAddChange implements EPPCodecComponent {
 		}
 
 		// voice
-		if (
-			!(
-					(voice == null) ? (theComp.voice == null)
-										: voice.equals(theComp.voice)
-				)) {
+		if (!((voice == null) ? (theComp.voice == null) : voice.equals(theComp.voice))) {
 			cat.error("equals(Object): voice not equal");
 			return false;
 		}
 
 		// voiceExt
-		if (
-			!(
-					(voiceExt == null) ? (theComp.voiceExt == null)
-										   : voiceExt.equals(theComp.voiceExt)
-				)) {
+		if (!((voiceExt == null) ? (theComp.voiceExt == null) : voiceExt.equals(theComp.voiceExt))) {
 			cat.error("equals(Object): voiceExt not equal");
 			return false;
 		}
@@ -585,41 +540,25 @@ public class EPPContactAddChange implements EPPCodecComponent {
 		}
 
 		// faxExt
-		if (
-			!(
-					(faxExt == null) ? (theComp.faxExt == null)
-										 : faxExt.equals(theComp.faxExt)
-				)) {
+		if (!((faxExt == null) ? (theComp.faxExt == null) : faxExt.equals(theComp.faxExt))) {
 			cat.error("equals(Object): faxExt not equal");
 			return false;
 		}
 
 		// email
-		if (
-			!(
-					(email == null) ? (theComp.email == null)
-										: email.equals(theComp.email)
-				)) {
+		if (!((email == null) ? (theComp.email == null) : email.equals(theComp.email))) {
 			cat.error("equals(Object): email not equal");
 			return false;
 		}
 
 		// authInfo
-		if (
-			!(
-					(authInfo == null) ? (theComp.authInfo == null)
-										   : authInfo.equals(theComp.authInfo)
-				)) {
+		if (!((authInfo == null) ? (theComp.authInfo == null) : authInfo.equals(theComp.authInfo))) {
 			cat.error("equals(Object): authInfo not equal");
 			return false;
 		}
 
 		// disclose
-		if (
-			!(
-					(disclose == null) ? (theComp.disclose == null)
-										   : disclose.equals(theComp.disclose)
-				)) {
+		if (!((disclose == null) ? (theComp.disclose == null) : disclose.equals(theComp.disclose))) {
 			cat.error("equals(Object): disclose not equal");
 			return false;
 		}
@@ -634,7 +573,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	 *
 	 * @return clone of <code>EPPContactAddChange</code>
 	 *
-	 * @exception CloneNotSupportedException standard Object.clone exception
+	 * @exception CloneNotSupportedException
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPContactAddChange clone = null;
@@ -645,18 +585,14 @@ public class EPPContactAddChange implements EPPCodecComponent {
 			clone.statuses = (Vector) statuses.clone();
 
 			for (int i = 0; i < statuses.size(); i++)
-				clone.statuses.setElementAt(
-											((EPPContactStatus) statuses
-											 .elementAt(i)).clone(), i);
+				clone.statuses.setElementAt(((EPPContactStatus) statuses.elementAt(i)).clone(), i);
 		}
 
 		if (postalContacts != null) {
 			clone.postalContacts = (Vector) postalContacts.clone();
 
 			for (int i = 0; i < postalContacts.size(); i++)
-				clone.postalContacts.setElementAt(
-												  ((EPPContactPostalDefinition) postalContacts
-												   .elementAt(i)).clone(), i);
+				clone.postalContacts.setElementAt(((EPPContactPostalDefinition) postalContacts.elementAt(i)).clone(), i);
 		}
 
 		if (authInfo != null) {
@@ -677,8 +613,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 * 		   <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
@@ -687,9 +623,9 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	// End EPPContactAddChange.toString()
 
 	/**
-	 * Gets the mode of <code>EPPContactAddChange</code>.  There are two valid
+	 * Gets the mode of <code>EPPContactAddChange</code>. There are two valid
 	 * modes <code>EPPContactAddChange.MODE_ADD</code> and
-	 * <code>EPPContactAddChange.MODE_REMOVE</code>.     If no mode has been
+	 * <code>EPPContactAddChange.MODE_REMOVE</code>. If no mode has been
 	 * satisfied, than the mode is set to
 	 * <code>EPPContactAddChange.MODE_NONE</code>.
 	 *
@@ -702,14 +638,15 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	// End EPPContactAddChange.getMode()
 
 	/**
-	 * Sets the mode of <code>EPPContactAddChange</code>.  There are two valid
+	 * Sets the mode of <code>EPPContactAddChange</code>. There are two valid
 	 * modes <code>EPPContactAddChange.MODE_ADD</code> and
-	 * <code>EPPContactAddChange.MODE_REMOVE</code>.     If no mode has been
+	 * <code>EPPContactAddChange.MODE_REMOVE</code>. If no mode has been
 	 * satisfied, than the mode is set to
 	 * <code>EPPContactAddChange.MODE_NONE</code>
 	 *
-	 * @param aMode <code>EPPContactAddChange.MODE_ADD</code> or
-	 * 		  <code>EPPContactAddChange.MODE_REMOVE</code>.
+	 * @param aMode
+	 *           <code>EPPContactAddChange.MODE_ADD</code> or
+	 *           <code>EPPContactAddChange.MODE_REMOVE</code>.
 	 */
 	void setMode(short aMode) {
 		mode = aMode;
@@ -731,14 +668,15 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set contact postalInfo.
 	 *
-	 * @param newPostalContacts java.util.Vector
+	 * @param newPostalContacts
+	 *           java.util.Vector
 	 */
 	public void setPostalInfo(java.util.Vector newPostalContacts) {
-		
-		for( int i=0; i<newPostalContacts.size(); i++){
-			if( newPostalContacts.elementAt(i) != null )
-				addPostalInfo((EPPContactPostalDefinition)newPostalContacts.elementAt(i));
-		}		
+
+		for (int i = 0; i < newPostalContacts.size(); i++) {
+			if (newPostalContacts.elementAt(i) != null)
+				addPostalInfo((EPPContactPostalDefinition) newPostalContacts.elementAt(i));
+		}
 	}
 
 	// End EPPContactAddChange.setPostalInfo(Vector)
@@ -747,7 +685,7 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	 * Adds contact postalInfo.
 	 *
 	 * @param newPostalInfo
-	 * 		  com.verisign.epp.codec.contact.EPPContactPostalDefinition
+	 *           com.verisign.epp.codec.contact.EPPContactPostalDefinition
 	 */
 	public void addPostalInfo(EPPContactPostalDefinition newPostalInfo) {
 		// clone necessary here
@@ -755,23 +693,22 @@ public class EPPContactAddChange implements EPPCodecComponent {
 
 		if (newPostalInfo != null) {
 			try {
-				aPostalInfo =
-					(EPPContactPostalDefinition) newPostalInfo.clone();
+				aPostalInfo = (EPPContactPostalDefinition) newPostalInfo.clone();
 			}
-			 catch (CloneNotSupportedException e) {
+			catch (CloneNotSupportedException e) {
 				// Nothing needs to be done here
 			}
 
-			//postalInfo = aPostalInfo;
-			//postalInfo.setRootName(EPPContactPostalDefinition.ELM_NAME_POSTAL_INFO);
+			// postalInfo = aPostalInfo;
+			// postalInfo.setRootName(EPPContactPostalDefinition.ELM_NAME_POSTAL_INFO);
 			newPostalInfo.setValidatedFlag(false);
 			postalContacts.add(newPostalInfo);
 
-			//postalInfo.setValidatedFlag(false);
+			// postalInfo.setValidatedFlag(false);
 		}
 	}
 
-	// End EPPContactAddChange.addPostalInfo(EPPContactPostalDefinition)	
+	// End EPPContactAddChange.addPostalInfo(EPPContactPostalDefinition)
 
 	/**
 	 * Get autorization information for contact change.
@@ -798,7 +735,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set disclose information.
 	 *
-	 * @param newDisclose com.verisign.epp.codec.gen.EPPContactDisclose
+	 * @param newDisclose
+	 *           com.verisign.epp.codec.gen.EPPContactDisclose
 	 */
 	public void setDisclose(com.verisign.epp.codec.contact.EPPContactDisclose newDisclose) {
 		if (newDisclose != null) {
@@ -812,7 +750,7 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Get email.
 	 *
-	 * @return String  email
+	 * @return String email
 	 */
 	public String getEmail() {
 		return email;
@@ -823,7 +761,7 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Get fax number.
 	 *
-	 * @return String  fax number
+	 * @return String fax number
 	 */
 	public String getFax() {
 		return fax;
@@ -856,7 +794,7 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Get voice number.
 	 *
-	 * @return String  fax number
+	 * @return String fax number
 	 */
 	public String getVoice() {
 		return voice;
@@ -878,7 +816,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set authorization information for contact change.
 	 *
-	 * @param newAuthInfo com.verisign.epp.codec.gen.EPPAuthInfo
+	 * @param newAuthInfo
+	 *           com.verisign.epp.codec.gen.EPPAuthInfo
 	 */
 	public void setAuthInfo(com.verisign.epp.codec.gen.EPPAuthInfo newAuthInfo) {
 		if (newAuthInfo != null) {
@@ -892,7 +831,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set email.
 	 *
-	 * @param newEmail String
+	 * @param newEmail
+	 *           String
 	 */
 	public void setEmail(String newEmail) {
 		email = newEmail;
@@ -903,7 +843,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set fax number.
 	 *
-	 * @param newFax String
+	 * @param newFax
+	 *           String
 	 */
 	public void setFax(String newFax) {
 		fax = newFax;
@@ -914,7 +855,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set fax number extension.
 	 *
-	 * @param newFaxExt Fax number extension
+	 * @param newFaxExt
+	 *           Fax number extension
 	 */
 	public void setFaxExt(String newFaxExt) {
 		faxExt = newFaxExt;
@@ -925,7 +867,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set a vector of statuses for contact add.
 	 *
-	 * @param newStatuses java.util.Vector
+	 * @param newStatuses
+	 *           java.util.Vector
 	 */
 	public void setStatuses(java.util.Vector newStatuses) {
 		statuses = newStatuses;
@@ -936,7 +879,8 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set voice number.
 	 *
-	 * @param newVoice String
+	 * @param newVoice
+	 *           String
 	 */
 	public void setVoice(String newVoice) {
 		voice = newVoice;
@@ -947,11 +891,22 @@ public class EPPContactAddChange implements EPPCodecComponent {
 	/**
 	 * Set contact voice extension.
 	 *
-	 * @param newVoiceExt voice extension
+	 * @param newVoiceExt
+	 *           voice extension
 	 */
 	public void setVoiceExt(String newVoiceExt) {
 		voiceExt = newVoiceExt;
 	}
 
-	// End EPPContactAddChange.setVoiceExt(String)
+	/**
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPContactMapFactory.NS;
+	}
+
 }
