@@ -24,7 +24,8 @@ import java.util.Enumeration;
 import java.util.Random;
 import java.util.Vector;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.contact.EPPContactAddress;
 import com.verisign.epp.codec.contact.EPPContactCheckResp;
@@ -35,7 +36,6 @@ import com.verisign.epp.codec.contact.EPPContactPostalDefinition;
 import com.verisign.epp.codec.contact.EPPContactTransferResp;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -67,17 +67,16 @@ import junit.framework.TestSuite;
  */
 public class EPPContactTst extends TestCase {
 	/**
-	 * Handle to the Singleton EPP Application instance (<code>EPPApplicationSingle</code>)
+	 * Handle to the Singleton EPP Application instance
+	 * (<code>EPPApplicationSingle</code>)
 	 */
-	private static EPPApplicationSingle app = EPPApplicationSingle
-			.getInstance();
+	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
 	/** Name of configuration file to use for test (default = epp.config). */
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPContactTst.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPContactTst.class);
 
 	/** EPP Contact associated with test */
 	private EPPContact contact = null;
@@ -93,11 +92,11 @@ public class EPPContactTst extends TestCase {
 
 	/**
 	 * Allocates an <code>EPPContactTst</code> with a logical name. The
-	 * constructor will initialize the base class <code>TestCase</code> with
-	 * the logical name.
+	 * constructor will initialize the base class <code>TestCase</code> with the
+	 * logical name.
 	 * 
 	 * @param name
-	 *            Logical name of the test
+	 *           Logical name of the test
 	 */
 	public EPPContactTst(String name) {
 		super(name);
@@ -146,10 +145,8 @@ public class EPPContactTst extends TestCase {
 
 		try {
 			// Check single contact name
-			System.out
-					.println("\n----------------------------------------------------------------");
-			System.out.println("contactCheck: Check single contact id "
-					+ theName);
+			System.out.println("\n----------------------------------------------------------------");
+			System.out.println("contactCheck: Check single contact id " + theName);
 			contact.setTransId("ABC-12345-XYZ");
 			contact.addContactId(theName);
 
@@ -160,16 +157,13 @@ public class EPPContactTst extends TestCase {
 
 			// For each result
 			for (int i = 0; i < response.getCheckResults().size(); i++) {
-				EPPContactCheckResult currResult = (EPPContactCheckResult) response
-						.getCheckResults().elementAt(i);
+				EPPContactCheckResult currResult = (EPPContactCheckResult) response.getCheckResults().elementAt(i);
 
 				if (currResult.isAvailable()) {
-					System.out.println("contactCheck: Contact "
-							+ currResult.getId() + " is available");
+					System.out.println("contactCheck: Contact " + currResult.getId() + " is available");
 				}
 				else {
-					System.out.println("contactCheck: Contact "
-							+ currResult.getId() + " is unavailable");
+					System.out.println("contactCheck: Contact " + currResult.getId() + " is unavailable");
 				}
 			}
 		}
@@ -179,8 +173,7 @@ public class EPPContactTst extends TestCase {
 
 		try {
 			// Check multiple contact names
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 			System.out.println("contactCheck: Check multiple contact ids");
 
 			contact.setTransId("ABC-12345-XYZ");
@@ -199,16 +192,13 @@ public class EPPContactTst extends TestCase {
 
 			// For each result
 			for (int i = 0; i < response.getCheckResults().size(); i++) {
-				EPPContactCheckResult currResult = (EPPContactCheckResult) response
-						.getCheckResults().elementAt(i);
+				EPPContactCheckResult currResult = (EPPContactCheckResult) response.getCheckResults().elementAt(i);
 
 				if (currResult.isAvailable()) {
-					System.out.println("contactCheck: Contact "
-							+ currResult.getId() + " is available");
+					System.out.println("contactCheck: Contact " + currResult.getId() + " is available");
 				}
 				else {
-					System.out.println("contactCheck: Contact "
-							+ currResult.getId() + " is unavailable");
+					System.out.println("contactCheck: Contact " + currResult.getId() + " is unavailable");
 				}
 			}
 		}
@@ -232,8 +222,7 @@ public class EPPContactTst extends TestCase {
 		String theName = this.makeContactName();
 
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 			System.out.println("\ncontactInfo: Contact info for " + theName);
 			contact.setTransId("ABC-12345-XYZ");
 			contact.addContactId(theName);
@@ -241,8 +230,7 @@ public class EPPContactTst extends TestCase {
 			response = contact.sendInfo();
 
 			// -- Output all of the response attributes
-			System.out
-					.println("contactInfo: Response = [" + response + "]\n\n");
+			System.out.println("contactInfo: Response = [" + response + "]\n\n");
 
 			// -- Output required response attributes using accessors
 			System.out.println("contactInfo: id = " + response.getId());
@@ -254,38 +242,30 @@ public class EPPContactTst extends TestCase {
 
 				for (int j = 0; j < postalContacts.size(); j++) {
 					// Name
-					System.out.println("contactInfo:\t\tname = "
-							+ ((EPPContactPostalDefinition) postalContacts
-									.elementAt(j)).getName());
+					System.out.println(
+					      "contactInfo:\t\tname = " + ((EPPContactPostalDefinition) postalContacts.elementAt(j)).getName());
 
 					// Organization
 					System.out.println("contactInfo:\t\torganization = "
-							+ ((EPPContactPostalDefinition) postalContacts
-									.elementAt(j)).getOrg());
+					      + ((EPPContactPostalDefinition) postalContacts.elementAt(j)).getOrg());
 
-					EPPContactAddress address = ((EPPContactPostalDefinition) postalContacts
-							.elementAt(j)).getAddress();
+					EPPContactAddress address = ((EPPContactPostalDefinition) postalContacts.elementAt(j)).getAddress();
 
 					for (int i = 0; i < address.getStreets().size(); i++) {
-						System.out.println("contactInfo:\t\tstreet" + (i + 1)
-								+ " = " + address.getStreets().elementAt(i));
+						System.out.println("contactInfo:\t\tstreet" + (i + 1) + " = " + address.getStreets().elementAt(i));
 					}
 
 					// Address City
-					System.out.println("contactInfo:\t\tcity = "
-							+ address.getCity());
+					System.out.println("contactInfo:\t\tcity = " + address.getCity());
 
 					// Address State/Province
-					System.out.println("contactInfo:\t\tstate province = "
-							+ address.getStateProvince());
+					System.out.println("contactInfo:\t\tstate province = " + address.getStateProvince());
 
 					// Address Postal Code
-					System.out.println("contactInfo:\t\tpostal code = "
-							+ address.getPostalCode());
+					System.out.println("contactInfo:\t\tpostal code = " + address.getPostalCode());
 
 					// Address County
-					System.out.println("contactInfo:\t\tcountry = "
-							+ address.getCountry());
+					System.out.println("contactInfo:\t\tcountry = " + address.getCountry());
 				}
 			}
 
@@ -296,27 +276,22 @@ public class EPPContactTst extends TestCase {
 			System.out.println("contactInfo:\tvoice = " + response.getVoice());
 
 			// Contact Voice Extension
-			System.out.println("contactInfo:\tvoice ext = "
-					+ response.getVoiceExt());
+			System.out.println("contactInfo:\tvoice ext = " + response.getVoiceExt());
 
 			// Contact Fax
 			System.out.println("contactInfo:\tfax = " + response.getFax());
 
 			// Contact Fax Extension
-			System.out.println("contactInfo:\tfax ext = "
-					+ response.getFaxExt());
+			System.out.println("contactInfo:\tfax ext = " + response.getFaxExt());
 
 			// Client Id
-			System.out.println("contactInfo: client id = "
-					+ response.getClientId());
+			System.out.println("contactInfo: client id = " + response.getClientId());
 
 			// Created By
-			System.out.println("contactInfo: created by = "
-					+ response.getCreatedBy());
+			System.out.println("contactInfo: created by = " + response.getCreatedBy());
 
 			// Created Date
-			System.out.println("contactInfo: create date = "
-					+ response.getCreatedDate());
+			System.out.println("contactInfo: create date = " + response.getCreatedDate());
 
 			// -- Output optional response attributes using accessors
 			// Contact Fax
@@ -326,38 +301,32 @@ public class EPPContactTst extends TestCase {
 
 			// Contact Voice
 			if (response.getVoice() != null) {
-				System.out.println("contactInfo:\tVoice = "
-						+ response.getVoice());
+				System.out.println("contactInfo:\tVoice = " + response.getVoice());
 			}
 
 			// Last Updated By
 			if (response.getLastUpdatedBy() != null) {
-				System.out.println("contactInfo: last updated by = "
-						+ response.getLastUpdatedBy());
+				System.out.println("contactInfo: last updated by = " + response.getLastUpdatedBy());
 			}
 
 			// Last Updated Date
 			if (response.getLastUpdatedDate() != null) {
-				System.out.println("contactInfo: last updated date = "
-						+ response.getLastUpdatedDate());
+				System.out.println("contactInfo: last updated date = " + response.getLastUpdatedDate());
 			}
 
 			// Last Transfer Date
 			if (response.getLastTransferDate() != null) {
-				System.out.println("contactInfo: last updated date = "
-						+ response.getLastTransferDate());
+				System.out.println("contactInfo: last updated date = " + response.getLastTransferDate());
 			}
 
 			// Authorization Id
 			if (response.getAuthInfo() != null) {
-				System.out.println("contactInfo: authorization info = "
-						+ response.getAuthInfo().getPassword());
+				System.out.println("contactInfo: authorization info = " + response.getAuthInfo().getPassword());
 			}
 
 			// Disclose
 			if (response.getDisclose() != null) {
-				System.out.println("contactInfo: disclose info = "
-						+ response.getDisclose());
+				System.out.println("contactInfo: disclose info = " + response.getDisclose());
 			}
 		}
 		catch (EPPCommandException e) {
@@ -380,8 +349,7 @@ public class EPPContactTst extends TestCase {
 		String theName = this.makeContactName();
 
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 			System.out.println("contactCreate: Contact create for " + theName);
 			contact.setTransId("ABC-12345-XYZ");
 			contact.setAuthorizationId("ClientXYZ");
@@ -406,8 +374,7 @@ public class EPPContactTst extends TestCase {
 			address.setPostalCode("20166-6503");
 			address.setCountry("US");
 
-			EPPContactPostalDefinition name = new EPPContactPostalDefinition(
-					EPPContactPostalDefinition.ATTR_TYPE_LOC);
+			EPPContactPostalDefinition name = new EPPContactPostalDefinition(EPPContactPostalDefinition.ATTR_TYPE_LOC);
 
 			name.setName("John Doe");
 			name.setOrg("Example Inc.");
@@ -424,8 +391,7 @@ public class EPPContactTst extends TestCase {
 			Intaddress.setPostalCode("20166-6503");
 			Intaddress.setCountry("US");
 
-			EPPContactPostalDefinition Intname = new EPPContactPostalDefinition(
-					EPPContactPostalDefinition.ATTR_TYPE_INT);
+			EPPContactPostalDefinition Intname = new EPPContactPostalDefinition(EPPContactPostalDefinition.ATTR_TYPE_INT);
 
 			Intname.setName("John Doe");
 			Intname.setOrg("Example Inc.");
@@ -450,8 +416,7 @@ public class EPPContactTst extends TestCase {
 			response = contact.sendCreate();
 
 			// -- Output all of the response attributes
-			System.out.println("contactCreate: Response = [" + response
-					+ "]\n\n");
+			System.out.println("contactCreate: Response = [" + response + "]\n\n");
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -473,18 +438,15 @@ public class EPPContactTst extends TestCase {
 		String theName = this.makeContactName();
 
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
-			System.out
-					.println("\ncontactDelete: Contact delete for " + theName);
+			System.out.println("\n----------------------------------------------------------------");
+			System.out.println("\ncontactDelete: Contact delete for " + theName);
 			contact.setTransId("ABC-12345-XYZ");
 			contact.addContactId(theName);
 
 			response = contact.sendDelete();
 
 			// -- Output all of the response attributes
-			System.out.println("contactDelete: Response = [" + response
-					+ "]\n\n");
+			System.out.println("contactDelete: Response = [" + response + "]\n\n");
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -506,10 +468,8 @@ public class EPPContactTst extends TestCase {
 		String theName = this.makeContactName();
 
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
-			System.out
-					.println("\ncontactDelete: Contact update for " + theName);
+			System.out.println("\n----------------------------------------------------------------");
+			System.out.println("\ncontactDelete: Contact update for " + theName);
 			contact.setTransId("ABC-12345-XYZ");
 			contact.addContactId(theName);
 
@@ -520,12 +480,10 @@ public class EPPContactTst extends TestCase {
 			streets.addElement("This is third line");
 
 			// Address
-			EPPContactAddress address = new EPPContactAddress(streets,
-					"Dulles", "VA", "20166-6503", "US");
+			EPPContactAddress address = new EPPContactAddress(streets, "Dulles", "VA", "20166-6503", "US");
 
-			EPPContactPostalDefinition postal = new EPPContactPostalDefinition(
-					"Joe Brown", "Example Corp.",
-					EPPContactPostalDefinition.ATTR_TYPE_LOC, address);
+			EPPContactPostalDefinition postal = new EPPContactPostalDefinition("Joe Brown", "Example Corp.",
+			      EPPContactPostalDefinition.ATTR_TYPE_LOC, address);
 
 			// statuses
 			contact.addStatus(EPPContact.STAT_PENDING_DELETE);
@@ -554,8 +512,7 @@ public class EPPContactTst extends TestCase {
 			response = contact.sendUpdate();
 
 			// -- Output all of the response attributes
-			System.out.println("contactUpdate: Response = [" + response
-					+ "]\n\n");
+			System.out.println("contactUpdate: Response = [" + response + "]\n\n");
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -578,11 +535,8 @@ public class EPPContactTst extends TestCase {
 
 		// Transfer Request
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
-			System.out
-					.println("\ncontactTransfer: Contact transfer request for "
-							+ theName);
+			System.out.println("\n----------------------------------------------------------------");
+			System.out.println("\ncontactTransfer: Contact transfer request for " + theName);
 			contact.setTransferOpCode(EPPContact.TRANSFER_REQUEST);
 			contact.setTransId("ABC-12345-XYZ");
 			contact.setAuthorizationId("ClientX");
@@ -592,21 +546,15 @@ public class EPPContactTst extends TestCase {
 			response = contact.sendTransfer();
 
 			// -- Output all of the response attributes
-			System.out.println("contactTransfer: Response = [" + response
-					+ "]\n\n");
+			System.out.println("contactTransfer: Response = [" + response + "]\n\n");
 
 			// -- Output required response attributes using accessors
 			System.out.println("contactTransfer: id = " + response.getId());
-			System.out.println("contactTransfer: request client = "
-					+ response.getRequestClient());
-			System.out.println("contactTransfer: action client = "
-					+ response.getActionClient());
-			System.out.println("contactTransfer: transfer status = "
-					+ response.getTransferStatus());
-			System.out.println("contactTransfer: request date = "
-					+ response.getRequestDate());
-			System.out.println("contactTransfer: action date = "
-					+ response.getActionDate());
+			System.out.println("contactTransfer: request client = " + response.getRequestClient());
+			System.out.println("contactTransfer: action client = " + response.getActionClient());
+			System.out.println("contactTransfer: transfer status = " + response.getTransferStatus());
+			System.out.println("contactTransfer: request date = " + response.getRequestDate());
+			System.out.println("contactTransfer: action date = " + response.getActionDate());
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -614,10 +562,8 @@ public class EPPContactTst extends TestCase {
 
 		// Transfer Query
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
-			System.out.println("\ncontactTransfer: Contact transfer query for "
-					+ theName);
+			System.out.println("\n----------------------------------------------------------------");
+			System.out.println("\ncontactTransfer: Contact transfer query for " + theName);
 			contact.setTransferOpCode(EPPContact.TRANSFER_QUERY);
 			contact.addContactId(this.makeContactName());
 
@@ -625,8 +571,7 @@ public class EPPContactTst extends TestCase {
 			response = contact.sendTransfer();
 
 			// -- Output all of the response attributes
-			System.out.println("contactTransfer: Response = [" + response
-					+ "]\n\n");
+			System.out.println("contactTransfer: Response = [" + response + "]\n\n");
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -634,11 +579,8 @@ public class EPPContactTst extends TestCase {
 
 		// Transfer Cancel
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
-			System.out
-					.println("\ncontactTransfer: Contact transfer cancel for "
-							+ theName);
+			System.out.println("\n----------------------------------------------------------------");
+			System.out.println("\ncontactTransfer: Contact transfer cancel for " + theName);
 			contact.setTransferOpCode(EPPContact.TRANSFER_CANCEL);
 			contact.addContactId(this.makeContactName());
 
@@ -646,8 +588,7 @@ public class EPPContactTst extends TestCase {
 			response = contact.sendTransfer();
 
 			// -- Output all of the response attributes
-			System.out.println("contactTransfer: Response = [" + response
-					+ "]\n\n");
+			System.out.println("contactTransfer: Response = [" + response + "]\n\n");
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -655,11 +596,8 @@ public class EPPContactTst extends TestCase {
 
 		// Transfer Reject
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
-			System.out
-					.println("\ncontactTransfer: Contact transfer reject for "
-							+ theName);
+			System.out.println("\n----------------------------------------------------------------");
+			System.out.println("\ncontactTransfer: Contact transfer reject for " + theName);
 			contact.setTransferOpCode(EPPContact.TRANSFER_REJECT);
 			contact.addContactId(this.makeContactName());
 
@@ -667,8 +605,7 @@ public class EPPContactTst extends TestCase {
 			response = contact.sendTransfer();
 
 			// -- Output all of the response attributes
-			System.out.println("contactTransfer: Response = [" + response
-					+ "]\n\n");
+			System.out.println("contactTransfer: Response = [" + response + "]\n\n");
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -676,11 +613,8 @@ public class EPPContactTst extends TestCase {
 
 		// Transfer Approve
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
-			System.out
-					.println("\ncontactTransfer: Contact transfer approve for "
-							+ theName);
+			System.out.println("\n----------------------------------------------------------------");
+			System.out.println("\ncontactTransfer: Contact transfer approve for " + theName);
 			contact.setTransferOpCode(EPPContact.TRANSFER_APPROVE);
 			contact.addContactId(this.makeContactName());
 
@@ -688,8 +622,7 @@ public class EPPContactTst extends TestCase {
 			response = contact.sendTransfer();
 
 			// -- Output all of the response attributes
-			System.out.println("contactTransfer: Response = [" + response
-					+ "]\n\n");
+			System.out.println("contactTransfer: Response = [" + response + "]\n\n");
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -703,8 +636,7 @@ public class EPPContactTst extends TestCase {
 				session.setPollOp(EPPSession.OP_REQ);
 
 				pollResponse = session.sendPoll();
-				System.out.println("contactTransfer: Poll Response = ["
-						+ pollResponse + "]\n\n");
+				System.out.println("contactTransfer: Poll Response = [" + pollResponse + "]\n\n");
 
 				// Need to ack the message?
 				if (pollResponse.getResult().getCode() == EPPResult.SUCCESS_POLL_MSG) {
@@ -712,8 +644,7 @@ public class EPPContactTst extends TestCase {
 					session.setMsgID(pollResponse.getMsgQueue().getId());
 					EPPResponse pollAckResponse = session.sendPoll();
 
-					System.out.println("contactTransfer: Poll Ack Response = ["
-							+ pollAckResponse + "]\n\n");
+					System.out.println("contactTransfer: Poll Ack Response = [" + pollAckResponse + "]\n\n");
 
 				}
 			}
@@ -729,9 +660,8 @@ public class EPPContactTst extends TestCase {
 	// End EPPContactTstcontactTransfer()
 
 	/**
-	 * Unit test of <code>EPPSession.initSession</code>. The session
-	 * attribute is initialized with the attributes defined in the EPP sample
-	 * files.
+	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
+	 * initialized with the attributes defined in the EPP sample files.
 	 */
 	private void initSession() {
 		printStart("initSession");
@@ -764,8 +694,8 @@ public class EPPContactTst extends TestCase {
 	// End EPPContactTst.initSession()
 
 	/**
-	 * Unit test of <code>EPPSession.endSession</code>. The session with the
-	 * EPP Server will be terminated.
+	 * Unit test of <code>EPPSession.endSession</code>. The session with the EPP
+	 * Server will be terminated.
 	 */
 	private void endSession() {
 		printStart("endSession");
@@ -806,16 +736,13 @@ public class EPPContactTst extends TestCase {
 					Class theSessionClass = Class.forName(theSessionClassName);
 
 					if (!EPPSession.class.isAssignableFrom((theSessionClass))) {
-						Assert.fail(theSessionClassName
-								+ " is not a subclass of EPPSession");
+						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
 					}
 
 					session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
 				}
 				catch (Exception ex) {
-					Assert
-							.fail("Exception instantiating EPP.SessionClass value "
-									+ theSessionClassName + ": " + ex);
+					Assert.fail("Exception instantiating EPP.SessionClass value " + theSessionClassName + ": " + ex);
 				}
 			}
 			else {
@@ -847,8 +774,8 @@ public class EPPContactTst extends TestCase {
 	// End EPPContactTst.tearDown();
 
 	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests
-	 * associated with <code>EPPContact</code>.
+	 * JUNIT <code>suite</code> static method, which returns the tests associated
+	 * with <code>EPPContact</code>.
 	 * 
 	 * @return DOCUMENT ME!
 	 */
@@ -875,21 +802,21 @@ public class EPPContactTst extends TestCase {
 	// End EPPContactTst.suite()
 
 	/**
-	 * Handle an <code>EPPCommandException</code>, which can be either a
-	 * server generated error or a general exception. If the exception was
-	 * caused by a server error, "Server Error : &lt;Response XML&gt;" will be
-	 * specified. If the exception was caused by a general algorithm error,
-	 * "General Error : &lt;Exception Description&gt;" will be specified.
+	 * Handle an <code>EPPCommandException</code>, which can be either a server
+	 * generated error or a general exception. If the exception was caused by a
+	 * server error, "Server Error : &lt;Response XML&gt;" will be specified. If
+	 * the exception was caused by a general algorithm error, "General Error :
+	 * &lt;Exception Description&gt;" will be specified.
 	 * 
 	 * @param aException
-	 *            Exception thrown during test
+	 *           Exception thrown during test
 	 */
 	public void handleException(EPPCommandException aException) {
 		EPPResponse theResponse = null;
 		if (aException instanceof EPPCommandException) {
 			theResponse = ((EPPCommandException) aException).getResponse();
 		}
-		
+
 		aException.printStackTrace();
 
 		// Is a server specified error?
@@ -908,14 +835,15 @@ public class EPPContactTst extends TestCase {
 	 * Unit test main, which accepts the following system property options:<br>
 	 * 
 	 * <ul>
-	 * <li> iterations Number of unit test iterations to run </li>
-	 * <li> validate Turn XML validation on (<code>true</code>) or off (<code>false</code>).
-	 * If validate is not specified, validation will be off. </li>
+	 * <li>iterations Number of unit test iterations to run</li>
+	 * <li>validate Turn XML validation on (<code>true</code>) or off
+	 * (<code>false</code>). If validate is not specified, validation will be
+	 * off.</li>
 	 * </ul>
 	 * 
 	 * 
 	 * @param args
-	 *            DOCUMENT ME!
+	 *           DOCUMENT ME!
 	 */
 	public static void main(String[] args) {
 		// Override the default configuration file name?
@@ -935,8 +863,7 @@ public class EPPContactTst extends TestCase {
 		if (numThreads > 1) {
 			// Spawn each thread passing in the Test Suite
 			for (int i = 0; i < numThreads; i++) {
-				TestThread thread = new TestThread("EPPSessionTst Thread " + i,
-						EPPContactTst.suite());
+				TestThread thread = new TestThread("EPPSessionTst Thread " + i, EPPContactTst.suite());
 				thread.start();
 			}
 		}
@@ -962,8 +889,7 @@ public class EPPContactTst extends TestCase {
 	public String makeDomainName() {
 		long tm = System.currentTimeMillis();
 
-		return new String(Thread.currentThread()
-				+ String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
+		return new String(Thread.currentThread() + String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
 	}
 
 	/**
@@ -974,25 +900,24 @@ public class EPPContactTst extends TestCase {
 	public String makeIP() {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(50)).substring(10)
-				+ "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
-				+ String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
-				+ String.valueOf(tm + rd.nextInt(50)).substring(10));
+		return new String(
+		      String.valueOf(tm + rd.nextInt(50)).substring(10) + "." + String.valueOf(tm + rd.nextInt(50)).substring(10)
+		            + "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
+		            + String.valueOf(tm + rd.nextInt(50)).substring(10));
 	}
 
 	/**
 	 * This method tries to generate a unique Host Name for a given Domain Name
 	 * 
 	 * @param newDomainName
-	 *            DOCUMENT ME!
+	 *           DOCUMENT ME!
 	 * 
 	 * @return DOCUMENT ME!
 	 */
 	public String makeHostName(String newDomainName) {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10)
-				+ "." + newDomainName);
+		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10) + "." + newDomainName);
 	}
 
 	/**
@@ -1003,48 +928,41 @@ public class EPPContactTst extends TestCase {
 	public String makeContactName() {
 		long tm = System.currentTimeMillis();
 
-		return new String("Con"
-				+ String.valueOf(tm + rd.nextInt(5)).substring(7));
+		return new String("Con" + String.valueOf(tm + rd.nextInt(5)).substring(7));
 	}
 
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the
-	 * current thread is a <code>TestThread</code>.
+	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 * 
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	private void printStart(String aTest) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": ");
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aTest + " Start");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " Start");
 		}
 
 		System.out.println("Start of " + aTest);
-		System.out
-				.println("****************************************************************\n");
+		System.out.println("****************************************************************\n");
 	}
 
 	// End EPPContactTst.printStart(String)
 
 	/**
-	 * Print the end of a test with the <code>Thread</code> name if the
-	 * current thread is a <code>TestThread</code>.
+	 * Print the end of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 * 
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	private void printEnd(String aTest) {
-		System.out
-				.println("****************************************************************");
+		System.out.println("****************************************************************");
 
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": ");
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aTest + " End");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " End");
 		}
 
 		System.out.println("End of " + aTest);
@@ -1057,14 +975,12 @@ public class EPPContactTst extends TestCase {
 	 * Print message
 	 * 
 	 * @param aMsg
-	 *            message to print
+	 *           message to print
 	 */
 	private void printMsg(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.println(Thread.currentThread().getName()
-					+ ", iteration " + iteration + ": " + aMsg);
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aMsg);
+			System.out.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 		else {
 			System.out.println(aMsg);
@@ -1078,14 +994,12 @@ public class EPPContactTst extends TestCase {
 	 * Print error message
 	 * 
 	 * @param aMsg
-	 *            errpr message to print
+	 *           errpr message to print
 	 */
 	private void printError(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.err.println(Thread.currentThread().getName()
-					+ ", iteration " + iteration + ": " + aMsg);
-			cat.error(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aMsg);
+			System.err.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
+			cat.error(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 		else {
 			System.err.println(aMsg);
