@@ -19,50 +19,39 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.codec.defReg;
 
-import org.w3c.dom.Document;
-
-// W3C Imports
-import org.w3c.dom.Element;
-
-//----------------------------------------------
-//
-// imports...
-//
-//----------------------------------------------
-// Java Core Imports
 import java.util.Vector;
 
-// EPP Imports
-import com.verisign.epp.codec.gen.*;
+import org.w3c.dom.Document;
+import org.w3c.dom.Element;
 
+import com.verisign.epp.codec.gen.EPPDecodeException;
+import com.verisign.epp.codec.gen.EPPEncodeException;
+import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.gen.EPPTransId;
+import com.verisign.epp.codec.gen.EPPUtil;
 
 /**
  * Represents an EPPDefReg &lt;defReg:chkData&gt; response to a
- * <code>EPPDefRegFwdCheckCmd</code>.     When a &lt;check&gt; command has
- * been processed successfully, the EPP &lt;resData&gt; element MUST contain a
- * child &lt;defReg:chkData&gt; element that identifies the defReg namespace
- * and the location of the defReg schema. The &lt;defReg:chkData&gt; elements
- * that contain the following child elements: <br>
+ * <code>EPPDefRegFwdCheckCmd</code>. When a &lt;check&gt; command has been
+ * processed successfully, the EPP &lt;resData&gt; element MUST contain a child
+ * &lt;defReg:chkData&gt; element that identifies the defReg namespace and the
+ * location of the defReg schema. The &lt;defReg:chkData&gt; elements that
+ * contain the following child elements: <br>
  * 
  * <ul>
- * <li>
- * A &lt;defReg:name&gt; element that contains the fully qualified name of the
- * queried defReg object with a attribute  level whose value is of either
- * "premium" or "standard". This element MUST contain an "avail" attribute
- * whose value indicates object availability at the moment the &lt;check&gt;
- * command was completed. A value of "1" or "true" menas that the object is
- * availabe.  A value of "0" or "false" means that the object is not
- * available.
- * </li>
- * <li>
- * An OPTIONAL &lt;defReg:reason&gt; element that MAY be provided when an
- * object is not available for provisioning.  If present,EPPDefReg this
- * element contains server-specific text to help explain why the object is
- * unavailable.  This text MUST be represented in the response language
- * previously negotiated with the client; an OPTIONAL "lang" attribute MAY be
- * present to identify the language if the negotiated value is something other
- * that a default value of "en" (English).
- * </li>
+ * <li>A &lt;defReg:name&gt; element that contains the fully qualified name of
+ * the queried defReg object with a attribute level whose value is of either
+ * "premium" or "standard". This element MUST contain an "avail" attribute whose
+ * value indicates object availability at the moment the &lt;check&gt; command
+ * was completed. A value of "1" or "true" menas that the object is availabe. A
+ * value of "0" or "false" means that the object is not available.</li>
+ * <li>An OPTIONAL &lt;defReg:reason&gt; element that MAY be provided when an
+ * object is not available for provisioning. If present,EPPDefReg this element
+ * contains server-specific text to help explain why the object is unavailable.
+ * This text MUST be represented in the response language previously negotiated
+ * with the client; an OPTIONAL "lang" attribute MAY be present to identify the
+ * language if the negotiated value is something other that a default value of
+ * "en" (English).</li>
  * </ul>
  * 
  *
@@ -77,7 +66,7 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	private Vector results;
 
 	/**
-	 * <code>EPPDefRegFwdCheckResp</code> default constructor.  It will set
+	 * <code>EPPDefRegFwdCheckResp</code> default constructor. It will set
 	 * results attribute to an empty <code>Vector</code>.
 	 */
 	public EPPDefRegCheckResp() {
@@ -87,14 +76,15 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	// End EPPDefRegFwdCheckResp()
 
 	/**
-	 * <code>EPPDefRegFwdCheckResp</code> constructor that will set the result
-	 * of an individual defReg.
+	 * <code>EPPDefRegFwdCheckResp</code> constructor that will set the result of
+	 * an individual defReg.
 	 *
-	 * @param aTransId Transaction Id associated with response.
-	 * @param aResult EPPDefRegCheckResult results.
+	 * @param aTransId
+	 *           Transaction Id associated with response.
+	 * @param aResult
+	 *           EPPDefRegCheckResult results.
 	 */
-	public EPPDefRegCheckResp(
-							  EPPTransId aTransId, EPPDefRegCheckResult aResult) {
+	public EPPDefRegCheckResp(EPPTransId aTransId, EPPDefRegCheckResult aResult) {
 		super(aTransId);
 
 		results = new Vector();
@@ -104,11 +94,13 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	// End EPPDefRegFwdCheckResp(EPPTransId, EPPDefRegFwdCheckResp)
 
 	/**
-	 * <code>EPPDefRegFwdCheckResp</code> constructor that will set the result
-	 * of multiple defRegs.
+	 * <code>EPPDefRegFwdCheckResp</code> constructor that will set the result of
+	 * multiple defRegs.
 	 *
-	 * @param aTransId Transaction Id associated with response.
-	 * @param someResults Vector of EPPDefRegFwdCheckResult instances.
+	 * @param aTransId
+	 *           Transaction Id associated with response.
+	 * @param someResults
+	 *           Vector of EPPDefRegFwdCheckResult instances.
 	 */
 	public EPPDefRegCheckResp(EPPTransId aTransId, Vector someResults) {
 		super(aTransId);
@@ -146,7 +138,8 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	 * Compare an instance of <code>EPPDefRegFwdCheckResp</code> with this
 	 * instance.
 	 *
-	 * @param aObject Object to compare with.
+	 * @param aObject
+	 *           Object to compare with.
 	 *
 	 * @return DOCUMENT ME!
 	 */
@@ -176,16 +169,15 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	 *
 	 * @return clone of <code>EPPDefRegFwdCheckResp</code>
 	 *
-	 * @exception CloneNotSupportedException standard Object.clone exception
+	 * @exception CloneNotSupportedException
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPDefRegCheckResp clone = (EPPDefRegCheckResp) super.clone();
 		clone.results = (Vector) results.clone();
 
 		for (int i = 0; i < results.size(); i++) {
-			clone.results.setElementAt(
-									   ((EPPDefRegCheckResult) results
-										.elementAt(i)).clone(), i);
+			clone.results.setElementAt(((EPPDefRegCheckResult) results.elementAt(i)).clone(), i);
 		}
 
 		return clone;
@@ -198,8 +190,8 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 * 		   <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
@@ -208,13 +200,13 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	// End EPPDefRegFwdCheckResp.toString()
 
 	/**
-	 * Set the results of a <code>EPPDefRegFwdCheckResp</code> Response.  There
-	 * is     one <code>EPPDefRegFwdCheckResult</code> instance in
-	 * <code>someResults</code> for each     defReg requested in the
+	 * Set the results of a <code>EPPDefRegFwdCheckResp</code> Response. There is
+	 * one <code>EPPDefRegFwdCheckResult</code> instance in
+	 * <code>someResults</code> for each defReg requested in the
 	 * <code>EPPDefRegFwdCheckCmd</code> Command.
 	 *
-	 * @param someResults Vector of <code>EPPDefRegFwdCheckResult</code>
-	 * 		  instances.
+	 * @param someResults
+	 *           Vector of <code>EPPDefRegFwdCheckResult</code> instances.
 	 */
 	public void setCheckResults(Vector someResults) {
 		results = someResults;
@@ -223,9 +215,9 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	// End EPPDefRegFwdCheckResp.setCheckResults(Vector)
 
 	/**
-	 * Get the results of a <code>EPPDefRegFwdCheckResp</code> Response.  There
-	 * is     one <code>EPPDefRegFwdCheckResult</code> instance in
-	 * <code>someResults</code> for each     defReg requested in the
+	 * Get the results of a <code>EPPDefRegFwdCheckResp</code> Response. There is
+	 * one <code>EPPDefRegFwdCheckResult</code> instance in
+	 * <code>someResults</code> for each defReg requested in the
 	 * <code>EPPDefRegFwdCheckResult</code> Command.
 	 *
 	 * @return Vector of <code>EPPDefRegFwdCheckResult</code> instances.
@@ -240,18 +232,18 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	 * Encode a DOM Element tree from the attributes of the
 	 * <code>EPPDefRegFwdCheckResp</code> instance.
 	 *
-	 * @param aDocument DOM Document that is being built.  Used as an Element
-	 * 		  factory.
+	 * @param aDocument
+	 *           DOM Document that is being built. Used as an Element factory.
 	 *
-	 * @return Element    Root DOM Element representing the
-	 * 		   <code>EPPDefRegFwdCheckResp</code> instance. defReg
+	 * @return Element Root DOM Element representing the
+	 *         <code>EPPDefRegFwdCheckResp</code> instance. defReg
 	 *
-	 * @exception EPPEncodeException Unable to encode
-	 * 			  <code>EPPDefRegFwdCheckResp</code> instance.
+	 * @exception EPPEncodeException
+	 *               Unable to encode <code>EPPDefRegFwdCheckResp</code>
+	 *               instance.
 	 */
 	protected Element doEncode(Document aDocument) throws EPPEncodeException {
-		Element root =
-			aDocument.createElementNS(EPPDefRegMapFactory.NS, ELM_NAME);
+		Element root = aDocument.createElementNS(EPPDefRegMapFactory.NS, ELM_NAME);
 		root.setAttribute("xmlns:defReg", EPPDefRegMapFactory.NS);
 
 		// Results
@@ -263,21 +255,20 @@ public class EPPDefRegCheckResp extends EPPResponse {
 	// End EPPDefRegFwdCheckResp.doEncode(Document)
 
 	/**
-	 * Decode the <code>EPPDefRegFwdCheckResp</code> attributes from the
-	 * aElement DOM Element tree.
+	 * Decode the <code>EPPDefRegFwdCheckResp</code> attributes from the aElement
+	 * DOM Element tree.
 	 *
-	 * @param aElement Root DOM Element to decode
-	 * 		  <code>EPPDefRegFwdCheckResp</code> from.
+	 * @param aElement
+	 *           Root DOM Element to decode <code>EPPDefRegFwdCheckResp</code>
+	 *           from.
 	 *
-	 * @exception EPPDecodeException Unable to decode aElement
+	 * @exception EPPDecodeException
+	 *               Unable to decode aElement
 	 */
 	protected void doDecode(Element aElement) throws EPPDecodeException {
 		// Results
-		results =
-			EPPUtil.decodeCompVector(
-									 aElement, EPPDefRegMapFactory.NS,
-									 EPPDefRegCheckResult.ELM_NAME,
-									 EPPDefRegCheckResult.class);
+		results = EPPUtil.decodeCompVector(aElement, EPPDefRegMapFactory.NS, EPPDefRegCheckResult.ELM_NAME,
+		      EPPDefRegCheckResult.class);
 	}
 
 	// End EPPDefRegFwdCheckResp.doDecode(Element)
