@@ -19,35 +19,33 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.interfaces;
 
-// JUNIT Imports
-import junit.framework.*;
-
-// Log4j imports
-import org.apache.log4j.*;
-
-//----------------------------------------------
-//
-// imports...
-//
-//----------------------------------------------
-// Java Core Imports
 import java.util.GregorianCalendar;
 import java.util.Random;
 
-import com.verisign.epp.codec.domain.*;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import com.verisign.epp.codec.domain.EPPDomainCheckResp;
+import com.verisign.epp.codec.domain.EPPDomainCheckResult;
+import com.verisign.epp.codec.domain.EPPDomainContact;
+import com.verisign.epp.codec.domain.EPPDomainCreateResp;
+import com.verisign.epp.codec.domain.EPPDomainInfoResp;
+import com.verisign.epp.codec.domain.EPPDomainMapFactory;
+import com.verisign.epp.codec.domain.EPPDomainRenewResp;
+import com.verisign.epp.codec.domain.EPPDomainStatus;
+import com.verisign.epp.codec.domain.EPPDomainTransferResp;
 import com.verisign.epp.codec.gen.EPPFactory;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
-
-// EPP Imports
-import com.verisign.epp.interfaces.EPPApplicationSingle;
-import com.verisign.epp.interfaces.EPPCommandException;
-import com.verisign.epp.interfaces.EPPDomain;
 import com.verisign.epp.transport.EPPClientCon;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Is a unit test of the <code>EPPDomain</code> class. The unit test will
  * initialize a session with an EPP Server, will invoke <code>EPPDomain</code>
@@ -81,8 +79,7 @@ public class EPPDomainTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPDomainTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPDomainTst.class);
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
