@@ -19,11 +19,6 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.codec.emailFwd;
 
-import junit.framework.Assert;
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 //----------------------------------------------
 //
 // imports...
@@ -47,6 +42,11 @@ import com.verisign.epp.codec.gen.EPPResult;
 import com.verisign.epp.codec.gen.EPPTransId;
 import com.verisign.epp.util.TestThread;
 
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 
 /**
  * Is a unit test of the com.verisign.epp.codec.emailFwd package.  The unit
@@ -628,7 +628,7 @@ public class EPPEmailFwdTst extends TestCase {
 
 		// Testing EmailFwd Reason
 		//EPPEmailFwdCheckResult emailFwdResult = new EPPEmailFwdCheckResult("example1.com", true);
-		//emailFwdResult.setEmailFwdReason("In Use");
+		//emailFwdResult.setEmailFwdReason("In use");
 		//emailFwdResult.setLanguage("en");
 		//
 		//theResponse = new EPPEmailFwdCheckResp(respTransId, emailFwdResult);
@@ -654,7 +654,7 @@ public class EPPEmailFwdTst extends TestCase {
 		// Testing EmailFwd Reason
 		EPPEmailFwdCheckResult emailFwdResult =
 			new EPPEmailFwdCheckResult("john@example2.com", false);
-		emailFwdResult.setEmailFwdReason("In Use");
+		emailFwdResult.setEmailFwdReason("In use");
 		emailFwdResult.setLanguage("fr");
 		emailFwdResults.addElement(emailFwdResult);
 
