@@ -24,7 +24,8 @@ import java.math.BigDecimal;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -32,7 +33,6 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -42,16 +42,15 @@ import com.verisign.epp.util.EqualityUtil;
  */
 public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 
-	/** 
-	 * XML root tag for <code>EPPFeeTransformResult</code>. 
+	/**
+	 * XML root tag for <code>EPPFeeTransformResult</code>.
 	 */
 	private String ELM_NAME = EPPFeeExtFactory.NS_PREFIX + ":" + getLocalName();
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPFeeTransformResult.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPFeeTransformResult.class);
 
 	/**
 	 * XML local name for the currency
@@ -113,7 +112,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * not set prior to the <code>encode</code>.
 	 * 
 	 * @throws EPPEncodeException
-	 *             When an attribute is incorrect set or not set.
+	 *            When an attribute is incorrect set or not set.
 	 */
 	protected abstract void validateAttributes() throws EPPEncodeException;
 
@@ -124,13 +123,13 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	}
 
 	/**
-	 * Constructor for <code>EPPFeeTransformResult</code> that takes the
-	 * required currency parameter along with a single fee.
+	 * Constructor for <code>EPPFeeTransformResult</code> that takes the required
+	 * currency parameter along with a single fee.
 	 * 
 	 * @param aCurrency
-	 *            Currency of the fee
+	 *           Currency of the fee
 	 * @param aFee
-	 *            A single fee value
+	 *           A single fee value
 	 */
 	public EPPFeeTransformResult(String aCurrency, EPPFeeValue aFee) {
 		this.setCurrency(aCurrency);
@@ -138,13 +137,13 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	}
 
 	/**
-	 * Constructor for <code>EPPFeeTransformResult</code> that takes the
-	 * required currency parameter along with a list of fees.
+	 * Constructor for <code>EPPFeeTransformResult</code> that takes the required
+	 * currency parameter along with a list of fees.
 	 * 
 	 * @param aCurrency
-	 *            Currency of the fee
+	 *           Currency of the fee
 	 * @param aFees
-	 *            The fees of the transform command
+	 *           The fees of the transform command
 	 */
 	public EPPFeeTransformResult(String aCurrency, List<EPPFeeValue> aFees) {
 		this.setCurrency(aCurrency);
@@ -152,35 +151,34 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	}
 
 	/**
-	 * Constructor for <code>EPPFeeTransformResult</code> that takes the
-	 * required currency parameter along with a single credit.
+	 * Constructor for <code>EPPFeeTransformResult</code> that takes the required
+	 * currency parameter along with a single credit.
 	 * 
 	 * @param aCurrency
-	 *            Currency of the fee
+	 *           Currency of the fee
 	 * @param aCredit
-	 *            A single credit value
+	 *           A single credit value
 	 */
 	public EPPFeeTransformResult(String aCurrency, EPPFeeCredit aCredit) {
 		this.setCurrency(aCurrency);
 		this.addCredit(aCredit);
 	}
-	
-	
+
 	/**
 	 * Constructor for <code>EPPFeeTransformResult</code> that takes all
 	 * attributes that includes fees.
 	 * 
 	 * @param aCurrency
-	 *            The currency of the fees
+	 *           The currency of the fees
 	 * @param aFees
-	 *            The fees of the transform command
+	 *           The fees of the transform command
 	 * @param aBalance
-	 *            The remaining client balance
+	 *           The remaining client balance
 	 * @param aCreditLimit
-	 *            The maximum credit available to the client
+	 *           The maximum credit available to the client
 	 */
-	public EPPFeeTransformResult(String aCurrency, List<EPPFeeValue> aFees,
-			BigDecimal aBalance, BigDecimal aCreditLimit) {
+	public EPPFeeTransformResult(String aCurrency, List<EPPFeeValue> aFees, BigDecimal aBalance,
+	      BigDecimal aCreditLimit) {
 		this.setCurrency(aCurrency);
 		this.setFees(aFees);
 		this.setBalance(aBalance);
@@ -192,24 +190,22 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * attributes that includes credits.
 	 * 
 	 * @param aCurrency
-	 *            The currency of the fees
+	 *           The currency of the fees
 	 * @param aBalance
-	 *            The remaining client balance
+	 *           The remaining client balance
 	 * @param aCreditLimit
-	 *            The maximum credit available to the client
+	 *           The maximum credit available to the client
 	 * @param aCredits
-	 *            The credits of the command
+	 *           The credits of the command
 	 */
-	public EPPFeeTransformResult(String aCurrency, 
-			BigDecimal aBalance, BigDecimal aCreditLimit,
-			List<EPPFeeCredit> aCredits) {
+	public EPPFeeTransformResult(String aCurrency, BigDecimal aBalance, BigDecimal aCreditLimit,
+	      List<EPPFeeCredit> aCredits) {
 		this.setCurrency(aCurrency);
 		this.setCredits(aCredits);
 		this.setBalance(aBalance);
 		this.setCreditLimit(aCreditLimit);
 	}
-	
-	
+
 	/**
 	 * Is the currency defined?
 	 * 
@@ -233,7 +229,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * Sets the currency value.
 	 * 
 	 * @param aCurrency
-	 *            Currency value
+	 *           Currency value
 	 */
 	public void setCurrency(String aCurrency) {
 		this.currency = aCurrency;
@@ -262,7 +258,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * Sets the period value.
 	 * 
 	 * @param aPeriod
-	 *            Period value
+	 *           Period value
 	 */
 	public void setPeriod(EPPFeePeriod aPeriod) {
 		this.period = aPeriod;
@@ -291,7 +287,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * Adds a fee to the list of fees.
 	 * 
 	 * @param aFee
-	 *            The fee to add.
+	 *           The fee to add.
 	 */
 	public void addFee(EPPFeeValue aFee) {
 		if (aFee == null)
@@ -304,7 +300,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * Sets the list of fees.
 	 * 
 	 * @param aFees
-	 *            The fees to set.
+	 *           The fees to set.
 	 */
 	public void setFees(List<EPPFeeValue> aFees) {
 		if (aFees == null)
@@ -338,7 +334,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * response.
 	 * 
 	 * @param aCredit
-	 *            The credit to add.
+	 *           The credit to add.
 	 */
 	public void addCredit(EPPFeeCredit aCredit) {
 		if (aCredit == null)
@@ -351,7 +347,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * Sets the list of credits. The credits are used on a delete response.
 	 * 
 	 * @param aCredits
-	 *            The credits to set.  Set to {@code null} for no credits.
+	 *           The credits to set. Set to {@code null} for no credits.
 	 */
 	public void setCredits(List<EPPFeeCredit> aCredits) {
 		if (aCredits == null)
@@ -385,7 +381,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * indicate that the server has provided the client with credit.
 	 * 
 	 * @param aBalance
-	 *            The available balance.
+	 *           The available balance.
 	 */
 	public void setBalance(BigDecimal aBalance) {
 		this.balance = aBalance;
@@ -417,7 +413,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * negative the <code>balance</code> attribute can go to.
 	 * 
 	 * @param aCreditLimit
-	 *            The maximum credit available to the client.
+	 *           The maximum credit available to the client.
 	 */
 	public void setCreditLimit(BigDecimal aCreditLimit) {
 		this.creditLimit = aCreditLimit;
@@ -430,18 +426,17 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * appended as a child node.
 	 * 
 	 * @param aDocument
-	 *            DOM Document, which acts is an Element factory
+	 *           DOM Document, which acts is an Element factory
 	 * 
 	 * @return Element Root element associated with the object
 	 * 
 	 * @exception EPPEncodeException
-	 *                Error encoding <code>EPPFeeTransformResult</code>
+	 *               Error encoding <code>EPPFeeTransformResult</code>
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " on in EPPFeeTransformResult.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " on in EPPFeeTransformResult.encode(Document)");
 		}
 
 		// Check for required attributes
@@ -451,9 +446,8 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 		Element root = aDocument.createElementNS(EPPFeeExtFactory.NS, ELM_NAME);
 
 		// Currency
-		EPPUtil.encodeString(aDocument, root, this.currency,
-				EPPFeeExtFactory.NS, EPPFeeExtFactory.NS_PREFIX + ":"
-						+ ELM_CURRENCY);
+		EPPUtil.encodeString(aDocument, root, this.currency, EPPFeeExtFactory.NS,
+		      EPPFeeExtFactory.NS_PREFIX + ":" + ELM_CURRENCY);
 		// Period
 		EPPUtil.encodeComp(aDocument, root, this.period);
 
@@ -464,57 +458,51 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 		EPPUtil.encodeCompList(aDocument, root, this.credits);
 
 		// Balance
-		EPPUtil.encodeBigDecimal(aDocument, root, this.balance,
-				EPPFeeExtFactory.NS, EPPFeeExtFactory.NS_PREFIX + ":"
-						+ ELM_BALANCE, null);
+		EPPUtil.encodeBigDecimal(aDocument, root, this.balance, EPPFeeExtFactory.NS,
+		      EPPFeeExtFactory.NS_PREFIX + ":" + ELM_BALANCE, null);
 
 		// creditLimit
-		EPPUtil.encodeBigDecimal(aDocument, root, this.creditLimit,
-				EPPFeeExtFactory.NS, EPPFeeExtFactory.NS_PREFIX + ":"
-						+ ELM_CREDIT_LIMIT, null);
+		EPPUtil.encodeBigDecimal(aDocument, root, this.creditLimit, EPPFeeExtFactory.NS,
+		      EPPFeeExtFactory.NS_PREFIX + ":" + ELM_CREDIT_LIMIT, null);
 
 		return root;
 	}
 
 	/**
 	 * Decode a DOM element tree to initialize the instance attributes. The
-	 * <code>aElement</code> argument represents the root DOM element and is
-	 * used to traverse the DOM nodes for instance attribute values.
+	 * <code>aElement</code> argument represents the root DOM element and is used
+	 * to traverse the DOM nodes for instance attribute values.
 	 * 
 	 * @param aElement
-	 *            <code>Element</code> to decode
+	 *           <code>Element</code> to decode
 	 * 
 	 * @exception EPPDecodeException
-	 *                Error decoding <code>Element</code>
+	 *               Error decoding <code>Element</code>
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 
 		// Currency
-		this.currency = EPPUtil.decodeString(aElement, EPPFeeExtFactory.NS,
-				ELM_CURRENCY);
+		this.currency = EPPUtil.decodeString(aElement, EPPFeeExtFactory.NS, ELM_CURRENCY);
 		if (this.currency != null && this.currency.isEmpty()) {
 			this.currency = null;
 		}
 
 		// Period
-		this.period = (EPPFeePeriod) EPPUtil.decodeComp(aElement,
-				EPPFeeExtFactory.NS, EPPFeePeriod.ELM_NAME, EPPFeePeriod.class);
+		this.period = (EPPFeePeriod) EPPUtil.decodeComp(aElement, EPPFeeExtFactory.NS, EPPFeePeriod.ELM_NAME,
+		      EPPFeePeriod.class);
 
 		// Fees
-		this.fees = EPPUtil.decodeCompList(aElement, EPPFeeExtFactory.NS,
-				EPPFeeValue.ELM_LOCALNAME, EPPFeeValue.class);
+		this.fees = EPPUtil.decodeCompList(aElement, EPPFeeExtFactory.NS, EPPFeeValue.ELM_LOCALNAME, EPPFeeValue.class);
 
 		// Credits
-		this.credits = EPPUtil.decodeCompList(aElement, EPPFeeExtFactory.NS,
-				EPPFeeCredit.ELM_LOCALNAME, EPPFeeCredit.class);
+		this.credits = EPPUtil.decodeCompList(aElement, EPPFeeExtFactory.NS, EPPFeeCredit.ELM_LOCALNAME,
+		      EPPFeeCredit.class);
 
 		// Balance
-		this.balance = EPPUtil.decodeBigDecimal(aElement, EPPFeeExtFactory.NS,
-				ELM_BALANCE);
+		this.balance = EPPUtil.decodeBigDecimal(aElement, EPPFeeExtFactory.NS, ELM_BALANCE);
 
 		// Credit Limit
-		this.creditLimit = EPPUtil.decodeBigDecimal(aElement,
-				EPPFeeExtFactory.NS, ELM_CREDIT_LIMIT);
+		this.creditLimit = EPPUtil.decodeBigDecimal(aElement, EPPFeeExtFactory.NS, ELM_CREDIT_LIMIT);
 
 	}
 
@@ -524,7 +512,7 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * @return clone of concrete <code>EPPFeeTransformResult</code>
 	 * 
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPFeeTransformResult clone = (EPPFeeTransformResult) super.clone();
@@ -576,8 +564,8 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
@@ -588,15 +576,14 @@ public abstract class EPPFeeTransformResult implements EPPCodecComponent {
 	 * instance.
 	 * 
 	 * @param aObject
-	 *            Object to compare with.
+	 *           Object to compare with.
 	 * 
 	 * @return <code>true</code> if equal; <code>false</code> otherwise.
 	 */
 	public boolean equals(Object aObject) {
 		if (!(aObject instanceof EPPFeeTransformResult)) {
-			cat.error("EPPFeeTransformResult.equals(): "
-					+ aObject.getClass().getName()
-					+ " not EPPFeeTransformResult instance");
+			cat.error("EPPFeeTransformResult.equals(): " + aObject.getClass().getName()
+			      + " not EPPFeeTransformResult instance");
 
 			return false;
 		}
