@@ -25,6 +25,8 @@ import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.io.StringReader;
+import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Date;
 import java.util.List;
 import java.util.Properties;
@@ -41,16 +43,15 @@ import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 import javax.xml.transform.stream.StreamSource;
 
-import org.apache.log4j.FileAppender;
-import org.apache.log4j.Level;
-import org.apache.log4j.Logger;
-import org.apache.log4j.PatternLayout;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.DocumentFragment;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
 
 import com.verisign.epp.exception.EPPException;
+import com.verisign.epp.util.EPPEnv;
 import com.verisign.epp.util.EPPSchemaCachingParser;
 import com.verisign.epp.util.EPPXMLErrorHandler;
 import com.verisign.epp.util.Environment;
@@ -131,27 +132,6 @@ public class EPPCodecTst extends TestCase {
 
 		services.addElement(service);
 
-		/*
-		 * services.addElement(new
-		 * EPPService("urn:ietf:params:xml:ns:domain-1.0",null,0));
-		 * services.addElement(new
-		 * EPPService("urn:ietf:params:xml:ns:contact-1.0",null,0));
-		 * services.addElement(new
-		 * EPPService("urn:ietf:params:xml:ns:contact-5.0",null,0));
-		 */
-
-		// Vector extservices=new Vector();
-		// extservices.addElement(new
-		// EPPService(null,"http://custom/obj1ext-1.0",1));
-
-		/*
-		 * services.addElement(new EPPService("domain", "urn:iana:xml:ns:domain",
-		 * "urn:iana:xml:ns:domain domain-1.0.xsd")); services.addElement(new
-		 * EPPService("host", "urn:iana:xml:ns:host",
-		 * "urn:iana:xml:ns:host host.xsd")); services.addElement(new
-		 * EPPService("contact", "urn:iana:xml:ns:contact",
-		 * "urn:iana:xml:ns:contact contact.xsd"));
-		 */
 		Vector statements = new Vector();
 
 		// DCP Statement Element
@@ -319,10 +299,10 @@ public class EPPCodecTst extends TestCase {
 
 		responseStats = testEncodeDecode(theResponse);
 		System.out.println(responseStats);
-		
+
 		// Error response
 		theResponse = new EPPResponse(new EPPTransId("ABC-12345", "54321-XYZ"));
-		
+
 		theResult = new EPPResult(EPPResult.PARAM_VALUE_POLICY_ERROR);
 		theResult.addExtValue(new EPPExtValue("error reason"));
 		theResponse.setResult(theResult);
@@ -331,7 +311,6 @@ public class EPPCodecTst extends TestCase {
 
 		responseStats = testEncodeDecode(theResponse);
 		System.out.println(responseStats);
-		
 
 		printEnd("testResponse");
 	}
@@ -375,8 +354,10 @@ public class EPPCodecTst extends TestCase {
 	 */
 	private static class Test1Extension implements EPPCodecComponent {
 
+		public static final String NS = "urn:ietf:params:xml:ns:epp:test1";
+
 		public Element encode(Document aDocument) throws EPPEncodeException {
-			Element root = aDocument.createElementNS(EPPCodec.NS, "test1");
+			Element root = aDocument.createElementNS(EPPCodec.NS, NS);
 			return root;
 		}
 
@@ -396,7 +377,7 @@ public class EPPCodecTst extends TestCase {
 		 */
 		@Override
 		public String getNamespace() {
-			return "test1";
+			return NS;
 		}
 	}
 
@@ -404,12 +385,14 @@ public class EPPCodecTst extends TestCase {
 	 * A stubbed out test extension used for tests that simply add, remove, check
 	 * for existence and get an extension. This extension does not really encode
 	 * or decode XML, so it should not be used with
-	 * {@link EPPCodecTst#testEncodeDecode(EPPMessage)}.
+	 * {@code EPPCodecTst.testEncodeDecode(EPPMessage)}.
 	 */
 	private static class Test2Extension implements EPPCodecComponent {
 
+		public static final String NS = "http://www.verisign-grs.com/epp/test2";
+
 		public Element encode(Document aDocument) throws EPPEncodeException {
-			Element root = aDocument.createElementNS(EPPCodec.NS, "test2");
+			Element root = aDocument.createElementNS(EPPCodec.NS, NS);
 			return root;
 		}
 
@@ -429,13 +412,82 @@ public class EPPCodecTst extends TestCase {
 		 */
 		@Override
 		public String getNamespace() {
-			return "test2";
+			return NS;
 		}
 
 	}
 
 	/**
-	 * Unit test for using {@link EPPCommand#getExtension(Class, boolean)}.
+	 * A stubbed out test extension used for tests use of an unsupported XML
+	 * namespace. The namespace in this case does not include a supported suffix.
+	 */
+	private static class Test1UnsupportedNamespaceExtension implements EPPCodecComponent {
+
+		public static final String NS = "http://www.verisign-grs.com/epp/";
+
+		public Element encode(Document aDocument) throws EPPEncodeException {
+			Element root = aDocument.createElementNS(EPPCodec.NS, NS);
+			return root;
+		}
+
+		public void decode(Element aElement) throws EPPDecodeException {
+
+		}
+
+		public Object clone() throws CloneNotSupportedException {
+			return null;
+		}
+
+		/**
+		 * Returns the XML namespace associated with the
+		 * <code>EPPCodecComponent</code>.
+		 * 
+		 * @return XML namespace for the <code>EPPCodecComponent</code>.
+		 */
+		@Override
+		public String getNamespace() {
+			return NS;
+		}
+
+	}
+
+	/**
+	 * A stubbed out test extension used for tests use of an unsupported XML
+	 * namespace. The namespace in this case does not include a supported
+	 * separator.
+	 */
+	private static class Test2UnsupportedNamespaceExtension implements EPPCodecComponent {
+
+		public static final String NS = "invalid;namespace";
+
+		public Element encode(Document aDocument) throws EPPEncodeException {
+			Element root = aDocument.createElementNS(EPPCodec.NS, NS);
+			return root;
+		}
+
+		public void decode(Element aElement) throws EPPDecodeException {
+
+		}
+
+		public Object clone() throws CloneNotSupportedException {
+			return null;
+		}
+
+		/**
+		 * Returns the XML namespace associated with the
+		 * <code>EPPCodecComponent</code>.
+		 * 
+		 * @return XML namespace for the <code>EPPCodecComponent</code>.
+		 */
+		@Override
+		public String getNamespace() {
+			return NS;
+		}
+
+	}
+
+	/**
+	 * Unit test for using {@code EPPCommand.getExtension(Class, boolean)}.
 	 */
 	public void testCommandGetExtensionFailOnDuplicate() {
 		printStart("testCommandGetExtensionFailOnDuplicate");
@@ -494,10 +546,9 @@ public class EPPCodecTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of using
-	 * {@link EPPUtil#findDuplicateExtNamespaces(List)} and
-	 * the corresponding {@link EPPCommand#findDuplicateExtNamespaces()} and
-	 * {@link EPPResponse#findDuplicateExtNamespaces()}. Test the following:<br>
+	 * Unit test of using {code EPPUtil.findDuplicateExtNamespaces(List)} and
+	 * the corresponding {@code EPPCommand.findDuplicateExtNamespaces()} and
+	 * {@code EPPResponse.findDuplicateExtNamespaces()}. Test the following:<br>
 	 * <ol>
 	 * <li>Test that no duplicates are found
 	 * <li>Test that duplicates are found when there are a single set of
@@ -528,14 +579,14 @@ public class EPPCodecTst extends TestCase {
 		theDuplicateExtNamespaces = EPPUtil.findDuplicateExtNamespaces(theCommand.getExtensions());
 		Assert.assertNotNull(theDuplicateExtNamespaces);
 		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test1Extension.NS));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test2Extension.NS));
 
 		theDuplicateExtNamespaces = theCommand.findDuplicateExtNamespaces();
 		Assert.assertNotNull(theDuplicateExtNamespaces);
 		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test1Extension.NS));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test2Extension.NS));
 
 		// Third instances
 		theCommand.addExtension(new Test1Extension());
@@ -544,15 +595,15 @@ public class EPPCodecTst extends TestCase {
 		theDuplicateExtNamespaces = EPPUtil.findDuplicateExtNamespaces(theCommand.getExtensions());
 		Assert.assertNotNull(theDuplicateExtNamespaces);
 		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test1Extension.NS));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test2Extension.NS));
 
 		theDuplicateExtNamespaces = theCommand.findDuplicateExtNamespaces();
 		Assert.assertNotNull(theDuplicateExtNamespaces);
 		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
-		
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test1Extension.NS));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test2Extension.NS));
+
 		// Test EPPResponse
 		EPPResponse theResponse = new EPPResponse();
 		theResponse.addExtension(new Test1Extension());
@@ -563,14 +614,171 @@ public class EPPCodecTst extends TestCase {
 		theDuplicateExtNamespaces = theResponse.findDuplicateExtNamespaces();
 		Assert.assertNotNull(theDuplicateExtNamespaces);
 		Assert.assertEquals(2, theDuplicateExtNamespaces.size());
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test1"));
-		Assert.assertTrue(theDuplicateExtNamespaces.contains("test2"));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test1Extension.NS));
+		Assert.assertTrue(theDuplicateExtNamespaces.contains(Test2Extension.NS));
 
 		printEnd("testFindDuplicateExtNamespaces");
 	}
 
 	/**
-	 * Unit test for using {@link EPPResponse#getExtension(Class, boolean)}.
+	 * Unit test of using
+	 * {@code EPPUtil.findUnsupportedExtNamespaces(List, List)} and the
+	 * corresponding {@code EPPCommand.findUnsupportedExtNamespaces(List)} and
+	 * {@code EPPResponse.findUnsupportedExtNamespaces(List)}. Test the
+	 * following:<br>
+	 * <ol>
+	 * <li>Test that no unsupported extensions found
+	 * <li>Test that there is an unsupported extension.
+	 * <li>Test that all extensions are unsupported.
+	 * </ol>
+	 */
+	public void testFindUnsupportedExtNamespaces() {
+		printStart("testFindUnsupportedExtNamespaces");
+
+		EPPPollCmd theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		// Test that no unsupported extensions found
+		String[] theSupportedExtensionsArray = { Test1Extension.NS, Test2Extension.NS };
+		List<String> theSuppportedExtensionsList = Arrays.asList(theSupportedExtensionsArray);
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		Set<String> theUnsupportedExtNamespaces = EPPUtil.findUnsupportedExtNamespaces(theSuppportedExtensionsList,
+		      theCommand.getExtensions());
+		Assert.assertNull(theUnsupportedExtNamespaces);
+
+		theUnsupportedExtNamespaces = theCommand.findUnsupportedExtNamespaces(theSuppportedExtensionsList);
+		Assert.assertNull(theUnsupportedExtNamespaces);
+
+		// Test that one unsupported extension found
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+		theSuppportedExtensionsList = new ArrayList<String>();
+		theSuppportedExtensionsList.add(Test1Extension.NS);
+
+		theUnsupportedExtNamespaces = EPPUtil.findUnsupportedExtNamespaces(theSuppportedExtensionsList,
+		      theCommand.getExtensions());
+		Assert.assertNotNull(theUnsupportedExtNamespaces);
+		Assert.assertEquals(1, theUnsupportedExtNamespaces.size());
+		Assert.assertTrue(theUnsupportedExtNamespaces.contains(Test2Extension.NS));
+
+		theUnsupportedExtNamespaces = theCommand.findUnsupportedExtNamespaces(theSuppportedExtensionsList);
+		Assert.assertNotNull(theUnsupportedExtNamespaces);
+		Assert.assertEquals(1, theUnsupportedExtNamespaces.size());
+		Assert.assertTrue(theUnsupportedExtNamespaces.contains(Test2Extension.NS));
+
+		// Test that all extensions are unsupported.
+		EPPResponse theResponse = new EPPResponse();
+		theResponse.addExtension(new Test1Extension());
+		theResponse.addExtension(new Test2Extension());
+
+		theUnsupportedExtNamespaces = EPPUtil.findUnsupportedExtNamespaces(null, theResponse.getExtensions());
+		Assert.assertNotNull(theUnsupportedExtNamespaces);
+		Assert.assertEquals(2, theUnsupportedExtNamespaces.size());
+		Assert.assertTrue(theUnsupportedExtNamespaces.contains(Test1Extension.NS));
+		Assert.assertTrue(theUnsupportedExtNamespaces.contains(Test2Extension.NS));
+
+		theUnsupportedExtNamespaces = theResponse.findUnsupportedExtNamespaces(null);
+		Assert.assertNotNull(theUnsupportedExtNamespaces);
+		Assert.assertEquals(2, theUnsupportedExtNamespaces.size());
+		Assert.assertTrue(theUnsupportedExtNamespaces.contains(Test1Extension.NS));
+		Assert.assertTrue(theUnsupportedExtNamespaces.contains(Test2Extension.NS));
+
+		printEnd("testFindUnsupportedExtNamespaces");
+	}
+
+	/**
+	 * Unit test of using
+	 * {@code EPPUtil.findUnsupportedExtNamespaceSuffixes(List, List)} and the
+	 * corresponding {@code EPPCommand.findUnsupportedExtNamespaceSuffixes(List)}
+	 * and {@code EPPResponse.findUnsupportedExtNamespaceSuffixes(List)}. Test
+	 * the following:<br>
+	 * <ol>
+	 * <li>Test that no unsupported extensions found
+	 * <li>Test that there is an unsupported extension.
+	 * <li>Test that all extensions are unsupported.
+	 * <li>Test inclusion of an unsupported namespace.
+	 * </ol>
+	 */
+	public void testFindUnsupportedExtNamespaceSuffixes() {
+		printStart("testFindUnsupportedExtNamespaceSuffixes");
+
+		EPPPollCmd theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		// Test that no unsupported extensions found
+		String[] theSupportedExtensionsArray = { EPPUtil.namespaceToNamespaceSuffix(Test1Extension.NS),
+		      EPPUtil.namespaceToNamespaceSuffix(Test2Extension.NS) };
+		List<String> theSupportedExtensionsList = Arrays.asList(theSupportedExtensionsArray);
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		Set<String> theUnsupportedExtNamespaceSuffixes = EPPUtil
+		      .findUnsupportedExtNamespaceSuffixes(theSupportedExtensionsList, theCommand.getExtensions());
+		Assert.assertNull(theUnsupportedExtNamespaceSuffixes);
+
+		theUnsupportedExtNamespaceSuffixes = theCommand.findUnsupportedExtNamespaceSuffixes(theSupportedExtensionsList);
+		Assert.assertNull(theUnsupportedExtNamespaceSuffixes);
+
+		// Test that one unsupported extension found
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+		theSupportedExtensionsList = new ArrayList<String>();
+		theSupportedExtensionsList.add(EPPUtil.namespaceToNamespaceSuffix(Test1Extension.NS));
+
+		theUnsupportedExtNamespaceSuffixes = EPPUtil.findUnsupportedExtNamespaceSuffixes(theSupportedExtensionsList,
+		      theCommand.getExtensions());
+		Assert.assertNotNull(theUnsupportedExtNamespaceSuffixes);
+		Assert.assertEquals(1, theUnsupportedExtNamespaceSuffixes.size());
+		Assert.assertTrue(
+		      theUnsupportedExtNamespaceSuffixes.contains(EPPUtil.namespaceToNamespaceSuffix(Test2Extension.NS)));
+
+		theUnsupportedExtNamespaceSuffixes = theCommand.findUnsupportedExtNamespaceSuffixes(theSupportedExtensionsList);
+		Assert.assertNotNull(theUnsupportedExtNamespaceSuffixes);
+		Assert.assertEquals(1, theUnsupportedExtNamespaceSuffixes.size());
+		Assert.assertTrue(
+		      theUnsupportedExtNamespaceSuffixes.contains(EPPUtil.namespaceToNamespaceSuffix(Test2Extension.NS)));
+
+		// Test that all extensions are unsupported.
+		EPPResponse theResponse = new EPPResponse();
+		theResponse.addExtension(new Test1Extension());
+		theResponse.addExtension(new Test2Extension());
+
+		theUnsupportedExtNamespaceSuffixes = EPPUtil.findUnsupportedExtNamespaceSuffixes(null,
+		      theResponse.getExtensions());
+		Assert.assertNotNull(theUnsupportedExtNamespaceSuffixes);
+		Assert.assertEquals(2, theUnsupportedExtNamespaceSuffixes.size());
+		Assert.assertTrue(
+		      theUnsupportedExtNamespaceSuffixes.contains(EPPUtil.namespaceToNamespaceSuffix(Test1Extension.NS)));
+		Assert.assertTrue(
+		      theUnsupportedExtNamespaceSuffixes.contains(EPPUtil.namespaceToNamespaceSuffix(Test2Extension.NS)));
+
+		theUnsupportedExtNamespaceSuffixes = theResponse.findUnsupportedExtNamespaceSuffixes(null);
+		Assert.assertNotNull(theUnsupportedExtNamespaceSuffixes);
+		Assert.assertEquals(2, theUnsupportedExtNamespaceSuffixes.size());
+		Assert.assertTrue(
+		      theUnsupportedExtNamespaceSuffixes.contains(EPPUtil.namespaceToNamespaceSuffix(Test1Extension.NS)));
+		Assert.assertTrue(
+		      theUnsupportedExtNamespaceSuffixes.contains(EPPUtil.namespaceToNamespaceSuffix(Test2Extension.NS)));
+
+		// Test inclusion of an unsupported namespace, which will match the full
+		// namespace
+		theResponse = new EPPResponse();
+		theResponse.addExtension(new Test1UnsupportedNamespaceExtension());
+		theResponse.addExtension(new Test2UnsupportedNamespaceExtension());
+		theUnsupportedExtNamespaceSuffixes = EPPUtil.findUnsupportedExtNamespaceSuffixes(null,
+		      theResponse.getExtensions());
+		Assert.assertNotNull(theUnsupportedExtNamespaceSuffixes);
+		Assert.assertEquals(2, theUnsupportedExtNamespaceSuffixes.size());
+		Assert.assertTrue(theUnsupportedExtNamespaceSuffixes
+		      .contains(EPPUtil.namespaceToNamespaceSuffix(Test1UnsupportedNamespaceExtension.NS)));
+		Assert.assertTrue(theUnsupportedExtNamespaceSuffixes
+		      .contains(EPPUtil.namespaceToNamespaceSuffix(Test2UnsupportedNamespaceExtension.NS)));
+
+		printEnd("testFindUnsupportedExtNamespaceSuffixes");
+	}
+
+	/**
+	 * Unit test for using {code EPPResponse.getExtension(Class, boolean)}.
 	 */
 	public void testResponseGetExtensionFailOnDuplicate() {
 		printStart("testResponseGetExtensionFailOnDuplicate");
@@ -629,6 +837,144 @@ public class EPPCodecTst extends TestCase {
 		printEnd("testResponseGetExtensionFailOnDuplicate");
 	}
 
+	/**
+	 * Unit test of using {@code EPPUtil.testFindExtNamespaces(List, List)} and
+	 * the corresponding {@code EPPCommand.testFindExtNamespaces(List)} and
+	 * {@code EPPResponse.testFindExtNamespaces(List)}. Test the following:<br>
+	 * <ol>
+	 * <li>Test that it doesn't fail with no extensions.
+	 * <li>Test with many extensions.
+	 * <li>Test the filtering of extensions.
+	 * </ol>
+	 */
+	public void testFindExtNamespaces() {
+		printStart("testFindExtNamespaces");
+
+		// Test that it doesn't fail with no extensions.
+		EPPPollCmd theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		Set<String> theExtNamespaces = EPPUtil.findExtNamespaces(theCommand.getExtensions(), null);
+		Assert.assertEquals(0, theExtNamespaces.size());
+
+		// Test with many extensions.
+		theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		theExtNamespaces = EPPUtil.findExtNamespaces(theCommand.getExtensions(), null);
+		Assert.assertEquals(2, theExtNamespaces.size());
+		System.out.println("EPPUtil: Extension namespaces = " + theExtNamespaces);
+
+		theExtNamespaces = theCommand.findExtNamespaces(null);
+		Assert.assertEquals(2, theExtNamespaces.size());
+		System.out.println("EPPCommand: Extension namespaces = " + theExtNamespaces);
+
+		EPPResponse theResponse = new EPPResponse();
+		theResponse.addExtension(new Test1Extension());
+		theResponse.addExtension(new Test2Extension());
+
+		theExtNamespaces = theResponse.findExtNamespaces(null);
+		Assert.assertEquals(2, theExtNamespaces.size());
+		System.out.println("EPPResponse: Extension namespaces = " + theExtNamespaces);
+
+		// Test the filtering of extensions.
+		theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		theExtNamespaces = EPPUtil.findExtNamespaces(theCommand.getExtensions(), Arrays.asList(Test2Extension.NS));
+		Assert.assertEquals(1, theExtNamespaces.size());
+		System.out.println("EPPUtil Filtered: Extension namespaces = " + theExtNamespaces);
+
+		theExtNamespaces = theCommand.findExtNamespaces(Arrays.asList(Test1Extension.NS));
+		Assert.assertEquals(1, theExtNamespaces.size());
+		System.out.println("EPPCommand Filtered: Extension namespaces = " + theExtNamespaces);
+
+		theResponse = new EPPResponse();
+		theResponse.addExtension(new Test1Extension());
+		theResponse.addExtension(new Test2Extension());
+
+		theExtNamespaces = theResponse.findExtNamespaces(Arrays.asList(Test1Extension.NS, Test2Extension.NS));
+		Assert.assertEquals(0, theExtNamespaces.size());
+		System.out.println("EPPResponse Filtered: Extension namespaces = " + theExtNamespaces);
+
+		printEnd("testFindExtNamespaces");
+	}
+
+	/**
+	 * Unit test of using
+	 * {@code EPPUtil.testFindExtNamespaceSuffixes(List, List)} and the
+	 * corresponding {@code EPPCommand.testFindExtNamespaceSuffixes(List)} and
+	 * {@code EPPResponse.testFindExtNamespaceSuffixes(List)}. Test the
+	 * following:<br>
+	 * <ol>
+	 * <li>Test that it doesn't fail with no extensions.
+	 * <li>Test with many extensions.
+	 * <li>Test the filtering of extensions.
+	 * </ol>
+	 */
+	public void testFindExtNamespaceSuffixes() {
+		printStart("testFindExtNamespaceSuffixes");
+
+		// Test that it doesn't fail with no extensions.
+		EPPPollCmd theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		Set<String> theExtNamespaceSuffixes = EPPUtil.findExtNamespaceSuffixes(theCommand.getExtensions(), null);
+		Assert.assertEquals(0, theExtNamespaceSuffixes.size());
+
+		// Test with many extensions.
+		theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		theExtNamespaceSuffixes = EPPUtil.findExtNamespaceSuffixes(theCommand.getExtensions(), null);
+		Assert.assertEquals(2, theExtNamespaceSuffixes.size());
+		System.out.println("EPPUtil: Extension namespace suffixes = " + theExtNamespaceSuffixes);
+
+		theExtNamespaceSuffixes = theCommand.findExtNamespaceSuffixes(null);
+		Assert.assertEquals(2, theExtNamespaceSuffixes.size());
+		System.out.println("EPPCommand: Extension namespace suffixes = " + theExtNamespaceSuffixes);
+
+		EPPResponse theResponse = new EPPResponse();
+		theResponse.addExtension(new Test1Extension());
+		theResponse.addExtension(new Test2Extension());
+
+		theExtNamespaceSuffixes = theResponse.findExtNamespaceSuffixes(null);
+		Assert.assertEquals(2, theExtNamespaceSuffixes.size());
+		System.out.println("EPPResponse: Extension namespace suffixes = " + theExtNamespaceSuffixes);
+
+		// Test the filtering of extensions.
+		theCommand = new EPPPollCmd("ABC-12345", "req");
+
+		theCommand.addExtension(new Test1Extension());
+		theCommand.addExtension(new Test2Extension());
+
+		theExtNamespaceSuffixes = EPPUtil.findExtNamespaceSuffixes(theCommand.getExtensions(),
+		      Arrays.asList(EPPUtil.namespaceToNamespaceSuffix(Test2Extension.NS)));
+		Assert.assertEquals(1, theExtNamespaceSuffixes.size());
+		System.out.println("EPPUtil Filtered: Extension namespace suffixes = " + theExtNamespaceSuffixes);
+
+		theExtNamespaceSuffixes = theCommand
+		      .findExtNamespaceSuffixes(Arrays.asList(EPPUtil.namespaceToNamespaceSuffix(Test1Extension.NS)));
+		Assert.assertEquals(1, theExtNamespaceSuffixes.size());
+		System.out.println("EPPCommand Filtered: Extension namespace suffixes = " + theExtNamespaceSuffixes);
+
+		theResponse = new EPPResponse();
+		theResponse.addExtension(new Test1Extension());
+		theResponse.addExtension(new Test2Extension());
+
+		theExtNamespaceSuffixes = theResponse
+		      .findExtNamespaceSuffixes(Arrays.asList(EPPUtil.namespaceToNamespaceSuffix(Test1Extension.NS),
+		            EPPUtil.namespaceToNamespaceSuffix(Test2Extension.NS)));
+		Assert.assertEquals(0, theExtNamespaceSuffixes.size());
+		System.out.println("EPPResponse Filtered: Extension namespace suffixes = " + theExtNamespaceSuffixes);
+
+		printEnd("testFindExtNamespaceSuffixes");
+	}
+
 	/**
 	 * JUNIT <code>setUp</code> method, which sets the default client Id to
 	 * "theRegistrar".
@@ -666,19 +1012,6 @@ public class EPPCodecTst extends TestCase {
 			theProps.setProperty("EPP.FullSchemaChecking", System.getProperty("fullschemachecking", "true"));
 			Environment.setProperties(theProps);
 
-			// Initialize logger
-			try {
-				Logger root = Logger.getRootLogger();
-				root.setLevel(Level.DEBUG);
-				root.addAppender(new FileAppender(new PatternLayout(PatternLayout.TTCC_CONVERSION_PATTERN),
-				      System.getProperty("logfile", "epp.log"), true));
-			}
-			catch (IOException ex) {
-				System.err.println("IOException initializing log4j");
-				ex.printStackTrace();
-				System.exit(1);
-			}
-
 			initialized = true;
 		}
 	}
@@ -776,8 +1109,8 @@ public class EPPCodecTst extends TestCase {
 	}
 
 	/**
-	 * Tests the encoding and decoding of an {@link EPPMessage}. If there is an
-	 * error with encoding or decoding the message, an {@link EPPException} will
+	 * Tests the encoding and decoding of an {@code EPPMessage}. If there is an
+	 * error with encoding or decoding the message, an {@code EPPException} will
 	 * be thrown.
 	 * 
 	 * @param aMessage
@@ -1020,7 +1353,9 @@ public class EPPCodecTst extends TestCase {
 	 * <code>EPPPollCmd</code> is <code>EPPResponse</code>. <br>
 	 * This test will be invoked by JUNIT, since it is prefixed with "test" and
 	 * is a public method.
-	 * @throws ParserConfigurationException Error creating DOM document.
+	 * 
+	 * @throws ParserConfigurationException
+	 *            Error creating DOM document.
 	 */
 	public void testPoll() throws ParserConfigurationException {
 		printStart("testPoll");
@@ -1090,8 +1425,8 @@ public class EPPCodecTst extends TestCase {
 
 	/**
 	 * Test the encoding and decoding of the <code>timeInstantFormat</code>
-	 * supported by the {@link EPPUtil#encodeTimeInstant(Date)} and
-	 * {@link EPPUtil#decodeTimeInstant(String)}.
+	 * supported by the {@code EPPUtil.encodeTimeInstant(Date)} and
+	 * {@code EPPUtil.decodeTimeInstant(String)}.
 	 */
 	public void testTimeInstantFormat() {
 		printStart("testTimeInstantFormat");
