@@ -21,27 +21,26 @@ package com.verisign.epp.codec.gen;
 
 // Log4j Imports
 import java.util.Iterator;
+import java.util.List;
 import java.util.Set;
 import java.util.Vector;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
-import com.verisign.epp.util.EPPCatFactory;
-
 /**
  * Represents an EPP command that is sent by an EPP Client and received by an
- * EPP Server. An <code>EPPCommand</code> can be encoded and decoded by
- * <code>EPPCodec</code>. <br>
+ * EPP Server. An {@code EPPCommand} can be encoded and decoded by
+ * {@code EPPCodec}. <br>
  * <br>
- * Every EPP command must extend <code>EPPCommand</code> and implement the
- * Template Method Design Pattern <code>doGenEncode</code> and
- * <code>doGenDecode</code> methods. An <code>EPPCommand</code> client will call
- * <code>encode</code> or <code>decode</code>, which in turn will call
- * <code>doGenEncode</code> or <code>doGenDecode</code>, respectively. There is
- * one derived <code>EPPCommand</code> for each type of command defined in the
- * general EPP Specification.
+ * Every EPP command must extend {@code EPPCommand} and implement the Template
+ * Method Design Pattern {@code doGenEncode} and {@code doGenDecode} methods. An
+ * {@code EPPCommand} client will call {@code encode} or {@code decode}, which
+ * in turn will call {@code doGenEncode} or {@code doGenDecode}, respectively.
+ * There is one derived {@code EPPCommand} for each type of command defined in
+ * the general EPP Specification.
  */
 public abstract class EPPCommand implements EPPMessage {
 	/** command type associated with the general EPP &lt;login&gt; command. */
@@ -92,7 +91,7 @@ public abstract class EPPCommand implements EPPMessage {
 	/** command request operation associated with a &lt;transfer&gt; command. */
 	public final static String OP_REQUEST = "request";
 
-	/** XML root tag name for <code>EPPCommand</code>. */
+	/** XML root tag name for {@code EPPCommand}. */
 	final static String ELM_NAME = "command";
 
 	/** XML tag name for transId. */
@@ -101,11 +100,11 @@ public abstract class EPPCommand implements EPPMessage {
 	/** XML tag name for unspecified extension element. */
 	private static final String ELM_EXTENSION = "extension";
 
-	/** XML tag name for the <code>op</code> XML attribute. */
+	/** XML tag name for the {@code op} XML attribute. */
 	final static String ATT_OP = "op";
 
-	/** Log4j category for logging */
-	private static Logger cat = Logger.getLogger(EPPCommand.class.getName(), EPPCatFactory.getInstance().getFactory());
+	/** Category for logging */
+	private static Logger cat = LoggerFactory.getLogger(EPPCommand.class);
 
 	/** Client Transaction id associated with the command */
 	protected String transId = null;
@@ -113,19 +112,18 @@ public abstract class EPPCommand implements EPPMessage {
 	/**
 	 * Extension objects associated with the command. The extension object is
 	 * associated with a unique XML Namespace, XML Schema, and can be any simple
-	 * or complex object that implements the <code>EPPCodecComponent</code>
-	 * interface.
+	 * or complex object that implements the {@code EPPCodecComponent} interface.
 	 */
 	protected Vector extensions = null;
 
 	/**
-	 * Allocates a new <code>EPPCommand</code> with default attribute values. The
+	 * Allocates a new {@code EPPCommand} with default attribute values. The
 	 * defaults include the following: <br>
 	 * <br>
 	 *
 	 * <ul>
-	 * <li>transaction id is set to <code>null</code>. This attribute can be set
-	 * using <code>setTransId</code> before invoking <code>encode</code>.</li>
+	 * <li>transaction id is set to {@code null}. This attribute can be set using
+	 * {@code setTransId} before invoking {@code encode}.</li>
 	 * </ul>
 	 *
 	 * <br>
@@ -136,7 +134,7 @@ public abstract class EPPCommand implements EPPMessage {
 	}
 
 	/**
-	 * Allocates a new <code>EPPCommand</code> setting the client transaction id.
+	 * Allocates a new {@code EPPCommand} setting the client transaction id.
 	 *
 	 * @param aTransId
 	 *           Client Transaction id associated with the command.
@@ -148,10 +146,9 @@ public abstract class EPPCommand implements EPPMessage {
 
 	/**
 	 * Does the command have a client transaction id? If so, the transaction id
-	 * can be retrieved with a call to <code>getTransId</code>.
+	 * can be retrieved with a call to {@code getTransId}.
 	 *
-	 * @return <code>true</code> if this is a transaction id; <code>false</code>
-	 *         otherwise.
+	 * @return {@code true} if this is a transaction id; {@code false} otherwise.
 	 */
 	public boolean hasTransId() {
 		if (this.transId != null) {
@@ -163,10 +160,9 @@ public abstract class EPPCommand implements EPPMessage {
 	}
 
 	/**
-	 * Gets the Client Transaction Id associated with the <code>EPPCommand</code>
-	 * .
+	 * Gets the Client Transaction Id associated with the {@code EPPCommand} .
 	 *
-	 * @return <code>String</code> instance if defined; null otherwise.
+	 * @return {@code String} instance if defined; null otherwise.
 	 */
 	public String getTransId() {
 		return this.transId;
@@ -176,34 +172,34 @@ public abstract class EPPCommand implements EPPMessage {
 	 * Sets the Client Transaction Id associated with the EPPCommand.
 	 *
 	 * @param aTransId
-	 *           Client Transaction Id <code>String</code>
+	 *           Client Transaction Id {@code String}
 	 */
 	public void setTransId(String aTransId) {
 		this.transId = aTransId;
 	}
 
 	/**
-	 * Gets the EPP namespace associated with the <code>EPPCommand</code>.
+	 * Gets the EPP namespace associated with the {@code EPPCommand}.
 	 *
-	 * @return Namespace URI associated with the <code>EPPCommand</code>.
+	 * @return Namespace URI associated with the {@code EPPCommand}.
 	 */
 	@Override
 	abstract public String getNamespace();
 
 	/**
-	 * Gets command type of the <code>EPPCommand</code>. Each command is
-	 * associated with a single command type equal to one of the
-	 * <code>EPPCommand.TYPE_</code> constants and optionally a command operation
-	 * equal to one of the <code>EPPCommand.OP_</code> constants.
+	 * Gets command type of the {@code EPPCommand}. Each command is associated
+	 * with a single command type equal to one of the {@code EPPCommand.TYPE_}
+	 * constants and optionally a command operation equal to one of the
+	 * {@code EPPCommand.OP_} constants.
 	 *
-	 * @return Command type <code>String</code> (<code>EPPCommand.TYPE_</code>)
+	 * @return Command type {@code String} ({@code EPPCommand.TYPE_})
 	 */
 	public abstract String getType();
 
 	/**
-	 * Gets the string operation of the concrete <code>EPPCommand</code>. The
-	 * type should be equal to one of the <code>EPPCommand.OP_</code> constants,
-	 * or null if there is no operation.
+	 * Gets the string operation of the concrete {@code EPPCommand}. The type
+	 * should be equal to one of the {@code EPPCommand.OP_} constants, or null if
+	 * there is no operation.
 	 *
 	 * @return Operation of concrete EPPCommand if exists; null otherwise.
 	 */
@@ -214,13 +210,13 @@ public abstract class EPPCommand implements EPPMessage {
 	/**
 	 * Does the command have a command extension object of a specified class? If
 	 * so, the command extension object can be retrieved with a call to
-	 * <code>getExtensions(Class)</code>.
+	 * {@code getExtensions(Class)}.
 	 *
 	 * @param aExtensionClass
 	 *           DOCUMENT ME!
 	 *
-	 * @return <code>true</code> if the extension object exists;
-	 *         <code>false</code> otherwise.
+	 * @return {@code true} if the extension object exists; {@code false}
+	 *         otherwise.
 	 */
 	public boolean hasExtension(Class aExtensionClass) {
 		if (getExtension(aExtensionClass) != null) {
@@ -235,16 +231,15 @@ public abstract class EPPCommand implements EPPMessage {
 	 * Gets the command extension object with the specified class. The extension
 	 * object is an unspecified element in the EPP Specifications. To create an
 	 * extension object, an XML Schema for the extension object must exist with a
-	 * unique XML Namespace. A custom <code>EPPExtensionFactory</code> must be
-	 * created for the extension, which returns an instance of
-	 * <code>EPPCodecComponent</code> for an instance of an extension object in
-	 * the EPP Command.
+	 * unique XML Namespace. A custom {@code EPPExtensionFactory} must be created
+	 * for the extension, which returns an instance of {@code EPPCodecComponent}
+	 * for an instance of an extension object in the EPP Command.
 	 *
 	 * @param aExtensionClass
 	 *           of desired extension
 	 *
-	 * @return Concrete <code>EPPCodecComponent</code> associated with the
-	 *         command if exists; <code>null</code> otherwise.
+	 * @return Concrete {@code EPPCodecComponent} associated with the command if
+	 *         exists; {@code null} otherwise.
 	 */
 	public EPPCodecComponent getExtension(Class aExtensionClass) {
 		if (this.extensions == null) {
@@ -269,19 +264,18 @@ public abstract class EPPCommand implements EPPMessage {
 	 * to fail when a duplicate extension is found. The extension object is an
 	 * unspecified element in the EPP Specifications. To create an extension
 	 * object, an XML Schema for the extension object must exist with a unique
-	 * XML Namespace. A custom <code>EPPExtensionFactory</code> must be created
-	 * for the extension, which returns an instance of
-	 * <code>EPPCodecComponent</code> for an instance of an extension object in
-	 * the <code>EPPCommand</code>.
+	 * XML Namespace. A custom {@code EPPExtensionFactory} must be created for
+	 * the extension, which returns an instance of {@code EPPCodecComponent} for
+	 * an instance of an extension object in the {@code EPPCommand}.
 	 *
 	 * @param aExtensionClass
-	 *           <code>Class</code> of desired extension
+	 *           {@code Class} of desired extension
 	 * @param aFailOnDuplicate
-	 *           Throw {@link EPPDuplicateExtensionException} if
-	 *           <code>true</code> and a duplicate extension is found
+	 *           Throw {@link EPPDuplicateExtensionException} if {@code true} and
+	 *           a duplicate extension is found
 	 *
-	 * @return Concrete <code>EPPCodecComponent</code> associated with the
-	 *         command if exists; <code>null</code> otherwise.
+	 * @return Concrete {@code EPPCodecComponent} associated with the command if
+	 *         exists; {@code null} otherwise.
 	 *
 	 * @exception EPPDuplicateExtensionException
 	 *               If a duplicate extension is found with the extension
@@ -354,11 +348,10 @@ public abstract class EPPCommand implements EPPMessage {
 
 	/**
 	 * Does the command have a command extension objects? If so, the command
-	 * extension objects can be retrieved with a call to
-	 * <code>getExtensions</code>.
+	 * extension objects can be retrieved with a call to {@code getExtensions}.
 	 *
-	 * @return <code>true</code> if there are extension objects;
-	 *         <code>false</code> otherwise.
+	 * @return {@code true} if there are extension objects; {@code false}
+	 *         otherwise.
 	 */
 	public boolean hasExtensions() {
 		if (this.extensions != null && !this.extensions.isEmpty()) {
@@ -373,13 +366,12 @@ public abstract class EPPCommand implements EPPMessage {
 	 * Gets the command extensions. The extension objects are an unspecified
 	 * elements in the EPP Specification. To create an extension object, an XML
 	 * Schema for the extension object must exist with a unique XML Namespace. A
-	 * custom <code>EPPExtensionFactory</code> must be created for the extension,
-	 * which returns an instance of <code>EPPCodecComponent</code> for an
-	 * instance of an extension object in the EPP Command.
+	 * custom {@code EPPExtensionFactory} must be created for the extension,
+	 * which returns an instance of {@code EPPCodecComponent} for an instance of
+	 * an extension object in the EPP Command.
 	 *
-	 * @return <code>Vector</code> of concrete <code>EPPCodecComponent</code>
-	 *         associated with the command if exists; <code>null</code>
-	 *         otherwise.
+	 * @return {@code Vector} of concrete {@code EPPCodecComponent} associated
+	 *         with the command if exists; {@code null} otherwise.
 	 */
 	public Vector getExtensions() {
 		return this.extensions;
@@ -409,7 +401,68 @@ public abstract class EPPCommand implements EPPMessage {
 	}
 
 	/**
-	 * encode <code>EPPCommand</code> into a DOM element tree. The &lt;command&gt;
+	 * Find the set of unsupported EPP extension XML namespaces based the passed
+	 * in supported extension XML namespaces and on the list of EPP extensions
+	 * set in the command.
+	 * 
+	 * @param aSupportedExtNamespaces
+	 *           List of EPP extensions to scan for unsupported XML namespaces.
+	 *           Pass {@code null} for no supported extensions.
+	 * 
+	 * @return {@link Set} of unsupported EPP extension XML namespaces;
+	 *         {@code null} otherwise.
+	 */
+	public Set<String> findUnsupportedExtNamespaces(List<String> aSupportedExtNamespaces) {
+		return EPPUtil.findUnsupportedExtNamespaces(aSupportedExtNamespaces, this.extensions);
+	}
+
+	/**
+	 * Find the set of unsupported EPP extensions based on passing the list of
+	 * supported extension XML namespace suffixes and the list of EPP extensions
+	 * set in the command.
+	 * 
+	 * @param aSupportedExtNamespaceSuffixes
+	 *           List of EPP extensions to scan for unsupported XML namespace
+	 *           suffixes. Pass {@code null} for no supported extensions.
+	 * 
+	 * @return {@link Set} of unsupported EPP extension XML namespace suffixes;
+	 *         {@code null} otherwise.
+	 */
+	public Set<String> findUnsupportedExtNamespaceSuffixes(List<String> aSupportedExtNamespaceSuffixes) {
+		return EPPUtil.findUnsupportedExtNamespaceSuffixes(aSupportedExtNamespaceSuffixes, this.extensions);
+	}
+
+	/**
+	 * Find the set of unique EPP extension XML namespaces based on the list of
+	 * EPP extensions set in the command.
+	 * 
+	 * @param aFilterExtNamespaces
+	 *           Filter extension namespaces from the returned set. Set to
+	 *           {@code null} for no filtering.
+	 * 
+	 * @return {@link Set} of unique EPP extension XML namespaces.
+	 */
+	public Set<String> findExtNamespaces(List<String> aFilterExtNamespaces) {
+		return EPPUtil.findExtNamespaces(this.extensions, aFilterExtNamespaces);
+	}
+
+	/**
+	 * Find the set of unique EPP extension XML namespace suffixes based on the
+	 * list of EPP extensions set in the command and the optional use of a list
+	 * of XML namespace suffixes to filter.
+	 * 
+	 * @param aFilterExtNamespaceSuffixes
+	 *           Filter extension namespace suffixes from the returned set. Set
+	 *           to {@code null} for no filtering.
+	 * 
+	 * @return {@link Set} of unique EPP extension XML namespace suffixes.
+	 */
+	public Set<String> findExtNamespaceSuffixes(List<String> aFilterExtNamespaceSuffixes) {
+		return EPPUtil.findExtNamespaceSuffixes(this.extensions, aFilterExtNamespaceSuffixes);
+	}
+
+	/**
+	 * encode {@code EPPCommand} into a DOM element tree. The &lt;command&gt;
 	 * element is created and the attribute nodes are appending as children. This
 	 * method is a <i>Template Method</i> in the Template Method Design Pattern.
 	 *
@@ -456,9 +509,9 @@ public abstract class EPPCommand implements EPPMessage {
 	}
 
 	/**
-	 * decode <code>EPPCommand</code> from a DOM element tree. The "command"
-	 * element needs to be the value of the <code>aElement</code> argument. This
-	 * method is a <i>Template Method</i> in the Template Method Design Pattern.
+	 * decode {@code EPPCommand} from a DOM element tree. The "command" element
+	 * needs to be the value of the {@code aElement} argument. This method is a
+	 * <i>Template Method</i> in the Template Method Design Pattern.
 	 *
 	 * @param aElement
 	 *           &lt;command&gt; root element tree.
@@ -515,10 +568,10 @@ public abstract class EPPCommand implements EPPMessage {
 	}
 
 	/**
-	 * implements a deep <code>EPPCommand</code> compare.
+	 * implements a deep {@code EPPCommand} compare.
 	 *
 	 * @param aObject
-	 *           <code>EPPCommand</code> instance to compare with
+	 *           {@code EPPCommand} instance to compare with
 	 *
 	 * @return DOCUMENT ME!
 	 */
@@ -540,9 +593,9 @@ public abstract class EPPCommand implements EPPMessage {
 	}
 
 	/**
-	 * Clone <code>EPPCommand</code>.
+	 * Clone {@code EPPCommand}.
 	 *
-	 * @return clone of <code>EPPCommand</code>
+	 * @return clone of {@code EPPCommand}
 	 *
 	 * @exception CloneNotSupportedException
 	 *               standard Object.clone exception
@@ -566,11 +619,11 @@ public abstract class EPPCommand implements EPPMessage {
 	} // End EPPCommand.clone()
 
 	/**
-	 * Implementation of <code>Object.toString</code>, which will result in an
-	 * indented XML <code>String</code> representation of the concrete
-	 * <code>EPPCodecComponent</code>.
+	 * Implementation of {@code Object.toString}, which will result in an
+	 * indented XML {@code String} representation of the concrete
+	 * {@code EPPCodecComponent}.
 	 *
-	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 * @return Indented XML {@code String} if successful; {@code ERROR}
 	 *         otherwise.
 	 */
 	@Override
@@ -579,10 +632,10 @@ public abstract class EPPCommand implements EPPMessage {
 	}
 
 	/**
-	 * Encodes the atributes of a general extension of <code>EPPCommand</code>.
-	 * An example of a general extension is <code>EPPCreateCmd</code>.
-	 * <code>encode</code> is a <i>Template Method</i> and this method is a
-	 * <i>Primitive Operation</i> within the Template Method Design Pattern.
+	 * Encodes the atributes of a general extension of {@code EPPCommand}. An
+	 * example of a general extension is {@code EPPCreateCmd}. {@code encode} is
+	 * a <i>Template Method</i> and this method is a <i>Primitive Operation</i>
+	 * within the Template Method Design Pattern.
 	 *
 	 * @param aDocument
 	 *           DOM document used as a factory of DOM objects.
@@ -595,10 +648,10 @@ public abstract class EPPCommand implements EPPMessage {
 	protected abstract Element doGenEncode(Document aDocument) throws EPPEncodeException;
 
 	/**
-	 * Decodes the atributes of a general extension of <code>EPPCommand</code>.
-	 * An example of a general extension is <code>EPPCreateCmd</code>.
-	 * <code>decode</code> is a <i>Template Method</i> and this method is a
-	 * <i>Primitive Operation</i> within the Template Method Design Pattern.
+	 * Decodes the atributes of a general extension of {@code EPPCommand}. An
+	 * example of a general extension is {@code EPPCreateCmd}. {@code decode} is
+	 * a <i>Template Method</i> and this method is a <i>Primitive Operation</i>
+	 * within the Template Method Design Pattern.
 	 *
 	 * @param aElement
 	 *           root DOM element associated with instance
