@@ -19,23 +19,23 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
  ***********************************************************/
 package com.verisign.epp.codec.gen;
 
-// Log4J Imports
 import java.util.Enumeration;
 import java.util.Vector;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.NodeList;
 
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * The EPP &lt;login&gt; command is used to establish a session with an EPP
  * server in response to a greeting issued by the server. A &lt;login&gt;
  * command MUST be sent to a server before any other EPP command to establish an
  * ongoing session. A server operator MAY limit the number of failed login
- * attempts N, 1 &lt= N &lt= infinity, after which a login failure results in
+ * attempts N, 1 &lt;= N &lt;= infinity, after which a login failure results in
  * the connection to the server (if a connection exists) being closed. <br>
  * A client identifier and initial password MUST be created on the server before
  * a client can successfully complete a &lt;login&gt; command. The client
@@ -47,42 +47,36 @@ import com.verisign.epp.util.EPPCatFactory;
  * <br>
  * 
  * <ul>
- * <li>
- * A &ltclID&gt element that contains the client identifier assigned to the
- * client by the server.</li>
- * <li>
- * A &ltpw&gt element that contains the client's plain text password. The value
- * of this element is case sensitive.</li>
- * <li>
- * An OPTIONAL &ltnewPW&gt element that contains a new plain text password to be
- * assigned to the client for use with subsequent &ltlogin&gt commands. The
+ * <li>A &lt;clID&gt; element that contains the client identifier assigned to
+ * the client by the server.</li>
+ * <li>A &lt;pw&gt; element that contains the client's plain text password. The
  * value of this element is case sensitive.</li>
+ * <li>An OPTIONAL &lt;newPW&gt; element that contains a new plain text password
+ * to be assigned to the client for use with subsequent &lt;login&gt; commands.
+ * The value of this element is case sensitive.</li>
  * </ul>
  * 
  * <br>
  * 
  * <ul>
- * <li>
- * An &ltoptions&gt element that contains the following child elements:</li>
- * <li>
- * A &ltversion&gt element that contains the protocol version to be used for the
- * command or ongoing server session.</li>
- * <li>
- * A &ltlang&gt element that contains the text response language to be used for
- * the command or ongoing server session commands.</li>
+ * <li>An &lt;options&gt; element that contains the following child
+ * elements:</li>
+ * <li>A &lt;version&gt; element that contains the protocol version to be used
+ * for the command or ongoing server session.</li>
+ * <li>A &lt;lang&gt; element that contains the text response language to be
+ * used for the command or ongoing server session commands.</li>
  * </ul>
  * 
  * <br>
- * The values of the &ltversion&gt and &ltlang&gt elements MUST exactly match
- * one of the values presented in the EPP greeting. <br>
+ * The values of the &lt;version&gt; and &lt;lang&gt; elements MUST exactly
+ * match one of the values presented in the EPP greeting. <br>
  * 
  * <ul>
- * <li>
- * A &ltsvcs&gt element that contains one or more &ltobjURI&gt elements that
- * contain namespace URIs representing the objects to be managed during the
- * session. The &ltsvcs&gt element MAY contain an OPTIONAL &ltsvcExtension&gt
- * element that contains one or more &ltextURI&gt elements that identify object
- * extensions to be used during the session.</li>
+ * <li>A &lt;svcs&gt; element that contains one or more &lt;objURI&gt; elements
+ * that contain namespace URIs representing the objects to be managed during the
+ * session. The &lt;svcs&gt; element MAY contain an OPTIONAL
+ * &lt;svcExtension&gt; element that contains one or more &lt;extURI&gt;
+ * elements that identify object extensions to be used during the session.</li>
  * </ul>
  * 
  * <br>
@@ -100,33 +94,33 @@ import com.verisign.epp.util.EPPCatFactory;
  * @see com.verisign.epp.codec.gen.EPPFactory
  */
 public class EPPLoginCmd extends EPPCommand {
-	/** XML root tag name for <code>EPPLoginCmd</code>. */
+	/** XML root tag name for {@code EPPLoginCmd}. */
 	final static String ELM_NAME = "login";
 
-	/** XML tag name for the <code>clientId</code> attribute. */
+	/** XML tag name for the {@code clientId} attribute. */
 	private final static String ELM_CLIENT_ID = "clID";
 
-	/** XML tag name for the <code>password</code> attribute. */
+	/** XML tag name for the {@code password} attribute. */
 	private final static String ELM_PASSWORD = "pw";
 
-	/** XML tag name for the <code>newPassword</code> attribute. */
+	/** XML tag name for the {@code newPassword} attribute. */
 	private final static String ELM_NEW_PASSWORD = "newPW";
 
 	/** XML tag name for the credential options. */
 	private final static String ELM_OPTIONS = "options";
 
-	/** XML tag name for the <code>services</code> attribute. */
+	/** XML tag name for the {@code services} attribute. */
 	private final static String ELM_SERVICES = "svcs";
 
-	/** XML tag name for the <code>services</code> attribute. */
+	/** XML tag name for the {@code services} attribute. */
 	private final static String ELM_EXT_SERVICES = "svcExtension";
 
-	/** XML tag name for the <code>extservices</code> attribute. */
+	/** XML tag name for the {@code extservices} attribute. */
 	private final static String ELM_EXT_URI = "extURI";
 
 	/** Class logger */
-	private static final Logger cat = Logger.getLogger(EPPLoginCmd.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPLoginCmd.class);
+	      
 
 	/** Client login id */
 	private String clientId = null;
@@ -151,34 +145,29 @@ public class EPPLoginCmd extends EPPCommand {
 	 */
 	private Vector extservices;
 
-	/** XML tag name for the <code>version</code> attribute. */
+	/** XML tag name for the {@code version} attribute. */
 	private final String ELM_VERSION = "version";
 
-	/** XML tag name for the <code>lang</code> attribute. */
+	/** XML tag name for the {@code lang} attribute. */
 	private final String ELM_LANG = "lang";
 
 	/**
-	 * Allocates a new <code>EPPLoginCmd</code> with default attribute values.
-	 * the defaults include the following: <br>
+	 * Allocates a new {@code EPPLoginCmd} with default attribute values. the
+	 * defaults include the following: <br>
 	 * <br>
 	 * 
 	 * <ul>
-	 * <li>
-	 * transaction id is set to <code>null</code>.</li>
-	 * <li>
-	 * client id is set to <code>null</code></li>
-	 * <li>
-	 * password is set to <code>null</code></li>
-	 * <li>
-	 * new password is set to <code>null</code></li>
-	 * <li>
-	 * services is initialized based on the <code>EPPFactory</code>
+	 * <li>transaction id is set to {@code null}.</li>
+	 * <li>client id is set to {@code null}</li>
+	 * <li>password is set to {@code null}</li>
+	 * <li>new password is set to {@code null}</li>
+	 * <li>services is initialized based on the {@code EPPFactory}
 	 * configuration.</li>
 	 * </ul>
 	 * 
 	 * <br>
 	 * The client id, password, and transaction id must be set before invoking
-	 * <code>encode</code>.
+	 * {@code encode}.
 	 */
 	public EPPLoginCmd() {
 		services = EPPFactory.getInstance().getServices();
@@ -186,25 +175,23 @@ public class EPPLoginCmd extends EPPCommand {
 	}
 
 	/**
-	 * Allocates a new <code>EPPLoginCmd</code> with the required attributes.
-	 * The other attributes are initialized as follows: <br>
+	 * Allocates a new {@code EPPLoginCmd} with the required attributes. The
+	 * other attributes are initialized as follows: <br>
 	 * <br>
 	 * 
 	 * <ul>
-	 * <li>
-	 * new password is set to <code>null</code></li>
-	 * <li>
-	 * services is initialized based on the <code>EPPFactory</code>
+	 * <li>new password is set to {@code null}</li>
+	 * <li>services is initialized based on the {@code EPPFactory}
 	 * configuration.</li>
 	 * </ul>
 	 * 
 	 *
 	 * @param aTransId
-	 *            transaction id of the command.
+	 *           transaction id of the command.
 	 * @param aClientId
-	 *            Client login id
+	 *           Client login id
 	 * @param aPassword
-	 *            Client password
+	 *           Client password
 	 */
 	public EPPLoginCmd(String aTransId, String aClientId, String aPassword) {
 		super(aTransId);
@@ -216,21 +203,20 @@ public class EPPLoginCmd extends EPPCommand {
 	}
 
 	/**
-	 * Allocates a new <code>EPPLoginCmd</code> with the required attributes and
-	 * the optional new password attribute. The services is initialized based on
-	 * the <code>EPPFactory</code> configuration.
+	 * Allocates a new {@code EPPLoginCmd} with the required attributes and the
+	 * optional new password attribute. The services is initialized based on the
+	 * {@code EPPFactory} configuration.
 	 *
 	 * @param aTransId
-	 *            transaction id of the command.
+	 *           transaction id of the command.
 	 * @param aClientId
-	 *            Client login id
+	 *           Client login id
 	 * @param aPassword
-	 *            Client password
+	 *           Client password
 	 * @param aNewPassword
-	 *            New client password
+	 *           New client password
 	 */
-	public EPPLoginCmd(String aTransId, String aClientId, String aPassword,
-			String aNewPassword) {
+	public EPPLoginCmd(String aTransId, String aClientId, String aPassword, String aNewPassword) {
 		super(aTransId);
 
 		services = EPPFactory.getInstance().getServices();
@@ -241,7 +227,7 @@ public class EPPLoginCmd extends EPPCommand {
 	}
 
 	/**
-	 * Gets the EPP command Namespace associated with <code>EPPLoginCmd</code>.
+	 * Gets the EPP command Namespace associated with {@code EPPLoginCmd}.
 	 *
 	 * @return EPPCodec.NS
 	 */
@@ -250,9 +236,9 @@ public class EPPLoginCmd extends EPPCommand {
 	}
 
 	/**
-	 * Gets the EPP command type associated with <code>EPPLoginCmd</code>.
+	 * Gets the EPP command type associated with {@code EPPLoginCmd}.
 	 *
-	 * @return <code>EPPCommand.TYPE_LOGIN</code>
+	 * @return {@code EPPCommand.TYPE_LOGIN}
 	 */
 	public String getType() {
 		return EPPCommand.TYPE_LOGIN;
@@ -261,7 +247,7 @@ public class EPPLoginCmd extends EPPCommand {
 	/**
 	 * Gets the client login identifier.
 	 *
-	 * @return Client login identifier if defined; <code>null</code> otherwise.
+	 * @return Client login identifier if defined; {@code null} otherwise.
 	 */
 	public String getClientId() {
 		return clientId;
@@ -271,7 +257,7 @@ public class EPPLoginCmd extends EPPCommand {
 	 * Sets the client login identifier.
 	 *
 	 * @param aClientId
-	 *            Client login identifier.
+	 *           Client login identifier.
 	 */
 	public void setClientId(String aClientId) {
 		clientId = aClientId;
@@ -280,7 +266,7 @@ public class EPPLoginCmd extends EPPCommand {
 	/**
 	 * Gets the client password.
 	 *
-	 * @return Client password if defined; <code>null</code> otherwise.
+	 * @return Client password if defined; {@code null} otherwise.
 	 */
 	public String getPassword() {
 		return password;
@@ -290,7 +276,7 @@ public class EPPLoginCmd extends EPPCommand {
 	 * Sets the client password.
 	 *
 	 * @param aPassword
-	 *            Client password.
+	 *           Client password.
 	 */
 	public void setPassword(String aPassword) {
 		password = aPassword;
@@ -299,7 +285,7 @@ public class EPPLoginCmd extends EPPCommand {
 	/**
 	 * Gets the new client password.
 	 *
-	 * @return New client password if defined; <code>null</code> otherwise.
+	 * @return New client password if defined; {@code null} otherwise.
 	 */
 	public String getNewPassword() {
 		return newPassword;
@@ -309,7 +295,7 @@ public class EPPLoginCmd extends EPPCommand {
 	 * Sets the new client password.
 	 *
 	 * @param aNewPassword
-	 *            New client password.
+	 *           New client password.
 	 */
 	public void setNewPassword(String aNewPassword) {
 		newPassword = aNewPassword;
@@ -318,8 +304,8 @@ public class EPPLoginCmd extends EPPCommand {
 	/**
 	 * Is a new password defined?
 	 *
-	 * @return <code>true</code> if the new password is defined;
-	 *         <code>false</code> otherwise.
+	 * @return {@code true} if the new password is defined; {@code false}
+	 *         otherwise.
 	 */
 	public boolean hasNewPassword() {
 		if (newPassword != null) {
@@ -332,9 +318,9 @@ public class EPPLoginCmd extends EPPCommand {
 
 	/**
 	 * Gets the desired EPP version. The default version is set to
-	 * <code>EPPCodec.VERSION</code>.
+	 * {@code EPPCodec.VERSION}.
 	 *
-	 * @return EPP version identifier if defined; <code>null</code> otherwise.
+	 * @return EPP version identifier if defined; {@code null} otherwise.
 	 */
 	public String getVersion() {
 		return version;
@@ -342,33 +328,33 @@ public class EPPLoginCmd extends EPPCommand {
 
 	/**
 	 * Sets the desired EPP version. The default version is set to
-	 * <code>EPPCodec.VERSION</code>.
+	 * {@code EPPCodec.VERSION}.
 	 *
 	 * @param aVersion
-	 *            EPP version identifier
+	 *           EPP version identifier
 	 */
 	public void setVersion(String aVersion) {
 		version = aVersion;
 	}
 
 	/**
-	 * Gets the desired EPP language. The EPP language determines the language
-	 * of the error description strings and should be one of the supported
-	 * languages of the <code>EPPGreeting</code>. The default language is "en".
+	 * Gets the desired EPP language. The EPP language determines the language of
+	 * the error description strings and should be one of the supported languages
+	 * of the {@code EPPGreeting}. The default language is "en".
 	 *
-	 * @return The desired EPP language if defined; <code>null</code> otherwise.
+	 * @return The desired EPP language if defined; {@code null} otherwise.
 	 */
 	public String getLang() {
 		return lang;
 	}
 
 	/**
-	 * Sets the desired EPP language. The EPP language determines the language
-	 * of the error description strings and should be one of the supported
-	 * languages of the <code>EPPGreeting</code>. The default language is "en".
+	 * Sets the desired EPP language. The EPP language determines the language of
+	 * the error description strings and should be one of the supported languages
+	 * of the {@code EPPGreeting}. The default language is "en".
 	 *
 	 * @param aLang
-	 *            The desired EPP language
+	 *           The desired EPP language
 	 */
 	public void setLang(String aLang) {
 		lang = aLang;
@@ -377,7 +363,7 @@ public class EPPLoginCmd extends EPPCommand {
 	/**
 	 * Gets the login services.
 	 *
-	 * @return <code>Vector</code> of <code>EPPService</code> instances
+	 * @return {@code Vector} of {@code EPPService} instances
 	 */
 	public Vector getServices() {
 		return services;
@@ -385,25 +371,24 @@ public class EPPLoginCmd extends EPPCommand {
 
 	/**
 	 * Sets the login services. The default services are retrieved from
-	 * <code>EPPFactory.getServices</code>.
+	 * {@code EPPFactory.getServices}.
 	 *
 	 * @param someServices
-	 *            <code>Vector</code> of desired <code>EPPService</code>
-	 *            instances
+	 *           {@code Vector} of desired {@code EPPService} instances
 	 */
 	public void setServices(Vector someServices) {
 		services = someServices;
 	}
-	
+
 	/**
-	 * Does the login service include a specified service based on the
-	 * Namespace URI?
+	 * Does the login service include a specified service based on the Namespace
+	 * URI?
 	 * 
 	 * @param aNamespaceURI
-	 *            Service Namespace URI to search for
+	 *           Service Namespace URI to search for
 	 * 
-	 * @return <code>true</code> if the login services include the
-	 *         service Namespace URI; <code>false</code> otherwise.
+	 * @return {@code true} if the login services include the service Namespace
+	 *         URI; {@code false} otherwise.
 	 */
 	public boolean hasService(String aNamespaceURI) {
 		boolean found = false;
@@ -411,8 +396,7 @@ public class EPPLoginCmd extends EPPCommand {
 		if (this.services != null) {
 			Enumeration theSvcEnum = this.services.elements();
 			while (!found && theSvcEnum.hasMoreElements()) {
-				EPPService theExtService = (EPPService) theSvcEnum
-						.nextElement();
+				EPPService theExtService = (EPPService) theSvcEnum.nextElement();
 
 				if (theExtService.getNamespaceURI().equals(aNamespaceURI)) {
 					found = true;
@@ -422,17 +406,16 @@ public class EPPLoginCmd extends EPPCommand {
 
 		return found;
 	}
-	
 
 	/**
-	 * Does the login extension service include a specified extension service based on the
-	 * Namespace URI?
+	 * Does the login extension service include a specified extension service
+	 * based on the Namespace URI?
 	 * 
 	 * @param aNamespaceURI
-	 *            Extension service Namespace URI to search for
+	 *           Extension service Namespace URI to search for
 	 * 
-	 * @return <code>true</code> if the login extension services include the
-	 *         extension service Namespace URI; <code>false</code> otherwise.
+	 * @return {@code true} if the login extension services include the extension
+	 *         service Namespace URI; {@code false} otherwise.
 	 */
 	public boolean hasExtensionService(String aNamespaceURI) {
 		boolean found = false;
@@ -440,8 +423,7 @@ public class EPPLoginCmd extends EPPCommand {
 		if (this.extservices != null) {
 			Enumeration theExtSvcEnum = this.extservices.elements();
 			while (!found && theExtSvcEnum.hasMoreElements()) {
-				EPPService theExtService = (EPPService) theExtSvcEnum
-						.nextElement();
+				EPPService theExtService = (EPPService) theExtSvcEnum.nextElement();
 
 				if (theExtService.getNamespaceURI().equals(aNamespaceURI)) {
 					found = true;
@@ -455,10 +437,10 @@ public class EPPLoginCmd extends EPPCommand {
 	/**
 	 * Gets the list of supported/desired extension services. An EPP Client will
 	 * retrieve the list of extension services supported by the EPP Server. An
-	 * EPP Server will retrieve the list of extension services desired by the
-	 * EPP Client.
+	 * EPP Server will retrieve the list of extension services desired by the EPP
+	 * Client.
 	 *
-	 * @return Vector of <code>EPPService</code> instances.
+	 * @return Vector of {@code EPPService} instances.
 	 */
 	public Vector getExtensionServices() {
 		return extservices;
@@ -470,65 +452,58 @@ public class EPPLoginCmd extends EPPCommand {
 	 * list of supported extension services.
 	 *
 	 * @param someExtServices
-	 *            Vector of <code>EPPService</code> instances.
+	 *           Vector of {@code EPPService} instances.
 	 */
 	public void setExtensionServices(Vector someExtServices) {
 		extservices = someExtServices;
 	}
 
 	/**
-	 * encode <code>EPPLoginCmd</code> into a DOM element tree. The &ltlogin&gt
+	 * encode {@code EPPLoginCmd} into a DOM element tree. The &lt;login&gt;
 	 * element is created and the attribute nodes are appended as children. This
-	 * method is part of the Template Design Pattern, where
-	 * <code>EPPCommand</code> provides the public <code>encode</code> and calls
-	 * the abstract <code>doGenEncode</code>.
+	 * method is part of the Template Design Pattern, where {@code EPPCommand}
+	 * provides the public {@code encode} and calls the abstract
+	 * {@code doGenEncode}.
 	 *
 	 * @param aDocument
-	 *            DOCUMENT ME!
+	 *           DOM Document to create elements from
 	 *
-	 * @return &ltlogin&gt root element tree.
+	 * @return &lt;login&gt; root element tree.
 	 *
 	 * @exception EPPEncodeException
-	 *                Error encoding the DOM element tree.
+	 *               Error encoding the DOM element tree.
 	 */
 	protected Element doGenEncode(Document aDocument) throws EPPEncodeException {
 		// login
 		Element root = aDocument.createElementNS(EPPCodec.NS, ELM_NAME);
 
 		// Client Id
-		EPPUtil.encodeString(aDocument, root, clientId, EPPCodec.NS,
-				ELM_CLIENT_ID);
+		EPPUtil.encodeString(aDocument, root, clientId, EPPCodec.NS, ELM_CLIENT_ID);
 
 		// Password
-		EPPUtil.encodeString(aDocument, root, password, EPPCodec.NS,
-				ELM_PASSWORD);
+		EPPUtil.encodeString(aDocument, root, password, EPPCodec.NS, ELM_PASSWORD);
 
 		// New Password
-		EPPUtil.encodeString(aDocument, root, newPassword, EPPCodec.NS,
-				ELM_NEW_PASSWORD);
+		EPPUtil.encodeString(aDocument, root, newPassword, EPPCodec.NS, ELM_NEW_PASSWORD);
 
 		// Options
-		Element optionsElm = aDocument
-				.createElementNS(EPPCodec.NS, ELM_OPTIONS);
+		Element optionsElm = aDocument.createElementNS(EPPCodec.NS, ELM_OPTIONS);
 		root.appendChild(optionsElm);
 
 		// Version
-		EPPUtil.encodeString(aDocument, optionsElm, version, EPPCodec.NS,
-				ELM_VERSION);
+		EPPUtil.encodeString(aDocument, optionsElm, version, EPPCodec.NS, ELM_VERSION);
 
 		// Language
 		EPPUtil.encodeString(aDocument, optionsElm, lang, EPPCodec.NS, ELM_LANG);
 
 		// Services svcs element
-		Element servicesElm = aDocument.createElementNS(EPPCodec.NS,
-				ELM_SERVICES);
+		Element servicesElm = aDocument.createElementNS(EPPCodec.NS, ELM_SERVICES);
 		root.appendChild(servicesElm);
 		EPPUtil.encodeCompVector(aDocument, servicesElm, services);
 
 		if ((extservices != null) && extservices.elements().hasMoreElements()) {
 			// svcExtension element
-			Element svcExtension = aDocument.createElementNS(EPPCodec.NS,
-					ELM_EXT_SERVICES);
+			Element svcExtension = aDocument.createElementNS(EPPCodec.NS, ELM_EXT_SERVICES);
 
 			EPPUtil.encodeCompVector(aDocument, svcExtension, extservices);
 			servicesElm.appendChild(svcExtension);
@@ -540,17 +515,16 @@ public class EPPLoginCmd extends EPPCommand {
 	}
 
 	/**
-	 * decode <code>EPPLoginCmd</code> from a DOM element tree. The "login"
-	 * element needs to be the value of the <code>aElement</code> argument. This
-	 * method is part of the Template Design Pattern, where
-	 * <code>EPPCommand</code> provides the public <code>decode</code> and calls
-	 * the abstract <code>doGenDecode</code>.
+	 * decode {@code EPPLoginCmd} from a DOM element tree. The "login" element
+	 * needs to be the value of the {@code aElement} argument. This method is
+	 * part of the Template Design Pattern, where {@code EPPCommand} provides the
+	 * public {@code decode} and calls the abstract {@code doGenDecode}.
 	 *
 	 * @param aElement
-	 *            &ltlogin&gt root element tree.
+	 *           &lt;login&gt; root element tree.
 	 *
 	 * @exception EPPDecodeException
-	 *                Error decoding the DOM element tree.
+	 *               Error decoding the DOM element tree.
 	 */
 	protected void doGenDecode(Element aElement) throws EPPDecodeException {
 		// Client Id
@@ -560,19 +534,16 @@ public class EPPLoginCmd extends EPPCommand {
 		password = EPPUtil.decodeString(aElement, EPPCodec.NS, ELM_PASSWORD);
 
 		// New Password
-		newPassword = EPPUtil.decodeString(aElement, EPPCodec.NS,
-				ELM_NEW_PASSWORD);
+		newPassword = EPPUtil.decodeString(aElement, EPPCodec.NS, ELM_NEW_PASSWORD);
 
 		// Options
-		NodeList elms = aElement.getElementsByTagNameNS(EPPCodec.NS,
-				ELM_OPTIONS);
+		NodeList elms = aElement.getElementsByTagNameNS(EPPCodec.NS, ELM_OPTIONS);
 
 		if (elms.getLength() == 1) {
 			Element optionsElm = (Element) elms.item(0);
 
 			// Version
-			version = EPPUtil
-					.decodeString(optionsElm, EPPCodec.NS, ELM_VERSION);
+			version = EPPUtil.decodeString(optionsElm, EPPCodec.NS, ELM_VERSION);
 
 			// Language
 			lang = EPPUtil.decodeString(optionsElm, EPPCodec.NS, ELM_LANG);
@@ -590,18 +561,15 @@ public class EPPLoginCmd extends EPPCommand {
 		extservices = new Vector();
 
 		// Get Services root node
-		Element servicesElm = EPPUtil.getElementByTagNameNS(aElement,
-				EPPCodec.NS, ELM_SERVICES);
+		Element servicesElm = EPPUtil.getElementByTagNameNS(aElement, EPPCodec.NS, ELM_SERVICES);
 
 		if (servicesElm == null) {
-			throw new EPPDecodeException(
-					"EPPLoginCmd.doGenDecode did not find a " + ELM_SERVICES
-							+ " element");
+			throw new EPPDecodeException("EPPLoginCmd.doGenDecode did not find a " + ELM_SERVICES + " element");
 		}
 
 		// Get the list of services
 		NodeList serviceElms = servicesElm.getElementsByTagNameNS(EPPCodec.NS,
-				EPPUtil.getLocalName(EPPService.ELM_OBJ_URI));
+		      EPPUtil.getLocalName(EPPService.ELM_OBJ_URI));
 
 		for (int i = 0; i < serviceElms.getLength(); i++) {
 			EPPService currService = new EPPService();
@@ -612,8 +580,8 @@ public class EPPLoginCmd extends EPPCommand {
 			services.addElement(currService);
 		}
 
-		NodeList svcExtensionNodeList = aElement.getElementsByTagNameNS(
-				EPPCodec.NS, EPPUtil.getLocalName(ELM_EXT_SERVICES));
+		NodeList svcExtensionNodeList = aElement.getElementsByTagNameNS(EPPCodec.NS,
+		      EPPUtil.getLocalName(ELM_EXT_SERVICES));
 
 		if (svcExtensionNodeList.getLength() != 0) {
 			Element svcExtension = null;
@@ -621,8 +589,8 @@ public class EPPLoginCmd extends EPPCommand {
 			for (int i = 0; i < svcExtensionNodeList.getLength(); i++) {
 				svcExtension = (Element) svcExtensionNodeList.item(i);
 
-				NodeList extensionElms = svcExtension.getElementsByTagNameNS(
-						EPPCodec.NS, EPPUtil.getLocalName(ELM_EXT_URI));
+				NodeList extensionElms = svcExtension.getElementsByTagNameNS(EPPCodec.NS,
+				      EPPUtil.getLocalName(ELM_EXT_URI));
 
 				for (int k = 0; k < extensionElms.getLength(); k++) {
 					EPPService extService = new EPPService();
@@ -641,12 +609,12 @@ public class EPPLoginCmd extends EPPCommand {
 	}
 
 	/**
-	 * implements a deep <code>EPPLoginCmd</code> compare.
+	 * implements a deep {@code EPPLoginCmd} compare.
 	 *
 	 * @param aObject
-	 *            <code>EPPLoginCmd</code> instance to compare with
+	 *           {@code EPPLoginCmd} instance to compare with
 	 *
-	 * @return <code>true</code> if equal; <code>false</code> otherwise
+	 * @return {@code true} if equal; {@code false} otherwise
 	 */
 	public boolean equals(Object aObject) {
 		if (!(aObject instanceof EPPLoginCmd)) {
@@ -661,32 +629,27 @@ public class EPPLoginCmd extends EPPCommand {
 		}
 
 		// clientId
-		if (!((clientId == null) ? (theLogin.clientId == null) : clientId
-				.equals(theLogin.clientId))) {
+		if (!((clientId == null) ? (theLogin.clientId == null) : clientId.equals(theLogin.clientId))) {
 			return false;
 		}
 
 		// password
-		if (!((password == null) ? (theLogin.password == null) : password
-				.equals(theLogin.password))) {
+		if (!((password == null) ? (theLogin.password == null) : password.equals(theLogin.password))) {
 			return false;
 		}
 
 		// newPassword
-		if (!((newPassword == null) ? (theLogin.newPassword == null)
-				: newPassword.equals(theLogin.newPassword))) {
+		if (!((newPassword == null) ? (theLogin.newPassword == null) : newPassword.equals(theLogin.newPassword))) {
 			return false;
 		}
 
 		// version
-		if (!((version == null) ? (theLogin.version == null) : version
-				.equals(theLogin.version))) {
+		if (!((version == null) ? (theLogin.version == null) : version.equals(theLogin.version))) {
 			return false;
 		}
 
 		// lang
-		if (!((lang == null) ? (theLogin.lang == null) : lang
-				.equals(theLogin.lang))) {
+		if (!((lang == null) ? (theLogin.lang == null) : lang.equals(theLogin.lang))) {
 			return false;
 		}
 
@@ -699,12 +662,12 @@ public class EPPLoginCmd extends EPPCommand {
 	}
 
 	/**
-	 * Clone <code>EPPLoginCmd</code>.
+	 * Clone {@code EPPLoginCmd}.
 	 *
-	 * @return clone of <code>EPPLoginCmd</code>
+	 * @return clone of {@code EPPLoginCmd}
 	 *
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPLoginCmd clone = null;
@@ -715,35 +678,34 @@ public class EPPLoginCmd extends EPPCommand {
 		clone.services = (Vector) services.clone();
 
 		for (int i = 0; i < services.size(); i++)
-			clone.services.setElementAt(
-					((EPPService) services.elementAt(i)).clone(), i);
+			clone.services.setElementAt(((EPPService) services.elementAt(i)).clone(), i);
 
 		return clone;
 	}
 
 	/**
-	 * Implementation of <code>Object.toString</code>, which will result in an
-	 * indented XML <code>String</code> representation of the concrete
-	 * <code>EPPCodecComponent</code>.
+	 * Implementation of {@code Object.toString}, which will result in an
+	 * indented XML {@code String} representation of the concrete
+	 * {@code EPPCodecComponent}.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML {@code String} if successful; {@code ERROR}
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
 	/**
-	 * Is the <code>EPPLoginCmd</code> services settings valid as compared with
-	 * the services specified in the <code>EPPGreeting</code>? The services
-	 * attributes defined in <code>EPPLoginCmd</code> must be a subset of the
-	 * available services specified in the <code>EPPGreeting</code>.
+	 * Is the {@code EPPLoginCmd} services settings valid as compared with the
+	 * services specified in the {@code EPPGreeting}? The services attributes
+	 * defined in {@code EPPLoginCmd} must be a subset of the available services
+	 * specified in the {@code EPPGreeting}.
 	 *
 	 * @param aGreeting
-	 *            Greeting to compare services with
+	 *           Greeting to compare services with
 	 *
-	 * @return <code>true</code> if the service settings are valid;
-	 *         <code>false</code> otherwise.
+	 * @return {@code true} if the service settings are valid; {@code false}
+	 *         otherwise.
 	 */
 	public boolean isValidServices(EPPGreeting aGreeting) {
 		cat.debug("isValidServices(): enter");
@@ -752,26 +714,21 @@ public class EPPLoginCmd extends EPPCommand {
 
 		// Language
 		if ((lang == null) || (!greetingServices.getLangs().contains(lang))) {
-			cat.error("lang mismatch " + lang + " not in "
-					+ greetingServices.getLangs());
+			cat.error("lang mismatch " + lang + " not in " + greetingServices.getLangs());
 
 			return false;
 		}
 
 		// Version
-		if ((version == null)
-				|| (!greetingServices.getVersions().contains(version))) {
-			cat.error("version mismatch " + version + " not in "
-					+ greetingServices.getVersions());
+		if ((version == null) || (!greetingServices.getVersions().contains(version))) {
+			cat.error("version mismatch " + version + " not in " + greetingServices.getVersions());
 
 			return false;
 		}
 
 		// Services
-		if (!EPPUtil.vectorSubset(services,
-				greetingServices.getObjectServices())) {
-			cat.debug("services mismatch " + services + " not in "
-					+ greetingServices.getObjectServices());
+		if (!EPPUtil.vectorSubset(services, greetingServices.getObjectServices())) {
+			cat.debug("services mismatch " + services + " not in " + greetingServices.getObjectServices());
 
 			return false;
 		}
@@ -782,17 +739,16 @@ public class EPPLoginCmd extends EPPCommand {
 	}
 
 	/**
-	 * Merge the services defined automatically in the EPP SDK configuration
-	 * with services and extension services defined in the EPP Greeting, so that
-	 * the login services are sent to only be a subset of the services defined
-	 * in the EPP Greeting.
+	 * Merge the services defined automatically in the EPP SDK configuration with
+	 * services and extension services defined in the EPP Greeting, so that the
+	 * login services are sent to only be a subset of the services defined in the
+	 * EPP Greeting.
 	 * 
 	 * @param aGreeting
-	 *            EPP Greeting to merge the services in the EPP Login.
+	 *           EPP Greeting to merge the services in the EPP Login.
 	 */
 	public void mergeServicesAndExtensionServices(EPPGreeting aGreeting) {
 		this.services.retainAll(aGreeting.getServiceMenu().getObjectServices());
-		this.extservices.retainAll(aGreeting.getServiceMenu()
-				.getExtensionServices());
+		this.extservices.retainAll(aGreeting.getServiceMenu().getExtensionServices());
 	}
 }
