@@ -19,99 +19,72 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.codec.gen;
 
-
-// Log4j Imports
-import org.apache.log4j.Logger;
-
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
-
-//----------------------------------------------
-//
-// imports...
-//
-//----------------------------------------------
-// W3C Imports
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
-import com.verisign.epp.util.EPPCatFactory;
-
-
 /**
  * The &lt;purpose&gt; element MUST contain one or more of the following child
  * elements that describe the purposes for which data is collected: <br>
  * 
  * <ul>
- * <li>
- * &lt;admin/&gt;: Administrative purposes.  Information can be used for
- * administrative and technical support of the provisioning system.
- * </li>
- * <li>
- * &lt;contact/&gt;: Contact for marketing purposes.  Information can be used
+ * <li>&lt;admin/&gt;: Administrative purposes. Information can be used for
+ * administrative and technical support of the provisioning system.</li>
+ * <li>&lt;contact/&gt;: Contact for marketing purposes. Information can be used
  * to contact individuals, through a communications channel other than the
- * protocol, for the promotion of a product or service.
- * </li>
- * <li>
- * &lt;prov/&gt;: Object provisioning purposes.  Information can be used to
- * identify objects and inter-object relationships.
- * </li>
- * <li>
- * &lt;other/&gt;: Other purposes.  Information may be used in other ways not
- * captured by the above definitions.
- * </li>
+ * protocol, for the promotion of a product or service.</li>
+ * <li>&lt;prov/&gt;: Object provisioning purposes. Information can be used to
+ * identify objects and inter-object relationships.</li>
+ * <li>&lt;other/&gt;: Other purposes. Information may be used in other ways not
+ * captured by the above definitions.</li>
  * </ul>
- * 
- *
- * @author $Author: jim $
- * @version $Revision: 1.6 $
  *
  * @see com.verisign.epp.codec.gen.EPPStatement
  */
 public class EPPPurpose implements EPPCodecComponent {
-	/** Default XML root tag name for <code>purpose</code>element. */
+	/** Default XML root tag name for {@code purpose}element. */
 	final static String ELM_NAME = "purpose";
 
-	/** XML tag name for the <code>admin</code> attribute. */
+	/** XML tag name for the {@code admin} attribute. */
 	private static final String ELM_ADMIN = "admin";
 
-	/** XML tag name for the <code>contact</code> element. */
+	/** XML tag name for the {@code contact} element. */
 	private static final String ELM_CONTACT = "contact";
 
-	/** XML tag name for the <code>other</code> attribute. */
+	/** XML tag name for the {@code other} attribute. */
 	private static final String ELM_OTHER = "other";
 
-	/** XML tag name for the <code>tmReg</code> element. */
+	/** XML tag name for the {@code tmReg} element. */
 	private static final String ELM_PROV = "prov";
 
-	/** Log4j category for logging */
-	private static Logger cat =
-		Logger.getLogger(
-						 EPPPurpose.class.getName(),
-						 EPPCatFactory.getInstance().getFactory());
+	/** Category for logging */
+	private static Logger cat = LoggerFactory.getLogger(EPPPurpose.class);
 
 	/**
-	 * Administrative purposes.  Information can be used for administrative and
+	 * Administrative purposes. Information can be used for administrative and
 	 * technical support of the provisioning system.
 	 */
 	private boolean admin = false;
 
 	/**
-	 * Contact for marketing purposes.  Information can be used to contact
-	 * individuals, through a communications channel other than the protocol,
-	 * for the promotion of a product or service.
+	 * Contact for marketing purposes. Information can be used to contact
+	 * individuals, through a communications channel other than the protocol, for
+	 * the promotion of a product or service.
 	 */
 	private boolean contact = false;
 
 	/**
-	 * Other purposes.  Information may be used in other ways not captured by
-	 * the above definitions.
+	 * Other purposes. Information may be used in other ways not captured by the
+	 * above definitions.
 	 */
 	private boolean other = false;
 
 	/**
-	 * Object provisioning purposes.  Information can be used to identify
-	 * objects and inter-object relationships.
+	 * Object provisioning purposes. Information can be used to identify objects
+	 * and inter-object relationships.
 	 */
 	private boolean prov = false;
 
@@ -122,33 +95,30 @@ public class EPPPurpose implements EPPCodecComponent {
 	}
 
 	/**
-	 * Allocates a new <code>EPPPurpose</code> with different child elements
-	 * based on the input parameters.
+	 * Allocates a new {@code EPPPurpose} with different child elements based on
+	 * the input parameters.
 	 *
-	 * @param aAdmin If set to <code>true</code> then the element
-	 * 		  <code>admin</code> is created
-	 * @param aContact If set to <code>true</code> then the element
-	 * 		  <code>contact</code> is created
-	 * @param aOther If set to <code>true</code> then the element
-	 * 		  <code>other</code> is created
-	 * @param aProv If set to <code>true</code> then the element
-	 * 		  <code>prov</code> is created
+	 * @param aAdmin
+	 *           If set to {@code true} then the element {@code admin} is created
+	 * @param aContact
+	 *           If set to {@code true} then the element {@code contact} is
+	 *           created
+	 * @param aOther
+	 *           If set to {@code true} then the element {@code other} is created
+	 * @param aProv
+	 *           If set to {@code true} then the element {@code prov} is created
 	 */
-	public EPPPurpose(
-					  boolean aAdmin, boolean aContact, boolean aOther,
-					  boolean aProv) {
-		this.admin		 = aAdmin;
-		this.contact     = aContact;
-		this.other		 = aOther;
-		this.prov		 = aProv;
+	public EPPPurpose(boolean aAdmin, boolean aContact, boolean aOther, boolean aProv) {
+		this.admin = aAdmin;
+		this.contact = aContact;
+		this.other = aOther;
+		this.prov = aProv;
 	}
 
-	// End EPPPurpose.EPPPurpose(boolean, boolean, boolean, boolean)
-
 	/**
 	 * &lt;admin&gt; element set?
 	 *
-	 * @return <code>true</code> if is set; <code>false</code> otherwise.
+	 * @return {@code true} if is set; {@code false} otherwise.
 	 */
 	public boolean isAdmin() {
 		return this.admin;
@@ -158,8 +128,9 @@ public class EPPPurpose implements EPPCodecComponent {
 	 * Sets the &lt;admin&gt; element to specify contact for administrative
 	 * purposes.
 	 *
-	 * @param aAdmin <code>true</code> to include the &lt;admin&gt; element;
-	 * 		  <code>false</code> otherwise.
+	 * @param aAdmin
+	 *           {@code true} to include the &lt;admin&gt; element; {@code false}
+	 *           otherwise.
 	 */
 	public void setAdmin(boolean aAdmin) {
 		this.admin = aAdmin;
@@ -168,7 +139,7 @@ public class EPPPurpose implements EPPCodecComponent {
 	/**
 	 * &lt;contact&gt; element set?
 	 *
-	 * @return <code>true</code> if is set; <code>false</code> otherwise.
+	 * @return {@code true} if is set; {@code false} otherwise.
 	 */
 	public boolean isContact() {
 		return this.contact;
@@ -178,8 +149,9 @@ public class EPPPurpose implements EPPCodecComponent {
 	 * Sets the &lt;contact&gt; element to specify contact for marketing
 	 * purposes.
 	 *
-	 * @param aContact <code>true</code> to include the &lt;contact&gt;
-	 * 		  element; <code>false</code> otherwise.
+	 * @param aContact
+	 *           {@code true} to include the &lt;contact&gt; element;
+	 *           {@code false} otherwise.
 	 */
 	public void setContact(boolean aContact) {
 		this.contact = aContact;
@@ -188,7 +160,7 @@ public class EPPPurpose implements EPPCodecComponent {
 	/**
 	 * &lt;other&gt; element set?
 	 *
-	 * @return <code>true</code> if is set; <code>false</code> otherwise.
+	 * @return {@code true} if is set; {@code false} otherwise.
 	 */
 	public boolean isOther() {
 		return this.other;
@@ -197,8 +169,9 @@ public class EPPPurpose implements EPPCodecComponent {
 	/**
 	 * Sets the &lt;other&gt; element to specify Other purposes.
 	 *
-	 * @param aOther <code>true</code> to include the &lt;other&gt; element;
-	 * 		  <code>false</code> otherwise.
+	 * @param aOther
+	 *           {@code true} to include the &lt;other&gt; element; {@code false}
+	 *           otherwise.
 	 */
 	public void setOther(boolean aOther) {
 		this.other = aOther;
@@ -207,7 +180,7 @@ public class EPPPurpose implements EPPCodecComponent {
 	/**
 	 * &lt;prov&gt; element set?
 	 *
-	 * @return <code>true</code> if is set; <code>false</code> otherwise.
+	 * @return {@code true} if is set; {@code false} otherwise.
 	 */
 	public boolean isProv() {
 		return this.prov;
@@ -216,22 +189,25 @@ public class EPPPurpose implements EPPCodecComponent {
 	/**
 	 * Sets the &lt;prov&gt; element to specify object provisioning purposes.
 	 *
-	 * @param aProv <code>true</code> to include the &lt;prov&gt; element;
-	 * 		  <code>false</code> otherwise.
+	 * @param aProv
+	 *           {@code true} to include the &lt;prov&gt; element; {@code false}
+	 *           otherwise.
 	 */
 	public void setProv(boolean aProv) {
 		this.prov = aProv;
 	}
 
 	/**
-	 * encode <code>EPPPurpose</code> into a DOM element tree.  The "purpose"
-	 * element is created and the child nodes are     appended as children.
+	 * encode {@code EPPPurpose} into a DOM element tree. The "purpose" element
+	 * is created and the child nodes are appended as children.
 	 *
-	 * @param aDocument DOCUMENT ME!
+	 * @param aDocument
+	 *           DOCUMENT ME!
 	 *
 	 * @return purpose root element tree.
 	 *
-	 * @exception EPPEncodeException Error encoding the DOM element tree.
+	 * @exception EPPEncodeException
+	 *               Error encoding the DOM element tree.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 		// Validate that at least one recipient is set
@@ -270,28 +246,25 @@ public class EPPPurpose implements EPPCodecComponent {
 		return root;
 	}
 
-	// End EPPPurpose.encode(Document)
-
 	/**
 	 * Reset all attribute to their initial values.
 	 */
 	private void reset() {
-		this.admin		 = false;
-		this.contact     = false;
-		this.other		 = false;
-		this.prov		 = false;
+		this.admin = false;
+		this.contact = false;
+		this.other = false;
+		this.prov = false;
 	}
 
-	// End reset()
-
 	/**
-	 * decode <code>EPPPurpose</code> from a DOM element tree.  The
-	 * <code>aElement</code> argument needs to be the &ltpurpose&gt element
-	 * for a <code>EPPPurpose</code>
+	 * decode {@code EPPPurpose} from a DOM element tree. The {@code aElement}
+	 * argument needs to be the &lt;purpose&gt; element for a {@code EPPPurpose}
 	 *
-	 * @param aElement root element tree.
+	 * @param aElement
+	 *           root element tree.
 	 *
-	 * @exception EPPDecodeException Error decoding the DOM element tree.
+	 * @exception EPPDecodeException
+	 *               Error decoding the DOM element tree.
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 		NodeList theList = aElement.getChildNodes();
@@ -322,27 +295,24 @@ public class EPPPurpose implements EPPCodecComponent {
 			}
 			else {
 				cat.error("EPPPurpose.decode(): Unknown element " + theElm);
-				throw new EPPDecodeException("EPPPurpose.decode(): Unknown element "
-											 + theElm);
+				throw new EPPDecodeException("EPPPurpose.decode(): Unknown element " + theElm);
 			}
 		}
 
-		// end for 
+		// end for
 	}
 
-	// End EPPPurpose.decode(Element)
-
 	/**
-	 * implements a  <code>EPPPurpose</code> compare.
+	 * implements a {@code EPPPurpose} compare.
 	 *
-	 * @param aObject <code>EPPPurpose</code> instance to compare with
+	 * @param aObject
+	 *           {@code EPPPurpose} instance to compare with
 	 *
-	 * @return DOCUMENT ME!
+	 * @return {@code true} if equal; {@code false} otherwise.
 	 */
 	public boolean equals(Object aObject) {
 		if (!(aObject instanceof EPPPurpose)) {
-			cat.error("EPPPurpose.equals(): " + aObject.getClass().getName()
-					  + " not EPPPurpose instance");
+			cat.error("EPPPurpose.equals(): " + aObject.getClass().getName() + " not EPPPurpose instance");
 
 			return false;
 		}
@@ -378,14 +348,13 @@ public class EPPPurpose implements EPPCodecComponent {
 		}
 	}
 
-	// End EPPPurpose.equals(Object)
-
 	/**
-	 * Clone <code>EPPPurpose</code>.
+	 * Clone {@code EPPPurpose}.
 	 *
-	 * @return clone of <code>EPPPurpose</code>
+	 * @return clone of {@code EPPPurpose}
 	 *
-	 * @exception CloneNotSupportedException standard Object.clone exception
+	 * @exception CloneNotSupportedException
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPPurpose clone = null;
@@ -395,30 +364,25 @@ public class EPPPurpose implements EPPCodecComponent {
 		return clone;
 	}
 
-	// End EPPPurpose.clone()*/
-
 	/**
-	 * Implementation of <code>Object.toString</code>, which will result in an
-	 * indented XML <code>String</code> representation of the concrete
-	 * <code>EPPCodecComponent</code>.
+	 * Implementation of {@code Object.toString}, which will result in an
+	 * indented XML {@code String} representation of the concrete
+	 * {@code EPPCodecComponent}.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 * 		   <code>ERROR</code> otherwise.
+	 * @return Indented XML {@code String} if successful; {@code ERROR}
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the {@code EPPCodecComponent}.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the {@code EPPCodecComponent}.
 	 */
 	@Override
 	public String getNamespace() {
 		return EPPCodec.NS;
 	}
 }
-
-
-// End class EPPPurpose
