@@ -23,12 +23,13 @@ package com.verisign.epp.framework;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.gen.EPPGreeting;
 import com.verisign.epp.codec.gen.EPPMessage;
 import com.verisign.epp.codec.gen.EPPResponse;
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * A Singleton class that delegates message assembly to an EPPAssembler then
@@ -46,9 +47,8 @@ public class EPPByteArrayDispatcher {
 	private static final EPPByteArrayDispatcher _instance = new EPPByteArrayDispatcher();
 
 	/** Class logger */
-	private static Logger LOG = Logger.getLogger(
-			EPPByteArrayDispatcher.class.getName(),
-			EPPCatFactory.getInstance().getFactory());
+	private static Logger LOG = LoggerFactory.getLogger(EPPByteArrayDispatcher.class);
+	      
 
 	/**
 	 * eventHandlers is a Hashtable where the key is a string that defines the
@@ -82,38 +82,36 @@ public class EPPByteArrayDispatcher {
 	 * Sets the ByteArrayAssembler.
 	 * 
 	 * @param aByteArrayAssembler
-	 *            The ByteArrayAssembler to use.
+	 *           The ByteArrayAssembler to use.
 	 */
 	public void setAssembler(EPPByteArrayAssembler aByteArrayAssembler) {
 		this.theAssembler = aByteArrayAssembler;
 	}
 
 	/**
-	 * Creates an <code>EPPMessage</code>, sends the message to the appropriate
-	 * <code>EPPEventHandler</code>, and then returns the response as a
-	 * <code>byte</code> array.
+	 * Creates an {@code EPPMessage}, sends the message to the appropriate
+	 * {@code EPPEventHandler}, and then returns the response as a {@code byte}
+	 * array.
 	 * 
 	 * @param aInputBytes
-	 *            The byte array containing the xml input
+	 *           The byte array containing the xml input
 	 * @param aData
-	 *            Any additional data that may be required by the
-	 *            EPPEventHandler
+	 *           Any additional data that may be required by the EPPEventHandler
+	 * @return {@code byte} array containing the response to the message.
 	 * @exception EPPEventException
-	 *                Exception related to the handling of an event
+	 *               Exception related to the handling of an event
 	 * @exception EPPAssemblerException
-	 *                Exception related to the assembling/de-assembling of
-	 *                messages. <code>EPPAssemberException.isFatal</code> can be
-	 *                called to determine if the exception is a fatal exception
-	 *                for the client session.
+	 *               Exception related to the assembling/de-assembling of
+	 *               messages. {@code EPPAssemberException.isFatal} can be called
+	 *               to determine if the exception is a fatal exception for the
+	 *               client session.
 	 */
-	public byte[] processMessage(byte[] aInputBytes, Object aData)
-			throws EPPEventException, EPPAssemblerException {
+	public byte[] processMessage(byte[] aInputBytes, Object aData) throws EPPEventException, EPPAssemblerException {
 		LOG.debug("processMessage(byte[], Object): Enter");
 
 		if (this.theAssembler == null) {
-			throw new EPPAssemblerException(
-					"No Assembler registered with EPPByteArrayDispatcher",
-					EPPAssemblerException.FATAL);
+			throw new EPPAssemblerException("No Assembler registered with EPPByteArrayDispatcher",
+			      EPPAssemblerException.FATAL);
 		}
 
 		EPPEvent event = this.theAssembler.decode(aInputBytes, aData);
@@ -122,13 +120,11 @@ public class EPPByteArrayDispatcher {
 
 		// Is the message not a supported type for dispatching?
 		if (message instanceof EPPResponse) {
-			LOG.info("processMessage(): Invalid message type "
-					+ message.getClass().getName() + " for dispatching");
+			LOG.info("processMessage(): Invalid message type " + message.getClass().getName() + " for dispatching");
 			throw new EPPEventException("Invalid request message type of response");
 		}
 		if (message instanceof EPPGreeting) {
-			LOG.info("processMessage(): Invalid message type "
-					+ message.getClass().getName() + " for dispatching");
+			LOG.info("processMessage(): Invalid message type " + message.getClass().getName() + " for dispatching");
 			throw new EPPEventException("Invalid request message type of greeting");
 		}
 
@@ -136,13 +132,10 @@ public class EPPByteArrayDispatcher {
 		String namespace = message.getNamespace();
 		LOG.debug("Sending event for Namespace " + namespace);
 
-		EPPEventHandler handler = (EPPEventHandler) this.eventHandlers
-				.get(namespace);
+		EPPEventHandler handler = (EPPEventHandler) this.eventHandlers.get(namespace);
 		if (handler == null) {
-			LOG.info("processMessage(): Handler not found for Namespace "
-					+ namespace);
-			throw new EPPEventException(
-					"Handler not found for Namespace " + namespace);
+			LOG.info("processMessage(): Handler not found for Namespace " + namespace);
+			throw new EPPEventException("Handler not found for Namespace " + namespace);
 		}
 
 		// Send the event to the message handler
@@ -162,37 +155,40 @@ public class EPPByteArrayDispatcher {
 	}
 
 	/**
-	 * Registers an <code>EPPEvenHandler</code> for notification of Events.
+	 * Registers an {@code EPPEvenHandler} for notification of Events.
 	 * 
 	 * @param aHandler
-	 *            The <code>EPPEventhandler</code> to register
+	 *           The {@code EPPEventhandler} to register
 	 */
 	public void registerHandler(EPPEventHandler aHandler) {
 		this.eventHandlers.put(aHandler.getNamespace(), aHandler);
 	}
 
 	/**
-	 * Encodes an EPP message to a <code>byte</code> array.
+	 * Encodes an EPP message to a {@code byte} array.
 	 * 
 	 * @param aMessage
-	 *            EPP Message to send to the client
+	 *           EPP Message to send to the client
+	 * @return Encoded {@code aMessage} as a {@code byte[]}.
 	 * @exception EPPAssemblerException
-	 *                Error encoding the EPP message
+	 *               Error encoding the EPP message
 	 */
 	public byte[] toBytes(EPPMessage aMessage) throws EPPAssemblerException {
 		return this.theAssembler.encode(new EPPEventResponse(aMessage), null);
 	}
 
 	/**
-	 * Encodes an EPP message to a <code>byte</code> array.
+	 * Encodes an EPP message to a {@code byte} array.
 	 * 
 	 * @param aMessage
-	 *            EPP Message to send to the client
+	 *           EPP Message to send to the client
+	 * @param aData
+	 *           Any additional data that may be required by the handler.
+	 * @return Encoded {@code aMessage} as a {@code byte[]}.
 	 * @exception EPPAssemblerException
-	 *                Error encoding the EPP message
+	 *               Error encoding the EPP message
 	 */
-	public byte[] toBytes(EPPMessage aMessage, Object aData)
-			throws EPPAssemblerException {
+	public byte[] toBytes(EPPMessage aMessage, Object aData) throws EPPAssemblerException {
 		return this.theAssembler.encode(new EPPEventResponse(aMessage), aData);
 	}
 }
