@@ -19,28 +19,23 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
  ***********************************************************/
 package com.verisign.epp.interfaces;
 
-import java.io.ByteArrayOutputStream;
+import javax.net.ssl.SSLHandshakeException;
 
-import javax.xml.transform.OutputKeys;
-import javax.xml.transform.Transformer;
-import javax.xml.transform.TransformerFactory;
-import javax.xml.transform.dom.DOMSource;
-import javax.xml.transform.stream.StreamResult;
-
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 
 import com.verisign.epp.codec.gen.EPPCodec;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPGreeting;
-import com.verisign.epp.codec.gen.EPPMessage;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
-import com.verisign.epp.util.EPPCatFactory;
+import com.verisign.epp.transport.client.EPPSSLClientSocket;
+import com.verisign.epp.interfaces.RenegotiationSession;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
-// JUNIT Imports
 import junit.framework.Assert;
 import junit.framework.Test;
 import junit.framework.TestCase;
@@ -81,8 +76,7 @@ public class EPPSessionTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPSessionTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPSessionTst.class);
 
 	/** EPP Session associated with test */
 	private EPPSession session = null;
@@ -115,6 +109,53 @@ public class EPPSessionTst extends TestCase {
 		endSession();
 	}
 
+	/**
+	 * Test attempting to execute TLS client-initiated renegotiation.
+	 */
+	public void testClientInitiatedRenegotation() {
+		printStart("testClientInitiatedRenegotation");
+
+		RenegotiationSession theSession = null;
+
+		try {
+			theSession = new RenegotiationSession();
+
+			// Get client id and password from configuration if defined
+			String theClientId = Environment.getProperty("EPP.Test.clientId", "ClientX");
+			String thePassword = Environment.getProperty("EPP.Test.password", "foo-BAR2");
+
+			// Set attributes for initSession
+			theSession.setClientID(theClientId);
+			theSession.setPassword(thePassword);
+			theSession.setTransId("ABC-12345-XYZ");
+			theSession.setVersion("1.0");
+			theSession.setLang("en");
+
+			// Initialize the session
+			theSession.initSession();
+
+			if (theSession.getClientCon() instanceof EPPSSLClientSocket) {
+				Assert.fail("testClientInitiatedRenegotation: Client-initiated renegotiation unexpectedly successful");
+			}
+
+		}
+		catch (EPPCommandException ex) {
+
+			if ((ex.getCause() != null) && (ex.getCause() instanceof SSLHandshakeException)) {
+				cat.info("testClientInitiatedRenegotation: Successfully failed with cause = " + ex.getCause());
+				System.out.println(Thread.currentThread().getName()
+				      + ": testClientInitiatedRenegotation: Successfully failed with cause = " + ex.getCause());
+
+			}
+			else {
+				handleException(ex);
+			}
+
+		}
+
+		printEnd("testClientInitiatedRenegotation");
+	}
+
 	/**
 	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
 	 * initialized with the attributes defined in the EPP sample files.
@@ -133,11 +174,13 @@ public class EPPSessionTst extends TestCase {
 		session.setVersion("1.0");
 		session.setLang("en");
 
-		// Initialize the session
 		try {
+			// Initialize the session
 			session.initSession();
 		}
-		catch (EPPCommandException e) {
+		catch (
+
+		EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -453,7 +496,7 @@ public class EPPSessionTst extends TestCase {
 	 * JUNIT <code>suite</code> static method, which returns the tests associated
 	 * with <code>EPPSessionTst</code>.
 	 *
-	 * @return DOCUMENT ME!
+	 * @return Tests to execute
 	 */
 	public static Test suite() {
 		TestSuite suite = new TestSuite(EPPSessionTst.class);
