@@ -19,19 +19,26 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.pool;
 
-import org.apache.commons.pool.PoolableObjectFactory;
-import org.apache.log4j.Logger;
+import java.util.concurrent.ThreadLocalRandom;
+
+import org.apache.commons.pool2.PooledObject;
+import org.apache.commons.pool2.PooledObjectFactory;
+import org.apache.commons.pool2.impl.DefaultPooledObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.interfaces.EPPCommandException;
-import com.verisign.epp.interfaces.EPPSession;
 import com.verisign.epp.transport.client.EPPSSLContext;
-import com.verisign.epp.util.EPPCatFactory;
 
-public class EPPSessionPoolableFactory implements PoolableObjectFactory {
+public class EPPSessionPoolableFactory implements PooledObjectFactory<EPPPooledGenericSession> {
 
-	/** Log4j category for logging */
-	private static Logger log = Logger.getLogger(EPPSessionPoolableFactory.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	/** Category for logging */
+	private static Logger log = LoggerFactory.getLogger(EPPSessionPoolableFactory.class);
+
+	/**
+	 * The timeout value is not set.
+	 */
+	public static long TIMEOUT_UNSET = -1;
 
 	/**
 	 * Client id used during session authentication.
@@ -44,14 +51,34 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	private String password;
 
 	/**
-	 * Session absolute timeout in milliseconds
+	 * Session absolute timeout in milliseconds for all sessions. If both
+	 * {@code minAbsoluteTimeout} and {@code maxAbsoluteTimemout} are set, they
+	 * will override the setting of the {@code absoluteTimeout}.
 	 */
-	private long absoluteTimeout;
+	private long absoluteTimeout = TIMEOUT_UNSET;
+
+	/**
+	 * Minimum absolute timeout in milliseconds. The actual absolute timeout will
+	 * be randomized between the {@code minAbsoluteTimeout} and
+	 * {@code maxAbsoluteTimeout}. If both {@code minAbsoluteTimeout} and
+	 * {@code maxAbsoluteTimemout} are set, they will override the setting of the
+	 * {@code absoluteTimeout}.
+	 */
+	private long minAbsoluteTimeout = TIMEOUT_UNSET;
+
+	/**
+	 * Maximum absolute timeout in milliseconds. The actual absolute timeout will
+	 * be randomized between the {@code minAbsoluteTimeout} and
+	 * {@code maxAbsoluteTimeout}. If both {@code minAbsoluteTimeout} and
+	 * {@code maxAbsoluteTimemout} are set, they will override the setting of the
+	 * {@code absoluteTimeout}.
+	 */
+	private long maxAbsoluteTimeout = TIMEOUT_UNSET;
 
 	/**
 	 * Idle timeout in milliseconds
 	 */
-	private long idleTimeout;
+	private long idleTimeout = TIMEOUT_UNSET;
 
 	/**
 	 * Name or IP address of TCP server or URL of HTTP server.
@@ -92,16 +119,12 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	 * </ul>
 	 */
 	public EPPSessionPoolableFactory() {
-		this.clientId = null;
-		this.password = null;
-		this.absoluteTimeout = -1;
-		this.idleTimeout = -1;
 	}
 
 	/**
 	 * Create an EPP session poolable factory with the client id, password used
-	 * to authenticate the session.
-	 * 
+	 * to authenticate the session along with the timeout settings.
+	 *
 	 * @param aClientId
 	 *           Login id used to authenticate
 	 * @param aPassword
@@ -119,11 +142,36 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 		this.idleTimeout = aIdleTimeout;
 	}
 
+	/**
+	 * Create an EPP session poolable factory with the client id, password used
+	 * to authenticate the session along with the timeout settings.
+	 *
+	 * @param aClientId
+	 *           Login id used to authenticate
+	 * @param aPassword
+	 *           Password used to authenticate
+	 * @param aMinAbsoluteTimeout
+	 *           Session minimum absolute timeout
+	 * @param aMaxAbsoluteTimeout
+	 *           Session maximum absolute timeout
+	 * @param aIdleTimeout
+	 *           Session idle timeout
+	 */
+	public EPPSessionPoolableFactory(String aClientId, String aPassword, long aMinAbsoluteTimeout,
+	      long aMaxAbsoluteTimeout, long aIdleTimeout) {
+
+		this.clientId = aClientId;
+		this.password = aPassword;
+		this.minAbsoluteTimeout = aMinAbsoluteTimeout;
+		this.maxAbsoluteTimeout = aMaxAbsoluteTimeout;
+		this.idleTimeout = aIdleTimeout;
+	}
+
 	/**
 	 * @return Returns the clientId.
 	 */
 	public String getClientId() {
-		return clientId;
+		return this.clientId;
 	}
 
 	/**
@@ -138,7 +186,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	 * @return Returns the password.
 	 */
 	public String getPassword() {
-		return password;
+		return this.password;
 	}
 
 	/**
@@ -150,8 +198,8 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	}
 
 	/**
-	 * Gets the session absolute timeout.
-	 * 
+	 * Gets the session absolute timeout in milliseconds.
+	 *
 	 * @return Absolute timeout in milliseconds
 	 */
 	public long getAbsoluteTimeout() {
@@ -159,8 +207,8 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	}
 
 	/**
-	 * Sets the session absolute timeout.
-	 * 
+	 * Sets the session absolute timeout in milliseconds.
+	 *
 	 * @param aAbsoluteTimeout
 	 *           Absolute timeout in milliseconds.
 	 */
@@ -169,8 +217,82 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	}
 
 	/**
-	 * Gets the session idle timeout.
+	 * Gets the minimum session absolute timeout in milliseconds. If both
+	 * {@code minAbsoluteTimeout} and {@code maxAbsoluteTimemout} are set, they
+	 * will override the setting of {@code absoluteTimeout}.
+	 *
+	 * @return Minimum absolute timeout in milliseconds
+	 */
+	public long getMinAbsoluteTimeout() {
+		return this.minAbsoluteTimeout;
+	}
+
+	/**
+	 * Sets the minimum session absolute timeout. If both
+	 * {@code minAbsoluteTimeout} and {@code maxAbsoluteTimemout} are set, they
+	 * will override the setting of the {@code absoluteTimeout}.
+	 *
+	 * @param aMinAbsoluteTimeout
+	 *           Minimum absolute timeout in milliseconds.
+	 */
+	public void setMinAbsoluteTimeout(long aMinAbsoluteTimeout) {
+		this.minAbsoluteTimeout = aMinAbsoluteTimeout;
+	}
+
+	/**
+	 * Gets the maximum session absolute timeout in milliseconds. If both
+	 * {@code minAbsoluteTimeout} and {@code maxAbsoluteTimemout} are set, they
+	 * will override the setting of {@code absoluteTimeout}.
+	 *
+	 * @return Maximum absolute timeout in milliseconds
+	 */
+	public long getMaxAbsoluteTimeout() {
+		return this.maxAbsoluteTimeout;
+	}
+
+	/**
+	 * Sets the maximum session absolute timeout. If both
+	 * {@code minAbsoluteTimeout} and {@code maxAbsoluteTimemout} are set, they
+	 * will override the setting of the {@code absoluteTimeout}.
+	 *
+	 * @param aMaxAbsoluteTimeout
+	 *           Maximum absolute timeout in milliseconds.
+	 */
+	public void setMaxAbsoluteTimeout(long aMaxAbsoluteTimeout) {
+		this.maxAbsoluteTimeout = aMaxAbsoluteTimeout;
+	}
+
+	/**
+	 * Returns whether the absolute timeout will be randomized between the
+	 * {@code minAbsoluteTimeout} and {@code maxAbsoluteTimemout}.
 	 * 
+	 * @return {@code true} if the absolute timeout will be randomized;
+	 *         {@code false} otherwise.
+	 */
+	public boolean isRandomAbsoluteTimeout() {
+		log.debug("isRandomAbsoluteTimeout: minAbsoluteTimeout = " + this.minAbsoluteTimeout + ", maxAbsoluteTimeout = "
+		      + this.maxAbsoluteTimeout);
+		if (this.minAbsoluteTimeout != TIMEOUT_UNSET && this.maxAbsoluteTimeout != TIMEOUT_UNSET) {
+			if (this.maxAbsoluteTimeout > this.minAbsoluteTimeout) {
+				log.debug("isRandomAbsoluteTimeout: returning true");
+				return true;
+			}
+			else {
+				log.debug("isRandomAbsoluteTimeout: maxAbsoluteTimeout <= minAbsoluteTimeout: returning false");
+				return false;
+			}
+
+		}
+		else {
+			log.debug("isRandomAbsoluteTimeout: maxAbsoluteTimeout or minAbsoluteTimeout not set: returning false");
+			return false;
+		}
+
+	}
+
+	/**
+	 * Gets the session idle timeout.
+	 *
 	 * @return The idle timeout in milliseconds
 	 */
 	public long getIdleTimeout() {
@@ -179,7 +301,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 
 	/**
 	 * Sets the session idle timeout.
-	 * 
+	 *
 	 * @param aIdleTimeout
 	 *           Idle session in milliseconds
 	 */
@@ -190,7 +312,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	/**
 	 * Gets the TCP server IP address or host name, or the URL of the HTTP
 	 * server.
-	 * 
+	 *
 	 * @return Server host name, IP address, or URL
 	 */
 	public String getServerName() {
@@ -199,7 +321,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 
 	/**
 	 * Sets the TCP server IP address or host name or the URL of the HTTP server.
-	 * 
+	 *
 	 * @param aServerName
 	 *           Server host name, IP address, or URL
 	 */
@@ -210,7 +332,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	/**
 	 * Gets the TCP server port number. This will be {@code null} if connecting
 	 * to a HTTP server.
-	 * 
+	 *
 	 * @return TCP server port number if defined; {@code null} otherwise.
 	 */
 	public Integer getServerPort() {
@@ -219,7 +341,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 
 	/**
 	 * Sets the TCP server port number.
-	 * 
+	 *
 	 * @param aServerPort
 	 *           TCP server port number
 	 */
@@ -230,7 +352,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	/**
 	 * Gets the TCP server IP address or host name to connect from. A
 	 * {@code null} value will use the loop back.
-	 * 
+	 *
 	 * @return Client host name or IP address if defined;{@code null} otherwise.
 	 */
 	public String getClientHost() {
@@ -240,7 +362,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	/**
 	 * Sets the TCP server IP address or host name to connect from. A
 	 * {@code null} value will use the loop back.
-	 * 
+	 *
 	 * @param aClientHost
 	 *           Client host name or IP address
 	 */
@@ -250,16 +372,16 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 
 	/**
 	 * Gets the optional {@code EPPSSLContext} associated with the factory.
-	 * 
+	 *
 	 * @return SSL Context if defined; {@code null} otherwise
 	 */
 	public EPPSSLContext getSSLContext() {
-		return sslContext;
+		return this.sslContext;
 	}
 
 	/**
 	 * Gets the optional {@code EPPSSLContext} associated with the factory.
-	 * 
+	 *
 	 * @param aSSLContext
 	 *           SSL Context to use by the factory
 	 */
@@ -269,7 +391,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 
 	/**
 	 * Gets the client transaction identifier generator object that is set.
-	 * 
+	 *
 	 * @return Client transaction identifier generator object if set;
 	 *         {@code null} otherwise.
 	 */
@@ -280,7 +402,7 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	/**
 	 * Sets the client transaction identifier generator object that is used to
 	 * generate client transaction identifiers for the login and logout commands.
-	 * 
+	 *
 	 * @param aClientTransIdGenerator
 	 *           Client transaction identifier generator object or {@code null}
 	 *           to unset the generator
@@ -291,27 +413,25 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 
 	/**
 	 * Session being borrowed from the pool.
-	 * 
+	 *
 	 * @param aSession
 	 *           Session being returned
-	 * 
-	 * @see org.apache.commons.pool.PoolableObjectFactory#activateObject(java.lang.Object)
 	 */
-	public void activateObject(Object aSession) throws Exception {
+	@Override
+	public void activateObject(PooledObject<EPPPooledGenericSession> aSession) throws Exception {
 		// Nothing for now
 	}
 
 	/**
 	 * Destroy object from the pool.
-	 * 
+	 *
 	 * @param aSession
 	 *           Session being destroyed
-	 * 
-	 * @see org.apache.commons.pool.PoolableObjectFactory#destroyObject(java.lang.Object)
 	 */
-	public void destroyObject(Object aSession) throws Exception {
-		log.debug("destroyObject(): enter, session id = " + aSession);
-		EPPSession theSession = (EPPSession) aSession;
+	@Override
+	public void destroyObject(PooledObject<EPPPooledGenericSession> aSession) throws Exception {
+		log.debug("destroyObject(): enter, sEPPPooledGenericSessionession id = " + aSession.getObject());
+		EPPPooledGenericSession theSession = aSession.getObject();
 
 		// Try to end the session gracefully
 		try {
@@ -330,14 +450,13 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 
 	/**
 	 * Creates a new session object.
-	 * 
-	 * @see org.apache.commons.pool.PoolableObjectFactory#makeObject()
 	 */
-	public Object makeObject() throws Exception {
+	@Override
+	public PooledObject<EPPPooledGenericSession> makeObject() throws Exception {
 
 		log.debug("makeObject(): enter");
 
-		EPPSession theSession = this.makeSession();
+		EPPPooledGenericSession theSession = this.makeSession();
 
 		log.debug("makeObject(): Make session with id = " + theSession);
 
@@ -372,49 +491,46 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 		}
 
 		log.debug("makeObject(): exit");
-		return theSession;
+		return new DefaultPooledObject<>(theSession);
 	}
 
 	/**
 	 * Session is being returned to the pool.
-	 * 
+	 *
 	 * @param aSession
 	 *           Session being returned
-	 * 
-	 * @see org.apache.commons.pool.PoolableObjectFactory#passivateObject(java.lang.Object)
 	 */
-	public void passivateObject(Object aSession) throws Exception {
+	@Override
+	public void passivateObject(PooledObject<EPPPooledGenericSession> aSession) throws Exception {
 		// Nothing for now
 	}
 
 	/**
 	 * Validates a session by sending a keep alive. If an exception occurs from
 	 * the keep alive, than the session is not valid.
-	 * 
-	 * @see org.apache.commons.pool.PoolableObjectFactory#validateObject(java.lang.Object)
-	 * 
+	 *
 	 * @param aSession
 	 *           Session to validate
-	 * 
+	 *
 	 * @return {@code true} if the session is valid; {@code false} otherwise.
 	 */
-	public boolean validateObject(Object aSession) {
+	@Override
+	public boolean validateObject(PooledObject<EPPPooledGenericSession> aSession) {
 		log.debug("validateObject(): enter, session id = " + aSession);
-		EPPSession theSession = (EPPSession) aSession;
-		EPPPooledSession thePooledSession = (EPPPooledSession) aSession;
+		EPPPooledGenericSession theSession = aSession.getObject();
 		long currentTime = System.currentTimeMillis();
 		boolean isValid;
 
 		try {
 			// Is session past absolute timeout?
-			if (currentTime - thePooledSession.getCreatedTime() > this.getAbsoluteTimeout()) {
+			if (currentTime - theSession.getCreatedTime() > theSession.getAbsoluteTimeout()) {
 				log.debug("validateObject(): session id = " + aSession + " is past absolute timeout");
 				isValid = false;
 			} // Idle timeout?
-			else if (System.currentTimeMillis() - thePooledSession.getLastTouched() > this.getIdleTimeout()) {
+			else if (System.currentTimeMillis() - theSession.getLastTouched() > this.getIdleTimeout()) {
 				log.debug("validateObject(): session id = " + aSession + " is past idle timeout, sending hello");
 				theSession.hello();
-				thePooledSession.touch();
+				theSession.touch();
 				isValid = true;
 			}
 			else {
@@ -435,27 +551,45 @@ public class EPPSessionPoolableFactory implements PoolableObjectFactory {
 	/**
 	 * Make an EPP session instance for pool. This can be overridden by a derived
 	 * class to create a custom EPP session instance (i.e. HTTP).
-	 * 
+	 *
 	 * @return {@code EPPSession} instance
-	 * 
+	 *
 	 * @throws Exception
 	 *            Configuration error or error creating pooled session.
 	 */
-	protected EPPSession makeSession() throws Exception {
+	protected EPPPooledGenericSession makeSession() throws Exception {
 		log.debug("makeSession(): enter");
 
+		EPPPooledGenericSession session = null;
+
 		if (this.serverName == null || this.serverPort == null) {
 			throw new EPPSessionPoolException("makeSession(): serverName or serverPort is null");
 		}
 
 		if (this.clientHost == null) {
-			return new EPPPooledGenericSession(this.serverName, this.serverPort.intValue(), this.sslContext);
+			session = new EPPPooledGenericSession(this.serverName, this.serverPort.intValue(), this.sslContext);
 		}
 		else {
-			return new EPPPooledGenericSession(this.serverName, this.serverPort.intValue(), this.clientHost,
+			session = new EPPPooledGenericSession(this.serverName, this.serverPort.intValue(), this.clientHost,
 			      this.sslContext);
 		}
 
+		// Randomize the absolute timeout?
+		if (this.isRandomAbsoluteTimeout()) {
+			// Randomize the session absolute timeout
+			long theAbsoluteTimeout = ThreadLocalRandom.current().nextLong(this.minAbsoluteTimeout,
+			      this.maxAbsoluteTimeout + 1);
+			log.debug("makeSession(): setting random absolute timeout (ms) = " + theAbsoluteTimeout);
+
+			session.setAbsoluteTimeout(theAbsoluteTimeout);
+		}
+		else {
+			log.debug("makeSession(): setting absolute timeout (ms) = " + this.absoluteTimeout);
+
+			session.setAbsoluteTimeout(this.absoluteTimeout);
+		}
+
+		return session;
 	}
 
 }
