@@ -25,46 +25,46 @@ import java.util.StringTokenizer;
 import com.verisign.epp.exception.EPPException;
 
 /**
- * The <code>EPPSSLConfig</code> class contains SSL configuration properties 
+ * The {@code EPPSSLConfig} class contains SSL configuration properties 
  * that can be used in conjunction with {@link EPPSSLImpl#initialize(EPPSSLConfig)} 
  * to initialize an {@link EPPSSLContext}.  The required properties include:<br>
  * <br><ol>
- * <li><code>sslProtocol</code> that defines the SSL protocol to use.  For example, 
+ * <li>{@code sslProtocol} that defines the SSL protocol to use.  For example, 
  * &quot;TLS&quot;.
- * <li><code>identityStoreType</code> that defines the type of the identity KeyStore.  
+ * <li>{@code identityStoreType} that defines the type of the identity KeyStore.  
  * For example, &quot;JKS&quot;. 
- * <li><code>identityFileName</code> that defines the name of the identity KeyStore file.  
+ * <li>{@code identityFileName} that defines the name of the identity KeyStore file.  
  * For example, &quot;identity.jks&quot;.
- * <li><code>identityPassPhrase</code> that defines the passphrase/password to access 
- * the identity KeyStore file defined by the <code>identityFileName</code> property.  
+ * <li>{@code identityPassPhrase} that defines the passphrase/password to access 
+ * the identity KeyStore file defined by the {@code identityFileName} property.  
  * </ol>
  * <br>
  * The optional properties include:<br>
  * <br><ol>
- * <li><code>identityKeyPassPhrase</code> that defines the passphrase/password for the 
+ * <li>{@code identityKeyPassPhrase} that defines the passphrase/password for the 
  * private key stored in the identity KeyStore.  If not defined, the value of the 
- * <code>identityPassPhrase</code> will be used.
- * <li><code>trustStoreType</code> that defines the KeyStore type of the Trust Store.  
- * This is only required if the Trust Store is defined by the <code>trustStoreFileName</code> 
+ * {@code identityPassPhrase} will be used.
+ * <li>{@code trustStoreType} that defines the KeyStore type of the Trust Store.  
+ * This is only required if the Trust Store is defined by the {@code trustStoreFileName} 
  * property.  For example, &quot;JKS&quot;.
- * <li><code>trustStoreFileName</code> that defines the name of the Trust Store file.  
+ * <li>{@code trustStoreFileName} that defines the name of the Trust Store file.  
  * For example, &quot;trust.jks&quot;.  If note defined, the default JDK Trust Store 
- * will be used that is located at the path <code>$JAVA_HOME/lib/security/cacerts</code>.
- * <li><code>trustStorePassPhrase</code> that defines the passphrase/password to access 
- * the identity KeyStore file defined by the <code>trustStoreFileName</code> property.  
- * This is only required if the Trust Store is defined by the <code>trustStoreFileName</code> 
+ * will be used that is located at the path {@code $JAVA_HOME/lib/security/cacerts}.
+ * <li>{@code trustStorePassPhrase} that defines the passphrase/password to access 
+ * the identity KeyStore file defined by the {@code trustStoreFileName} property.  
+ * This is only required if the Trust Store is defined by the {@code trustStoreFileName} 
  * property.   
- * <li><code>sslDebug</code> that defines that value of the SSL debug Java system property
- * <code>javax.net.debug</code>.  If not set, than the <code>javax.net.debug</code> 
+ * <li>{@code sslDebug} that defines that value of the SSL debug Java system property
+ * {@code javax.net.debug}.  If not set, than the {@code javax.net.debug} 
  * system property will not set.  The possible values include &quot;none&quot; and 
  * &quot;all&quot; and since it sets a Java system property it will global apply across all
  * SSL connections om the Java process.   
- * <li><code>sslEnabledProtocols</code> that defines the support SSL protocols supported.  
+ * <li>{@code sslEnabledProtocols} that defines the support SSL protocols supported.  
  * If not defined, the default protocols provided by the JSSE provider will be used.  
  * For example, {&quot;TLSv1&quot;, &quot;SSLv3&quot;}.
- * <li><code>sslEnabledCipherSuites</code> that defines the support SSL cipher suites supported.  
+ * <li>{@code sslEnabledCipherSuites} that defines the support SSL cipher suites supported.  
  * If not defined, the default cipher suites provided by the JSSE provider will be used.  
- * For example, <code>SSL_RSA_WITH_RC4_128_MD5 SSL_RSA_WITH_RC4_128_SHA</code>. 
+ * For example, {@code SSL_RSA_WITH_RC4_128_MD5 SSL_RSA_WITH_RC4_128_SHA}. 
  * </ol>
  * 
  * @see EPPSSLImpl
@@ -90,20 +90,20 @@ public class EPPSSLConfig {
 	/**
 	 * Defines the passphrase/password to access 
 	 * the identity KeyStore file defined by the 
-	 * <code>identityFileName</code> property.
+	 * {@code identityFileName} property.
 	 */
 	private String identityPassPhrase=null;
 	
 	/**
 	 * Defines the passphrase/password for the 
 	 * private key stored in the identity KeyStore.  If not defined, the value of the 
-	 * <code>identityPassPhrase</code> will be used.
+	 * {@code identityPassPhrase} will be used.
 	 */
 	private String identityKeyPassPhrase=null;
 	
 	/**
 	 * Defines the KeyStore type of the Trust Store.  
-	 * This is only required if the Trust Store is defined by the <code>trustStoreFileName</code> 
+	 * This is only required if the Trust Store is defined by the {@code trustStoreFileName} 
 	 * property.  For example, &quot;JKS&quot;.
 	 */
 	private String trustStoreType = null;
@@ -111,20 +111,20 @@ public class EPPSSLConfig {
 	/**
 	 * Defines the name of the Trust Store file.  
 	 * For example, &quot;trust.jks&quot;.  If note defined, the default JDK Trust Store 
-	 * will be used that is located at the path <code>$JAVA_HOME/lib/security/cacerts</code>.
+	 * will be used that is located at the path {@code $JAVA_HOME/lib/security/cacerts}.
 	 */
 	private String trustStoreFileName = null;
 	
 	/**
 	 * Defines the passphrase/password to access 
-	 * the Trust Store file defined by the <code>trustStoreFileName</code> property.  
-	 * This is only required if the Trust Store is defined by the <code>trustStoreFileName</code> 
+	 * the Trust Store file defined by the {@code trustStoreFileName} property.  
+	 * This is only required if the Trust Store is defined by the {@code trustStoreFileName} 
 	 * property.
 	 */
 	private String trustStorePassPhrase = null;
 	
 	/**defines that value of the SSL debug Java system property
-	 * <code>javax.net.debug</code>.  If not set, than the <code>javax.net.debug</code> 
+	 * {@code javax.net.debug}.  If not set, than the {@code javax.net.debug} 
 	 * system property will not set.
 	 */
 	private String sslDebug = null;
@@ -150,7 +150,7 @@ public class EPPSSLConfig {
 	}
 	
 	/**
-	 * Creates an instance of <code>EPPSSLConfig</code> that takes the required set of 
+	 * Creates an instance of {@code EPPSSLConfig} that takes the required set of 
 	 * attributes.
 	 * 
 	 * @param aSslProtocol SSL Protocol like &quot;TLS&quot;
@@ -167,25 +167,25 @@ public class EPPSSLConfig {
 	}
 	
 	/** 
-	 * Gets the Identity File Name <code>String</code>.
+	 * Gets the Identity File Name {@code String}.
 	 * 
-	 * @return <code>String</code> if set; <code>null</code> otherwise.
+	 * @return {@code String} if set; {@code null} otherwise.
 	 */
 	public String getIdentityFileName() {
 		return this.identityFileName;
 	}
 
 	/** 
-	 * Sets the Identity File Name <code>String</code>.
+	 * Sets the Identity File Name {@code String}.
 	 * 
-	 * @param aIdentityFileName <code>String</code>. 
+	 * @param aIdentityFileName {@code String}. 
 	 */
 	public void setIdentityFileName(String aIdentityFileName) {
 		this.identityFileName = aIdentityFileName;
 	}
 
 	/** 
-	 * Gets the Identity Key Pass Phrase <code>String</code> using the 
+	 * Gets the Identity Key Pass Phrase {@code String} using the 
 	 * Identity Pass Phrase as the default value.  
 	 * 
 	 * @return Identity Key Pass Phrase if set; otherwise the Identity Pass Phrase
@@ -199,10 +199,10 @@ public class EPPSSLConfig {
 	}
 	
 	/** 
-	 * Gets the Identity Key Pass Phrase as <code>char[]</code> using the 
+	 * Gets the Identity Key Pass Phrase as {@code char[]} using the 
 	 * Identity Pass Phrase as the default value.  
 	 * 
-	 * @return Identity Key Pass Phrase if set; otherwise the Identity Pass Phrase as <code>char[]</code>
+	 * @return Identity Key Pass Phrase if set; otherwise the Identity Pass Phrase as {@code char[]}
 	 */
 	public char[] getIdentityKeyPassPhraseCharArray() {
 		String theIdentityKeyPassPhrase = this.getIdentityKeyPassPhrase();
@@ -216,27 +216,27 @@ public class EPPSSLConfig {
 	
 
 	/** 
-	 * Sets the Identity Key Pass Phrase <code>String</code>.
+	 * Sets the Identity Key Pass Phrase {@code String}.
 	 * 
-	 * @param aIdentityKeyPassPhrase <code>String</code>. 
+	 * @param aIdentityKeyPassPhrase {@code String}. 
 	 */
 	public void setIdentityKeyPassPhrase(String aIdentityKeyPassPhrase) {
 		this.identityKeyPassPhrase = aIdentityKeyPassPhrase;
 	}
 
 	/** 
-	 * Gets the Identity Pass Phrase <code>String</code>.
+	 * Gets the Identity Pass Phrase {@code String}.
 	 * 
-	 * @return Identity Pass Phrase if set; <code>null</code> otherwise.
+	 * @return Identity Pass Phrase if set; {@code null} otherwise.
 	 */
 	public String getIdentityPassPhrase() {
 		return this.identityPassPhrase;
 	}
 	
 	/** 
-	 * Gets the Identity Pass Phrase as a <code>char[]</code>.
+	 * Gets the Identity Pass Phrase as a {@code char[]}.
 	 * 
-	 * @return Identity Pass Phrase if set; <code>null</code> otherwise.
+	 * @return Identity Pass Phrase if set; {@code null} otherwise.
 	 */
 	public char[] getIdentityPassPhraseCharArray() {
 		if (this.identityPassPhrase == null) {
@@ -248,63 +248,63 @@ public class EPPSSLConfig {
 	}
 
 	/** 
-	 * Sets the Identity Pass Phrase <code>String</code>.
+	 * Sets the Identity Pass Phrase {@code String}.
 	 * 
-	 * @param aIdentityPassPhrase <code>String</code>. 
+	 * @param aIdentityPassPhrase {@code String}. 
 	 */
 	public void setIdentityPassPhrase(String aIdentityPassPhrase) {
 		this.identityPassPhrase = aIdentityPassPhrase;
 	}
 
 	/** 
-	 * Gets the Identity Store Type <code>String</code>.
+	 * Gets the Identity Store Type {@code String}.
 	 * 
-	 * @return <code>String</code> if set; <code>null</code> otherwise.
+	 * @return {@code String} if set; {@code null} otherwise.
 	 */
 	public String getIdentityStoreType() {
 		return this.identityStoreType;
 	}
 
 	/** 
-	 * Sets the Identity Store Type <code>String</code>.
+	 * Sets the Identity Store Type {@code String}.
 	 * 
-	 * @param aIdentityStoreType <code>String</code>. 
+	 * @param aIdentityStoreType {@code String}. 
 	 */
 	public void setIdentityStoreType(String aIdentityStoreType) {
 		this.identityStoreType = aIdentityStoreType;
 	}
 
 	/** 
-	 * Gets the SSL Debug <code>String</code>.
+	 * Gets the SSL Debug {@code String}.
 	 * 
-	 * @return <code>String</code> if set; <code>null</code> otherwise.
+	 * @return {@code String} if set; {@code null} otherwise.
 	 */
 	public String getSslDebug() {
 		return this.sslDebug;
 	}
 
 	/** 
-	 * Sets the SSL Debug <code>String</code>.
+	 * Sets the SSL Debug {@code String}.
 	 * 
-	 * @param aSslDebug <code>String</code>. 
+	 * @param aSslDebug {@code String}. 
 	 */
 	public void setSslDebug(String aSslDebug) {
 		this.sslDebug = aSslDebug;
 	}
 
 	/** 
-	 * Gets the SSL Protocol <code>String</code>.
+	 * Gets the SSL Protocol {@code String}.
 	 * 
-	 * @return <code>String</code> if set; <code>null</code> otherwise.
+	 * @return {@code String} if set; {@code null} otherwise.
 	 */
 	public String getSslProtocol() {
 		return this.sslProtocol;
 	}
 
 	/** 
-	 * Sets the SSL Protocol <code>String</code>.
+	 * Sets the SSL Protocol {@code String}.
 	 * 
-	 * @param aSslProtocol <code>String</code>. 
+	 * @param aSslProtocol {@code String}. 
 	 */
 	public void setSslProtocol(String aSslProtocol) {
 		this.sslProtocol = aSslProtocol;
@@ -325,54 +325,54 @@ public class EPPSSLConfig {
 	}
 	
 	/** 
-	 * Gets the Trust Store Type <code>String</code>.
+	 * Gets the Trust Store Type {@code String}.
 	 * 
-	 * @return <code>String</code> if set; <code>null</code> otherwise.
+	 * @return {@code String} if set; {@code null} otherwise.
 	 */
 	public String getTrustStoreType() {
 		return this.trustStoreType;
 	}
 
 	/** 
-	 * Sets the Trust Store Type <code>String</code>.
+	 * Sets the Trust Store Type {@code String}.
 	 * 
-	 * @param aTrustStoreType <code>String</code>. 
+	 * @param aTrustStoreType {@code String}. 
 	 */
 	public void setTrustStoreType(String aTrustStoreType) {
 		this.trustStoreType = aTrustStoreType;
 	}
 
 	/** 
-	 * Gets the Trust Store File Name <code>String</code>.
+	 * Gets the Trust Store File Name {@code String}.
 	 * 
-	 * @return <code>String</code> if set; <code>null</code> otherwise.
+	 * @return {@code String} if set; {@code null} otherwise.
 	 */
 	public String getTrustStoreFileName() {
 		return this.trustStoreFileName;
 	}
 
 	/** 
-	 * Sets the Trust Store File Name <code>String</code>.
+	 * Sets the Trust Store File Name {@code String}.
 	 * 
-	 * @param aTrustStoreFileName <code>String</code>. 
+	 * @param aTrustStoreFileName {@code String}. 
 	 */
 	public void setTrustStoreFileName(String aTrustStoreFileName) {
 		this.trustStoreFileName = aTrustStoreFileName;
 	}
 
 	/** 
-	 * Gets the Trust Store Pass Phrase <code>String</code>.
+	 * Gets the Trust Store Pass Phrase {@code String}.
 	 * 
-	 * @return Trust Store Pass Phrase if set; <code>null</code> otherwise.
+	 * @return Trust Store Pass Phrase if set; {@code null} otherwise.
 	 */
 	public String getTrustStorePassPhrase() {
 		return this.trustStorePassPhrase;
 	}
 	
 	/** 
-	 * Gets the Trust Store Pass Phrase as <code>char[]</code>.
+	 * Gets the Trust Store Pass Phrase as {@code char[]}.
 	 * 
-	 * @return Trust Store Pass Phrase if set; <code>null</code> otherwise.
+	 * @return Trust Store Pass Phrase if set; {@code null} otherwise.
 	 */
 	public char[] getTrustStorePassPhraseCharArray() {
 		if (this.trustStorePassPhrase == null) {
@@ -385,9 +385,9 @@ public class EPPSSLConfig {
 	
 
 	/** 
-	 * Sets the Trust Store Pass Phrase <code>String</code>.
+	 * Sets the Trust Store Pass Phrase {@code String}.
 	 * 
-	 * @param aTrustStorePassPhrase <code>String</code>. 
+	 * @param aTrustStorePassPhrase {@code String}. 
 	 */
 	public void setTrustStorePassPhrase(String aTrustStorePassPhrase) {
 		this.trustStorePassPhrase = aTrustStorePassPhrase;
@@ -395,9 +395,9 @@ public class EPPSSLConfig {
 		
 	
 	/**
-	 * Gets the optional SSL enabled protocols <code>String</code> array.  
+	 * Gets the optional SSL enabled protocols {@code String} array.  
 	 * 
-	 * @return <code>>String</code> array if set; <code>null</code> otherwise.
+	 * @return {@code String} array if set; {@code null} otherwise.
 	 */
 	public String[] getSSLEnabledProtocols() {
 		return this.sslEnabledProtocols;
@@ -405,9 +405,9 @@ public class EPPSSLConfig {
 
 
 	/**
-	 * Sets the optional SSL enabled protocols <code>String</code> array.
+	 * Sets the optional SSL enabled protocols {@code String} array.
 	 * 
-	 * @param aSslEnabledProtocols <code>String</code> array of enabled SSL protocols
+	 * @param aSslEnabledProtocols {@code String} array of enabled SSL protocols
 	 */
 	public void setSSLEnabledProtocols(String[] aSslEnabledProtocols) {
 		this.sslEnabledProtocols = aSslEnabledProtocols;
@@ -434,9 +434,9 @@ public class EPPSSLConfig {
 	}
 	
 	/**
-	 * Gets the optional SSL enabled cipher suites <code>String</code> array.  
+	 * Gets the optional SSL enabled cipher suites {@code String} array.  
 	 * 
-	 * @return <code>>String</code> array if set; <code>null</code> otherwise.
+	 * @return {@code >String} array if set; {@code null} otherwise.
 	 */
 	public String[] getSSLEnabledCipherSuites() {
 		return this.sslEnabledCipherSuites;
@@ -444,9 +444,9 @@ public class EPPSSLConfig {
 	
 	
 	/**
-	 * Sets the optional SSL enabled cipher suites <code>String</code> array.
+	 * Sets the optional SSL enabled cipher suites {@code String} array.
 	 * 
-	 * @param aSslEnabledCipherSuites <code>String</code> array of enabled SSL cipher suites
+	 * @param aSslEnabledCipherSuites {@code String} array of enabled SSL cipher suites
 	 */
 	public void setSSLEnabledCipherSuites(String[] aSslEnabledCipherSuites) {
 		this.sslEnabledCipherSuites = aSslEnabledCipherSuites;
@@ -474,7 +474,7 @@ public class EPPSSLConfig {
 	
 	
 	/**
-	 * Validates the properties of the <code>EPPSSLConfig</code> by checking 
+	 * Validates the properties of the {@code EPPSSLConfig} by checking 
 	 * that the required properties are set. 
 	 * 
 	 * @throws EPPException On error
@@ -501,11 +501,11 @@ public class EPPSSLConfig {
 	}
 	
 	/**
-	 * Output the contents of the <code>EPPSSLConfig</code> instance 
-	 * which includes a comma seperated list of <code>EPPSSLConfig</code> 
+	 * Output the contents of the {@code EPPSSLConfig} instance 
+	 * which includes a comma seperated list of {@code EPPSSLConfig} 
 	 * properties with the values.  For example, &quot;sslProtocol = &lt;value&gt;&quot;.
 	 * 
-	 * @return <code>String</code> containing the <code>EPPSSLConfig</code> 
+	 * @return {@code String} containing the {@code EPPSSLConfig} 
 	 * properties and values
 	 */
 	public String toString() {
@@ -514,12 +514,12 @@ public class EPPSSLConfig {
 		theBuf.append("sslProtocol = " + this.sslProtocol);
 		theBuf.append(", identityStoreType = " + this.identityStoreType);
 		theBuf.append(", identityFileName = " + this.identityFileName);
-		theBuf.append(", identityPassPhrase = " + this.identityPassPhrase);
+/*		theBuf.append(", identityPassPhrase = " + this.identityPassPhrase);
 		theBuf.append(", identityKeyPassPhrase = " + this.identityKeyPassPhrase);
-		theBuf.append(", trustStoreStoreType = " + this.trustStoreType);
+*/		theBuf.append(", trustStoreStoreType = " + this.trustStoreType);
 		theBuf.append(", trustStoreFileName = " + this.trustStoreFileName);
-		theBuf.append(", trustStorePassPhrase = " + this.trustStorePassPhrase);
-		
+/*		theBuf.append(", trustStorePassPhrase = " + this.trustStorePassPhrase);
+*/		
 		if (this.sslEnabledProtocols != null) {
 			theBuf.append(", sslEnabledProtocols = [");
 			for (int i = 0; i < this.sslEnabledProtocols.length; i++) {
