@@ -32,7 +32,12 @@ import java.util.Set;
 import org.w3c.dom.Element;
 
 // EPP Imports
-import com.verisign.epp.codec.gen.*;
+import com.verisign.epp.codec.gen.EPPCodecException;
+import com.verisign.epp.codec.gen.EPPCommand;
+import com.verisign.epp.codec.gen.EPPMapFactory;
+import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.gen.EPPService;
+import com.verisign.epp.codec.gen.EPPUtil;
 
 
 /**
