@@ -19,13 +19,10 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.codec.host;
 
-
 // Log4j Imports
-import org.apache.log4j.Logger;
-import org.apache.log4j.Priority;
-
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
-
 //----------------------------------------------
 //
 // imports...
@@ -35,52 +32,48 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
 // EPP Imports
-import com.verisign.epp.codec.gen.*;
-import com.verisign.epp.util.EPPCatFactory;
-
+import com.verisign.epp.codec.gen.EPPDecodeException;
+import com.verisign.epp.codec.gen.EPPEncodeException;
+import com.verisign.epp.codec.gen.EPPUpdateCmd;
+import com.verisign.epp.codec.gen.EPPUtil;
 
 /**
  * Represents an EPP Host &lt;update&gt; command, which provides a transform
- * operation that allows a client to modify the attributes of a host object.
- * In addition to the standard EPP command elements, the &lt;update&gt;
- * command MUST contain a &lt;host:update&gt; element that identifies the host
- * namespace and the location of the host schema. The &lt;host:update&gt;
- * element SHALL contain the following child elements:<br><br>
+ * operation that allows a client to modify the attributes of a host object. In
+ * addition to the standard EPP command elements, the &lt;update&gt; command
+ * MUST contain a &lt;host:update&gt; element that identifies the host namespace
+ * and the location of the host schema. The &lt;host:update&gt; element SHALL
+ * contain the following child elements:<br>
+ * <br>
  * 
  * <ul>
- * <li>
- * A &lt;host:name&gt; element that contains the fully qualified host name of
- * the object to be updated.  Use <code>getName</code> and
- * <code>setName</code>     to get and set the element.
- * </li>
- * <li>
- * An OPTIONAL &lt;host:add&gt; element that contains attribute values to be
- * added to the host object.  Use <code>getAdd</code> and <code>setAdd</code>
- * to get and set the element.
- * </li>
- * <li>
- * An OPTIONAL &lt;host:rem&gt; element that contains attribute values to be
- * removed from the host object.  Use <code>getRemove</code> and
- * <code>setRemove</code>     to get and set the element.
- * </li>
- * <li>
- * An OPTIONAL &lt;host:chg&gt; element that contains attribute values to be
- * changed from the host object.  Use <code>getChange</code> and
- * <code>setChange</code>     to get and set the element.
- * </li>
+ * <li>A &lt;host:name&gt; element that contains the fully qualified host name
+ * of the object to be updated. Use <code>getName</code> and
+ * <code>setName</code> to get and set the element.</li>
+ * <li>An OPTIONAL &lt;host:add&gt; element that contains attribute values to be
+ * added to the host object. Use <code>getAdd</code> and <code>setAdd</code> to
+ * get and set the element.</li>
+ * <li>An OPTIONAL &lt;host:rem&gt; element that contains attribute values to be
+ * removed from the host object. Use <code>getRemove</code> and
+ * <code>setRemove</code> to get and set the element.</li>
+ * <li>An OPTIONAL &lt;host:chg&gt; element that contains attribute values to be
+ * changed from the host object. Use <code>getChange</code> and
+ * <code>setChange</code> to get and set the element.</li>
  * </ul>
  * 
- * <br>     Host name changes MAY require the addition or removal of IP
- * addresses to be accepted by the server.  If a new host name exists in a TLD
- * for which the server is not authoritative, then the host object MUST NOT
- * have any associated IP addresses.  If a new host name exists in a TLD for
- * which the server is authoritative, then the host object MAY have associated
- * IP addresses. Host name changes MAY have an impact on associated objects
- * that refer to the host object.  A host name change SHOULD not require
- * additional updates of associated objects to preserve existing associations. <br>
  * <br>
- * <code>EPPReponse</code> is the response associated     with
- * <code>EPPHostUpdateCmd</code>.     <br><br>
+ * Host name changes MAY require the addition or removal of IP addresses to be
+ * accepted by the server. If a new host name exists in a TLD for which the
+ * server is not authoritative, then the host object MUST NOT have any
+ * associated IP addresses. If a new host name exists in a TLD for which the
+ * server is authoritative, then the host object MAY have associated IP
+ * addresses. Host name changes MAY have an impact on associated objects that
+ * refer to the host object. A host name change SHOULD not require additional
+ * updates of associated objects to preserve existing associations. <br>
+ * <br>
+ * <code>EPPReponse</code> is the response associated with
+ * <code>EPPHostUpdateCmd</code>. <br>
+ * <br>
  *
  * @author $Author: jim $
  * @version $Revision: 1.2 $
@@ -95,11 +88,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/** XML Element Name for the name attribute. */
 	private final static String ELM_HOST_NAME = "host:name";
 
-	/** Log4j category for logging */
-	private static Logger cat =
-		Logger.getLogger(
-						 EPPHostUpdateCmd.class.getName(),
-						 EPPCatFactory.getInstance().getFactory());
+	/** Category for logging */
+	private static Logger cat = LoggerFactory.getLogger(EPPHostUpdateCmd.class);
 
 	/** Host Name of host to update. */
 	private String name = null;
@@ -114,9 +104,9 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	private EPPHostAddRemove change = null;
 
 	/**
-	 * <code>EPPHostUpdateCmd</code> default constructor.  The name is
-	 * initialized to <code>null</code>.     The name must be set before
-	 * invoking <code>encode</code>.
+	 * <code>EPPHostUpdateCmd</code> default constructor. The name is initialized
+	 * to <code>null</code>. The name must be set before invoking
+	 * <code>encode</code>.
 	 */
 	public EPPHostUpdateCmd() {
 	}
@@ -126,8 +116,10 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * <code>EPPHostUpdateCmd</code> constructor.
 	 *
-	 * @param aTransId Transaction Id associated with the command.
-	 * @param aName Host name to update.
+	 * @param aTransId
+	 *           Transaction Id associated with the command.
+	 * @param aName
+	 *           Host name to update.
 	 */
 	public EPPHostUpdateCmd(String aTransId, String aName) {
 		super(aTransId);
@@ -141,21 +133,25 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	 * <code>EPPHostUpdateCmd</code> constructor that takes the required
 	 * attributes as arguments.
 	 *
-	 * @param aTransId Transaction Id associated with the command.
-	 * @param aName Host name to update.
-	 * @param aAdd Attributes to add to the host.  <code>null</code> if no
-	 * 		  additions.
-	 * @param aRemove Attributes to remove from the host.  <code>null</code> if
-	 * 		  no removals.
-	 * @param aChange Attributes to change from the host.  <code>null</code> if
-	 * 		  no changes.
+	 * @param aTransId
+	 *           Transaction Id associated with the command.
+	 * @param aName
+	 *           Host name to update.
+	 * @param aAdd
+	 *           Attributes to add to the host. <code>null</code> if no
+	 *           additions.
+	 * @param aRemove
+	 *           Attributes to remove from the host. <code>null</code> if no
+	 *           removals.
+	 * @param aChange
+	 *           Attributes to change from the host. <code>null</code> if no
+	 *           changes.
 	 */
-	public EPPHostUpdateCmd(
-							String aTransId, String aName, EPPHostAddRemove aAdd,
-							EPPHostAddRemove aRemove, EPPHostAddRemove aChange) {
+	public EPPHostUpdateCmd(String aTransId, String aName, EPPHostAddRemove aAdd, EPPHostAddRemove aRemove,
+	      EPPHostAddRemove aChange) {
 		super(aTransId);
 
-		name     = aName;
+		name = aName;
 
 		add = aAdd;
 
@@ -176,7 +172,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 		}
 	}
 
-	// End EPPHostUpdateCmd.EPPHostUpdateCmd(String, String, EPPHostAddRemove, EPPHostAddRemove, EPPHostAddRemove)
+	// End EPPHostUpdateCmd.EPPHostUpdateCmd(String, String, EPPHostAddRemove,
+	// EPPHostAddRemove, EPPHostAddRemove)
 
 	/**
 	 * Gets the EPP command Namespace associated with
@@ -194,14 +191,14 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	 * Encode a DOM Element tree from the attributes of the
 	 * <code>EPPHostUpdateCmd</code> instance.
 	 *
-	 * @param aDocument DOM Document that is being built.  Used as an Element
-	 * 		  factory.
+	 * @param aDocument
+	 *           DOM Document that is being built. Used as an Element factory.
 	 *
 	 * @return Root DOM Element representing the <code>EPPHostUpdateCmd</code>
-	 * 		   instance.
+	 *         instance.
 	 *
-	 * @exception EPPEncodeException Unable to encode
-	 * 			  <code>EPPHostUpdateCmd</code> instance.
+	 * @exception EPPEncodeException
+	 *               Unable to encode <code>EPPHostUpdateCmd</code> instance.
 	 */
 	protected Element doEncode(Document aDocument) throws EPPEncodeException {
 		// Validate state
@@ -209,15 +206,12 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 			throw new EPPEncodeException("required attribute name is not set");
 		}
 
-		Element root =
-			aDocument.createElementNS(EPPHostMapFactory.NS, ELM_NAME);
+		Element root = aDocument.createElementNS(EPPHostMapFactory.NS, ELM_NAME);
 
 		root.setAttribute("xmlns:host", EPPHostMapFactory.NS);
 
 		// Name
-		EPPUtil.encodeString(
-							 aDocument, root, name, EPPHostMapFactory.NS,
-							 ELM_HOST_NAME);
+		EPPUtil.encodeString(aDocument, root, name, EPPHostMapFactory.NS, ELM_HOST_NAME);
 
 		// Add
 		EPPUtil.encodeComp(aDocument, root, add);
@@ -234,47 +228,38 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	// End EPPHostUpdateCmd.doEncode(Document)
 
 	/**
-	 * Decode the <code>EPPHostUpdateCmd</code> attributes from the aElement
-	 * DOM Element tree.
+	 * Decode the <code>EPPHostUpdateCmd</code> attributes from the aElement DOM
+	 * Element tree.
 	 *
-	 * @param aElement Root DOM Element to decode <code>EPPHostUpdateCmd</code>
-	 * 		  from.
+	 * @param aElement
+	 *           Root DOM Element to decode <code>EPPHostUpdateCmd</code> from.
 	 *
-	 * @exception EPPDecodeException Unable to decode aElement
+	 * @exception EPPDecodeException
+	 *               Unable to decode aElement
 	 */
 	protected void doDecode(Element aElement) throws EPPDecodeException {
 		// Host Name
-		name =
-			EPPUtil.decodeString(aElement, EPPHostMapFactory.NS, ELM_HOST_NAME);
+		name = EPPUtil.decodeString(aElement, EPPHostMapFactory.NS, ELM_HOST_NAME);
 
 		// Add
-		add = (EPPHostAddRemove) EPPUtil.decodeComp(
-													aElement,
-													EPPHostMapFactory.NS,
-													EPPHostAddRemove.ELM_ADD,
-													EPPHostAddRemove.class);
+		add = (EPPHostAddRemove) EPPUtil.decodeComp(aElement, EPPHostMapFactory.NS, EPPHostAddRemove.ELM_ADD,
+		      EPPHostAddRemove.class);
 
 		if (add != null) {
 			add.setMode(EPPHostAddRemove.MODE_ADD);
 		}
 
 		// Remove
-		remove =
-			(EPPHostAddRemove) EPPUtil.decodeComp(
-												  aElement, EPPHostMapFactory.NS,
-												  EPPHostAddRemove.ELM_REMOVE,
-												  EPPHostAddRemove.class);
+		remove = (EPPHostAddRemove) EPPUtil.decodeComp(aElement, EPPHostMapFactory.NS, EPPHostAddRemove.ELM_REMOVE,
+		      EPPHostAddRemove.class);
 
 		if (remove != null) {
 			remove.setMode(EPPHostAddRemove.MODE_REMOVE);
 		}
 
 		// Change
-		change =
-			(EPPHostAddRemove) EPPUtil.decodeComp(
-												  aElement, EPPHostMapFactory.NS,
-												  EPPHostAddRemove.ELM_CHANGE,
-												  EPPHostAddRemove.class);
+		change = (EPPHostAddRemove) EPPUtil.decodeComp(aElement, EPPHostMapFactory.NS, EPPHostAddRemove.ELM_CHANGE,
+		      EPPHostAddRemove.class);
 
 		if (change != null) {
 			change.setMode(EPPHostAddRemove.MODE_CHANGE);
@@ -286,7 +271,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * Compare an instance of <code>EPPHostUpdateCmd</code> with this instance.
 	 *
-	 * @param aObject Object to compare with.
+	 * @param aObject
+	 *           Object to compare with.
 	 *
 	 * @return DOCUMENT ME!
 	 */
@@ -302,11 +288,7 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 		EPPHostUpdateCmd theComp = (EPPHostUpdateCmd) aObject;
 
 		// Name
-		if (
-			!(
-					(name == null) ? (theComp.name == null)
-									   : name.equals(theComp.name)
-				)) {
+		if (!((name == null) ? (theComp.name == null) : name.equals(theComp.name))) {
 			cat.error("Name " + name + " != " + theComp.name);
 
 			return false;
@@ -320,22 +302,14 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 		}
 
 		// Remove
-		if (
-			!(
-					(remove == null) ? (theComp.remove == null)
-										 : remove.equals(theComp.remove)
-				)) {
+		if (!((remove == null) ? (theComp.remove == null) : remove.equals(theComp.remove))) {
 			cat.error("Remove " + remove + " != " + theComp.remove);
 
 			return false;
 		}
 
 		// Change
-		if (
-			!(
-					(change == null) ? (theComp.change == null)
-										 : change.equals(theComp.change)
-				)) {
+		if (!((change == null) ? (theComp.change == null) : change.equals(theComp.change))) {
 			cat.error("Change " + change + " != " + theComp.change);
 
 			return false;
@@ -351,7 +325,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	 *
 	 * @return clone of <code>EPPHostUpdateCmd</code>
 	 *
-	 * @exception CloneNotSupportedException standard Object.clone exception
+	 * @exception CloneNotSupportedException
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPHostUpdateCmd clone = (EPPHostUpdateCmd) super.clone();
@@ -378,8 +353,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 * 		   <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
@@ -390,7 +365,7 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * Gets the host name to update.
 	 *
-	 * @return Host Name    if defined; <code>null</code> otherwise.
+	 * @return Host Name if defined; <code>null</code> otherwise.
 	 */
 	public String getName() {
 		return name;
@@ -401,7 +376,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * Sets the host name to update.
 	 *
-	 * @param aName Host Name
+	 * @param aName
+	 *           Host Name
 	 */
 	public void setName(String aName) {
 		name = aName;
@@ -413,7 +389,7 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	 * Gets the items to add to the host.
 	 *
 	 * @return Object that contains the list of elements to add to the host if
-	 * 		   defined; <code>null</code> otherwise.
+	 *         defined; <code>null</code> otherwise.
 	 */
 	public EPPHostAddRemove getAdd() {
 		return add;
@@ -424,8 +400,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * Sets the items to add to the host.
 	 *
-	 * @param aAdd Object that contains the list of elements to add to the
-	 * 		  host.
+	 * @param aAdd
+	 *           Object that contains the list of elements to add to the host.
 	 */
 	public void setAdd(EPPHostAddRemove aAdd) {
 		add = aAdd;
@@ -437,8 +413,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * Gets the items to remove from the host.
 	 *
-	 * @return Object that contains the list of elements to remove from the
-	 * 		   host if defined; <code>null</code> otherwise.
+	 * @return Object that contains the list of elements to remove from the host
+	 *         if defined; <code>null</code> otherwise.
 	 */
 	public EPPHostAddRemove getRemove() {
 		return remove;
@@ -449,8 +425,9 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * Sets the items to remove from the host.
 	 *
-	 * @param aRemove Object that contains the list of elements to remove from
-	 * 		  the host.
+	 * @param aRemove
+	 *           Object that contains the list of elements to remove from the
+	 *           host.
 	 */
 	public void setRemove(EPPHostAddRemove aRemove) {
 		remove = aRemove;
@@ -462,8 +439,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * Gets the items to change to the host.
 	 *
-	 * @return Object that contains the list of elements to change to the host
-	 * 		   if defined; <code>null</code> otherwise.
+	 * @return Object that contains the list of elements to change to the host if
+	 *         defined; <code>null</code> otherwise.
 	 */
 	public EPPHostAddRemove getChange() {
 		return change;
@@ -474,8 +451,8 @@ public class EPPHostUpdateCmd extends EPPUpdateCmd {
 	/**
 	 * Sets the items to add to the host.
 	 *
-	 * @param newChange Object that contains the list of elements to change to
-	 * 		  the host.
+	 * @param newChange
+	 *           Object that contains the list of elements to change to the host.
 	 */
 	public void setChange(EPPHostAddRemove newChange) {
 		change = newChange;
