@@ -23,14 +23,15 @@ import java.util.Enumeration;
 import java.util.Random;
 
 // Log4j imports
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.host.EPPHostAddress;
 import com.verisign.epp.codec.host.EPPHostCheckResp;
 import com.verisign.epp.codec.host.EPPHostCheckResult;
 import com.verisign.epp.codec.host.EPPHostInfoResp;
-import com.verisign.epp.util.EPPCatFactory;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -71,8 +72,8 @@ public class EPPHostTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPHostTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPHostTst.class);
+	      
 
 	/** EPP Host associated with test */
 	private EPPHost host = null;
