@@ -18,18 +18,18 @@ This library is free software; you can redistribute it and/or
 package com.verisign.epp.codec.idnext;
 
 // Log4j Imports
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
 
-import com.verisign.epp.codec.gen.EPPCodec;
 import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 // EPP imports
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  *
@@ -47,10 +47,10 @@ public class EPPIdnLangTag
     implements EPPCodecComponent {
 
     /**
-     * Log4j category for logging
+     * Category for logging
      */
-    private static Logger cat = Logger.getLogger(EPPIdnLangTag.class.getName(),
-                                EPPCatFactory.getInstance().getFactory());
+        private static Logger cat = LoggerFactory.getLogger(EPPIdnLangTag.class);
+                                
 
     /**
      * Constant for the idn lang tag 
