@@ -30,34 +30,32 @@ package com.verisign.epp.interfaces;
 // Java Core Imports
 import java.util.Random;
 
-// JUNIT Imports
-import junit.framework.*;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
-// Log4j imports
-import org.apache.log4j.*;
-
-// EPP Imports
-import com.verisign.epp.interfaces.EPPApplicationSingle;
-import com.verisign.epp.interfaces.EPPDomain;
-import com.verisign.epp.interfaces.EPPCommandException;
-import com.verisign.epp.transport.EPPClientCon;
+import com.verisign.epp.codec.domain.EPPDomainCreateResp;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.idnext.EPPIdnLangTag;
-import com.verisign.epp.codec.domain.*;
+import com.verisign.epp.transport.EPPClientCon;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
-import com.verisign.epp.util.EPPCatFactory;
+
+// JUNIT Imports
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
 
 /**
  * Is a unit test of the using the IDN Lang Extension classes with the
- * {@code EPPDomain} class. The unit test will initialize a session with an
- * EPP Server, will invoke {@code EPPDomain} operations with IDN Lang
- * Extensions, and will end a session with an EPP Server. The configuration file
- * used by the unit test defaults to epp.config, but can be changed by passing
- * the file path as the first command line argument. The unit test can be run in
- * multiple threads by setting the "threads" system property. For example, the
- * unit test can be run in 2 threads with the configuration file
- * ../../epp.config with the following command: <br>
+ * {@code EPPDomain} class. The unit test will initialize a session with an EPP
+ * Server, will invoke {@code EPPDomain} operations with IDN Lang Extensions,
+ * and will end a session with an EPP Server. The configuration file used by the
+ * unit test defaults to epp.config, but can be changed by passing the file path
+ * as the first command line argument. The unit test can be run in multiple
+ * threads by setting the "threads" system property. For example, the unit test
+ * can be run in 2 threads with the configuration file ../../epp.config with the
+ * following command: <br>
  * <br>
  * java com.verisign.epp.interfaces.EPPPersRegTst -Dthreads=2 ../../epp.config
  * <br>
@@ -69,9 +67,8 @@ import com.verisign.epp.util.EPPCatFactory;
 public class EPPIdnDomainTst extends TestCase {
 
 	/**
-	 * Allocates an {@code EPPIdnDomainTst} with a logical name. The
-	 * constructor will initialize the base class {@code TestCase} with the
-	 * logical name.
+	 * Allocates an {@code EPPIdnDomainTst} with a logical name. The constructor
+	 * will initialize the base class {@code TestCase} with the logical name.
 	 * 
 	 * @param name
 	 *           Logical name of the test
@@ -84,8 +81,8 @@ public class EPPIdnDomainTst extends TestCase {
 	} // End EPPIdnDomainTst(String)
 
 	/**
-	 * JUNIT test method to implement the {@code EPPIdnDomainTst TestCase}.
-	 * Each sub-test will be invoked in order to satisfy testing the EPPDomain
+	 * JUNIT test method to implement the {@code EPPIdnDomainTst TestCase}. Each
+	 * sub-test will be invoked in order to satisfy testing the EPPDomain
 	 * interface.
 	 */
 
@@ -114,8 +111,7 @@ public class EPPIdnDomainTst extends TestCase {
 	} // End EPPIdnDomainTst.testIdnLang()
 
 	/**
-	 * Unit test of using the IDN Lang Extension with {@code EPPDomain}
-	 * Create .
+	 * Unit test of using the IDN Lang Extension with {@code EPPDomain} Create .
 	 */
 
 	public void idnLangCreate() {
@@ -330,8 +326,8 @@ public class EPPIdnDomainTst extends TestCase {
 	} // End EPPIdnDomainTst.tearDown();
 
 	/**
-	 * JUNIT {@code suite} static method, which returns the tests associated
-	 * with {@code EPPIdnDomainTst}.
+	 * JUNIT {@code suite} static method, which returns the tests associated with
+	 * {@code EPPIdnDomainTst}.
 	 * 
 	 * @return Test to execute
 	 */
@@ -360,8 +356,8 @@ public class EPPIdnDomainTst extends TestCase {
 	/**
 	 * Handle an {@code EPPCommandException}, which can be either a server
 	 * generated error or a general exception. If the exception was caused by a
-	 * server error, "Server Error :&lt;Response XML&gt;" will be specified. If the
-	 * exception was caused by a general algorithm error, "General Error
+	 * server error, "Server Error :&lt;Response XML&gt;" will be specified. If
+	 * the exception was caused by a general algorithm error, "General Error
 	 * :&lt;Exception Description&gt;" will be specified.
 	 * 
 	 * @param aException
@@ -394,12 +390,12 @@ public class EPPIdnDomainTst extends TestCase {
 	 * Unit test main, which accepts the following system property options: <br>
 	 * <ul>
 	 * <li>iterations Number of unit test iterations to run
-	 * <li>validate Turn XML validation on ({@code true}) or off
-	 * ({@code false}). If validate is not specified, validation will be
-	 * off.
+	 * <li>validate Turn XML validation on ({@code true}) or off ({@code false}).
+	 * If validate is not specified, validation will be off.
 	 * </ul>
 	 * 
-	 * @param args Command line arguments
+	 * @param args
+	 *           Command line arguments
 	 */
 
 	public static void main(String args[]) {
@@ -512,8 +508,8 @@ public class EPPIdnDomainTst extends TestCase {
 	} // End EPPIdnDomainTst.testStart(String)
 
 	/**
-	 * Print the end of a test with the {@code Thread} name if the current
-	 * thread is a {@code TestThread}.
+	 * Print the end of a test with the {@code Thread} name if the current thread
+	 * is a {@code TestThread}.
 	 * 
 	 * @param Logical
 	 *           name for the test
@@ -638,8 +634,6 @@ public class EPPIdnDomainTst extends TestCase {
 	/**
 	 * Logging category
 	 */
-
-	private static final Logger cat = Logger.getLogger(EPPIdnDomainTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPIdnDomainTst.class);
 
 } // End class EPPIdnDomainTst
