@@ -18,7 +18,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 package com.verisign.epp.codec.launch;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -26,7 +27,6 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -37,11 +37,9 @@ import com.verisign.epp.util.EqualityUtil;
 public class EPPLaunchCheck implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(
-			EPPLaunchCheck.class.getName(), EPPCatFactory.getInstance()
-					.getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPLaunchCheck.class);
 
 	/**
 	 * Constant used to specify the claims check form type
@@ -66,8 +64,7 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	/**
 	 * Constant for the launch phase info extension tag
 	 */
-	public static final String ELM_NAME = EPPLaunchExtFactory.NS_PREFIX + ":"
-			+ ELM_LOCALNAME;
+	public static final String ELM_NAME = EPPLaunchExtFactory.NS_PREFIX + ":" + ELM_LOCALNAME;
 
 	/**
 	 * The "type" attribute name
@@ -96,7 +93,7 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * attribute value.
 	 * 
 	 * @param aPhase
-	 *            The phase with the value of to execute the check against.
+	 *           The phase with the value of to execute the check against.
 	 */
 	public EPPLaunchCheck(EPPLaunchPhase aPhase) {
 		this.phase = aPhase;
@@ -107,10 +104,10 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * type attribute value.
 	 * 
 	 * @param aPhase
-	 *            The phase with the value of to execute the check against.
+	 *           The phase with the value of to execute the check against.
 	 * @param aType
-	 *            Claims form type using either {@link #TYPE_CLAIMS} or
-	 *            {@link #TYPE_AVAILABILITY} or {@link #TYPE_TRADEMARK}.
+	 *           Claims form type using either {@link #TYPE_CLAIMS} or
+	 *           {@link #TYPE_AVAILABILITY} or {@link #TYPE_TRADEMARK}.
 	 */
 	public EPPLaunchCheck(EPPLaunchPhase aPhase, String aType) {
 		this.phase = aPhase;
@@ -122,8 +119,8 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * value.
 	 * 
 	 * @param aType
-	 *            Claims form type using either {@link #TYPE_CLAIMS} or
-	 *            {@link #TYPE_AVAILABILITY} or {@link #TYPE_TRADEMARK}.
+	 *           Claims form type using either {@link #TYPE_CLAIMS} or
+	 *           {@link #TYPE_AVAILABILITY} or {@link #TYPE_TRADEMARK}.
 	 */
 	public EPPLaunchCheck(String aType) {
 		this.type = aType;
@@ -155,7 +152,7 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * {@link #TYPE_CLAIMS} if undefined.
 	 * 
 	 * @param aType
-	 *            {@link #TYPE_CLAIMS} or {@link #TYPE_AVAILABILITY}
+	 *           {@link #TYPE_CLAIMS} or {@link #TYPE_AVAILABILITY}
 	 */
 	public void setType(String aType) {
 		this.type = aType;
@@ -184,7 +181,7 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * Sets the phase of the check command.
 	 * 
 	 * @param aPhase
-	 *            The phase with the value of to execute the check against.
+	 *           The phase with the value of to execute the check against.
 	 */
 	public void setPhase(EPPLaunchPhase aPhase) {
 		this.phase = aPhase;
@@ -195,8 +192,8 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * <code>PHASE</code> constants.
 	 * 
 	 * @param aPhaseString
-	 *            One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
-	 *            constants.
+	 *           One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
+	 *           constants.
 	 */
 	public void setPhase(String aPhaseString) {
 		this.phase = new EPPLaunchPhase(aPhaseString);
@@ -209,8 +206,7 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 *         <code>false</code> otherwise.
 	 */
 	public boolean isClaimsCheckForm() {
-		return (this.type == null || this.type.equals(TYPE_CLAIMS) ? true
-				: false);
+		return (this.type == null || this.type.equals(TYPE_CLAIMS) ? true : false);
 	}
 
 	/**
@@ -220,8 +216,7 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 *         <code>false</code> otherwise.
 	 */
 	public boolean isAvailabilityCheckForm() {
-		return (this.type != null && this.type.equals(TYPE_AVAILABILITY) ? true
-				: false);
+		return (this.type != null && this.type.equals(TYPE_AVAILABILITY) ? true : false);
 	}
 
 	/**
@@ -231,8 +226,7 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 *         <code>false</code> otherwise.
 	 */
 	public boolean isTrademarkCheckForm() {
-		return (this.type != null && this.type.equals(TYPE_TRADEMARK) ? true
-				: false);
+		return (this.type != null && this.type.equals(TYPE_TRADEMARK) ? true : false);
 	}
 
 	/**
@@ -240,7 +234,7 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * 
 	 * @return clone of <code>EPPLaunchCheck</code>
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 
@@ -252,42 +246,35 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * Encode the <code>EPPLaunchCheck</code> to a DOM Element
 	 * 
 	 * @param aDocument
-	 *            a DOM Document to attach data to.
+	 *           a DOM Document to attach data to.
 	 * @return The root element of this component.
 	 * 
 	 * @throws EPPEncodeException
-	 *             Thrown if any errors prevent encoding.
+	 *            Thrown if any errors prevent encoding.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " on in EPPLaunchCheck.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " on in EPPLaunchCheck.encode(Document)");
 		}
 
 		// Validate the setting of the phase
 		if (this.isTrademarkCheckForm()) {
 			if (this.phase != null) {
-				throw new EPPEncodeException(
-						"EPPLaunchCheck phase attribute must not be set using Trademark Check Form.");
+				throw new EPPEncodeException("EPPLaunchCheck phase attribute must not be set using Trademark Check Form.");
 			}
 		}
 		else if (this.phase == null) {
-			throw new EPPEncodeException(
-					"EPPLaunchCheck phase attribute must be set when not the Trademark Check Form.");
+			throw new EPPEncodeException("EPPLaunchCheck phase attribute must be set when not the Trademark Check Form.");
 		}
 
-		Element root = aDocument.createElementNS(EPPLaunchExtFactory.NS,
-				ELM_NAME);
+		Element root = aDocument.createElementNS(EPPLaunchExtFactory.NS, ELM_NAME);
 
 		// Type
 		if (this.type != null) {
-			if (!this.type.equals(TYPE_CLAIMS)
-					&& !this.type.equals(TYPE_AVAILABILITY)
-					&& !this.type.equals(TYPE_TRADEMARK)) {
-				throw new EPPEncodeException(
-						"EPPLaunchCheck type attribute with invalid value of: "
-								+ this.type);
+			if (!this.type.equals(TYPE_CLAIMS) && !this.type.equals(TYPE_AVAILABILITY)
+			      && !this.type.equals(TYPE_TRADEMARK)) {
+				throw new EPPEncodeException("EPPLaunchCheck type attribute with invalid value of: " + this.type);
 			}
 
 			root.setAttribute(ATTR_TYPE, this.type);
@@ -303,9 +290,9 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * Decode the DOM element to the <code>EPPLaunchCheck</code>.
 	 * 
 	 * @param aElement
-	 *            DOM Element to decode the attribute values
+	 *           DOM Element to decode the attribute values
 	 * @throws EPPDecodeException
-	 *             Error decoding the DOM Element
+	 *            Error decoding the DOM Element
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 
@@ -317,21 +304,18 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 
 		if (this.isClaimsCheckForm() || this.isAvailabilityCheckForm()) {
 			// Phase
-			this.phase = (EPPLaunchPhase) EPPUtil.decodeComp(aElement,
-					EPPLaunchExtFactory.NS, EPPLaunchPhase.ELM_NAME,
-					EPPLaunchPhase.class);
+			this.phase = (EPPLaunchPhase) EPPUtil.decodeComp(aElement, EPPLaunchExtFactory.NS, EPPLaunchPhase.ELM_NAME,
+			      EPPLaunchPhase.class);
 
 			if (this.phase == null) {
-				throw new EPPDecodeException(
-						"EPPLaunchCheck phase element not found.");
+				throw new EPPDecodeException("EPPLaunchCheck phase element not found.");
 			}
 		}
 		else if (this.isTrademarkCheckForm()) {
 			this.phase = null;
 		}
 		else {
-			throw new EPPDecodeException(
-					"EPPLaunchCheck invalid form on decode");
+			throw new EPPDecodeException("EPPLaunchCheck invalid form on decode");
 		}
 
 	}
@@ -340,16 +324,14 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * implements a deep <code>EPPLaunchCheck</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPLaunchCheck</code> instance to compare with
+	 *           <code>EPPLaunchCheck</code> instance to compare with
 	 * 
 	 * @return true if equal false otherwise
 	 */
 	public boolean equals(Object aObject) {
 
 		if (!(aObject instanceof EPPLaunchCheck)) {
-			cat.error("EPPLaunchCheck.equals(): "
-					+ aObject.getClass().getName()
-					+ " not EPPLaunchCheck instance");
+			cat.error("EPPLaunchCheck.equals(): " + aObject.getClass().getName() + " not EPPLaunchCheck instance");
 
 			return false;
 		}
@@ -376,11 +358,22 @@ public class EPPLaunchCheck implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
+	/**
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPLaunchExtFactory.NS;
+	}
+
 }
\ No newline at end of file
