@@ -22,7 +22,8 @@ package com.verisign.epp.codec.launch;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -30,7 +31,6 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -42,10 +42,9 @@ import com.verisign.epp.util.EqualityUtil;
 public class EPPLaunchChkData implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPLaunchChkData.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPLaunchChkData.class);
 
 	/**
 	 * Constant for the launch phase check response
@@ -55,8 +54,7 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	/**
 	 * Constant for the launch phase info extension tag
 	 */
-	public static final String ELM_NAME = EPPLaunchExtFactory.NS_PREFIX + ":"
-			+ ELM_LOCALNAME;
+	public static final String ELM_NAME = EPPLaunchExtFactory.NS_PREFIX + ":" + ELM_LOCALNAME;
 
 	/**
 	 * The phase using one of the <code>EPPLaunchPhase</code> <code>PHASE</code>
@@ -70,8 +68,8 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	private List<EPPLaunchCheckResult> results = new ArrayList<EPPLaunchCheckResult>();
 
 	/**
-	 * <code>EPPLaunchCheckResp</code> default constructor. The results list
-	 * will be empty.
+	 * <code>EPPLaunchCheckResp</code> default constructor. The results list will
+	 * be empty.
 	 */
 	public EPPLaunchChkData() {
 	}
@@ -81,19 +79,19 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * <code>transId</code> attribute.
 	 * 
 	 * @param aPhase
-	 *            One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
-	 *            constants.
+	 *           One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
+	 *           constants.
 	 */
 	public EPPLaunchChkData(EPPLaunchPhase aPhase) {
 		this.phase = aPhase;
 	}
 
 	/**
-	 * <code>EPPLaunchCheckResp</code> constructor that will set the result of
-	 * an individual domain without a phase.
+	 * <code>EPPLaunchCheckResp</code> constructor that will set the result of an
+	 * individual domain without a phase.
 	 * 
 	 * @param aResult
-	 *            Result of a single domain name.
+	 *           Result of a single domain name.
 	 */
 	public EPPLaunchChkData(EPPLaunchCheckResult aResult) {
 		this.addCheckResult(aResult);
@@ -104,21 +102,21 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * multiple domains without a phase.
 	 * 
 	 * @param aResults
-	 *            List of claims check results
+	 *           List of claims check results
 	 */
 	public EPPLaunchChkData(List<EPPLaunchCheckResult> aResults) {
 		this.setCheckResults(aResults);
 	}
 
 	/**
-	 * <code>EPPLaunchCheckResp</code> constructor that will set the result of
-	 * an individual domain.
+	 * <code>EPPLaunchCheckResp</code> constructor that will set the result of an
+	 * individual domain.
 	 * 
 	 * @param aPhase
-	 *            One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
-	 *            constants.
+	 *           One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
+	 *           constants.
 	 * @param aResult
-	 *            Result of a single domain name.
+	 *           Result of a single domain name.
 	 */
 	public EPPLaunchChkData(EPPLaunchPhase aPhase, EPPLaunchCheckResult aResult) {
 		this.phase = aPhase;
@@ -130,13 +128,12 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * multiple domains.
 	 * 
 	 * @param aPhase
-	 *            One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
-	 *            constants.
+	 *           One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
+	 *           constants.
 	 * @param aResults
-	 *            List of claims check results
+	 *           List of claims check results
 	 */
-	public EPPLaunchChkData(EPPLaunchPhase aPhase,
-			List<EPPLaunchCheckResult> aResults) {
+	public EPPLaunchChkData(EPPLaunchPhase aPhase, List<EPPLaunchCheckResult> aResults) {
 		this.phase = aPhase;
 		this.setCheckResults(aResults);
 	}
@@ -165,7 +162,7 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * implements a deep <code>EPPLaunchCheckResp</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPLaunchCheckResp</code> instance to compare with
+	 *           <code>EPPLaunchCheckResp</code> instance to compare with
 	 * 
 	 * @return true if equal false otherwise
 	 */
@@ -198,7 +195,7 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * @return clone of <code>EPPLaunchCheckResp</code>
 	 * 
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPLaunchChkData clone = (EPPLaunchChkData) super.clone();
@@ -235,8 +232,8 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * Sets the phase of the check response.
 	 * 
 	 * @param aPhase
-	 *            One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
-	 *            constants.
+	 *           One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
+	 *           constants.
 	 */
 	public void setPhase(EPPLaunchPhase aPhase) {
 		this.phase = aPhase;
@@ -247,8 +244,8 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * <code>PHASE</code> constants.
 	 * 
 	 * @param aPhaseString
-	 *            One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
-	 *            constants.
+	 *           One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
+	 *           constants.
 	 */
 	public void setPhase(String aPhaseString) {
 		this.phase = new EPPLaunchPhase(aPhaseString);
@@ -273,7 +270,7 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * Command.
 	 * 
 	 * @param aResults
-	 *            List of claims check results
+	 *           List of claims check results
 	 */
 	public void setCheckResults(List<EPPLaunchCheckResult> aResults) {
 		if (aResults == null) {
@@ -288,7 +285,7 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * Add a claims check result to the list of results.
 	 * 
 	 * @param aResult
-	 *            Claims check result to add to the list.
+	 *           Claims check result to add to the list.
 	 */
 	public void addCheckResult(EPPLaunchCheckResult aResult) {
 		this.results.add(aResult);
@@ -298,7 +295,7 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * Sets the claims result of an individual domain name.
 	 * 
 	 * @param aResult
-	 *            Claims check result to set
+	 *           Claims check result to set
 	 */
 	public void setCheckResult(EPPLaunchCheckResult aResult) {
 		this.results = new ArrayList<EPPLaunchCheckResult>();
@@ -310,23 +307,21 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * <code>EPPLaunchCheckResp</code> instance.
 	 * 
 	 * @param aDocument
-	 *            DOM Document that is being built. Used as an Element factory.
+	 *           DOM Document that is being built. Used as an Element factory.
 	 * 
 	 * @return Element Root DOM Element representing the
 	 *         <code>EPPLaunchCheckResp</code> instance.
 	 * 
 	 * @exception EPPEncodeException
-	 *                Unable to encode <code>EPPLaunchCheckResp</code> instance.
+	 *               Unable to encode <code>EPPLaunchCheckResp</code> instance.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " on in EPPLaunchCheckResp.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " on in EPPLaunchCheckResp.encode(Document)");
 		}
 
-		Element root = aDocument.createElementNS(EPPLaunchExtFactory.NS,
-				ELM_NAME);
+		Element root = aDocument.createElementNS(EPPLaunchExtFactory.NS, ELM_NAME);
 
 		// Phase
 		EPPUtil.encodeComp(aDocument, root, this.phase);
@@ -342,22 +337,20 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * DOM Element tree.
 	 * 
 	 * @param aElement
-	 *            Root DOM Element to decode <code>EPPLaunchCheckResp</code>
-	 *            from.
+	 *           Root DOM Element to decode <code>EPPLaunchCheckResp</code> from.
 	 * 
 	 * @exception EPPDecodeException
-	 *                Unable to decode aElement
+	 *               Unable to decode aElement
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 
 		// Phase
-		this.phase = (EPPLaunchPhase) EPPUtil.decodeComp(aElement,
-				EPPLaunchExtFactory.NS, EPPLaunchPhase.ELM_NAME,
-				EPPLaunchPhase.class);
+		this.phase = (EPPLaunchPhase) EPPUtil.decodeComp(aElement, EPPLaunchExtFactory.NS, EPPLaunchPhase.ELM_NAME,
+		      EPPLaunchPhase.class);
 
 		// Results
-		this.results = EPPUtil.decodeCompList(aElement, EPPLaunchExtFactory.NS,
-				EPPLaunchCheckResult.ELM_NAME, EPPLaunchCheckResult.class);
+		this.results = EPPUtil.decodeCompList(aElement, EPPLaunchExtFactory.NS, EPPLaunchCheckResult.ELM_NAME,
+		      EPPLaunchCheckResult.class);
 	}
 
 	/**
@@ -365,8 +358,8 @@ public class EPPLaunchChkData implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
