@@ -43,9 +43,6 @@ public class EPPLaunchExtFactory extends EPPExtFactory {
 	/** Namespace prefix associated with EPPLaunchExtFactory. */
 	public static final String NS_PREFIX = "launch";
 
-	/** XML Schema definition for EPPLaunchExtFactory */
-	public static final String NS_SCHEMA = "urn:ietf:params:xml:ns:launch-1.0 launch-1.0.xsd";
-
 	/**
 	 * Service object associated with EPPLaunchExtFactory. The service object is
 	 * used when creating the Greeting or the Login.
@@ -56,7 +53,7 @@ public class EPPLaunchExtFactory extends EPPExtFactory {
 	 * Create a new instance of EPPLaunchExtFactory
 	 */
 	public EPPLaunchExtFactory() {
-		service = new EPPService(NS_PREFIX, NS, NS_SCHEMA);
+		service = new EPPService(NS_PREFIX, NS);
 		service.setServiceType(EPPService.EXT_SERVICE);
 	}
 
