@@ -17,7 +17,8 @@
  ***********************************************************/
 package com.verisign.epp.codec.mark;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
@@ -26,7 +27,6 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -35,11 +35,9 @@ import com.verisign.epp.util.EqualityUtil;
 public class EPPMarkContact implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(
-			EPPMarkContact.class.getName(), EPPCatFactory.getInstance()
-					.getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPMarkContact.class);
 
 	/**
 	 * Owner entitlement for a holder contact.
@@ -84,14 +82,12 @@ public class EPPMarkContact implements EPPCodecComponent {
 	/**
 	 * Constant for the owner tag name
 	 */
-	public static final String ELM_HOLDER_NAME = EPPMark.NS_PREFIX + ":"
-			+ ELM_HOLDER_LOCALNAME;
+	public static final String ELM_HOLDER_NAME = EPPMark.NS_PREFIX + ":" + ELM_HOLDER_LOCALNAME;
 
 	/**
 	 * Constant for the contact tag name
 	 */
-	public static final String ELM_CONTACT_NAME = EPPMark.NS_PREFIX + ":"
-			+ ELM_CONTACT_LOCALNAME;
+	public static final String ELM_CONTACT_NAME = EPPMark.NS_PREFIX + ":" + ELM_CONTACT_LOCALNAME;
 
 	/**
 	 * Element local name for name of the individual or role represented by the
@@ -136,8 +132,8 @@ public class EPPMarkContact implements EPPCodecComponent {
 	private String localName = ELM_CONTACT_LOCALNAME;
 
 	/**
-	 * Entitlement for a holder contact using one of the
-	 * <code>ENTITLEMENT</code> constants.
+	 * Entitlement for a holder contact using one of the <code>ENTITLEMENT</code>
+	 * constants.
 	 */
 	private String entitlement;
 
@@ -198,20 +194,20 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * and email attributes.
 	 * 
 	 * @param aName
-	 *            name of the individual or role represented by the contact.
+	 *           name of the individual or role represented by the contact.
 	 * @param aOrg
-	 *            name of the organization with which the contact is affiliated.
+	 *           name of the organization with which the contact is affiliated.
 	 * @param aAddress
-	 *            address information associated with the contact.
+	 *           address information associated with the contact.
 	 * @param aVoice
-	 *            contact's voice telephone number
+	 *           contact's voice telephone number
 	 * @param aFax
-	 *            contact's facsimile telephone number
+	 *           contact's facsimile telephone number
 	 * @param aEmail
-	 *            contact's email address
+	 *           contact's email address
 	 */
-	public EPPMarkContact(String aName, String aOrg, EPPMarkAddress aAddress,
-			String aVoice, String aFax, String aEmail) {
+	public EPPMarkContact(String aName, String aOrg, EPPMarkAddress aAddress, String aVoice, String aFax,
+	      String aEmail) {
 		this.name = aName;
 		this.org = aOrg;
 		this.address = aAddress;
@@ -225,7 +221,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * 
 	 * @return clone of <code>EPPMark</code>
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPMarkContact clone = (EPPMarkContact) super.clone();
@@ -241,17 +237,16 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets all this instance's data in the given XML document
 	 * 
 	 * @param aDocument
-	 *            a DOM Document to attach data to.
+	 *           a DOM Document to attach data to.
 	 * @return The root element of this component.
 	 * 
 	 * @throws EPPEncodeException
-	 *             Thrown if any errors prevent encoding.
+	 *            Thrown if any errors prevent encoding.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " on in EPPMark.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " on in EPPMark.encode(Document)");
 		}
 
 		// Validate attribute independent of type of contact
@@ -275,8 +270,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 			}
 		}
 
-		Element root = aDocument.createElementNS(EPPMark.NS, EPPMark.NS_PREFIX
-				+ ":" + this.localName);
+		Element root = aDocument.createElementNS(EPPMark.NS, EPPMark.NS_PREFIX + ":" + this.localName);
 
 		// Is contact (non-holder contact)?
 		if (this.isContact()) {
@@ -295,20 +289,17 @@ public class EPPMarkContact implements EPPCodecComponent {
 		}
 
 		// Name
-		EPPUtil.encodeString(aDocument, root, this.name, EPPMark.NS,
-				EPPMark.NS_PREFIX + ":" + ELM_NAME);
+		EPPUtil.encodeString(aDocument, root, this.name, EPPMark.NS, EPPMark.NS_PREFIX + ":" + ELM_NAME);
 
 		// Org
-		EPPUtil.encodeString(aDocument, root, this.org, EPPMark.NS,
-				EPPMark.NS_PREFIX + ":" + ELM_ORG);
+		EPPUtil.encodeString(aDocument, root, this.org, EPPMark.NS, EPPMark.NS_PREFIX + ":" + ELM_ORG);
 
 		// Address
 		EPPUtil.encodeComp(aDocument, root, this.address);
 
 		// Voice
 		if (this.voice != null) {
-			Element currElm = aDocument.createElementNS(EPPMark.NS,
-					EPPMark.NS_PREFIX + ":" + ELM_VOICE);
+			Element currElm = aDocument.createElementNS(EPPMark.NS, EPPMark.NS_PREFIX + ":" + ELM_VOICE);
 			Text currVal = aDocument.createTextNode(this.voice);
 
 			if (this.voiceExt != null) {
@@ -321,8 +312,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 
 		// Fax
 		if (this.fax != null) {
-			Element currElm = aDocument.createElementNS(EPPMark.NS,
-					EPPMark.NS_PREFIX + ":" + ELM_FAX);
+			Element currElm = aDocument.createElementNS(EPPMark.NS, EPPMark.NS_PREFIX + ":" + ELM_FAX);
 			Text currVal = aDocument.createTextNode(this.fax);
 
 			if (this.faxExt != null) {
@@ -334,8 +324,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 		}
 
 		// Email
-		EPPUtil.encodeString(aDocument, root, this.email, EPPMark.NS,
-				EPPMark.NS_PREFIX + ":" + ELM_EMAIL);
+		EPPUtil.encodeString(aDocument, root, this.email, EPPMark.NS, EPPMark.NS_PREFIX + ":" + ELM_EMAIL);
 
 		return root;
 	}
@@ -344,9 +333,9 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Decode the <code>EPPMark</code> component
 	 * 
 	 * @param aElement
-	 *            Root element of the <code>EPPMark</code>
+	 *           Root element of the <code>EPPMark</code>
 	 * @throws EPPDecodeException
-	 *             Error decoding the <code>EPPMark</code>
+	 *            Error decoding the <code>EPPMark</code>
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 
@@ -380,15 +369,14 @@ public class EPPMarkContact implements EPPCodecComponent {
 		this.org = EPPUtil.decodeString(aElement, EPPMark.NS, ELM_ORG);
 
 		// Address
-		this.address = (EPPMarkAddress) EPPUtil.decodeComp(aElement,
-				EPPMark.NS, EPPMarkAddress.ELM_NAME, EPPMarkAddress.class);
+		this.address = (EPPMarkAddress) EPPUtil.decodeComp(aElement, EPPMark.NS, EPPMarkAddress.ELM_NAME,
+		      EPPMarkAddress.class);
 
 		// Voice
 		this.voice = EPPUtil.decodeString(aElement, EPPMark.NS, ELM_VOICE);
 
 		if (this.voice != null) {
-			Element currElm = EPPUtil.getElementByTagNameNS(aElement,
-					EPPMark.NS, ELM_VOICE);
+			Element currElm = EPPUtil.getElementByTagNameNS(aElement, EPPMark.NS, ELM_VOICE);
 			this.voiceExt = currElm.getAttribute(ATTR_EXT);
 
 			if (this.voiceExt.isEmpty()) {
@@ -403,8 +391,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 		this.fax = EPPUtil.decodeString(aElement, EPPMark.NS, ELM_FAX);
 
 		if (this.fax != null) {
-			Element currElm = EPPUtil.getElementByTagNameNS(aElement,
-					EPPMark.NS, ELM_FAX);
+			Element currElm = EPPUtil.getElementByTagNameNS(aElement, EPPMark.NS, ELM_FAX);
 			this.faxExt = currElm.getAttribute(ATTR_EXT);
 
 			if (this.faxExt.isEmpty()) {
@@ -424,7 +411,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * implements a deep <code>EPPMarkContact</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPMarkContact</code> instance to compare with
+	 *           <code>EPPMarkContact</code> instance to compare with
 	 * 
 	 * @return true if equal false otherwise
 	 */
@@ -525,7 +512,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * <code>ELM_HOLDER_LOCALNAME</code> or <code>ELM_CONTACT_LOCALNAME</code>.
 	 * 
 	 * @param aLocalName
-	 *            XML local name of the mark contact
+	 *           XML local name of the mark contact
 	 */
 	public void setLocalName(String aLocalName) {
 		this.localName = aLocalName;
@@ -545,8 +532,8 @@ public class EPPMarkContact implements EPPCodecComponent {
 	/**
 	 * Gets the entitlement of the holder contact.
 	 * 
-	 * @return Entitlement using one of the <code>ENTITLEMENT</code> constants
-	 *         if defined; <code>null</code> otherwise.
+	 * @return Entitlement using one of the <code>ENTITLEMENT</code> constants if
+	 *         defined; <code>null</code> otherwise.
 	 */
 	public String getEntitlement() {
 		return this.entitlement;
@@ -556,8 +543,8 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the entitlement of the holder contact.
 	 * 
 	 * @param aEntitlement
-	 *            Entitlement of the holder contact using one of the
-	 *            <code>ENTITLEMENT</code> constants.
+	 *           Entitlement of the holder contact using one of the
+	 *           <code>ENTITLEMENT</code> constants.
 	 */
 	public void setEntitlement(String aEntitlement) {
 		this.entitlement = aEntitlement;
@@ -576,8 +563,8 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the type of the (non-holder) contact.
 	 * 
 	 * @param aType
-	 *            Type of the contact using one of the <code>TYPE</code>
-	 *            constants.
+	 *           Type of the contact using one of the <code>TYPE</code>
+	 *           constants.
 	 */
 	public void setType(String aType) {
 		this.type = aType;
@@ -597,7 +584,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets name of the individual or role represented by the contact.
 	 * 
 	 * @param aName
-	 *            Name of the individual or role represented by the contact.
+	 *           Name of the individual or role represented by the contact.
 	 */
 	public void setName(String aName) {
 		this.name = aName;
@@ -617,8 +604,8 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the name of the organization with which the contact is affiliated.
 	 * 
 	 * @param aOrg
-	 *            The name of the organization with which the contact is
-	 *            affiliated.
+	 *           The name of the organization with which the contact is
+	 *           affiliated.
 	 */
 	public void setOrg(String aOrg) {
 		this.org = aOrg;
@@ -638,7 +625,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the address information associated with the contact.
 	 * 
 	 * @param aAddress
-	 *            address information associated with the contact.
+	 *           address information associated with the contact.
 	 */
 	public void setAddress(EPPMarkAddress aAddress) {
 		this.address = aAddress;
@@ -647,8 +634,8 @@ public class EPPMarkContact implements EPPCodecComponent {
 	/**
 	 * Gets the contact's voice telephone number.
 	 * 
-	 * @return The contact's voice telephone number if defined;
-	 *         <code>null</code> otherwise.
+	 * @return The contact's voice telephone number if defined; <code>null</code>
+	 *         otherwise.
 	 */
 	public String getVoice() {
 		return this.voice;
@@ -658,7 +645,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the contact's voice telephone number.
 	 * 
 	 * @param aVoice
-	 *            The contact's voice telephone number.
+	 *           The contact's voice telephone number.
 	 */
 	public void setVoice(String aVoice) {
 		this.voice = aVoice;
@@ -678,7 +665,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the contact's voice telephone extension number.
 	 * 
 	 * @param aVoiceExt
-	 *            The contact's voice telephone extension number.
+	 *           The contact's voice telephone extension number.
 	 */
 	public void setVoiceExt(String aVoiceExt) {
 		this.voiceExt = aVoiceExt;
@@ -698,7 +685,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the contact's facsimile telephone number.
 	 * 
 	 * @param aFax
-	 *            The contact's facsimile telephone number.
+	 *           The contact's facsimile telephone number.
 	 */
 	public void setFax(String aFax) {
 		this.fax = aFax;
@@ -718,7 +705,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the contact's facsimile telephone extension number.
 	 * 
 	 * @param aFaxExt
-	 *            The contact's facsimile telephone extension number.
+	 *           The contact's facsimile telephone extension number.
 	 */
 	public void setFaxExt(String aFaxExt) {
 		this.faxExt = aFaxExt;
@@ -738,7 +725,7 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * Sets the contact's email address.
 	 * 
 	 * @param aEmail
-	 *            The contact's email address.
+	 *           The contact's email address.
 	 */
 	public void setEmail(String aEmail) {
 		this.email = aEmail;
@@ -749,21 +736,22 @@ public class EPPMarkContact implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
-	
+
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
 	 */
 	@Override
 	public String getNamespace() {
 		return EPPMark.NS;
 	}
-	
+
 }
