@@ -28,7 +28,8 @@ import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.domain.EPPDomainCheckResp;
 import com.verisign.epp.codec.domain.EPPDomainCheckResult;
@@ -44,7 +45,7 @@ import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
 import com.verisign.epp.codec.namestoreext.EPPNamestoreExtNamestoreExt;
 import com.verisign.epp.transport.EPPClientCon;
-import com.verisign.epp.util.EPPCatFactory;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -81,8 +82,8 @@ public class EPPNamestoreExtDomainTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPNamestoreExtDomainTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPNamestoreExtDomainTst.class);
+	      
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
