@@ -19,15 +19,7 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.codec.nameWatch;
 
-import org.w3c.dom.Document;
-
-// W3C Imports
-import org.w3c.dom.Element;
-import org.w3c.dom.NodeList;
-
 import java.util.Date;
-import java.util.Enumeration;
-
 //----------------------------------------------
 //
 // imports...
@@ -36,8 +28,18 @@ import java.util.Enumeration;
 // Java Core Imports
 import java.util.Vector;
 
+import org.w3c.dom.Document;
+// W3C Imports
+import org.w3c.dom.Element;
+
 // EPP Imports
-import com.verisign.epp.codec.gen.*;
+import com.verisign.epp.codec.gen.EPPAuthInfo;
+import com.verisign.epp.codec.gen.EPPCodecException;
+import com.verisign.epp.codec.gen.EPPDecodeException;
+import com.verisign.epp.codec.gen.EPPEncodeException;
+import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.gen.EPPTransId;
+import com.verisign.epp.codec.gen.EPPUtil;
 
 
 /**
@@ -866,9 +868,6 @@ public class EPPNameWatchInfoResp extends EPPResponse {
 			aDocument.createElementNS(EPPNameWatchMapFactory.NS, ELM_NAME);
 
 		root.setAttribute("xmlns:nameWatch", EPPNameWatchMapFactory.NS);
-		root.setAttributeNS(
-							EPPCodec.NS_XSI, "xsi:schemaLocation",
-							EPPNameWatchMapFactory.NS_SCHEMA);
 
 		// roid
 		EPPUtil.encodeString(
