@@ -19,24 +19,19 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.codec.nameWatch;
 
-import org.w3c.dom.Document;
+import java.util.Date;
 
+import org.w3c.dom.Document;
 // W3C Imports
 import org.w3c.dom.Element;
 
-import java.util.Date;
-import java.util.Enumeration;
-
-//----------------------------------------------
-//
-// imports...
-//
-//----------------------------------------------
-// Java Core Imports
-import java.util.Vector;
-
 // EPP Imports
-import com.verisign.epp.codec.gen.*;
+import com.verisign.epp.codec.gen.EPPCodecException;
+import com.verisign.epp.codec.gen.EPPDecodeException;
+import com.verisign.epp.codec.gen.EPPEncodeException;
+import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.gen.EPPTransId;
+import com.verisign.epp.codec.gen.EPPUtil;
 
 
 /**
