@@ -94,7 +94,8 @@ package com.verisign.epp.interfaces;
 
 import java.util.GregorianCalendar;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
@@ -104,7 +105,7 @@ import com.verisign.epp.codec.nameWatch.EPPNameWatchRenewResp;
 import com.verisign.epp.codec.nameWatch.EPPNameWatchStatus;
 import com.verisign.epp.codec.nameWatch.EPPNameWatchTransferResp;
 import com.verisign.epp.transport.EPPClientCon;
-import com.verisign.epp.util.EPPCatFactory;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -115,10 +116,10 @@ import junit.framework.TestSuite;
 
 /**
  * 
- * Is a unit test of the <code>EPPNameWatch</code> class. The unit test will
+ * Is a unit test of the {@code EPPNameWatch} class. The unit test will
  * initialize a
  * 
- * session with an EPP Server, will invoke <code>EPPNameWatch</code> operations,
+ * session with an EPP Server, will invoke {@code EPPNameWatch} operations,
  * 
  * and will end a session with an EPP Server. The
  * 
@@ -162,9 +163,9 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Allocates an <code>EPPNameWatchTst</code> with a logical name. The
+	 * Allocates an {@code EPPNameWatchTst} with a logical name. The
 	 * 
-	 * constructor will initialize the base class <code>TestCase</code>
+	 * constructor will initialize the base class {@code TestCase}
 	 * 
 	 * with the logical name.
 	 *
@@ -183,8 +184,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * JUNIT test method to implement the <code>EPPNameWatchTst TestCase</code>.
-	 * Each
+	 * JUNIT test method to implement the {@code EPPNameWatchTst TestCase}. Each
 	 * 
 	 * sub-test will be invoked in order to satisfy testing the EPPNameWatch
 	 * interface.
@@ -229,7 +229,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPNameWatch.sendInfo</code>.
+	 * Unit test of {@code EPPNameWatch.sendInfo}.
 	 * 
 	 */
 
@@ -374,7 +374,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPNameWatch.sendCreate</code>.
+	 * Unit test of {@code EPPNameWatch.sendCreate}.
 	 * 
 	 */
 
@@ -474,7 +474,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPNameWatch.sendDelete</code>.
+	 * Unit test of {@code EPPNameWatch.sendDelete}.
 	 * 
 	 */
 
@@ -555,7 +555,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPNameWatch.sendRenew</code>.
+	 * Unit test of {@code EPPNameWatch.sendRenew}.
 	 * 
 	 */
 
@@ -645,7 +645,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPNameWatch.sendUpdate</code>.
+	 * Unit test of {@code EPPNameWatch.sendUpdate}.
 	 * 
 	 */
 
@@ -743,7 +743,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPNameWatch.sendTransfer</code> for a transfer query.
+	 * Unit test of {@code EPPNameWatch.sendTransfer} for a transfer query.
 	 * 
 	 */
 
@@ -811,7 +811,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPNameWatch.sendTransfer</code> for a transfer query.
+	 * Unit test of {@code EPPNameWatch.sendTransfer} for a transfer query.
 	 * 
 	 */
 
@@ -967,7 +967,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPSession.initSession</code>. The session attribute
+	 * Unit test of {@code EPPSession.initSession}. The session attribute
 	 * 
 	 * is initialized with the attributes defined in the EPP sample files.
 	 * 
@@ -1026,7 +1026,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Unit test of <code>EPPSession.endSession</code>. The session with the
+	 * Unit test of {@code EPPSession.endSession}. The session with the
 	 * 
 	 * EPP Server will be terminated.
 	 * 
@@ -1084,7 +1084,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * JUNIT <code>setUp</code> method, which sets the default client Id to
+	 * JUNIT {@code setUp} method, which sets the default client Id to
 	 * "theRegistrar".
 	 * 
 	 */
@@ -1118,7 +1118,7 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * JUNIT <code>tearDown</code>, which currently does nothing.
+	 * JUNIT {@code tearDown}, which currently does nothing.
 	 * 
 	 */
 
@@ -1130,12 +1130,12 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * JUNIT <code>suite</code> static method, which returns the tests
+	 * JUNIT {@code suite} static method, which returns the tests
 	 * 
-	 * associated with <code>EPPNameWatchTst</code>.
+	 * associated with {@code EPPNameWatchTst}.
 	 * 
+	 * @return Test to execute
 	 */
-
 	public static Test suite() {
 
 		TestSuite suite = new TestSuite(EPPNameWatchTst.class);
@@ -1160,16 +1160,16 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Handle an <code>EPPCommandException</code>, which can be either
+	 * Handle an {@code EPPCommandException}, which can be either
 	 * 
 	 * a server generated error or a general exception. If the exception
 	 * 
-	 * was caused by a server error, "Server Error : <Response XML>" will be
-	 * specified.
+	 * was caused by a server error, "Server Error : &lt;Response XML&gt;" will
+	 * be specified.
 	 * 
 	 * If the exception was caused by a general
 	 * 
-	 * algorithm error, "General Error : <Exception Description>" will
+	 * algorithm error, "General Error : &lt;Exception Description&gt;" will
 	 * 
 	 * be specified.
 	 *
@@ -1206,13 +1206,15 @@ public class EPPNameWatchTst extends TestCase
 	 * 
 	 * <li>iterations Number of unit test iterations to run
 	 * 
-	 * <li>validate Turn XML validation on (<code>true</code>) or off (
-	 * <code>false</code>).
+	 * <li>validate Turn XML validation on ({@code true}) or off (
+	 * {@code false}).
 	 * 
 	 * If validate is not specified, validation will be off.
 	 * 
 	 * </ul>
 	 * 
+	 * @param args
+	 *           Command line arguments
 	 */
 
 	public static void main(String args[]) {
@@ -1273,9 +1275,9 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * Print the start of a test with the {@code Thread} name if the current
 	 * 
-	 * thread is a <code>TestThread</code>.
+	 * thread is a {@code TestThread}.
 	 *
 	 * 
 	 * 
@@ -1304,9 +1306,9 @@ public class EPPNameWatchTst extends TestCase
 
 	/**
 	 * 
-	 * Print the end of a test with the <code>Thread</code> name if the current
+	 * Print the end of a test with the {@code Thread} name if the current
 	 * 
-	 * thread is a <code>TestThread</code>.
+	 * thread is a {@code TestThread}.
 	 *
 	 * 
 	 * 
@@ -1436,7 +1438,7 @@ public class EPPNameWatchTst extends TestCase
 	/**
 	 * 
 	 * Handle to the Singleton EPP Application instance (
-	 * <code>EPPApplicationSingle</code>)
+	 * {@code EPPApplicationSingle})
 	 * 
 	 */
 
@@ -1456,8 +1458,8 @@ public class EPPNameWatchTst extends TestCase
 	 * 
 	 */
 
-	private static final Logger cat = Logger.getLogger(EPPNameWatchTst.class.getName(),
+	private static Logger cat = LoggerFactory.getLogger(EPPNameWatchTst.class);
 
-	      EPPCatFactory.getInstance().getFactory());
+	      
 
 } // End class EPPNameWatchTst
