@@ -21,7 +21,8 @@ package com.verisign.epp.interfaces;
 
 import java.util.Random;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.domain.EPPDomainCreateResp;
 import com.verisign.epp.codec.domain.EPPDomainInfoResp;
@@ -31,7 +32,7 @@ import com.verisign.epp.codec.orgext.EPPOrgExtId;
 import com.verisign.epp.codec.orgext.EPPOrgExtInfData;
 import com.verisign.epp.codec.orgext.EPPOrgExtUpdate;
 import com.verisign.epp.transport.EPPClientCon;
-import com.verisign.epp.util.EPPCatFactory;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -74,8 +75,8 @@ public class EPPOrgExtDomainTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPOrgExtDomainTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPOrgExtDomainTst.class);
+	      
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
