@@ -19,7 +19,8 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
  ***********************************************************/
 package com.verisign.epp.codec.registry;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -99,9 +100,9 @@ public class EPPRegistryContact implements EPPCodecComponent {
 	private static final long serialVersionUID = -2835245153428894020L;
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPRegistryContact.class);
+	private static Logger cat =  LoggerFactory.getLogger(EPPRegistryContact.class);
 
 	/**
 	 * Constant for share policy where contacts are shared across all objects of
@@ -634,7 +635,7 @@ public class EPPRegistryContact implements EPPCodecComponent {
 	/**
 	 * Gets maximum number of contacts allowed in the check command.
 	 * 
-	 * parm maxCheckContact maximum number of contact identifiers
+	 * @param maxCheckContact maximum number of contact identifiers
 	 * (&lt;contact:id&gt; elements) that can be included in a contact check
 	 * command defined in RFC 5733
 	 */
