@@ -61,7 +61,7 @@ public class EPPRegistryContactPostalCode extends EPPRegistryMinMaxLength {
 	 * @param max DOCUMENT ME!
 	 */
 	public EPPRegistryContactPostalCode(int min, int max) {
-		this(new Integer(min), new Integer(max));
+		this(Integer.valueOf(min), Integer.valueOf(max));
 	}
 
 	/**
