@@ -23,7 +23,8 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -32,53 +33,46 @@ import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 
 /**
  * This class is encoded to the &lt;registry:domainName&gt; element inside the
  * &lt;registry:domain&gt; element. It represents policies for a domain name
  * label for a specific level, defined with the "level" attribute, with a
  * minimum value of "2" for the second level domain name label level. The
- * &lt;registry:domainName&gt; element contains the following child elements <br>
+ * &lt;registry:domainName&gt; element contains the following child elements
+ * <br>
  * <br>
  * 
  * <ul>
- * <li>
- * &lt;registry:minLength&gt; - An OPTIONAL minimum length of the domain name
- * label. Use {@link #getMinLength()} and {@link #setMinLength(Integer)} to get
- * and set the element.</li>
- * <li>
- * &lt;registry:maxLength&gt; - An OPTIONAL maximum length of the domain name
- * label. Use {@link #getMaxLength()} and {@link #setMaxLength(Integer)} to get
- * and set the element.</li>
- * <li>
- * &lt;registry:alphaNumStart&gt; - An OPTIONAL flag indicating whether the
+ * <li>&lt;registry:minLength&gt; - An OPTIONAL minimum length of the domain
+ * name label. Use {@link #getMinLength()} and {@link #setMinLength(Integer)} to
+ * get and set the element.</li>
+ * <li>&lt;registry:maxLength&gt; - An OPTIONAL maximum length of the domain
+ * name label. Use {@link #getMaxLength()} and {@link #setMaxLength(Integer)} to
+ * get and set the element.</li>
+ * <li>&lt;registry:alphaNumStart&gt; - An OPTIONAL flag indicating whether the
  * label must start with an alphanumeric character with a default of "false".
  * Use {@link #getAlphaNumStart()} and {@link #setAlphaNumStart(Boolean)} to get
  * and set the element.</li>
- * <li>
- * &lt;registry:alphaNumEnd&gt; - An OPTIONAL flag indicating whether the label
- * must end with an alphanumeric character with a default value of "false". Use
- * {@link #getAlphaNumEnd()} and {@link #setAlphaNumEnd(Boolean)} to get and set
- * the element.</li>
- * <li>
- * &lt;registry:onlyDnsChars&gt; - An OPTIONAL flag indicating whether the label
- * MUST only contain valid DNS characters (alphanumeric and '-') with a default
- * value of "true". Use {@link #getOnlyDnsChars()} and
+ * <li>&lt;registry:alphaNumEnd&gt; - An OPTIONAL flag indicating whether the
+ * label must end with an alphanumeric character with a default value of
+ * "false". Use {@link #getAlphaNumEnd()} and {@link #setAlphaNumEnd(Boolean)}
+ * to get and set the element.</li>
+ * <li>&lt;registry:onlyDnsChars&gt; - An OPTIONAL flag indicating whether the
+ * label MUST only contain valid DNS characters (alphanumeric and '-') with a
+ * default value of "true". Use {@link #getOnlyDnsChars()} and
  * {@link #setOnlyDnsChars(Boolean)} to get and set the element.</li>
- * <li>
- * &lt;registry:regex&gt; - Zero or more &lt;registry:regex&gt; elements that
- * contain a &lt;registry:expression&gt; child element that defines the regular
- * expression to apply to domain name label along with an OPTIONAL
+ * <li>&lt;registry:regex&gt; - Zero or more &lt;registry:regex&gt; elements
+ * that contain a &lt;registry:expression&gt; child element that defines the
+ * regular expression to apply to domain name label along with an OPTIONAL
  * &lt;registry:explanation&gt; child element that describes the regular
  * expression with an OPTIONAL "lang" attribute that defines the language of the
  * explanation with a default value of "en". Use {@link #getRegex()} and
  * {@link #setRegex(List)} to get and set the element.</li>
- * <li>
- * &lt;registry:reservedNames&gt; - An OPTIONAL element that defines the set of
- * reserved domain names starting from that label level. The reserved names can
- * refer to values with more than one level which is relative to the level of
- * the parent &lt;registry:domainName&gt; element. Use
+ * <li>&lt;registry:reservedNames&gt; - An OPTIONAL element that defines the set
+ * of reserved domain names starting from that label level. The reserved names
+ * can refer to values with more than one level which is relative to the level
+ * of the parent &lt;registry:domainName&gt; element. Use
  * {@link #getReservedNames()} and
  * {@link #setReservedNames(EPPRegistryReservedNames)} to get and set the
  * element.</li>
@@ -93,9 +87,8 @@ import com.verisign.epp.util.EPPCatFactory;
 public class EPPRegistryDomainName implements EPPCodecComponent {
 	private static final long serialVersionUID = -3575272010031382087L;
 
-	/** Log4j category for logging */
-	private static Logger cat = Logger.getLogger(EPPRegistryDomainName.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	/** Category for logging */
+	private static Logger cat = LoggerFactory.getLogger(EPPRegistryDomainName.class);
 
 	/** XML Element Name of <code>EPPRegistryDomainName</code> root element. */
 	final static String ELM_NAME = "registry:domainName";
@@ -121,7 +114,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	/** XML attribute name for the <code>level</code> attribute. */
 	final static String ATTR_LEVEL = "level";
 
-	/** Level of domain name. Value should be >= 2 */
+	/** Level of domain name. Value should be &gt;= 2 */
 	private Integer level = null;
 
 	/** Minimum number of characters in a domain name */
@@ -130,7 +123,9 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	/** Maximum number of characters in a domain name */
 	private Integer maxLength = null;
 
-	/** Whether or not to allow domain name start with an alphanumeric character */
+	/**
+	 * Whether or not to allow domain name start with an alphanumeric character
+	 */
 	private Boolean alphaNumStart = Boolean.FALSE;
 
 	/** Whether or not to allow domain name end with an alphanumeric character */
@@ -153,48 +148,42 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * {@code EPPRegistryDomainName} instance.
 	 * 
 	 * @param aDocument
-	 *            DOM Document that is being built. Used as an Element factory.
+	 *           DOM Document that is being built. Used as an Element factory.
 	 * 
 	 * @return Element Root DOM Element representing the
 	 *         {@code EPPRegistryDomainName} instance.
 	 * 
 	 * @exception EPPEncodeException
-	 *                - Unable to encode {@code EPPRegistryDomainName} instance.
+	 *               - Unable to encode {@code EPPRegistryDomainName} instance.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 		try {
 			validateState();
-		} catch (EPPCodecException e) {
-			throw new EPPEncodeException(
-					"Invalid state on EPPRegistryDomainName.encode: " + e);
+		}
+		catch (EPPCodecException e) {
+			throw new EPPEncodeException("Invalid state on EPPRegistryDomainName.encode: " + e);
 		}
 
-		Element root = aDocument.createElementNS(EPPRegistryMapFactory.NS,
-				ELM_NAME);
+		Element root = aDocument.createElementNS(EPPRegistryMapFactory.NS, ELM_NAME);
 		root.setAttribute(ATTR_LEVEL, level.toString());
 		if (minLength != null) {
-			EPPUtil.encodeString(aDocument, root, minLength.toString(),
-					EPPRegistryMapFactory.NS, ELM_MIN_LENGTH);
+			EPPUtil.encodeString(aDocument, root, minLength.toString(), EPPRegistryMapFactory.NS, ELM_MIN_LENGTH);
 		}
 		if (maxLength != null) {
-			EPPUtil.encodeString(aDocument, root, maxLength.toString(),
-					EPPRegistryMapFactory.NS, ELM_MAX_LENGTH);
+			EPPUtil.encodeString(aDocument, root, maxLength.toString(), EPPRegistryMapFactory.NS, ELM_MAX_LENGTH);
 		}
 		if (alphaNumStart == null) {
 			alphaNumStart = Boolean.FALSE;
 		}
-		EPPUtil.encodeString(aDocument, root, alphaNumStart.toString(),
-				EPPRegistryMapFactory.NS, ELM_ALPHA_NUM_START);
+		EPPUtil.encodeString(aDocument, root, alphaNumStart.toString(), EPPRegistryMapFactory.NS, ELM_ALPHA_NUM_START);
 		if (alphaNumEnd == null) {
 			alphaNumEnd = Boolean.FALSE;
 		}
-		EPPUtil.encodeString(aDocument, root, alphaNumEnd.toString(),
-				EPPRegistryMapFactory.NS, ELM_ALPHA_NUM_END);
+		EPPUtil.encodeString(aDocument, root, alphaNumEnd.toString(), EPPRegistryMapFactory.NS, ELM_ALPHA_NUM_END);
 		if (onlyDnsChars == null) {
 			onlyDnsChars = Boolean.TRUE;
 		}
-		EPPUtil.encodeString(aDocument, root, onlyDnsChars.toString(),
-				EPPRegistryMapFactory.NS, ELM_ONLY_DNS_CHARS);
+		EPPUtil.encodeString(aDocument, root, onlyDnsChars.toString(), EPPRegistryMapFactory.NS, ELM_ONLY_DNS_CHARS);
 		if (regex != null && regex.size() > 0) {
 			EPPUtil.encodeCompList(aDocument, root, regex);
 		}
@@ -210,50 +199,43 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * Element tree.
 	 * 
 	 * @param aElement
-	 *            Root DOM Element to decode {@code EPPRegistryDomainName} from.
+	 *           Root DOM Element to decode {@code EPPRegistryDomainName} from.
 	 * 
 	 * @exception EPPDecodeException
-	 *                Unable to decode aElement
+	 *               Unable to decode aElement
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 		String levelStr = null;
 		try {
 			levelStr = aElement.getAttribute(ATTR_LEVEL);
 			level = Integer.valueOf(levelStr);
-		} catch (NumberFormatException e) {
-			throw new EPPDecodeException("Cannot decode level: " + levelStr
-					+ "." + e);
 		}
-		minLength = EPPUtil.decodeInteger(aElement, EPPRegistryMapFactory.NS,
-				ELM_MIN_LENGTH);
-		maxLength = EPPUtil.decodeInteger(aElement, EPPRegistryMapFactory.NS,
-				ELM_MAX_LENGTH);
-		alphaNumStart = EPPUtil.decodeBoolean(aElement,
-				EPPRegistryMapFactory.NS, ELM_ALPHA_NUM_START);
+		catch (NumberFormatException e) {
+			throw new EPPDecodeException("Cannot decode level: " + levelStr + "." + e);
+		}
+		minLength = EPPUtil.decodeInteger(aElement, EPPRegistryMapFactory.NS, ELM_MIN_LENGTH);
+		maxLength = EPPUtil.decodeInteger(aElement, EPPRegistryMapFactory.NS, ELM_MAX_LENGTH);
+		alphaNumStart = EPPUtil.decodeBoolean(aElement, EPPRegistryMapFactory.NS, ELM_ALPHA_NUM_START);
 		if (alphaNumStart == null) {
 			alphaNumStart = Boolean.FALSE;
 		}
-		alphaNumEnd = EPPUtil.decodeBoolean(aElement, EPPRegistryMapFactory.NS,
-				ELM_ALPHA_NUM_END);
+		alphaNumEnd = EPPUtil.decodeBoolean(aElement, EPPRegistryMapFactory.NS, ELM_ALPHA_NUM_END);
 		if (alphaNumEnd == null) {
 			alphaNumEnd = Boolean.FALSE;
 		}
-		onlyDnsChars = EPPUtil.decodeBoolean(aElement,
-				EPPRegistryMapFactory.NS, ELM_ONLY_DNS_CHARS);
+		onlyDnsChars = EPPUtil.decodeBoolean(aElement, EPPRegistryMapFactory.NS, ELM_ONLY_DNS_CHARS);
 		if (onlyDnsChars == null) {
 			onlyDnsChars = Boolean.TRUE;
 		}
-		this.setRegex(EPPUtil.decodeCompList(aElement,
-				EPPRegistryMapFactory.NS, ELM_REGEX, EPPRegistryRegex.class));
-		reservedNames = (EPPRegistryReservedNames) EPPUtil.decodeComp(aElement,
-				EPPRegistryMapFactory.NS, EPPRegistryReservedNames.ELM_NAME,
-				EPPRegistryReservedNames.class);
+		this.setRegex(EPPUtil.decodeCompList(aElement, EPPRegistryMapFactory.NS, ELM_REGEX, EPPRegistryRegex.class));
+		reservedNames = (EPPRegistryReservedNames) EPPUtil.decodeComp(aElement, EPPRegistryMapFactory.NS,
+		      EPPRegistryReservedNames.ELM_NAME, EPPRegistryReservedNames.class);
 
 		try {
 			validateState();
-		} catch (EPPCodecException e) {
-			throw new EPPDecodeException(
-					"Invalid state on EPPRegistryDomainName.decode: " + e);
+		}
+		catch (EPPCodecException e) {
+			throw new EPPDecodeException("Invalid state on EPPRegistryDomainName.decode: " + e);
 		}
 	}
 
@@ -261,7 +243,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * implements a deep <code>EPPRegistryDomainName</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPRegistryDomainName</code> instance to compare with
+	 *           <code>EPPRegistryDomainName</code> instance to compare with
 	 * 
 	 * @return {@code true} if this object is the same as the aObject argument;
 	 *         {@code false} otherwise
@@ -272,43 +254,35 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 		}
 
 		EPPRegistryDomainName theComp = (EPPRegistryDomainName) aObject;
-		if (!((level == null) ? (theComp.level == null) : level
-				.equals(theComp.level))) {
+		if (!((level == null) ? (theComp.level == null) : level.equals(theComp.level))) {
 			cat.error("EPPRegistryDomainName.equals(): level not equal");
 			return false;
 		}
-		if (!((minLength == null) ? (theComp.minLength == null) : minLength
-				.equals(theComp.minLength))) {
+		if (!((minLength == null) ? (theComp.minLength == null) : minLength.equals(theComp.minLength))) {
 			cat.error("EPPRegistryDomainName.equals(): minLength not equal");
 			return false;
 		}
-		if (!((maxLength == null) ? (theComp.maxLength == null) : maxLength
-				.equals(theComp.maxLength))) {
+		if (!((maxLength == null) ? (theComp.maxLength == null) : maxLength.equals(theComp.maxLength))) {
 			cat.error("EPPRegistryDomainName.equals(): maxLength not equal");
 			return false;
 		}
-		if (!((alphaNumStart == null) ? (theComp.alphaNumStart == null)
-				: alphaNumStart.equals(theComp.alphaNumStart))) {
+		if (!((alphaNumStart == null) ? (theComp.alphaNumStart == null) : alphaNumStart.equals(theComp.alphaNumStart))) {
 			cat.error("EPPRegistryDomainName.equals(): alphaNumStart not equal");
 			return false;
 		}
-		if (!((alphaNumEnd == null) ? (theComp.alphaNumEnd == null)
-				: alphaNumEnd.equals(theComp.alphaNumEnd))) {
+		if (!((alphaNumEnd == null) ? (theComp.alphaNumEnd == null) : alphaNumEnd.equals(theComp.alphaNumEnd))) {
 			cat.error("EPPRegistryDomainName.equals(): alphaNumEnd not equal");
 			return false;
 		}
-		if (!((onlyDnsChars == null) ? (theComp.onlyDnsChars == null)
-				: onlyDnsChars.equals(theComp.onlyDnsChars))) {
+		if (!((onlyDnsChars == null) ? (theComp.onlyDnsChars == null) : onlyDnsChars.equals(theComp.onlyDnsChars))) {
 			cat.error("EPPRegistryDomainName.equals(): onlyDnsChars not equal");
 			return false;
 		}
-		if (!((regex == null) ? (theComp.regex == null) : EPPUtil.equalLists(
-				regex, theComp.regex))) {
+		if (!((regex == null) ? (theComp.regex == null) : EPPUtil.equalLists(regex, theComp.regex))) {
 			cat.error("EPPRegistryDomainName.equals(): regex not equal");
 			return false;
 		}
-		if (!((reservedNames == null) ? (theComp.reservedNames == null)
-				: reservedNames.equals(theComp.reservedNames))) {
+		if (!((reservedNames == null) ? (theComp.reservedNames == null) : reservedNames.equals(theComp.reservedNames))) {
 			cat.error("EPPRegistryDomainName.equals(): reservedNames not equal");
 			return false;
 		}
@@ -328,22 +302,19 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 */
 	void validateState() throws EPPCodecException {
 		if (level == null || level.intValue() < 2) {
-			throw new EPPCodecException(
-					"level should exist and be greater than or equal to 2");
+			throw new EPPCodecException("level should exist and be greater than or equal to 2");
 		}
 		if (minLength != null && minLength.intValue() < 1) {
-			throw new EPPCodecException(
-					"minLength, if specified, should be greater than 0");
+			throw new EPPCodecException("minLength, if specified, should be greater than 0");
 		}
 		if (maxLength != null) {
 			if (minLength != null) {
 				if (maxLength.intValue() < minLength.intValue()) {
-					throw new EPPCodecException(
-							"maxLength, if specified, should be no less than minLength");
+					throw new EPPCodecException("maxLength, if specified, should be no less than minLength");
 				}
-			} else if (maxLength.intValue() < 1) {
-				throw new EPPCodecException(
-						"maxLength, if specified, should be greater than 0");
+			}
+			else if (maxLength.intValue() < 1) {
+				throw new EPPCodecException("maxLength, if specified, should be greater than 0");
 			}
 		}
 	}
@@ -354,7 +325,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * @return clone of <code>EPPRegistryDomainName</code>
 	 * 
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPRegistryDomainName clone = (EPPRegistryDomainName) super.clone();
@@ -364,8 +335,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 		}
 
 		if (reservedNames != null) {
-			clone.reservedNames = (EPPRegistryReservedNames) reservedNames
-					.clone();
+			clone.reservedNames = (EPPRegistryReservedNames) reservedNames.clone();
 		}
 
 		return clone;
@@ -376,8 +346,8 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
@@ -386,7 +356,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	/**
 	 * Get the level of domain name.
 	 * 
-	 * @return level of domain name. Must be >= 2
+	 * @return level of domain name. Must be &gt;= 2
 	 */
 	public Integer getLevel() {
 		return level;
@@ -396,7 +366,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * Set the level of domain name.
 	 * 
 	 * @param level
-	 *            level of domain name. Must be >= 2
+	 *           level of domain name. Must be &gt;= 2
 	 */
 	public void setLevel(Integer level) {
 		this.level = level;
@@ -415,7 +385,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * Set minimum number of characters in a domain name.
 	 * 
 	 * @param minLength
-	 *            minimum number of characters in a domain name
+	 *           minimum number of characters in a domain name
 	 */
 	public void setMinLength(Integer minLength) {
 		this.minLength = minLength;
@@ -434,7 +404,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * Set maximum number of characters in a domain name.
 	 * 
 	 * @param maxLength
-	 *            maximum number of characters in a domain name
+	 *           maximum number of characters in a domain name
 	 */
 	public void setMaxLength(Integer maxLength) {
 		this.maxLength = maxLength;
@@ -457,9 +427,9 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * character.
 	 * 
 	 * @param alphaNumStart
-	 *            {@code true} allow domain name start with an alphanumeric
-	 *            character. {@code false} do not allow domain name start with
-	 *            an alphanumeric character
+	 *           {@code true} allow domain name start with an alphanumeric
+	 *           character. {@code false} do not allow domain name start with an
+	 *           alphanumeric character
 	 */
 	public void setAlphaNumStart(Boolean alphaNumStart) {
 		this.alphaNumStart = alphaNumStart;
@@ -469,9 +439,9 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * Get whether or not to allow domain name end with an alphanumeric
 	 * character.
 	 * 
-	 * @return {@code true} allow domain name end with an alphanumeric
-	 *         character. {@code false} do not allow domain name end with an
-	 *         alphanumeric character
+	 * @return {@code true} allow domain name end with an alphanumeric character.
+	 *         {@code false} do not allow domain name end with an alphanumeric
+	 *         character
 	 */
 	public Boolean getAlphaNumEnd() {
 		return alphaNumEnd;
@@ -482,9 +452,9 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * character.
 	 * 
 	 * @param alphaNumEnd
-	 *            {@code true} allow domain name end with an alphanumeric
-	 *            character. {@code false} do not allow domain name end with an
-	 *            alphanumeric character
+	 *           {@code true} allow domain name end with an alphanumeric
+	 *           character. {@code false} do not allow domain name end with an
+	 *           alphanumeric character
 	 */
 	public void setAlphaNumEnd(Boolean alphaNumEnd) {
 		this.alphaNumEnd = alphaNumEnd;
@@ -505,9 +475,9 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * Set whether to limit only DNS characters in the domain name.
 	 * 
 	 * @param onlyDnsChars
-	 *            {@code true} allow only DNS characters (alphanumeric and '-')
-	 *            in the domain name. {@code false} allow non-DNS characters in
-	 *            the domain name
+	 *           {@code true} allow only DNS characters (alphanumeric and '-') in
+	 *           the domain name. {@code false} allow non-DNS characters in the
+	 *           domain name
 	 */
 	public void setOnlyDnsChars(Boolean onlyDnsChars) {
 		this.onlyDnsChars = onlyDnsChars;
@@ -528,7 +498,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * {@code List}.
 	 * 
 	 * @param re
-	 *            instance of {@link EPPRegistryRegex}
+	 *           instance of {@link EPPRegistryRegex}
 	 */
 	public void addRegex(EPPRegistryRegex re) {
 		if (re != null) {
@@ -545,7 +515,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	 * domain name must follow.
 	 * 
 	 * @param regex
-	 *            {@code List} of {@link EPPRegistryRegex} regular expressions
+	 *           {@code List} of {@link EPPRegistryRegex} regular expressions
 	 */
 	public void setRegex(List regex) {
 		if (regex != null) {
@@ -558,8 +528,8 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	}
 
 	/**
-	 * Get the instance of {@link EPPRegistryReservedNames} that defines a set
-	 * of reserved domain names.
+	 * Get the instance of {@link EPPRegistryReservedNames} that defines a set of
+	 * reserved domain names.
 	 * 
 	 * @return instance of {@link EPPRegistryReservedNames}
 	 */
@@ -568,24 +538,25 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	}
 
 	/**
-	 * Set the instance of {@link EPPRegistryReservedNames} that defines a set
-	 * of reserved domain names.
+	 * Set the instance of {@link EPPRegistryReservedNames} that defines a set of
+	 * reserved domain names.
 	 * 
 	 * @param reservedNames
-	 *            instance of {@link EPPRegistryReservedNames}
+	 *           instance of {@link EPPRegistryReservedNames}
 	 */
 	public void setReservedNames(EPPRegistryReservedNames reservedNames) {
 		this.reservedNames = reservedNames;
 	}
-	
+
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
 	 */
 	@Override
 	public String getNamespace() {
 		return EPPRegistryMapFactory.NS;
 	}
-	
+
 }
