@@ -20,7 +20,8 @@ package com.verisign.epp.codec.registry;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -28,19 +29,17 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
- * Class that defines the management of related fields.   
+ * Class that defines the management of related fields.
  */
 public class EPPRegistryFields implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPRegistryFields.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPRegistryFields.class);
 
 	/**
 	 * Constant for the related zone fields being shared, where there is one set
@@ -64,8 +63,7 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	/**
 	 * Constant for the qualified name (prefix and local name)
 	 */
-	public static final String ELM_NAME = EPPRegistryMapFactory.NS_PREFIX + ":"
-			+ ELM_LOCALNAME;
+	public static final String ELM_NAME = EPPRegistryMapFactory.NS_PREFIX + ":" + ELM_LOCALNAME;
 
 	/**
 	 * Element local name for a field
@@ -91,9 +89,8 @@ public class EPPRegistryFields implements EPPCodecComponent {
 
 	/**
 	 * Default constructor. The type value MUST be set using the
-	 * {@link #setType(String)} method and the fields MUST be set using 
-	 * {@link #setFields(List)} or 
-	 * {@link #addField(String)}.
+	 * {@link #setType(String)} method and the fields MUST be set using
+	 * {@link #setFields(List)} or {@link #addField(String)}.
 	 */
 	public EPPRegistryFields() {
 	}
@@ -102,10 +99,10 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	 * Create <code>EPPRegistryFields</code> instance with required attributes.
 	 * 
 	 * @param aType
-	 *            Type of related fields with either {@link #TYPE_SHARED} or
-	 *            {@link #TYPE_SYNC}.
+	 *           Type of related fields with either {@link #TYPE_SHARED} or
+	 *           {@link #TYPE_SYNC}.
 	 * @param aFields
-	 *            List of related fields.
+	 *           List of related fields.
 	 */
 	public EPPRegistryFields(String aType, List<String> aFields) {
 		this.type = aType;
@@ -128,8 +125,8 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	 * or {@link #TYPE_SYNC}.
 	 * 
 	 * @param aType
-	 *            the type, which should be either {@link #TYPE_SHARED} or
-	 *            {@link #TYPE_SYNC}
+	 *           the type, which should be either {@link #TYPE_SHARED} or
+	 *           {@link #TYPE_SYNC}
 	 */
 	public void setType(String aType) {
 		this.type = aType;
@@ -148,23 +145,23 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	 * Sets the related field names.
 	 * 
 	 * @param aFields
-	 *            The list of related field names.
+	 *           The list of related field names.
 	 */
 	public void setFields(List<String> aFields) {
 		this.fields = aFields;
 	}
-	
-	
+
 	/**
 	 * Adds a field to the list of fields.
 	 * 
-	 * @param aField Field to add to the list of fields.
+	 * @param aField
+	 *           Field to add to the list of fields.
 	 */
 	public void addField(String aField) {
 		if (this.fields == null) {
 			this.fields = new ArrayList<String>();
 		}
-		
+
 		this.fields.add(aField);
 	}
 
@@ -174,7 +171,7 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	 * @return clone of <code>EPPRegistryFields</code>
 	 * 
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPRegistryFields clone = null;
@@ -189,11 +186,11 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	 * tree.
 	 * 
 	 * @param aElement
-	 *            - Root DOM Element to decode <code>EPPRegistryFields</code>
-	 *            from.
+	 *           - Root DOM Element to decode <code>EPPRegistryFields</code>
+	 *           from.
 	 * 
 	 * @exception EPPDecodeException
-	 *                Unable to decode aElement
+	 *               Unable to decode aElement
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 		// Type
@@ -206,8 +203,7 @@ public class EPPRegistryFields implements EPPCodecComponent {
 		}
 
 		// Fields
-		this.fields = EPPUtil.decodeList(aElement, EPPRegistryMapFactory.NS,
-				ELM_FIELD);
+		this.fields = EPPUtil.decodeList(aElement, EPPRegistryMapFactory.NS, ELM_FIELD);
 	}
 
 	/**
@@ -215,42 +211,35 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	 * <code>EPPRegistryFields</code> instance.
 	 * 
 	 * @param aDocument
-	 *            - DOM Document that is being built. Used as an Element
-	 *            factory.
+	 *           - DOM Document that is being built. Used as an Element factory.
 	 * 
 	 * @return Element - Root DOM Element representing the
 	 *         <code>EPPRegistryFields</code> instance.
 	 * 
 	 * @exception EPPEncodeException
-	 *                - Unable to encode <code>EPPRegistryFields</code>
-	 *                instance.
+	 *               - Unable to encode <code>EPPRegistryFields</code> instance.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " in EPPRegistryFields.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " in EPPRegistryFields.encode(Document)");
 		}
 		if (this.type == null) {
-			throw new EPPEncodeException("type is null"
-					+ " in EPPRegistryFields.encode(Document)");
+			throw new EPPEncodeException("type is null" + " in EPPRegistryFields.encode(Document)");
 		}
 		if (this.fields == null || this.fields.isEmpty()) {
-			throw new EPPEncodeException("fields is null or empty"
-					+ " in EPPRegistryFields.encode(Document)");
+			throw new EPPEncodeException("fields is null or empty" + " in EPPRegistryFields.encode(Document)");
 		}
 
 		// Status with Attributes
-		Element root = aDocument.createElementNS(EPPRegistryMapFactory.NS,
-				ELM_NAME);
+		Element root = aDocument.createElementNS(EPPRegistryMapFactory.NS, ELM_NAME);
 
 		// Type
 		root.setAttribute(ATTR_TYPE, this.type);
 
 		// Fields
-		EPPUtil.encodeList(aDocument, root, this.fields,
-				EPPRegistryMapFactory.NS, EPPRegistryMapFactory.NS_PREFIX + ":"
-						+ ELM_FIELD);
+		EPPUtil.encodeList(aDocument, root, this.fields, EPPRegistryMapFactory.NS,
+		      EPPRegistryMapFactory.NS_PREFIX + ":" + ELM_FIELD);
 
 		return root;
 	}
@@ -259,7 +248,7 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	 * implements a deep <code>EPPRegistryFields</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPRegistryFields</code> instance to compare with
+	 *           <code>EPPRegistryFields</code> instance to compare with
 	 * 
 	 * @return <code>true</code> if equal; <code>false</code> otherwise
 	 */
@@ -290,17 +279,18 @@ public class EPPRegistryFields implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
 	 */
 	@Override
 	public String getNamespace() {
