@@ -67,8 +67,8 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	/**
 	 * Constructs a new instance with given key and value.
 	 * 
-	 * @param key
-	 * @param value
+	 * @param key Attribute key
+	 * @param value Attribute value
 	 */
 	public EPPRegistryKeyValue(String key, String value) {
 		super();
@@ -86,24 +86,23 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	 * {@code EPPRegistryKeyValue} instance.
 	 * 
 	 * @param aDocument
-	 *            DOM Document that is being built. Used as an Element factory.
+	 *           DOM Document that is being built. Used as an Element factory.
 	 * 
 	 * @return Element Root DOM Element representing the
 	 *         {@code EPPRegistryKeyValue} instance.
 	 * 
 	 * @exception EPPEncodeException
-	 *                - Unable to encode {@code EPPRegistryKeyValue} instance.
+	 *               - Unable to encode {@code EPPRegistryKeyValue} instance.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 		try {
 			validateState();
-		} catch (EPPCodecException e) {
-			throw new EPPEncodeException(
-					"Invalid state on EPPRegistryKeyValue.encode: " + e);
+		}
+		catch (EPPCodecException e) {
+			throw new EPPEncodeException("Invalid state on EPPRegistryKeyValue.encode: " + e);
 		}
 
-		Element root = aDocument.createElementNS(EPPRegistryMapFactory.NS,
-				getRootName());
+		Element root = aDocument.createElementNS(EPPRegistryMapFactory.NS, getRootName());
 		Text currVal = aDocument.createTextNode(value);
 		root.setAttribute(ATTR_KEY, key);
 		root.appendChild(currVal);
@@ -116,10 +115,10 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	 * Element tree.
 	 * 
 	 * @param aElement
-	 *            Root DOM Element to decode {@code EPPRegistryKeyValue} from.
+	 *           Root DOM Element to decode {@code EPPRegistryKeyValue} from.
 	 * 
 	 * @exception EPPDecodeException
-	 *                Unable to decode aElement
+	 *               Unable to decode aElement
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 		key = aElement.getAttribute(ATTR_KEY);
@@ -154,7 +153,7 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	 * @return clone of <code>EPPRegistryKeyValue</code>
 	 * 
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		return (EPPRegistryKeyValue) super.clone();
@@ -164,7 +163,7 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	 * implements a deep <code>EPPRegistryKeyValue</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPRegistryKeyValue</code> instance to compare with
+	 *           <code>EPPRegistryKeyValue</code> instance to compare with
 	 * 
 	 * @return {@code true} if this object is the same as the aObject argument;
 	 *         {@code false} otherwise
@@ -179,12 +178,10 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 		if (!((key == null) ? (theComp.key == null) : key.equals(theComp.key))) {
 			return false;
 		}
-		if (!((value == null) ? (theComp.value == null) : value
-				.equals(theComp.value))) {
+		if (!((value == null) ? (theComp.value == null) : value.equals(theComp.value))) {
 			return false;
 		}
-		if (!((rootName == null) ? (theComp.rootName == null) : rootName
-				.equals(theComp.rootName))) {
+		if (!((rootName == null) ? (theComp.rootName == null) : rootName.equals(theComp.rootName))) {
 			return false;
 		}
 
@@ -196,8 +193,8 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
@@ -216,6 +213,7 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	 * Set the key.
 	 * 
 	 * @param key
+	 *           Key to use
 	 */
 	public void setKey(String key) {
 		this.key = key;
@@ -234,6 +232,7 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	 * Set the value
 	 * 
 	 * @param value
+	 *           Value to use
 	 */
 	public void setValue(String value) {
 		this.value = value;
@@ -249,13 +248,14 @@ public class EPPRegistryKeyValue implements EPPCodecComponent {
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
 	 */
 	@Override
 	public String getNamespace() {
 		return EPPRegistryMapFactory.NS;
 	}
-	
+
 }
