@@ -132,4 +132,15 @@ public class EPPRegistryReservedNames implements EPPCodecComponent {
 	public void setReservedNameURI(String reservedNameURI) {
 		this.reservedNameURI = reservedNameURI;
 	}
+	
+	/**
+	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPRegistryMapFactory.NS;
+	}
+	
 }
