@@ -22,7 +22,8 @@ package com.verisign.epp.codec.registry.v02;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -31,8 +32,6 @@ import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.codec.registry.v02.EPPRegistryContact.SharePolicy;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -162,8 +161,8 @@ public class EPPRegistryDomain implements EPPCodecComponent {
 	/**
 	 * Logger
 	 */
-	private static Logger cat = Logger.getLogger(EPPRegistryDomain.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	    private static Logger cat = LoggerFactory.getLogger(EPPRegistryDomain.class);
+	      
 
 	/**
 	 * Possible values for the {@code hostModelSupported} attribute.
