@@ -19,9 +19,8 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
  ***********************************************************/
 package com.verisign.epp.codec.registry.v02;
 
-import org.apache.log4j.Logger;
-
-import com.verisign.epp.util.EPPCatFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * Defines the minimum and maximum number of delegated host objects (name
@@ -31,8 +30,7 @@ public class EPPRegistryDomainNSLimit extends EPPRegistryAbstractMinMax {
 	/**
 	 * Logger
 	 */
-	private static Logger cat = Logger.getLogger(EPPRegistryDomainNSLimit.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPRegistryDomainNSLimit.class);
 
 	/**
 	 * XML local name for {@code EPPRegistryDomainNSLimit}.
