@@ -22,7 +22,8 @@ package com.verisign.epp.codec.registry.v02;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
@@ -32,7 +33,6 @@ import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -56,8 +56,8 @@ public class EPPRegistryServices implements EPPCodecComponent {
 	/**
 	 * Logger
 	 */
-	private static Logger cat = Logger.getLogger(EPPRegistryServices.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	    private static Logger cat = LoggerFactory.getLogger(EPPRegistryServices.class);
+	      
 
 	/**
 	 * XML local name for {@code EPPRegistryServices}.
