@@ -20,7 +20,8 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 
 package com.verisign.epp.framework.registry.v02;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPFactory;
@@ -36,7 +37,7 @@ import com.verisign.epp.framework.EPPEventException;
 import com.verisign.epp.framework.EPPEventHandler;
 import com.verisign.epp.framework.EPPEventResponse;
 import com.verisign.epp.framework.EPPHandleEventException;
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * The {@code EPPRegistryHandler} class provides an interface for handling EPP
@@ -54,9 +55,9 @@ import com.verisign.epp.util.EPPCatFactory;
  * @see EPPEvent
  */
 public abstract class EPPRegistryHandler implements EPPEventHandler {
-	/** Log4j category for logging */
-	private static final Logger cat = Logger.getLogger(EPPRegistryHandler.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	/** Category for logging */
+	private static Logger cat = LoggerFactory.getLogger(EPPRegistryHandler.class);
+	      
 
 	/**
 	 * Construct an instance of {@code EPPRegistryHandler} that automatically
