@@ -1,3 +1,23 @@
+/***********************************************************
+Copyright (C) 2013 VeriSign, Inc.
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+
+http://www.verisign.com/nds/naming/namestore/techdocs.html
+ ***********************************************************/
+
 package com.verisign.epp.interfaces;
 
 import java.util.ArrayList;
@@ -405,12 +425,12 @@ public class EPPRegistry {
 
 		List domainNames = new ArrayList();
 		EPPRegistryDomainName domainName = new EPPRegistryDomainName();
-		domainName.setLevel(new Integer(2));
-		domainName.setMinLength(new Integer(5));
-		domainName.setMaxLength(new Integer(50));
-		domainName.setAlphaNumStart(new Boolean(true));
-		domainName.setAlphaNumEnd(new Boolean(false));
-		domainName.setOnlyDnsChars(new Boolean(true));
+		domainName.setLevel(Integer.valueOf(2));
+		domainName.setMinLength(Integer.valueOf(5));
+		domainName.setMaxLength(Integer.valueOf(50));
+		domainName.setAlphaNumStart(Boolean.valueOf(true));
+		domainName.setAlphaNumEnd(Boolean.valueOf(false));
+		domainName.setOnlyDnsChars(Boolean.valueOf(true));
 
 		List regex = new ArrayList();
 		EPPRegistryRegex r = new EPPRegistryRegex("^\\w+.*$", "test regex");
@@ -432,7 +452,7 @@ public class EPPRegistry {
 
 		try {
 			domainName = (EPPRegistryDomainName) domainName.clone();
-			domainName.setLevel(new Integer(3));
+			domainName.setLevel(Integer.valueOf(3));
 			domainName.getReservedNames().setReservedNames(new ArrayList());
 			domainName.getReservedNames().setReservedNameURI(
 					"http://testrn.vrsn.com");
@@ -457,8 +477,8 @@ public class EPPRegistry {
 		idn.setCommingleAllowed(Boolean.TRUE);
 		domain.setIdn(idn);
 
-		domain.setPremiumSupport(new Boolean(true));
-		domain.setContactsSupported(new Boolean(false));
+		domain.setPremiumSupport(Boolean.valueOf(true));
+		domain.setContactsSupported(Boolean.valueOf(false));
 
 		domain.addContact(new EPPRegistryDomainContact(
 				EPPRegistryDomainContact.TYPE_ADMIN, 1, 4));
@@ -510,7 +530,7 @@ public class EPPRegistry {
 		dnssec.setUrgent(Boolean.TRUE);
 
 		domain.setDnssec(dnssec);
-		domain.setMaxCheckDomain(new Integer(12));
+		domain.setMaxCheckDomain(Integer.valueOf(12));
 		domain.setAuthInfoRegex(new EPPRegistryRegex("^.*$", "exp"));
 
 		EPPRegistryCustomData customData = new EPPRegistryCustomData();
@@ -550,7 +570,7 @@ public class EPPRegistry {
 				EPPRegistryExternalHost.TYPE_PER_ZONE));
 		host.addNameRegex(new EPPRegistryRegex("^.*$", "exp1"));
 		host.addNameRegex(new EPPRegistryRegex("^.*$", "exp2"));
-		host.setMaxCheckHost(new Integer(15));
+		host.setMaxCheckHost(Integer.valueOf(15));
 
 		EPPRegistryCustomData customData = new EPPRegistryCustomData();
 		customData.addKeyValue(new EPPRegistryKeyValue("hk1", "hv1"));
@@ -588,7 +608,7 @@ public class EPPRegistry {
 
 		contact.setAuthInfoRegex(new EPPRegistryRegex("^.*$", "exp"));
 
-		contact.setMaxCheckContact(new Integer(15));
+		contact.setMaxCheckContact(Integer.valueOf(15));
 
 		EPPRegistryPostal postalInfo = new EPPRegistryPostal();
 		postalInfo.setName(new EPPRegistryContactName(5, 15));
@@ -610,7 +630,7 @@ public class EPPRegistry {
 		postalInfo.setVoiceExt(new EPPRegistryMinMaxLength(5, 15));
 		postalInfo.setFaxExt(new EPPRegistryMinMaxLength(5, 15));
 
-		contact.setMaxCheckContact(new Integer(5));
+		contact.setMaxCheckContact(Integer.valueOf(5));
 
 		contact.setPostalInfo(postalInfo);
 		
