@@ -25,7 +25,8 @@ import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
@@ -91,7 +92,6 @@ import com.verisign.epp.codec.registry.EPPRegistryZoneMember;
 import com.verisign.epp.framework.EPPEvent;
 import com.verisign.epp.framework.EPPEventResponse;
 import com.verisign.epp.framework.EPPRegistryHandler;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EPPEnvSingle;
 
 public class RegistryHandler extends EPPRegistryHandler {
@@ -109,8 +109,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 			len = Integer.parseInt(num);
 		}
 		for (int i = 0; i < len; i++) {
-			EPPRegistryZoneInfo zoneInfo = new EPPRegistryZoneInfo("samplezone"
-					+ i, "client" + i, new Date());
+			EPPRegistryZoneInfo zoneInfo = new EPPRegistryZoneInfo("samplezone" + i, "client" + i, new Date());
 			zoneInfo.setLastUpdatedBy("client" + i);
 			zoneInfo.setLastUpdatedDate(new Date());
 
@@ -118,7 +117,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 			zoneInfo.setSubProduct("dotSamplezone" + i);
 
 			EPPRegistryRelated related = new EPPRegistryRelated();
-			
+
 			EPPRegistryFields fields = new EPPRegistryFields();
 			fields.setType(EPPRegistryFields.TYPE_SYNC);
 			fields.addField("clID");
@@ -126,69 +125,44 @@ public class RegistryHandler extends EPPRegistryHandler {
 			fields.addField("ns");
 			related.setFields(fields);
 
-			related.addMember(new EPPRegistryZoneMember("EXAMPLE",  EPPRegistryZoneMember.TYPE_EQUAL));
-			related.addMember(new EPPRegistryZoneMember("EXAMPLE2",  EPPRegistryZoneMember.TYPE_EQUAL));
-			related.addMember(new EPPRegistryZoneMember("EXAMPLE3",  EPPRegistryZoneMember.TYPE_EQUAL));
+			related.addMember(new EPPRegistryZoneMember("EXAMPLE", EPPRegistryZoneMember.TYPE_EQUAL));
+			related.addMember(new EPPRegistryZoneMember("EXAMPLE2", EPPRegistryZoneMember.TYPE_EQUAL));
+			related.addMember(new EPPRegistryZoneMember("EXAMPLE3", EPPRegistryZoneMember.TYPE_EQUAL));
 
 			zoneInfo.setRelated(related);
 
-			EPPRegistryPhase phase = new EPPRegistryPhase(
-					EPPRegistryPhase.PHASE_SUNRISE, new Date(), new Date());
+			EPPRegistryPhase phase = new EPPRegistryPhase(EPPRegistryPhase.PHASE_SUNRISE, new Date(), new Date());
 			phase.setMode(EPPRegistryPhase.MODE_PENDING_APPLICATION);
 			zoneInfo.addPhase(phase);
-			phase = new EPPRegistryPhase(EPPRegistryPhase.PHASE_PRE_DELEGATION,
-					new Date(), new Date());
+			phase = new EPPRegistryPhase(EPPRegistryPhase.PHASE_PRE_DELEGATION, new Date(), new Date());
 			phase.setMode(EPPRegistryPhase.MODE_PENDING_REGISTRATION);
 			zoneInfo.addPhase(phase);
-			zoneInfo.addPhase(new EPPRegistryPhase(
-					EPPRegistryPhase.PHASE_LANDRUSH, new Date(), new Date()));
-			zoneInfo.addPhase(new EPPRegistryPhase(
-					EPPRegistryPhase.PHASE_PRE_DELEGATION, new Date(),
-					new Date()));
-			zoneInfo.addPhase(new EPPRegistryPhase(
-					EPPRegistryPhase.PHASE_CLAIMS, new Date(), new Date()));
-			zoneInfo.addPhase(new EPPRegistryPhase(EPPRegistryPhase.PHASE_OPEN,
-					new Date()));
-			zoneInfo.addPhase(new EPPRegistryPhase(
-					EPPRegistryPhase.PHASE_CUSTOM, "userDefined", new Date()));
+			zoneInfo.addPhase(new EPPRegistryPhase(EPPRegistryPhase.PHASE_LANDRUSH, new Date(), new Date()));
+			zoneInfo.addPhase(new EPPRegistryPhase(EPPRegistryPhase.PHASE_PRE_DELEGATION, new Date(), new Date()));
+			zoneInfo.addPhase(new EPPRegistryPhase(EPPRegistryPhase.PHASE_CLAIMS, new Date(), new Date()));
+			zoneInfo.addPhase(new EPPRegistryPhase(EPPRegistryPhase.PHASE_OPEN, new Date()));
+			zoneInfo.addPhase(new EPPRegistryPhase(EPPRegistryPhase.PHASE_CUSTOM, "userDefined", new Date()));
 
 			EPPRegistryServices services = new EPPRegistryServices();
-			services.addObjURI(new EPPRegistryObjURI(
-					"http://www.verisign.com/epp/rgp-poll-1.0", Boolean.TRUE));
-			services.addObjURI(new EPPRegistryObjURI(
-					"urn:ietf:params:xml:ns:host-1.0", Boolean.TRUE));
-			services.addObjURI(new EPPRegistryObjURI(
-					"urn:ietf:params:xml:ns:contact-1.0", Boolean.TRUE));
-			services.addObjURI(new EPPRegistryObjURI(
-					"urn:ietf:params:xml:ns:domain-1.0", Boolean.TRUE));
-			services.addObjURI(new EPPRegistryObjURI(
-					"http://www.verisign.com/epp/lowbalance-poll-1.0",
-					Boolean.FALSE));
+			services.addObjURI(new EPPRegistryObjURI("http://www.verisign.com/epp/rgp-poll-1.0", Boolean.TRUE));
+			services.addObjURI(new EPPRegistryObjURI("urn:ietf:params:xml:ns:host-1.0", Boolean.TRUE));
+			services.addObjURI(new EPPRegistryObjURI("urn:ietf:params:xml:ns:contact-1.0", Boolean.TRUE));
+			services.addObjURI(new EPPRegistryObjURI("urn:ietf:params:xml:ns:domain-1.0", Boolean.TRUE));
+			services.addObjURI(new EPPRegistryObjURI("http://www.verisign.com/epp/lowbalance-poll-1.0", Boolean.FALSE));
 			EPPRegistryServicesExt svcExt = new EPPRegistryServicesExt();
 			services.setExtension(svcExt);
-			svcExt.addExtURI(new EPPRegistryExtURI(
-					"http://www.verisign-grs.com/epp/namestoreExt-1.1",
-					Boolean.TRUE));
-			svcExt.addExtURI(new EPPRegistryExtURI(
-					"urn:ietf:params:xml:ns:rgp-1.0", Boolean.TRUE));
-			svcExt.addExtURI(new EPPRegistryExtURI(
-					"http://www.verisign.com/epp/sync-1.0", Boolean.TRUE));
-			svcExt.addExtURI(new EPPRegistryExtURI(
-					"http://www.verisign.com/epp/idnLang-1.0", Boolean.TRUE));
-			svcExt.addExtURI(new EPPRegistryExtURI(
-					"http://www.verisign.com/epp/jobsContact-1.0", Boolean.TRUE));
-			svcExt.addExtURI(new EPPRegistryExtURI(
-					"http://www.verisign.com/epp/premiumdomain-1.0",
-					Boolean.TRUE));
-			svcExt.addExtURI(new EPPRegistryExtURI(
-					"urn:ietf:params:xml:ns:secDNS-1.1", Boolean.FALSE));
+			svcExt.addExtURI(new EPPRegistryExtURI("http://www.verisign-grs.com/epp/namestoreExt-1.1", Boolean.TRUE));
+			svcExt.addExtURI(new EPPRegistryExtURI("urn:ietf:params:xml:ns:rgp-1.0", Boolean.TRUE));
+			svcExt.addExtURI(new EPPRegistryExtURI("http://www.verisign.com/epp/sync-1.0", Boolean.TRUE));
+			svcExt.addExtURI(new EPPRegistryExtURI("http://www.verisign.com/epp/idnLang-1.0", Boolean.TRUE));
+			svcExt.addExtURI(new EPPRegistryExtURI("http://www.verisign.com/epp/jobsContact-1.0", Boolean.TRUE));
+			svcExt.addExtURI(new EPPRegistryExtURI("http://www.verisign.com/epp/premiumdomain-1.0", Boolean.TRUE));
+			svcExt.addExtURI(new EPPRegistryExtURI("urn:ietf:params:xml:ns:secDNS-1.1", Boolean.FALSE));
 			zoneInfo.setServices(services);
 
 			EPPRegistrySLAInfo slaInfo = new EPPRegistrySLAInfo();
-			slaInfo.addSla(new EPPRegistrySLA("response", "ext", "create", 500,
-					"ms"));
-			slaInfo.addSla(new EPPRegistrySLA("availability", null, "create",
-					99.9, "percent"));
+			slaInfo.addSla(new EPPRegistrySLA("response", "ext", "create", 500, "ms"));
+			slaInfo.addSla(new EPPRegistrySLA("availability", null, "create", 99.9, "percent"));
 			zoneInfo.setSlaInfo(slaInfo);
 
 			zoneInfo.setCreatedBy("crId");
@@ -205,19 +179,16 @@ public class RegistryHandler extends EPPRegistryHandler {
 		}
 	}
 
-	private static Logger cat = Logger.getLogger(RegistryHandler.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(RegistryHandler.class);
 
 	protected EPPEventResponse doRegistryCreate(EPPEvent aEvent, Object aData) {
 		cat.debug("doRegistryCreate: enter");
-		EPPRegistryCreateCmd message = (EPPRegistryCreateCmd) aEvent
-				.getMessage();
+		EPPRegistryCreateCmd message = (EPPRegistryCreateCmd) aEvent.getMessage();
 
 		// Encode EPPRegistryCreate Response
 		EPPRegistryCreateResp theResponse;
 
-		EPPTransId respTransId = new EPPTransId(message.getTransId(),
-				svrTransId);
+		EPPTransId respTransId = new EPPTransId(message.getTransId(), svrTransId);
 		String name = message.getZone().getName();
 		boolean tldExist = false;
 		theResponse = new EPPRegistryCreateResp(respTransId, name);
@@ -226,8 +197,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 			EPPRegistryZoneInfo zoneInfo = (EPPRegistryZoneInfo) it.next();
 			if (zoneInfo.getName().equals(name)) {
 				tldExist = true;
-				theResponse.setResult(EPPResult.OBJECT_EXISTS,
-						"TLD name exists");
+				theResponse.setResult(EPPResult.OBJECT_EXISTS, "TLD name exists");
 				phaseIterator = zoneInfo.getPhases().iterator();
 				break;
 			}
@@ -259,9 +229,8 @@ public class RegistryHandler extends EPPRegistryHandler {
 				}
 			}
 		}
-		
+
 		// Process policy extensions
-		
 
 		cat.debug("doRegistryCreate: exit");
 		return new EPPEventResponse(theResponse);
@@ -269,14 +238,12 @@ public class RegistryHandler extends EPPRegistryHandler {
 
 	protected EPPEventResponse doRegistryUpdate(EPPEvent aEvent, Object aData) {
 		cat.debug("doRegistryUpdate: enter");
-		EPPRegistryUpdateCmd message = (EPPRegistryUpdateCmd) aEvent
-				.getMessage();
+		EPPRegistryUpdateCmd message = (EPPRegistryUpdateCmd) aEvent.getMessage();
 
 		// Encode EPPRegistryUpdate Response
 		EPPResponse theResponse;
 
-		EPPTransId respTransId = new EPPTransId(message.getTransId(),
-				svrTransId);
+		EPPTransId respTransId = new EPPTransId(message.getTransId(), svrTransId);
 		String name = message.getZone().getName();
 		boolean tldExist = false;
 		theResponse = new EPPResponse(respTransId);
@@ -305,10 +272,10 @@ public class RegistryHandler extends EPPRegistryHandler {
 
 			availableTlds.add(zoneInfo);
 			theResponse.setResult(EPPResult.SUCCESS);
-		} else {
-			theResponse.setResult(EPPResult.OBJECT_DOES_NOT_EXIST, "Tld "
-					+ message.getZone().getName()
-					+ " does not exist. Please create it first");
+		}
+		else {
+			theResponse.setResult(EPPResult.OBJECT_DOES_NOT_EXIST,
+			      "Tld " + message.getZone().getName() + " does not exist. Please create it first");
 		}
 
 		cat.debug("doRegistryUpdate: exit");
@@ -321,8 +288,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 		// Encode EPPRegistryInfo Response
 		EPPRegistryCheckResp theResponse;
 
-		EPPTransId respTransId = new EPPTransId(message.getTransId(),
-				svrTransId);
+		EPPTransId respTransId = new EPPTransId(message.getTransId(), svrTransId);
 		List names = message.getNames();
 		List results = new ArrayList();
 		outer: for (Iterator it = names.iterator(); it.hasNext();) {
@@ -343,9 +309,9 @@ public class RegistryHandler extends EPPRegistryHandler {
 		}
 
 		if (results.size() == 1) {
-			theResponse = new EPPRegistryCheckResp(respTransId,
-					(EPPRegistryCheckResult) results.get(0));
-		} else {
+			theResponse = new EPPRegistryCheckResp(respTransId, (EPPRegistryCheckResult) results.get(0));
+		}
+		else {
 			theResponse = new EPPRegistryCheckResp(respTransId, results);
 		}
 
@@ -359,19 +325,19 @@ public class RegistryHandler extends EPPRegistryHandler {
 		// Encode EPPRegistryInfo Response
 		EPPResponse theResponse;
 
-		EPPTransId respTransId = new EPPTransId(message.getTransId(),
-				svrTransId);
+		EPPTransId respTransId = new EPPTransId(message.getTransId(), svrTransId);
 		boolean all = message.isAll();
 		if (all) {
 			EPPRegistryZoneList zoneList = new EPPRegistryZoneList();
 			for (Iterator it = availableTlds.iterator(); it.hasNext();) {
 				EPPRegistryZoneInfo info = (EPPRegistryZoneInfo) it.next();
-				EPPRegistryZone zone = new EPPRegistryZone(info.getName(),
-						info.getCreatedDate(), info.getLastUpdatedDate());
+				EPPRegistryZone zone = new EPPRegistryZone(info.getName(), info.getCreatedDate(),
+				      info.getLastUpdatedDate());
 				zoneList.addZone(zone);
 			}
 			theResponse = new EPPRegistryInfoResp(respTransId, zoneList);
-		} else {
+		}
+		else {
 			EPPRegistryZoneInfo zoneInfo = null;
 			for (Iterator it = availableTlds.iterator(); it.hasNext();) {
 				EPPRegistryZoneInfo ti = (EPPRegistryZoneInfo) it.next();
@@ -380,15 +346,13 @@ public class RegistryHandler extends EPPRegistryHandler {
 					zoneInfo.setGroup("1");
 					if (zoneInfo.getName().length() == 0) {
 						zoneInfo.setSubProduct("dot");
-					} else if (zoneInfo.getName().length() == 1) {
-						zoneInfo.setSubProduct("dot"
-								+ zoneInfo.getName().substring(0, 1)
-										.toUpperCase());
-					} else {
-						zoneInfo.setSubProduct("dot"
-								+ zoneInfo.getName().substring(0, 1)
-										.toUpperCase()
-								+ zoneInfo.getName().substring(1));
+					}
+					else if (zoneInfo.getName().length() == 1) {
+						zoneInfo.setSubProduct("dot" + zoneInfo.getName().substring(0, 1).toUpperCase());
+					}
+					else {
+						zoneInfo.setSubProduct(
+						      "dot" + zoneInfo.getName().substring(0, 1).toUpperCase() + zoneInfo.getName().substring(1));
 					}
 					break;
 				}
@@ -397,7 +361,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 				if ("com".equalsIgnoreCase(zoneInfo.getName())) {
 					if (zoneInfo.getRelated() == null) {
 						EPPRegistryRelated related = new EPPRegistryRelated();
-						
+
 						EPPRegistryFields fields = new EPPRegistryFields();
 						fields.setType(EPPRegistryFields.TYPE_SYNC);
 						fields.addField("clID");
@@ -405,9 +369,9 @@ public class RegistryHandler extends EPPRegistryHandler {
 						fields.addField("ns");
 						related.setFields(fields);
 
-						related.addMember(new EPPRegistryZoneMember("com",  EPPRegistryZoneMember.TYPE_EQUAL));
-						related.addMember(new EPPRegistryZoneMember("com2",  EPPRegistryZoneMember.TYPE_EQUAL));
-						related.addMember(new EPPRegistryZoneMember("com3",  EPPRegistryZoneMember.TYPE_EQUAL));
+						related.addMember(new EPPRegistryZoneMember("com", EPPRegistryZoneMember.TYPE_EQUAL));
+						related.addMember(new EPPRegistryZoneMember("com2", EPPRegistryZoneMember.TYPE_EQUAL));
+						related.addMember(new EPPRegistryZoneMember("com3", EPPRegistryZoneMember.TYPE_EQUAL));
 
 						zoneInfo.setRelated(related);
 					}
@@ -415,7 +379,8 @@ public class RegistryHandler extends EPPRegistryHandler {
 				theResponse = new EPPRegistryInfoResp(respTransId, zoneInfo);
 
 				theResponse.setResult(EPPResult.SUCCESS);
-			} else {
+			}
+			else {
 				cat.warn("tld does not exist: " + message.getName());
 				theResponse = new EPPResponse();
 				theResponse.setResult(EPPResult.OBJECT_DOES_NOT_EXIST);
@@ -429,17 +394,16 @@ public class RegistryHandler extends EPPRegistryHandler {
 	 * Invoked when a Registry Delete command is received.
 	 * 
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPRegistryHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPRegistryHandler</code>
 	 * 
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
 	 */
 	protected EPPEventResponse doRegistryDelete(EPPEvent aEvent, Object aData) {
-		EPPRegistryDeleteCmd theMessage = (EPPRegistryDeleteCmd) aEvent
-				.getMessage();
+		EPPRegistryDeleteCmd theMessage = (EPPRegistryDeleteCmd) aEvent.getMessage();
 
 		/**
 		 * Create the transId for the response with the client trans id and the
@@ -462,8 +426,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 			}
 		}
 		if (!deleted) {
-			theResponse.setResult(EPPResult.OBJECT_DOES_NOT_EXIST,
-					"Requested tld \"" + name + "\" does not exist");
+			theResponse.setResult(EPPResult.OBJECT_DOES_NOT_EXIST, "Requested tld \"" + name + "\" does not exist");
 		}
 
 		return new EPPEventResponse(theResponse);
@@ -503,10 +466,10 @@ public class RegistryHandler extends EPPRegistryHandler {
 			domainName = (EPPRegistryDomainName) domainName.clone();
 			domainName.setLevel(Integer.valueOf(3));
 			domainName.getReservedNames().setReservedNames(new ArrayList());
-			domainName.getReservedNames().setReservedNameURI(
-					"http://testrn.vrsn.com");
+			domainName.getReservedNames().setReservedNameURI("http://testrn.vrsn.com");
 			domainNames.add(domainName);
-		} catch (CloneNotSupportedException e) {
+		}
+		catch (CloneNotSupportedException e) {
 			// Swallow. This should not happen
 		}
 
@@ -516,25 +479,20 @@ public class RegistryHandler extends EPPRegistryHandler {
 		idn.setIdnVersion("1.1");
 		idn.setIdnaVersion("2008");
 		idn.setUnicodeVersion("6.0");
-		idn.addLanguage(new EPPRegistryLanguageType("CHI",
-				"http://www.iana.org/domains/idn-tables/tables/com_zh_1.1.txt",
-				EPPRegistryLanguageType.VARIANT_STRATEGY_RESTRICTED));
-		idn.addLanguage(new EPPRegistryLanguageType(
-				"LATN",
-				"http://www.iana.org/domains/idn-tables/tables/eu_latn_1.0.html",
-				EPPRegistryLanguageType.VARIANT_STRATEGY_BLOCKED));
+		idn.addLanguage(new EPPRegistryLanguageType("CHI", "http://www.iana.org/domains/idn-tables/tables/com_zh_1.1.txt",
+		      EPPRegistryLanguageType.VARIANT_STRATEGY_RESTRICTED));
+		idn.addLanguage(
+		      new EPPRegistryLanguageType("LATN", "http://www.iana.org/domains/idn-tables/tables/eu_latn_1.0.html",
+		            EPPRegistryLanguageType.VARIANT_STRATEGY_BLOCKED));
 		idn.setCommingleAllowed(Boolean.TRUE);
 		domain.setIdn(idn);
 
 		domain.setPremiumSupport(Boolean.valueOf(true));
 		domain.setContactsSupported(Boolean.valueOf(true));
 
-		domain.addContact(new EPPRegistryDomainContact(
-				EPPRegistryDomainContact.TYPE_ADMIN, 1, 4));
-		domain.addContact(new EPPRegistryDomainContact(
-				EPPRegistryDomainContact.TYPE_BILLING, 2, 5));
-		domain.addContact(new EPPRegistryDomainContact(
-				EPPRegistryDomainContact.TYPE_TECH, 3, 6));
+		domain.addContact(new EPPRegistryDomainContact(EPPRegistryDomainContact.TYPE_ADMIN, 1, 4));
+		domain.addContact(new EPPRegistryDomainContact(EPPRegistryDomainContact.TYPE_BILLING, 2, 5));
+		domain.addContact(new EPPRegistryDomainContact(EPPRegistryDomainContact.TYPE_TECH, 3, 6));
 
 		domain.setNameServerLimit(new EPPRegistryDomainNSLimit(1, 16));
 
@@ -542,26 +500,20 @@ public class RegistryHandler extends EPPRegistryHandler {
 
 		// domain.addPeriod(new EPPRegistryDomainPeriod("create",
 		// Boolean.TRUE));
-		domain.addPeriod(new EPPRegistryDomainPeriod("create", 1, "y", 10, "y",
-				2, "y"));
-		domain.addPeriod(new EPPRegistryDomainPeriod("renew", 1, "y", 10, "y",
-				2, "y"));
-		domain.addPeriod(new EPPRegistryDomainPeriod("transfer", 1, "y", 8,
-				"y", 2, "y"));
+		domain.addPeriod(new EPPRegistryDomainPeriod("create", 1, "y", 10, "y", 2, "y"));
+		domain.addPeriod(new EPPRegistryDomainPeriod("renew", 1, "y", 10, "y", 2, "y"));
+		domain.addPeriod(new EPPRegistryDomainPeriod("transfer", 1, "y", 8, "y", 2, "y"));
 
-		domain.setTransferHoldPeriod(new EPPRegistryTransferHoldPeriodType(1,
-				"y"));
+		domain.setTransferHoldPeriod(new EPPRegistryTransferHoldPeriodType(1, "y"));
 
 		domain.addGracePeriod(new EPPRegistryGracePeriod("create", 1, "d"));
 		domain.addGracePeriod(new EPPRegistryGracePeriod("renew", 2, "m"));
 		domain.addGracePeriod(new EPPRegistryGracePeriod("transfer", 3, "h"));
 
 		EPPRegistryRGP rgp = new EPPRegistryRGP();
-		rgp.setPendingDeletePeriod(new EPPRegistryPendingDeletePeriodType(1,
-				"m"));
+		rgp.setPendingDeletePeriod(new EPPRegistryPendingDeletePeriodType(1, "m"));
 		rgp.setRedemptionPeriod(new EPPRegistryRedemptionPeriodType(1, "m"));
-		rgp.setPendingRestorePeriod(new EPPRegistryPendingRestorePeriodType(1,
-				"m"));
+		rgp.setPendingRestorePeriod(new EPPRegistryPendingRestorePeriodType(1, "m"));
 		domain.setRgp(rgp);
 
 		EPPRegistryDNSSEC dnssec = new EPPRegistryDNSSEC();
@@ -586,10 +538,8 @@ public class RegistryHandler extends EPPRegistryHandler {
 		domain.setAuthInfoRegex(new EPPRegistryRegex("^.*$", "exp"));
 
 		EPPRegistryCustomData customData = new EPPRegistryCustomData();
-		customData.addKeyValue(new EPPRegistryKeyValue("dk" + seq + "1", "dv"
-				+ seq + "1"));
-		customData.addKeyValue(new EPPRegistryKeyValue("dk" + seq + "2", "dv"
-				+ seq + "2"));
+		customData.addKeyValue(new EPPRegistryKeyValue("dk" + seq + "1", "dv" + seq + "1"));
+		customData.addKeyValue(new EPPRegistryKeyValue("dk" + seq + "2", "dv" + seq + "2"));
 		domain.setCustomData(customData);
 
 		EPPRegistrySupportedStatus supportedStatus = new EPPRegistrySupportedStatus();
@@ -618,19 +568,15 @@ public class RegistryHandler extends EPPRegistryHandler {
 	private static EPPRegistryHost buildInfoHost(int seq) {
 		EPPRegistryHost host = new EPPRegistryHost();
 
-		host.setInternal(new EPPRegistryInternalHost(5, 15,
-				EPPRegistryInternalHost.TYPE_PER_ZONE));
-		host.setExternal(new EPPRegistryExternalHost(2, 12,
-				EPPRegistryExternalHost.TYPE_PER_ZONE));
+		host.setInternal(new EPPRegistryInternalHost(5, 15, EPPRegistryInternalHost.TYPE_PER_ZONE));
+		host.setExternal(new EPPRegistryExternalHost(2, 12, EPPRegistryExternalHost.TYPE_PER_ZONE));
 		host.addNameRegex(new EPPRegistryRegex("^.*$", "exp" + seq + "1"));
 		host.addNameRegex(new EPPRegistryRegex("^.*$", "exp" + seq + "2"));
 		host.setMaxCheckHost(Integer.valueOf(15));
 
 		EPPRegistryCustomData customData = new EPPRegistryCustomData();
-		customData.addKeyValue(new EPPRegistryKeyValue("hk" + seq + "1", "hv"
-				+ seq + "1"));
-		customData.addKeyValue(new EPPRegistryKeyValue("hk" + seq + "2", "hv"
-				+ seq + "2"));
+		customData.addKeyValue(new EPPRegistryKeyValue("hk" + seq + "1", "hv" + seq + "1"));
+		customData.addKeyValue(new EPPRegistryKeyValue("hk" + seq + "2", "hv" + seq + "2"));
 		host.setCustomData(customData);
 
 		EPPRegistrySupportedStatus supportedStatus = new EPPRegistrySupportedStatus();
@@ -651,17 +597,15 @@ public class RegistryHandler extends EPPRegistryHandler {
 
 	private static EPPRegistryContact buildContact(int seq) {
 		EPPRegistryContact contact = new EPPRegistryContact();
-		
-		contact.setContactIdRegex(new EPPRegistryRegex("^.*$"));		
+
+		contact.setContactIdRegex(new EPPRegistryRegex("^.*$"));
 		contact.setSharePolicy(EPPRegistryContact.TYPE_PER_ZONE);
 		contact.setLocSupport(Boolean.TRUE);
 		contact.setIntSupport(Boolean.FALSE);
 
 		EPPRegistryCustomData customData = new EPPRegistryCustomData();
-		customData.addKeyValue(new EPPRegistryKeyValue("ck" + seq + "1", "cv1"
-				+ seq + ""));
-		customData.addKeyValue(new EPPRegistryKeyValue("ck" + seq + "2", "cv"
-				+ seq + "2"));
+		customData.addKeyValue(new EPPRegistryKeyValue("ck" + seq + "1", "cv1" + seq + ""));
+		customData.addKeyValue(new EPPRegistryKeyValue("ck" + seq + "2", "cv" + seq + "2"));
 		contact.setCustomData(customData);
 
 		contact.setAuthInfoRegex(new EPPRegistryRegex("^.*$", "exp"));
