@@ -1,33 +1,31 @@
-/**************************************************************************
- *                                                                        *
- * The information in this document is proprietary to VeriSign, Inc.      *
- * It may not be used, reproduced or disclosed without the written        *
- * approval of VeriSign.                                                  *
- *                                                                        *
- * VERISIGN PROPRIETARY & CONFIDENTIAL INFORMATION                        *
- *                                                                        *
- *                                                                        *
- * Copyright (c) 2011 VeriSign, Inc.  All rights reserved.                *
- *                                                                        *
- *************************************************************************/
+/***********************************************************
+Copyright (C) 2013 VeriSign, Inc.
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+
+http://www.verisign.com/nds/naming/namestore/techdocs.html
+ ***********************************************************/
 
 package com.verisign.epp.codec.relateddomainext;
 
-import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.GregorianCalendar;
-import java.util.List;
 import java.util.TimeZone;
 import java.util.Vector;
 
-import junit.framework.Assert;
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
-import org.apache.log4j.Logger;
-
 import com.verisign.epp.codec.domain.EPPDomainAddRemove;
 import com.verisign.epp.codec.domain.EPPDomainContact;
 import com.verisign.epp.codec.domain.EPPDomainCreateCmd;
@@ -54,9 +52,13 @@ import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
 import com.verisign.epp.codec.gen.EPPTransId;
 import com.verisign.epp.codec.host.EPPHostAddress;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.TestThread;
 
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Is a unit test of the com.verisign.epp.codec.releateddomainext package. The
  * unit test will execute, gather statistics, and output the results of a test
@@ -68,8 +70,6 @@ import com.verisign.epp.util.TestThread;
  * @version 1.0
  */
 public class EPPRelatedDomainExtTst extends TestCase {
-	private static Logger cat = Logger.getLogger(EPPRelatedDomainExtTst.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
 
 	/**
 	 * Number of unit test iterations to run. This is set in
@@ -86,7 +86,7 @@ public class EPPRelatedDomainExtTst extends TestCase {
 	 * off.</li>
 	 * </ul>
 	 * 
-	 * @param args
+	 * @param args Command line arguments
 	 */
 	public static void main(final String[] args) {
 		// Number of Threads
@@ -125,6 +125,8 @@ public class EPPRelatedDomainExtTst extends TestCase {
 	/**
 	 * JUNIT <code>suite</code> static method, which returns the tests
 	 * associated with <code>EPPRelatedDomainExtTst</code>.
+	 * 
+	 * @return Test to execute
 	 */
 	public static Test suite() {
 		EPPCodecTst.initEnvironment();
@@ -256,13 +258,13 @@ public class EPPRelatedDomainExtTst extends TestCase {
 		theCommand = new EPPDomainCreateCmd("ABC-12345", "example.com",
 				new EPPAuthInfo("2fooBAR"));
 
-		final Vector serverAttrs = new Vector();
+		final Vector<EPPHostAttr> serverAttrs = new Vector<EPPHostAttr>();
 		serverAttrs.add(new EPPHostAttr("ns1.example.com"));
 
 		final Vector hostAddresses = new Vector();
 		hostAddresses.add(new EPPHostAddress("197.162.10.10"));
 		serverAttrs.add(new EPPHostAttr("ns2.example.com", hostAddresses));
-		theCommand.setServers(serverAttrs);
+		theCommand.setServerAttrs(serverAttrs);
 
 		final EPPRelatedDomainExtCreate create = new EPPRelatedDomainExtCreate();
 		final EPPRelatedDomainExtAuthInfo authInfo = new EPPRelatedDomainExtAuthInfo(
