@@ -29,7 +29,8 @@ import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.domain.EPPDomainInfoResp;
 import com.verisign.epp.codec.gen.EPPResponse;
@@ -42,7 +43,7 @@ import com.verisign.epp.codec.rgpext.EPPRgpExtRestore;
 import com.verisign.epp.codec.rgpext.EPPRgpExtStatus;
 import com.verisign.epp.codec.rgpext.EPPRgpExtUpdate;
 import com.verisign.epp.transport.EPPClientCon;
-import com.verisign.epp.util.EPPCatFactory;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -78,8 +79,8 @@ public class EPPRgpDomainTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPRgpDomainTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPRgpDomainTst.class);
+	      
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
