@@ -21,7 +21,8 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 package com.verisign.epp.codec.secdnsext.v10;
 
 // W3C Imports
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -30,7 +31,7 @@ import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * The EPPSecDNSExtDsData is the EPPCodecComponent that knows how to encode and
@@ -55,10 +56,10 @@ import com.verisign.epp.util.EPPCatFactory;
 public class EPPSecDNSExtDsData implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPSecDNSExtDsData.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	    private static Logger cat = LoggerFactory.getLogger(EPPSecDNSExtDsData.class);
+	      
 
 	/** XML Element Name of <code>EPPSecDNSExtDsData</code> root element. */
 	static final String ELM_NAME = EPPSecDNSExtFactory.NS_PREFIX + ":dsData";
