@@ -24,14 +24,8 @@ package com.verisign.epp.codec.secdnsext.v10;
 import java.util.Date;
 import java.util.Vector;
 
-import junit.framework.Assert;
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.w3c.dom.Document;
 
-import com.verisign.epp.codec.domain.EPPDomainAddRemove;
 import com.verisign.epp.codec.domain.EPPDomainContact;
 import com.verisign.epp.codec.domain.EPPDomainCreateCmd;
 import com.verisign.epp.codec.domain.EPPDomainInfoResp;
@@ -50,6 +44,11 @@ import com.verisign.epp.codec.gen.EPPResult;
 import com.verisign.epp.codec.gen.EPPTransId;
 import com.verisign.epp.util.TestThread;
 
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 
 /**
  * Is a unit test of the com.verisign.epp.codec.secdnsxt package. The unit test
@@ -367,8 +366,8 @@ public class EPPSecDNSExtTst extends TestCase {
         chgDsDataVec.add(dsData);
         
 		// instantiate a secDNS:keyTag
-		Integer keyTag = new Integer(34095);
-		Integer keyTag2 = new Integer(10563);
+		Integer keyTag = Integer.valueOf(34095);
+		Integer keyTag2 = Integer.valueOf(10563);
 		
         // instantiate the rem DS Key Tag List
         Vector remKeyTagVec = new Vector();
