@@ -19,45 +19,37 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.interfaces.secdnsext.v11;
 
-// JUNIT Imports
-import junit.framework.*;
-
-// Log4j imports
-import org.apache.log4j.*;
-
-//----------------------------------------------
-//
-// imports...
-//
-//----------------------------------------------
-// Java Core Imports
-import java.util.Collection;
 import java.util.Iterator;
 import java.util.Random;
-import java.util.Vector;
 
-import com.verisign.epp.codec.domain.*;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import com.verisign.epp.codec.domain.EPPDomainCreateResp;
+import com.verisign.epp.codec.domain.EPPDomainInfoResp;
+import com.verisign.epp.codec.domain.EPPDomainMapFactory;
 import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPFactory;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
-
 import com.verisign.epp.codec.secdnsext.v11.EPPSecDNSAlgorithm;
 import com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtCreate;
 import com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtDsData;
 import com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtInfData;
 import com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtKeyData;
 import com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtUpdate;
-
-// EPP Imports
 import com.verisign.epp.interfaces.EPPApplicationSingle;
 import com.verisign.epp.interfaces.EPPCommandException;
 import com.verisign.epp.interfaces.EPPDomain;
 import com.verisign.epp.interfaces.EPPSession;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Is a unit test of the <code>EPPDomain</code> class including the
  * secDNS:create and secDNS:update (add, chg, rem) command extensions, as well
@@ -91,8 +83,7 @@ public class EPPSecDNSDomainTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPSecDNSDomainTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPSecDNSDomainTst.class);
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
