@@ -26,7 +26,8 @@ import java.util.Enumeration;
 import java.util.GregorianCalendar;
 import java.util.Vector;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.domain.EPPDomainCheckCmd;
 import com.verisign.epp.codec.domain.EPPDomainCheckResp;
@@ -48,7 +49,6 @@ import com.verisign.epp.codec.gen.EPPAuthInfo;
 import com.verisign.epp.codec.gen.EPPCommand;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
-import com.verisign.epp.codec.gen.EPPService;
 import com.verisign.epp.codec.gen.EPPTransId;
 import com.verisign.epp.framework.EPPDomainHandler;
 import com.verisign.epp.framework.EPPEvent;
@@ -56,7 +56,6 @@ import com.verisign.epp.framework.EPPEventResponse;
 import com.verisign.epp.framework.EPPHandleEventException;
 import com.verisign.epp.framework.EPPPollQueueException;
 import com.verisign.epp.framework.EPPPollQueueMgr;
-import com.verisign.epp.util.EPPCatFactory;
 
 /**
  * The <code>SecDNSDomainHandler</code> class is a concrete implementation of
@@ -79,8 +78,7 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	private static final String roid = "NS1EXAMPLE1-VRSN";
 
 	/** Used for logging */
-	private static Logger cat = Logger.getLogger(SecDNSDomainHandler.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(SecDNSDomainHandler.class);
 
 	// Sub-handler for handling version 1.0 extension messages.
 	SecDNSV10SubDomainHandler v10SubHandler = new SecDNSV10SubDomainHandler();
@@ -93,18 +91,17 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	 * before they execute their command specific behavior.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPSecDNSDomainHandler</code> This is assumed to be an
-	 *            instance of SessionData here.
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPSecDNSDomainHandler</code> This is assumed to be an
+	 *           instance of SessionData here.
 	 *
 	 * @exception EPPHandleEventException
-	 *                Thrown if an error condition occurs. It must contain an
-	 *                <code>EPPEventResponse</code>
+	 *               Thrown if an error condition occurs. It must contain an
+	 *               <code>EPPEventResponse</code>
 	 */
-	protected void preHandleEvent(EPPEvent aEvent, Object aData)
-			throws EPPHandleEventException {
+	protected void preHandleEvent(EPPEvent aEvent, Object aData) throws EPPHandleEventException {
 		SessionData sessionData = (SessionData) aData;
 		EPPCommand theMessage = (EPPCommand) aEvent.getMessage();
 
@@ -114,47 +111,44 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 			 * command. Sending COMMAND_FAILED_END
 			 */
 			/**
-			 * Create the transId for the response with the client trans id and
-			 * the server trans id.
+			 * Create the transId for the response with the client trans id and the
+			 * server trans id.
 			 */
-			EPPTransId transId = new EPPTransId(theMessage.getTransId(),
-					svrTransId);
+			EPPTransId transId = new EPPTransId(theMessage.getTransId(), svrTransId);
 
 			// Create the Response (Standard EPPResponse)
 			EPPResponse theResponse = new EPPResponse(transId);
 
 			theResponse.setResult(EPPResult.COMMAND_FAILED_END);
-			throw new EPPHandleEventException(
-					"The client has not established a session", theResponse);
+			throw new EPPHandleEventException("The client has not established a session", theResponse);
 		}
 	}
 
 	/**
-	 * Handles any common behavior that all Domain commands need to execute
-	 * after they execute their command specific behavior.
+	 * Handles any common behavior that all Domain commands need to execute after
+	 * they execute their command specific behavior.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPSecDNSDomainHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPSecDNSDomainHandler</code>
 	 *
 	 * @exception EPPHandleEventException
-	 *                Thrown if an error condition occurs. It must contain an
-	 *                <code>EPPEventResponse</code>
+	 *               Thrown if an error condition occurs. It must contain an
+	 *               <code>EPPEventResponse</code>
 	 */
-	protected void postHandleEvent(EPPEvent aEvent, Object aData)
-			throws EPPHandleEventException {
+	protected void postHandleEvent(EPPEvent aEvent, Object aData) throws EPPHandleEventException {
 	}
 
 	/**
 	 * Invoked when a Domain Check command is received.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPDomaindHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPDomaindHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
@@ -195,10 +189,10 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	 * Invoked when a Domain Renew command is received.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPDomaindHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPDomaindHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
@@ -214,8 +208,7 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 		EPPTransId transId = new EPPTransId(theMessage.getTransId(), svrTransId);
 
 		// Test with transId, domain name, roid, and expiration date
-		theResponse = new EPPDomainRenewResp(transId, theMessage.getName(),
-				new Date());
+		theResponse = new EPPDomainRenewResp(transId, theMessage.getName(), new Date());
 
 		theResponse.setResult(EPPResult.SUCCESS);
 
@@ -226,17 +219,16 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	 * Invoked when a Domain Delete command is received.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPDomaindHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPDomaindHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
 	 */
 	protected EPPEventResponse doDomainDelete(EPPEvent aEvent, Object aData) {
-		EPPDomainDeleteCmd theMessage = (EPPDomainDeleteCmd) aEvent
-				.getMessage();
+		EPPDomainDeleteCmd theMessage = (EPPDomainDeleteCmd) aEvent.getMessage();
 
 		// Test with transId, domain name, and expiration date
 
@@ -246,8 +238,7 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 		 */
 		EPPTransId transId = new EPPTransId(theMessage.getTransId(), svrTransId);
 
-		EPPResponse theResponse = new EPPDomainCreateResp(transId,
-				theMessage.getName(), new Date());
+		EPPResponse theResponse = new EPPDomainCreateResp(transId, theMessage.getName(), new Date());
 		theResponse.setResult(EPPResult.SUCCESS);
 
 		return new EPPEventResponse(theResponse);
@@ -257,10 +248,10 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	 * Invoked when a Domain Create command is received.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPDomaindHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPDomaindHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
@@ -268,37 +259,28 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	protected EPPEventResponse doDomainCreate(EPPEvent aEvent, Object aData) {
 		EPPResponse theResponse;
 
-		EPPDomainCreateCmd theMessage = (EPPDomainCreateCmd) aEvent
-				.getMessage();
+		EPPDomainCreateCmd theMessage = (EPPDomainCreateCmd) aEvent.getMessage();
 
-		EPPTransId theTransId = new EPPTransId(theMessage.getTransId(),
-				this.svrTransId);
+		EPPTransId theTransId = new EPPTransId(theMessage.getTransId(), this.svrTransId);
 
 		// Both extension versions set?
-		if (theMessage
-				.hasExtension(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtCreate.class)
-				&& theMessage
-						.hasExtension(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtCreate.class)) {
+		if (theMessage.hasExtension(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtCreate.class)
+		      && theMessage.hasExtension(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtCreate.class)) {
 			cat.error("SecDNSDomainHandler.doDomainCreate: both v10 and v11 of EPPSecDNSExtCreate passed.");
 
-			EPPResult theResult = new EPPResult(
-					EPPResult.PARAM_VALUE_POLICY_ERROR);
-			theResult
-					.addExtValueReason("Both v10 and v11 of secDNS extension passed");
+			EPPResult theResult = new EPPResult(EPPResult.PARAM_VALUE_POLICY_ERROR);
+			theResult.addExtValueReason("Both v10 and v11 of secDNS extension passed");
 			theResponse = new EPPResponse(null, theResult);
 		} // v10 extension set?
-		else if (theMessage
-				.hasExtension(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtCreate.class)) {
+		else if (theMessage.hasExtension(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtCreate.class)) {
 			theResponse = this.v10SubHandler.doDomainCreate(theMessage, aData);
 		} // v11 extension set?
-		else if (theMessage
-				.hasExtension(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtCreate.class)) {
+		else if (theMessage.hasExtension(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtCreate.class)) {
 			theResponse = this.v11SubHandler.doDomainCreate(theMessage, aData);
 		} // no extension set
 		else {
 			cat.info("SecDNSDomainHandler.doDomainCreate: no EPPSecDNSExtCreate extension");
-			theResponse = new EPPDomainCreateResp(theTransId,
-					theMessage.getName(), new Date());
+			theResponse = new EPPDomainCreateResp(theTransId, theMessage.getName(), new Date());
 		}
 
 		// Set the transaction id (client and server)
@@ -311,17 +293,16 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	 * Invoked when a Domain Transfer command is received.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPDomaindHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPDomaindHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
 	 */
 	protected EPPEventResponse doDomainTransfer(EPPEvent aEvent, Object aData) {
-		EPPDomainTransferCmd theMessage = (EPPDomainTransferCmd) aEvent
-				.getMessage();
+		EPPDomainTransferCmd theMessage = (EPPDomainTransferCmd) aEvent.getMessage();
 
 		/**
 		 * Create the transId for the response with the client trans id and the
@@ -344,12 +325,10 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 			thePollMsg.setResult(EPPResult.SUCCESS);
 
 			try {
-				EPPPollQueueMgr.getInstance().put(null, EPPDomainMapFactory.NS,
-						thePollMsg, null);
+				EPPPollQueueMgr.getInstance().put(null, EPPDomainMapFactory.NS, thePollMsg, null);
 			}
 			catch (EPPPollQueueException ex) {
-				cat.error("doDomainTransfer: Error putting message ["
-						+ thePollMsg + "]");
+				cat.error("doDomainTransfer: Error putting message [" + thePollMsg + "]");
 
 				EPPResult theResult = new EPPResult(EPPResult.COMMAND_FAILED);
 				EPPResponse theResponse = new EPPResponse(transId, theResult);
@@ -358,8 +337,7 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 			}
 		}
 
-		EPPDomainTransferResp theResponse = new EPPDomainTransferResp(transId,
-				theMessage.getName());
+		EPPDomainTransferResp theResponse = new EPPDomainTransferResp(transId, theMessage.getName());
 		theResponse.setTransferStatus(EPPResponse.TRANSFER_PENDING);
 
 		theResponse.setRequestClient("ClientX");
@@ -382,10 +360,10 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	 * Invoked when a Domain Update command is received.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPDomaindHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPDomaindHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
@@ -394,31 +372,23 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 
 		EPPResponse theResponse;
 
-		EPPDomainUpdateCmd theMessage = (EPPDomainUpdateCmd) aEvent
-				.getMessage();
+		EPPDomainUpdateCmd theMessage = (EPPDomainUpdateCmd) aEvent.getMessage();
 
-		EPPTransId theTransId = new EPPTransId(theMessage.getTransId(),
-				this.svrTransId);
+		EPPTransId theTransId = new EPPTransId(theMessage.getTransId(), this.svrTransId);
 
 		// Both extension versions set?
-		if (theMessage
-				.hasExtension(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtUpdate.class)
-				&& theMessage
-						.hasExtension(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtUpdate.class)) {
+		if (theMessage.hasExtension(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtUpdate.class)
+		      && theMessage.hasExtension(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtUpdate.class)) {
 			cat.error("SecDNSDomainHandler.doDomainUpdate: both v10 and v11 of EPPSecDNSExtUpdate passed.");
 
-			EPPResult theResult = new EPPResult(
-					EPPResult.PARAM_VALUE_POLICY_ERROR);
-			theResult
-					.addExtValueReason("Both v10 and v11 of secDNS extension passed");
+			EPPResult theResult = new EPPResult(EPPResult.PARAM_VALUE_POLICY_ERROR);
+			theResult.addExtValueReason("Both v10 and v11 of secDNS extension passed");
 			theResponse = new EPPResponse(null, theResult);
 		} // v10 extension set?
-		else if (theMessage
-				.hasExtension(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtUpdate.class)) {
+		else if (theMessage.hasExtension(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtUpdate.class)) {
 			theResponse = this.v10SubHandler.doDomainUpdate(theMessage, aData);
 		} // v11 extension set?
-		else if (theMessage
-				.hasExtension(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtUpdate.class)) {
+		else if (theMessage.hasExtension(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtUpdate.class)) {
 			theResponse = this.v11SubHandler.doDomainUpdate(theMessage, aData);
 		} // no extension set
 		else {
@@ -436,10 +406,10 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 	 * Invoked when a Domain Info command is received.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>EPPDomaindHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>EPPDomaindHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
@@ -448,22 +418,18 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 
 		EPPDomainInfoCmd theMessage = (EPPDomainInfoCmd) aEvent.getMessage();
 
-		EPPTransId theTransId = new EPPTransId(theMessage.getTransId(),
-				this.svrTransId);
+		EPPTransId theTransId = new EPPTransId(theMessage.getTransId(), this.svrTransId);
 
 		// EPPDomainInfo Response requires a vector of status
 		Vector theStatuses = new Vector();
-		theStatuses.addElement(new EPPDomainStatus(
-				EPPDomainStatus.ELM_STATUS_OK));
-		theStatuses.addElement(new EPPDomainStatus(
-				EPPDomainStatus.ELM_STATUS_CLIENT_HOLD));
+		theStatuses.addElement(new EPPDomainStatus(EPPDomainStatus.ELM_STATUS_OK));
+		theStatuses.addElement(new EPPDomainStatus(EPPDomainStatus.ELM_STATUS_CLIENT_HOLD));
 
 		// Required EPPDomainInfoResp attributes.
 		// trans id, domain name, roid, client id, statuses, created by id,
 		// expiration date, Auth Info
-		EPPDomainInfoResp theResponse = new EPPDomainInfoResp(null,
-				"NS1EXAMPLE1-VRSN", theMessage.getName(), "ClientX",
-				theStatuses, "ClientY", new Date(), new EPPAuthInfo("2fooBAR"));
+		EPPDomainInfoResp theResponse = new EPPDomainInfoResp(null, "NS1EXAMPLE1-VRSN", theMessage.getName(), "ClientX",
+		      theStatuses, "ClientY", new Date(), new EPPAuthInfo("2fooBAR"));
 
 		// Add Name Servers
 		Vector theNses = new Vector();
@@ -479,12 +445,9 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 
 		// Add Contacts
 		Vector theContacts = new Vector();
-		theContacts.addElement(new EPPDomainContact("sh8013",
-				EPPDomainContact.TYPE_ADMINISTRATIVE));
-		theContacts.addElement(new EPPDomainContact("sh8013",
-				EPPDomainContact.TYPE_BILLING));
-		theContacts.addElement(new EPPDomainContact("sh8013",
-				EPPDomainContact.TYPE_TECHNICAL));
+		theContacts.addElement(new EPPDomainContact("sh8013", EPPDomainContact.TYPE_ADMINISTRATIVE));
+		theContacts.addElement(new EPPDomainContact("sh8013", EPPDomainContact.TYPE_BILLING));
+		theContacts.addElement(new EPPDomainContact("sh8013", EPPDomainContact.TYPE_TECHNICAL));
 		theResponse.setContacts(theContacts);
 
 		// Set the expiration date to today plus one year
@@ -504,24 +467,18 @@ public class SecDNSDomainHandler extends EPPDomainHandler {
 
 		// Determine what version of the secDNS extension is supported
 		SessionData theSessionData = (SessionData) aData;
-		boolean hasV10ExtService = theSessionData
-				.getLoginCmd()
-				.hasExtensionService(
-						com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtFactory.NS);
-		boolean hasV11ExtService = theSessionData
-				.getLoginCmd()
-				.hasExtensionService(
-						com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtFactory.NS);
+		boolean hasV10ExtService = theSessionData.getLoginCmd()
+		      .hasExtensionService(com.verisign.epp.codec.secdnsext.v10.EPPSecDNSExtFactory.NS);
+		boolean hasV11ExtService = theSessionData.getLoginCmd()
+		      .hasExtensionService(com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtFactory.NS);
 
 		// Version 1.1 specified? This applies if both version 1.0 and 1.1 was
 		// specified.
 		if (hasV11ExtService) {
-			theResponse = this.v11SubHandler.doDomainInfo(theMessage,
-					theResponse, aData);
+			theResponse = this.v11SubHandler.doDomainInfo(theMessage, theResponse, aData);
 		} // Version 1.0 specified only?
 		else if (hasV10ExtService) {
-			theResponse = this.v10SubHandler.doDomainInfo(theMessage,
-					theResponse, aData);
+			theResponse = this.v10SubHandler.doDomainInfo(theMessage, theResponse, aData);
 		} // No secDNS extension URI specified in login
 		else {
 			cat.info("SecDNSDomainHandler.doDomainInfo: no secDNS extension URI specified in login");
