@@ -53,19 +53,19 @@ import javax.xml.crypto.dsig.keyinfo.KeyInfoFactory;
 import javax.xml.crypto.dsig.keyinfo.X509Data;
 import javax.xml.crypto.dsig.spec.C14NMethodParameterSpec;
 import javax.xml.crypto.dsig.spec.TransformParameterSpec;
-import javax.xml.parsers.DocumentBuilder;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 
-import org.apache.log4j.Logger;
-import org.apache.xerces.dom.DocumentImpl;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
+import org.apache.xerces.dom.DocumentImpl;
 
 import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPCodecException;
@@ -73,9 +73,9 @@ import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
 import com.verisign.epp.exception.EPPException;
-import com.verisign.epp.util.EPPCatFactory;
+import com.verisign.epp.pool.parser.EPPXMLSignatureParserPool;
 import com.verisign.epp.util.EPPXMLErrorHandler;
-import com.verisign.epp.util.EPPXMLSignatureParserPool;
+import com.verisign.epp.util.EPPXMLSignatureSchemaCachingParser;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -90,10 +90,9 @@ public class EPPSignedCode implements EPPCodecComponent {
 	private static final long serialVersionUID = 3210389145062853193L;
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPSignedCode.class.getName(),
-			EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPSignedCode.class);	      
 
 	/**
 	 * Constant for the code local name for signedCode element
@@ -103,8 +102,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	/**
 	 * Constant for the code tag for signedCode element
 	 */
-	public static final String ELM_SIGNED_CODE = EPPVerificationCodeExtFactory.NS
-			+ ":" + ELM_SIGNED_CODE_LOCALNAME;
+	public static final String ELM_SIGNED_CODE = EPPVerificationCodeExtFactory.NS + ":" + ELM_SIGNED_CODE_LOCALNAME;
 
 	/**
 	 * The ID attribute name
@@ -119,13 +117,12 @@ public class EPPSignedCode implements EPPCodecComponent {
 	/**
 	 * XML Signature Factory
 	 */
-	private static XMLSignatureFactory sigFactory = XMLSignatureFactory
-			.getInstance("DOM");
+	private static XMLSignatureFactory sigFactory = XMLSignatureFactory.getInstance("DOM");
 
 	/**
-	 * Case where constructing the signed code data (i.e. without signature),
-	 * XML is not valid as per schema (Signature is required as per schema). In
-	 * this case, ignore the XML parsing exception and create a DOM object.
+	 * Case where constructing the signed code data (i.e. without signature), XML
+	 * is not valid as per schema (Signature is required as per schema). In this
+	 * case, ignore the XML parsing exception and create a DOM object.
 	 */
 	private static final boolean IGNORE_XML_PARSE_EXCEPTION = true;
 
@@ -136,8 +133,8 @@ public class EPPSignedCode implements EPPCodecComponent {
 	private static final boolean DO_NOT_IGNORE_XML_PARSE_EXCEPTION = false;
 
 	/**
-	 * XML local name for the root element of the signed code. This should be
-	 * set to <code>ELM_SIGNED_CODE_LOCALNAME</code>.
+	 * XML local name for the root element of the signed code. This should be set
+	 * to <code>ELM_SIGNED_CODE_LOCALNAME</code>.
 	 */
 	private String localName = ELM_SIGNED_CODE_LOCALNAME;
 
@@ -161,7 +158,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * Trust anchor of validated signed code.
 	 */
 	private TrustAnchor trustAnchor;
-	
+
 	/**
 	 * Create an <code>EPPSignedCode</code> instance.
 	 */
@@ -173,7 +170,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * <code>EPPSignedCode</code>.
 	 * 
 	 * @param aEncodedSignedCode
-	 *            <code>EPPEncodedSignedCode</code> to convert from.
+	 *           <code>EPPEncodedSignedCode</code> to convert from.
 	 */
 	public EPPSignedCode(EPPEncodedSignedCodeValue aEncodedSignedCode) {
 
@@ -184,16 +181,16 @@ public class EPPSignedCode implements EPPCodecComponent {
 	}
 
 	/**
-	 * Create an <code>EPPSignedCode</code> with the code of the signed code.
-	 * The default encoding is XML and the signature must be generated by
-	 * calling {@link #sign(PrivateKey)}. Once the object is created using this
-	 * constructor, one should not update the object. In the case the object
-	 * gets updated, changes will not be included in XML/signature.
+	 * Create an <code>EPPSignedCode</code> with the code of the signed code. The
+	 * default encoding is XML and the signature must be generated by calling
+	 * {@link #sign(PrivateKey)}. Once the object is created using this
+	 * constructor, one should not update the object. In the case the object gets
+	 * updated, changes will not be included in XML/signature.
 	 * 
 	 * @param aCode
-	 *            Verification code
+	 *           Verification code
 	 * @throws EPPEncodeException
-	 *             Thrown if any errors prevent encoding.
+	 *            Thrown if any errors prevent encoding.
 	 */
 	public EPPSignedCode(EPPVerificationCode aCode) throws EPPEncodeException {
 		this.code = aCode;
@@ -204,15 +201,15 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * Create an <code>EPPSignedCode</code> with the type and code of the signed
 	 * code. The default encoding is XML and the signature must be generated by
 	 * calling {@link #sign(PrivateKey)}. Once the object is created using this
-	 * constructor, one should not update the object. In the case the object
-	 * gets updated, changes will not be included in XML/signature.
+	 * constructor, one should not update the object. In the case the object gets
+	 * updated, changes will not be included in XML/signature.
 	 * 
 	 * @param aCode
-	 *            Verification code
+	 *           Verification code
 	 * @param aType
-	 *            Type of the verification code
+	 *           Type of the verification code
 	 * @throws EPPEncodeException
-	 *             Thrown if any errors prevent encoding.
+	 *            Thrown if any errors prevent encoding.
 	 */
 	public EPPSignedCode(String aCode, String aType) throws EPPEncodeException {
 		this.code = new EPPVerificationCode(aCode, aType);
@@ -224,9 +221,9 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * <code>byte[]</code> (XML).
 	 * 
 	 * @param aSignedCodeArray
-	 *            <code>byte[]</code> to decode the attribute values
+	 *           <code>byte[]</code> to decode the attribute values
 	 * @throws EPPDecodeException
-	 *             Error decoding the <code>byte[]</code>.
+	 *            Error decoding the <code>byte[]</code>.
 	 */
 	public EPPSignedCode(byte[] aSignedCodeArray) throws EPPDecodeException {
 		cat.debug("EPPSignedCode(byte[]): enter");
@@ -238,9 +235,9 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * Decode the <code>EPPSignedCode</code> component
 	 * 
 	 * @param aElement
-	 *            Root element of the <code>EPPSignedCode</code>
+	 *           Root element of the <code>EPPSignedCode</code>
 	 * @throws EPPDecodeException
-	 *             Error decoding the <code>EPPSignedCode</code>
+	 *            Error decoding the <code>EPPSignedCode</code>
 	 */
 	@Override
 	public void decode(Element aElement) throws EPPDecodeException {
@@ -254,11 +251,11 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * like code, issuer etc. Sets the signedCodeElement.
 	 * 
 	 * @param aSignedCodeArray
-	 *            <code>byte[]</code> to decode the attribute values
+	 *           <code>byte[]</code> to decode the attribute values
 	 * @throws EPPDecodeException
-	 *             Error decoding the <code>byte[]</code>.
+	 *            Error decoding the <code>byte[]</code>.
 	 */
-	protected void decode(byte[] aSignedCodeArray) throws EPPDecodeException {
+	public void decode(byte[] aSignedCodeArray) throws EPPDecodeException {
 		Element elm;
 		elm = parseAndGetDocElement(aSignedCodeArray);
 		initializeObject(elm);
@@ -267,13 +264,13 @@ public class EPPSignedCode implements EPPCodecComponent {
 
 	/**
 	 * Initialized the signedCode elements from DOM element and sets localName,
-	 * attributeIdValue and code attributes of object to instance variables.
-	 * Once these variables are set, can not be changed.
+	 * attributeIdValue and code attributes of object to instance variables. Once
+	 * these variables are set, can not be changed.
 	 * 
 	 * @param aElement
-	 *            Root element of the <code>EPPSignedCode</code>
+	 *           Root element of the <code>EPPSignedCode</code>
 	 * @throws EPPDecodeException
-	 *             Error decoding the <code>EPPSignedCode</code>
+	 *            Error decoding the <code>EPPSignedCode</code>
 	 */
 	private void initializeObject(Element aElement) throws EPPDecodeException {
 
@@ -283,9 +280,8 @@ public class EPPSignedCode implements EPPCodecComponent {
 		this.attrIdValue = aElement.getAttribute(ATTR_ID);
 
 		// Code
-		this.code = (EPPVerificationCode) EPPUtil.decodeComp(aElement,
-				EPPVerificationCodeExtFactory.NS, EPPVerificationCode.ELM_NAME,
-				EPPVerificationCode.class);
+		this.code = (EPPVerificationCode) EPPUtil.decodeComp(aElement, EPPVerificationCodeExtFactory.NS,
+		      EPPVerificationCode.ELM_NAME, EPPVerificationCode.class);
 	}
 
 	/**
@@ -293,12 +289,11 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * variables like code. Sets the signedCodeElement.
 	 * 
 	 * @param aElement
-	 *            Root element of the <code>EPPSignedCode</code>
+	 *           Root element of the <code>EPPSignedCode</code>
 	 * @throws EPPDecodeException
-	 *             Error decoding the <code>EPPSignedCode</code>
+	 *            Error decoding the <code>EPPSignedCode</code>
 	 */
-	private void decodeSignedCodeElement(Element aElement)
-			throws EPPDecodeException {
+	private void decodeSignedCodeElement(Element aElement) throws EPPDecodeException {
 		initializeObject(aElement);
 		try {
 			this.signedCodeElement = parseAndGetDocElement(getByteArrayForElement(aElement));
@@ -313,7 +308,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * 
 	 * @return <code>byte[]</code> representing signed code
 	 * @throws EPPEncodeException
-	 *             Error encoding the signed code
+	 *            Error encoding the signed code
 	 */
 	public byte[] encode() throws EPPEncodeException {
 		return getByteArrayForElement(this.signedCodeElement);
@@ -323,18 +318,17 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * Sets all this instance's data in the given XML document
 	 * 
 	 * @param aDocument
-	 *            a DOM Document to attach data to.
+	 *           a DOM Document to attach data to.
 	 * @return The root element of this component.
 	 * @throws EPPEncodeException
-	 *             Thrown if any errors prevent encoding.
+	 *            Thrown if any errors prevent encoding.
 	 */
 	@Override
 	public Element encode(Document aDocument) throws EPPEncodeException {
 		cat.debug("EPPSignedCode.encode(Document): enter");
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " on in EPPSignedCode.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " on in EPPSignedCode.encode(Document)");
 		}
 
 		// By this time, signedCode element must have been set.
@@ -353,7 +347,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * attributes is not set.
 	 * 
 	 * @throws EPPEncodeException
-	 *             Thrown if any required parameter is missing.
+	 *            Thrown if any required parameter is missing.
 	 */
 	private void validateRequiredAttributes() throws EPPEncodeException {
 		// Validate required attributes
@@ -367,21 +361,19 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * Identifier of signed code
 	 * 
 	 * @param aCode
-	 *            Verification code
+	 *           Verification code
 	 * @throws EPPEncodeException
-	 *             Thrown if any errors prevent encoding.
+	 *            Thrown if any errors prevent encoding.
 	 */
-	private void parseAndSetSignedCodeElement(EPPVerificationCode aCode)
-			throws EPPEncodeException {
+	private void parseAndSetSignedCodeElement(EPPVerificationCode aCode) throws EPPEncodeException {
 
 		this.code = aCode;
 		validateRequiredAttributes();
 
 		Document document = new DocumentImpl();
 
-		Element root = document.createElementNS(
-				EPPVerificationCodeExtFactory.NS,
-				EPPVerificationCodeExtFactory.NS_PREFIX + ":" + this.localName);
+		Element root = document.createElementNS(EPPVerificationCodeExtFactory.NS,
+		      EPPVerificationCodeExtFactory.NS_PREFIX + ":" + this.localName);
 
 		// Add the "id" Attribute
 		root.setAttribute(ATTR_ID, this.attrIdValue);
@@ -400,8 +392,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 		// even if
 		// we do encode/decode multiple time.
 		try {
-			this.signedCodeElement = parseAndGetDocElement(xmlBytes,
-					IGNORE_XML_PARSE_EXCEPTION);
+			this.signedCodeElement = parseAndGetDocElement(xmlBytes, IGNORE_XML_PARSE_EXCEPTION);
 		}
 		catch (EPPDecodeException e) {
 			throw new EPPEncodeException(e);
@@ -413,7 +404,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * 
 	 * @return clone of <code>EPPSignedCode</code>
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 		EPPSignedCode clone = (EPPSignedCode) super.clone();
@@ -427,9 +418,9 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * added use {@link #sign(PrivateKey, Certificate[])}.
 	 * 
 	 * @param aPrivateKey
-	 *            Private key used to sign the signed code
+	 *           Private key used to sign the signed code
 	 * @throws EPPException
-	 *             Error creating the digital signature
+	 *            Error creating the digital signature
 	 */
 	public void sign(PrivateKey aPrivateKey) throws EPPException {
 		cat.debug("EPPSignedCode.sign(PrivateKey): enter");
@@ -438,45 +429,38 @@ public class EPPSignedCode implements EPPCodecComponent {
 	}
 
 	/**
-	 * Digitally sign the signed code using the passed private key and a chain
-	 * of certificates.
+	 * Digitally sign the signed code using the passed private key and a chain of
+	 * certificates.
 	 * 
 	 * @param aPrivateKey
-	 *            Private key used to sign the signed code
+	 *           Private key used to sign the signed code
 	 * @param aCertChain
-	 *            Certificate chain to include in the XMLSignature associated
-	 *            with the private key. Pass <code>null</code> to not include
-	 *            the certificate chain in the XMLSignature.
+	 *           Certificate chain to include in the XMLSignature associated with
+	 *           the private key. Pass <code>null</code> to not include the
+	 *           certificate chain in the XMLSignature.
 	 * @throws EPPException
-	 *             Error creating the digital signature
+	 *            Error creating the digital signature
 	 */
-	public void sign(PrivateKey aPrivateKey, Certificate[] aCertChain)
-			throws EPPException {
+	public void sign(PrivateKey aPrivateKey, Certificate[] aCertChain) throws EPPException {
 		cat.debug("EPPSignedCode.sign(PrivateKey, Certificate[]): enter");
 
 		// Required parameter is null?
 		if (aPrivateKey == null) {
-			throw new EPPException(
-					"EPPSignedCode.sign(PrivateKey, Certificate[]): null aPrivateKey parameter");
+			throw new EPPException("EPPSignedCode.sign(PrivateKey, Certificate[]): null aPrivateKey parameter");
 		}
 
 		try {
-			DigestMethod digestMethod = sigFactory.newDigestMethod(
-					DigestMethod.SHA256, null);
+			DigestMethod digestMethod = sigFactory.newDigestMethod(DigestMethod.SHA256, null);
 
 			List<Transform> transforms = new ArrayList<Transform>();
-			transforms.add(sigFactory.newTransform(Transform.ENVELOPED,
-					(TransformParameterSpec) null));
-			Reference xmlSigRef = sigFactory.newReference("#"
-					+ this.attrIdValue, digestMethod, transforms, null, null);
+			transforms.add(sigFactory.newTransform(Transform.ENVELOPED, (TransformParameterSpec) null));
+			Reference xmlSigRef = sigFactory.newReference("#" + this.attrIdValue, digestMethod, transforms, null, null);
 
 			// Create the SignedInfo
-			SignedInfo signedInfo = sigFactory.newSignedInfo(sigFactory
-					.newCanonicalizationMethod(
-							CanonicalizationMethod.INCLUSIVE_WITH_COMMENTS,
-							(C14NMethodParameterSpec) null), sigFactory
-					.newSignatureMethod(SignatureMethod.RSA_SHA1, null),
-					Collections.singletonList(xmlSigRef));
+			SignedInfo signedInfo = sigFactory.newSignedInfo(
+			      sigFactory.newCanonicalizationMethod(CanonicalizationMethod.INCLUSIVE_WITH_COMMENTS,
+			            (C14NMethodParameterSpec) null),
+			      sigFactory.newSignatureMethod(SignatureMethod.RSA_SHA1, null), Collections.singletonList(xmlSigRef));
 
 			// Add certificate chain to signature?
 			KeyInfo keyInfo = null;
@@ -488,33 +472,31 @@ public class EPPSignedCode implements EPPCodecComponent {
 				for (Certificate cert : aCertChain) {
 					if (cert == null || !(cert instanceof X509Certificate)) {
 						throw new EPPException(
-								"EPPSignedCode.sign(PrivateKey, Certificate[]): Null or invalid certificate type");
+						      "EPPSignedCode.sign(PrivateKey, Certificate[]): Null or invalid certificate type");
 					}
 					certChain.add((X509Certificate) cert);
-					cat.debug("EPPSignedCode.sign(PrivateKey, Certificate[]): Added certificate ["
-							+ cert + "] to X509Certificate list");
+					cat.debug("EPPSignedCode.sign(PrivateKey, Certificate[]): Added certificate [" + cert
+					      + "] to X509Certificate list");
 				}
 				List<X509Data> certDataList = new ArrayList<X509Data>();
 				certDataList.add(keyInfoFactory.newX509Data(certChain));
 				keyInfo = keyInfoFactory.newKeyInfo(certDataList);
 			}
 			else {
-				cat.debug("EPPSignedCode.sign(PrivateKey, Certificate[]): null certificate chain passed, no certificates added");
+				cat.debug(
+				      "EPPSignedCode.sign(PrivateKey, Certificate[]): null certificate chain passed, no certificates added");
 			}
 
-			DOMSignContext signContext = new DOMSignContext(aPrivateKey,
-					this.signedCodeElement);
+			DOMSignContext signContext = new DOMSignContext(aPrivateKey, this.signedCodeElement);
 			signContext.setDefaultNamespacePrefix("dsig");
-			XMLSignature signature = sigFactory.newXMLSignature(signedInfo,
-					keyInfo);
+			XMLSignature signature = sigFactory.newXMLSignature(signedInfo, keyInfo);
 			signature.sign(signContext);
 
 		}
 		catch (Exception ex) {
 			ex.printStackTrace();
 			cat.debug("Error signing the EPPSignedCode: " + ex);
-			throw new EPPException(
-					"EPPSignedCode.sign(PrivateKey, Certificate[]): Error signing the EPPSignedCode");
+			throw new EPPException("EPPSignedCode.sign(PrivateKey, Certificate[]): Error signing the EPPSignedCode");
 		}
 		cat.debug("EPPSignedCode.sign(PrivateKey, Certificate[]): exit");
 	}
@@ -524,17 +506,17 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * using the public key of the certificate or the top certificate in the
 	 * certificate chain contained in the <code>XMLSignature</code> with using
 	 * the passed PKIX parameters to the PKIX <code>CertPathValidator</code>
-	 * algorithm. The trust store can be loaded and used to create an instance
-	 * of <code>PKIXParameters</code> to verify the certificate chain included
-	 * in the <code>XMLSignature</code> with the trust anchors included in the
-	 * trust store. This method will automatically synchronize the
+	 * algorithm. The trust store can be loaded and used to create an instance of
+	 * <code>PKIXParameters</code> to verify the certificate chain included in
+	 * the <code>XMLSignature</code> with the trust anchors included in the trust
+	 * store. This method will automatically synchronize the
 	 * <code>aPKIXParameters</code> parameter when used, since it is not
 	 * thread-safe. Use {@link #validate(PKIXParameters, boolean)} to explicitly
 	 * set the <code>aPKIXParameters</code> synchronization setting.
 	 * 
 	 * @param aPKIXParameters
-	 *            Parameters used as input for the PKIX
-	 *            <code>CertPathValidator</code> algorithm.
+	 *           Parameters used as input for the PKIX
+	 *           <code>CertPathValidator</code> algorithm.
 	 * @return <code>true</code> if valid; <code>false</code> otherwise.
 	 */
 	public boolean validate(PKIXParameters aPKIXParameters) {
@@ -547,8 +529,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * @return signature element from signedCode DOM object.
 	 */
 	private Element findSignatureElement() {
-		return EPPUtil.getElementByTagNameNS(this.signedCodeElement,
-				XMLSignature.XMLNS, "Signature");
+		return EPPUtil.getElementByTagNameNS(this.signedCodeElement, XMLSignature.XMLNS, "Signature");
 	}
 
 	/**
@@ -556,22 +537,21 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * using the public key of the certificate or the top certificate in the
 	 * certificate chain contained in the <code>XMLSignature</code> with using
 	 * the passed PKIX parameters to the PKIX <code>CertPathValidator</code>
-	 * algorithm. The trust store can be loaded and used to create an instance
-	 * of <code>PKIXParameters</code> to verify the certificate chain included
-	 * in the <code>XMLSignature</code> with the trust anchors included in the
-	 * trust store.
+	 * algorithm. The trust store can be loaded and used to create an instance of
+	 * <code>PKIXParameters</code> to verify the certificate chain included in
+	 * the <code>XMLSignature</code> with the trust anchors included in the trust
+	 * store.
 	 * 
 	 * @param aPKIXParameters
-	 *            Parameters used as input for the PKIX
-	 *            <code>CertPathValidator</code> algorithm.
+	 *           Parameters used as input for the PKIX
+	 *           <code>CertPathValidator</code> algorithm.
 	 * @param aSynchronizePKIXParameters
-	 *            Should the <code>aPKIXParameters</code> be synchronized inside
-	 *            the method? If there is no reason to synchronize, then
-	 *            <code>false</code> can be passed to increase performance.
+	 *           Should the <code>aPKIXParameters</code> be synchronized inside
+	 *           the method? If there is no reason to synchronize, then
+	 *           <code>false</code> can be passed to increase performance.
 	 * @return <code>true</code> if valid; <code>false</code> otherwise.
 	 */
-	public boolean validate(PKIXParameters aPKIXParameters,
-			boolean aSynchronizePKIXParameters) {
+	public boolean validate(PKIXParameters aPKIXParameters, boolean aSynchronizePKIXParameters) {
 
 		cat.debug("validate(PKIXParameters): enter");
 
@@ -581,8 +561,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 			Element sigElement = findSignatureElement();
 
 			DOMStructure domStructure = new DOMStructure(sigElement);
-			XMLSignature signature = sigFactory
-					.unmarshalXMLSignature(domStructure);
+			XMLSignature signature = sigFactory.unmarshalXMLSignature(domStructure);
 
 			// No key info found?
 			if (signature.getKeyInfo() == null) {
@@ -620,8 +599,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 							// Check validity of certificate
 							x509Cert.checkValidity();
 
-							cat.debug("validate(PKIXParameters): Found X509Certificate ["
-									+ x509Cert + "]");
+							cat.debug("validate(PKIXParameters): Found X509Certificate [" + x509Cert + "]");
 							certificates.add(x509Cert);
 						}
 					}
@@ -632,17 +610,15 @@ public class EPPSignedCode implements EPPCodecComponent {
 					throw new Exception("No certificates found in Signature");
 				}
 
-				CertificateFactory certFactory = CertificateFactory
-						.getInstance("X.509");
+				CertificateFactory certFactory = CertificateFactory.getInstance("X.509");
 				CertPath certPath = certFactory.generateCertPath(certificates);
 
 				// Validate certificate path against trust anchors
 				// (aPKIXParameters)
-				CertPathValidator pathValidator = CertPathValidator
-						.getInstance("PKIX");
+				CertPathValidator pathValidator = CertPathValidator.getInstance("PKIX");
 
 				PKIXCertPathValidatorResult result = null;
-				
+
 				// Must synchronize around the use of PKIXParameters
 				// since it is NOT thread-safe.
 				if (aSynchronizePKIXParameters) {
@@ -653,21 +629,19 @@ public class EPPSignedCode implements EPPCodecComponent {
 				else {
 					result = (PKIXCertPathValidatorResult) pathValidator.validate(certPath, aPKIXParameters);
 				}
-				
+
 				this.trustAnchor = result.getTrustAnchor();
 			}
 
 			// Get the public key from top certificate to validate signature
 			X509Certificate cert = certificates.get(0);
-			cat.debug("validate(PKIXParameters): Getting public key from top certificate ["
-					+ cert + "]");
+			cat.debug("validate(PKIXParameters): Getting public key from top certificate [" + cert + "]");
 			PublicKey publicKey = cert.getPublicKey();
 
 			valid = this.validate(sigElement, publicKey);
 		}
 		catch (Exception ex) {
-			cat.debug("validate(PKIXParameters): Error validating the EPPSignedCode: "
-					+ ex);
+			cat.debug("validate(PKIXParameters): Error validating the EPPSignedCode: " + ex);
 			valid = false;
 		}
 
@@ -680,7 +654,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * Validate the signature attribute against the signed code attributes.
 	 * 
 	 * @param aPublicKey
-	 *            Public used to validate the signature
+	 *           Public used to validate the signature
 	 * @return <code>true</code> if valid; <code>false</code> otherwise.
 	 */
 	public boolean validate(PublicKey aPublicKey) {
@@ -693,8 +667,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 			valid = this.validate(sigElm, aPublicKey);
 		}
 		catch (Exception ex) {
-			cat.debug("validate(PublicKey): Error validating the EPPSignedCode: "
-					+ ex);
+			cat.debug("validate(PublicKey): Error validating the EPPSignedCode: " + ex);
 			valid = false;
 		}
 
@@ -707,13 +680,12 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * array.
 	 * 
 	 * @param aElement
-	 *            DOM element for which to get the byte array
+	 *           DOM element for which to get the byte array
 	 * @return <code>byte[]</code> representing DOM element
 	 * @throws EPPEncodeException
-	 *             thrown if any errors prevent transforming.
+	 *            thrown if any errors prevent transforming.
 	 */
-	private byte[] getByteArrayForElement(Element aElement)
-			throws EPPEncodeException {
+	private byte[] getByteArrayForElement(Element aElement) throws EPPEncodeException {
 		cat.debug("EPPSignedCode.getByteArrayForElement(): enter");
 
 		ByteArrayOutputStream os = new ByteArrayOutputStream();
@@ -737,36 +709,33 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * Parse the input byte array and return the DOM document element.
 	 * 
 	 * @param aSignedCodeArray
-	 *            <code>byte[]</code> to parse to create DOM element.
+	 *           <code>byte[]</code> to parse to create DOM element.
 	 * @return DOM element created from <code>byte[]</code>.
 	 * @throws EPPDecodeException
-	 *             thrown if any errors parsing <code>byte[]</code>.
+	 *            thrown if any errors parsing <code>byte[]</code>.
 	 */
-	private Element parseAndGetDocElement(byte[] aSignedCodeArray)
-			throws EPPDecodeException {
-		return parseAndGetDocElement(aSignedCodeArray,
-				DO_NOT_IGNORE_XML_PARSE_EXCEPTION);
+	private Element parseAndGetDocElement(byte[] aSignedCodeArray) throws EPPDecodeException {
+		return parseAndGetDocElement(aSignedCodeArray, DO_NOT_IGNORE_XML_PARSE_EXCEPTION);
 	}
 
 	/**
 	 * Parse the input byte array and return the DOM document element.
 	 * 
 	 * @param aSignedCodeArray
-	 *            <code>byte[]</code> to parse to create DOM element.
+	 *           <code>byte[]</code> to parse to create DOM element.
 	 * @return DOM element created from <code>byte[]</code>.
 	 * @throws EPPDecodeException
-	 *             thrown if any errors parsing <code>byte[]</code>.
+	 *            thrown if any errors parsing <code>byte[]</code>.
 	 */
-	private Element parseAndGetDocElement(byte[] aSignedCodeArray,
-			boolean aIgnoreParsingError) throws EPPDecodeException {
+	private Element parseAndGetDocElement(byte[] aSignedCodeArray, boolean aIgnoreParsingError)
+	      throws EPPDecodeException {
 		Element elm;
 		ByteArrayInputStream is = null;
-		DocumentBuilder parser = null;
+		EPPXMLSignatureSchemaCachingParser parser = null;
 		try {
 			is = new ByteArrayInputStream(aSignedCodeArray);
 
-			parser = (DocumentBuilder) EPPXMLSignatureParserPool.getInstance()
-					.getPool().requestObject();
+			parser = EPPXMLSignatureParserPool.getInstance().getPool().borrowObject();
 
 			if (aIgnoreParsingError) {
 				// Disable error handler
@@ -781,26 +750,19 @@ public class EPPSignedCode implements EPPCodecComponent {
 		}
 		catch (SAXParseException ex) {
 			// Error generated by parser
-			cat.debug(
-					"parseAndGetDocElement():Got SAXParseException while decoding signed code array",
-					ex);
-			throw new EPPDecodeException("[SAXParseException]" + "\nline      "
-					+ ex.getLineNumber() + "\ncolumn    "
-					+ ex.getColumnNumber() + "\nuri       " + ex.getSystemId()
-					+ "\nMessage : " + ex.getMessage(),
-					EPPCodecException.SAX_EXCEPTION);
+			cat.debug("parseAndGetDocElement():Got SAXParseException while decoding signed code array", ex);
+			throw new EPPDecodeException(
+			      "[SAXParseException]" + "\nline      " + ex.getLineNumber() + "\ncolumn    " + ex.getColumnNumber()
+			            + "\nuri       " + ex.getSystemId() + "\nMessage : " + ex.getMessage(),
+			      EPPCodecException.SAX_EXCEPTION);
 		}
 		catch (SAXException ex) {
 			// Error generated by this application
-			cat.debug(
-					"parseAndGetDocElement():Got SAXException while decoding signed code array",
-					ex);
-			throw new EPPDecodeException("[SAXException] " + ex,
-					EPPCodecException.SAX_EXCEPTION);
+			cat.debug("parseAndGetDocElement():Got SAXException while decoding signed code array", ex);
+			throw new EPPDecodeException("[SAXException] " + ex, EPPCodecException.SAX_EXCEPTION);
 		}
 		catch (Exception ex) {
-			throw new EPPDecodeException("Error decoding signed code array: "
-					+ ex);
+			throw new EPPDecodeException("Error decoding signed code array: " + ex);
 		}
 		finally {
 			if (is != null) {
@@ -817,8 +779,12 @@ public class EPPSignedCode implements EPPCodecComponent {
 					parser.setErrorHandler(new EPPXMLErrorHandler());
 				}
 
-				EPPXMLSignatureParserPool.getInstance().getPool()
-						.returnObject(parser);
+				try {
+					EPPXMLSignatureParserPool.getInstance().getPool().returnObject(parser);
+				}
+				catch (Exception ex) {
+					throw new EPPDecodeException("parseAndGetDocElement():Exception returning parser to pool: " + ex);
+				}
 			}
 		}
 	}
@@ -827,7 +793,7 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * implements a deep <code>EPPSignedCode</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPSignedCode</code> instance to compare with
+	 *           <code>EPPSignedCode</code> instance to compare with
 	 * @return true if equal false otherwise
 	 */
 	public boolean equals(Object aObject) {
@@ -898,15 +864,15 @@ public class EPPSignedCode implements EPPCodecComponent {
 	/**
 	 * Has the Trust Anchor been set?
 	 * 
-	 * @return <code>true</code> if the Trust Anchor has been set; <code>false</code>
-	 *         otherwise.
+	 * @return <code>true</code> if the Trust Anchor has been set;
+	 *         <code>false</code> otherwise.
 	 */
 	public boolean hasTrustAnchor() {
 		return (this.trustAnchor != null ? true : false);
 	}
-	
+
 	/**
-	 * Gets the Trust Anchor associated with the validated signed code. 
+	 * Gets the Trust Anchor associated with the validated signed code.
 	 * 
 	 * @return Trust Anchor if defined; <code>null</code> otherwise.
 	 */
@@ -914,15 +880,14 @@ public class EPPSignedCode implements EPPCodecComponent {
 		return this.trustAnchor;
 	}
 
-
 	/**
 	 * Validate the signature attribute against the signed code attributes given
 	 * the <code>Signature</code> DOM <code>Element</code>.
 	 * 
 	 * @param aSigElm
-	 *            DOM <code>Signature Element</code>
+	 *           DOM <code>Signature Element</code>
 	 * @param aPublicKey
-	 *            Public used to validate the signature
+	 *           Public used to validate the signature
 	 * @return <code>true</code> if valid; <code>false</code> otherwise.
 	 */
 	private boolean validate(Element aSigElm, PublicKey aPublicKey) {
@@ -931,10 +896,8 @@ public class EPPSignedCode implements EPPCodecComponent {
 		boolean valid = false;
 
 		try {
-			DOMValidateContext valContext = new DOMValidateContext(aPublicKey,
-					aSigElm);
-			XMLSignature signature = sigFactory
-					.unmarshalXMLSignature(valContext);
+			DOMValidateContext valContext = new DOMValidateContext(aPublicKey, aSigElm);
+			XMLSignature signature = sigFactory.unmarshalXMLSignature(valContext);
 
 			if (signature.validate(valContext)) {
 				valid = true;
@@ -942,23 +905,19 @@ public class EPPSignedCode implements EPPCodecComponent {
 			else {
 				valid = false;
 				cat.debug("validate(Element, PublicKey): validation status = "
-						+ signature.getSignatureValue().validate(valContext));
-				Iterator<?> i = signature.getSignedInfo().getReferences()
-						.iterator();
+				      + signature.getSignatureValue().validate(valContext));
+				Iterator<?> i = signature.getSignedInfo().getReferences().iterator();
 
 				for (int j = 0; i.hasNext(); j++) {
 					Reference next = (Reference) i.next();
 
-					cat.debug("validate(Element, PublicKey): ref[" + j
-							+ "], URI = " + next.getURI()
-							+ ", validity status = "
-							+ next.validate(valContext));
+					cat.debug("validate(Element, PublicKey): ref[" + j + "], URI = " + next.getURI() + ", validity status = "
+					      + next.validate(valContext));
 				}
 			}
 		}
 		catch (Exception ex) {
-			cat.debug("validate(Element, PublicKey): Error validating the EPPSignedCode: "
-					+ ex);
+			cat.debug("validate(Element, PublicKey): Error validating the EPPSignedCode: " + ex);
 			valid = false;
 		}
 
@@ -971,11 +930,22 @@ public class EPPSignedCode implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
+	/**
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPVerificationCodeExtFactory.NS;
+	}
+
 }
\ No newline at end of file
