@@ -22,7 +22,8 @@ import java.security.InvalidParameterException;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -30,7 +31,6 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -43,11 +43,9 @@ import com.verisign.epp.util.EqualityUtil;
 public class EPPVerificationCodeInfData implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(
-			EPPVerificationCodeInfData.class.getName(), EPPCatFactory
-					.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPVerificationCodeInfData.class);
 
 	/**
 	 * Constant for the info response extension local name
@@ -57,8 +55,7 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	/**
 	 * Constant for the info response extension tag
 	 */
-	public static final String ELM_NAME = EPPVerificationCodeExtFactory.NS_PREFIX
-			+ ":" + ELM_LOCALNAME;
+	public static final String ELM_NAME = EPPVerificationCodeExtFactory.NS_PREFIX + ":" + ELM_LOCALNAME;
 
 	/**
 	 * Verification statuses that include:<br>
@@ -67,17 +64,17 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * client since there is no assigned verification profile.</li>
 	 * <li><code>NON_COMPLIANT</code> - The object is non-compliant according to
 	 * the verification profile.</li>
-	 * <li><code>PENDING_COMPLIANCE</code> - The object is not in compliance
-	 * with the verification profile, but has a grace period to set the required
-	 * set of verification codes, as reflected by the due date of the
-	 * verification code type.</li>
+	 * <li><code>PENDING_COMPLIANCE</code> - The object is not in compliance with
+	 * the verification profile, but has a grace period to set the required set
+	 * of verification codes, as reflected by the due date of the verification
+	 * code type.</li>
 	 * <li><code>COMPLIANT</code> The object is compliant with the verification
 	 * profile.</li>
 	 * </ul>
 	 */
 	public enum Status {
 		NOT_APPLICABLE("notApplicable"), NON_COMPLIANT("nonCompliant"), PENDING_COMPLIANCE(
-				"pendingCompliance"), COMPLIANT("compliant");
+		      "pendingCompliance"), COMPLIANT("compliant");
 
 		private final String statusStr;
 
@@ -85,7 +82,7 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 		 * Define the string value for the enumerated value.
 		 * 
 		 * @param aStatusStr
-		 *            Enumerated value string
+		 *           Enumerated value string
 		 */
 		Status(String aStatusStr) {
 			this.statusStr = aStatusStr;
@@ -95,15 +92,15 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 		 * Get the status enumerated value given the matching string.
 		 * 
 		 * @param aString
-		 *            <code>Status</code> enumerated string to convert to an
-		 *            enumerated <code>Status</code> instance.
+		 *           <code>Status</code> enumerated string to convert to an
+		 *           enumerated <code>Status</code> instance.
 		 * 
 		 * @return Enumerated <code>Status</code> value matching the
 		 *         <code>String</code>.
 		 * 
 		 * @throws InvalidParameterException
-		 *             If <code>aString</code> does not match an enumerated
-		 *             <code>Status</code> string value.
+		 *            If <code>aString</code> does not match an enumerated
+		 *            <code>Status</code> string value.
 		 */
 		public static Status getStatus(String aString) {
 			if (aString.equals(NOT_APPLICABLE.statusStr)) {
@@ -119,8 +116,7 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 				return COMPLIANT;
 			}
 			else {
-				throw new InvalidParameterException("Status enum value of "
-						+ aString + " is not valid.");
+				throw new InvalidParameterException("Status enum value of " + aString + " is not valid.");
 			}
 		}
 
@@ -159,7 +155,7 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * Create a EPPVerificationCodeInfData instance with the required status.
 	 * 
 	 * @param aStatus
-	 *            Status of the verification
+	 *           Status of the verification
 	 */
 	public EPPVerificationCodeInfData(Status aStatus) {
 		this.status = aStatus;
@@ -170,12 +166,11 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * the a single profile.
 	 * 
 	 * @param aStatus
-	 *            Status of the verification
+	 *           Status of the verification
 	 * @param aProfile
-	 *            Single verification profile
+	 *           Single verification profile
 	 */
-	public EPPVerificationCodeInfData(Status aStatus,
-			EPPVerificationCodeProfile aProfile) {
+	public EPPVerificationCodeInfData(Status aStatus, EPPVerificationCodeProfile aProfile) {
 		this.status = aStatus;
 		this.addProfile(aProfile);
 	}
@@ -185,12 +180,11 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * the optional profiles.
 	 * 
 	 * @param aStatus
-	 *            Status of the verification
+	 *           Status of the verification
 	 * @param aProfiles
-	 *            OPTIONAL verification profiles
+	 *           OPTIONAL verification profiles
 	 */
-	public EPPVerificationCodeInfData(Status aStatus,
-			List<EPPVerificationCodeProfile> aProfiles) {
+	public EPPVerificationCodeInfData(Status aStatus, List<EPPVerificationCodeProfile> aProfiles) {
 		this.status = aStatus;
 		this.profiles = aProfiles;
 	}
@@ -200,18 +194,16 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * 
 	 * @return clone of <code>EPPVerificationCodeInfData</code>
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
-		EPPVerificationCodeInfData clone = (EPPVerificationCodeInfData) super
-				.clone();
+		EPPVerificationCodeInfData clone = (EPPVerificationCodeInfData) super.clone();
 
 		// Status
 		clone.status = this.status;
 
 		// Profiles
-		clone.profiles = new ArrayList<EPPVerificationCodeProfile>(
-				this.profiles.size());
+		clone.profiles = new ArrayList<EPPVerificationCodeProfile>(this.profiles.size());
 		for (EPPVerificationCodeProfile profile : this.profiles)
 			clone.profiles.add((EPPVerificationCodeProfile) profile.clone());
 
@@ -222,26 +214,23 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * Sets all this instance's data in the given XML document
 	 * 
 	 * @param aDocument
-	 *            a DOM Document to attach data to.
+	 *           a DOM Document to attach data to.
 	 * @return The root element of this component.
 	 * 
 	 * @throws EPPEncodeException
-	 *             Thrown if any errors prevent encoding.
+	 *            Thrown if any errors prevent encoding.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " on in EPPVerificationCodeInfData.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " on in EPPVerificationCodeInfData.encode(Document)");
 		}
 
-		Element root = aDocument.createElementNS(
-				EPPVerificationCodeExtFactory.NS, ELM_NAME);
+		Element root = aDocument.createElementNS(EPPVerificationCodeExtFactory.NS, ELM_NAME);
 
 		// Status
-		EPPUtil.encodeString(aDocument, root, this.status.toString(),
-				EPPVerificationCodeExtFactory.NS,
-				EPPVerificationCodeExtFactory.NS_PREFIX + ":" + ELM_STATUS);
+		EPPUtil.encodeString(aDocument, root, this.status.toString(), EPPVerificationCodeExtFactory.NS,
+		      EPPVerificationCodeExtFactory.NS_PREFIX + ":" + ELM_STATUS);
 
 		// Profiles
 		if (this.hasProfiles()) {
@@ -255,36 +244,33 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * Decode the EPPVerificationCodeInfData component
 	 * 
 	 * @param aElement
+	 *           Element to decode from
 	 * @throws EPPDecodeException
+	 *            On decoding error
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 
 		// Status
-		this.status = Status.getStatus(EPPUtil.decodeString(aElement,
-				EPPVerificationCodeExtFactory.NS, ELM_STATUS));
+		this.status = Status.getStatus(EPPUtil.decodeString(aElement, EPPVerificationCodeExtFactory.NS, ELM_STATUS));
 
 		// Profiles
-		this.profiles = EPPUtil.decodeCompList(aElement,
-				EPPVerificationCodeExtFactory.NS,
-				EPPVerificationCodeProfile.ELM_NAME,
-				EPPVerificationCodeProfile.class);
+		this.profiles = EPPUtil.decodeCompList(aElement, EPPVerificationCodeExtFactory.NS,
+		      EPPVerificationCodeProfile.ELM_NAME, EPPVerificationCodeProfile.class);
 	}
 
 	/**
 	 * implements a deep <code>EPPVerificationCodeInfData</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPVerificationCodeInfData</code> instance to compare
-	 *            with
+	 *           <code>EPPVerificationCodeInfData</code> instance to compare with
 	 * 
 	 * @return true if equal false otherwise
 	 */
 	public boolean equals(Object aObject) {
 
 		if (!(aObject instanceof EPPVerificationCodeInfData)) {
-			cat.error("EPPVerificationCodeInfData.equals(): "
-					+ aObject.getClass().getName()
-					+ " not EPPVerificationCodeInfData instance");
+			cat.error("EPPVerificationCodeInfData.equals(): " + aObject.getClass().getName()
+			      + " not EPPVerificationCodeInfData instance");
 
 			return false;
 		}
@@ -319,7 +305,7 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * Sets the verification status.
 	 * 
 	 * @param aStatus
-	 *            Verification status
+	 *           Verification status
 	 */
 	public void setStatus(Status aStatus) {
 		this.status = aStatus;
@@ -349,8 +335,8 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * Sets the profiles.
 	 * 
 	 * @param aProfiles
-	 *            The list of profiles. Set to <code>null</code> or an empty
-	 *            list to indicate that there are no profiles.
+	 *           The list of profiles. Set to <code>null</code> or an empty list
+	 *           to indicate that there are no profiles.
 	 */
 	public void setProfiles(List<EPPVerificationCodeProfile> aProfiles) {
 		if (aProfiles == null) {
@@ -365,7 +351,7 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * Add a profile to the list of profiles.
 	 * 
 	 * @param aProfile
-	 *            Profile to add to the list of profiles.
+	 *           Profile to add to the list of profiles.
 	 */
 	public void addProfile(EPPVerificationCodeProfile aProfile) {
 		this.profiles.add(aProfile);
@@ -402,7 +388,7 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * consisting of <code>aProfile</code>.
 	 * 
 	 * @param aProfile
-	 *            Single profile to set.
+	 *           Single profile to set.
 	 */
 	public void setProfile(EPPVerificationCodeProfile aProfile) {
 		this.profiles = new ArrayList<EPPVerificationCodeProfile>();
@@ -414,17 +400,18 @@ public class EPPVerificationCodeInfData implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
 	 */
 	@Override
 	public String getNamespace() {
