@@ -19,7 +19,8 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
  ***********************************************************/
 package com.verisign.epp.codec.nv;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -28,8 +29,6 @@ import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPTransId;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.codec.verificationcode.EPPEncodedSignedCodeValue;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -41,11 +40,9 @@ import com.verisign.epp.util.EqualityUtil;
 public class EPPNameVerificationCreateResp extends EPPResponse {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(
-			EPPNameVerificationCreateResp.class.getName(), EPPCatFactory
-					.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPNameVerificationCreateResp.class);
 
 	/**
 	 * XML local name for <code>EPPNameVerificationCreateResp</code>.
@@ -55,8 +52,7 @@ public class EPPNameVerificationCreateResp extends EPPResponse {
 	/**
 	 * XML root tag for <code>EPPNameVerificationCreateResp</code>.
 	 */
-	public static final String ELM_NAME = EPPNameVerificationMapFactory.NS_PREFIX
-			+ ":" + ELM_LOCALNAME;
+	public static final String ELM_NAME = EPPNameVerificationMapFactory.NS_PREFIX + ":" + ELM_LOCALNAME;
 
 	/**
 	 * The concrete result of the create, which is either success, pending, or
@@ -71,28 +67,27 @@ public class EPPNameVerificationCreateResp extends EPPResponse {
 	}
 
 	/**
-	 * <code>EPPNameVerificationCreateResp</code> constructor that the transaction
-	 * id associated with the response. The create result must be set.
+	 * <code>EPPNameVerificationCreateResp</code> constructor that the
+	 * transaction id associated with the response. The create result must be
+	 * set.
 	 * 
 	 * @param aTransId
-	 *            Transaction Id associated with response.
+	 *           Transaction Id associated with response.
 	 */
 	public EPPNameVerificationCreateResp(EPPTransId aTransId) {
 		super(aTransId);
 	}
-	
-	
+
 	/**
 	 * <code>EPPNameVerificationCreateResp</code> constructor that includes the
 	 * required result.
 	 * 
 	 * @param aTransId
-	 *            Transaction Id associated with response.
+	 *           Transaction Id associated with response.
 	 * @param aResult
-	 *            The concrete result of the create.
+	 *           The concrete result of the create.
 	 */
-	public EPPNameVerificationCreateResp(EPPTransId aTransId,
-			EPPNameVerificationCreateResult aResult) {
+	public EPPNameVerificationCreateResp(EPPTransId aTransId, EPPNameVerificationCreateResult aResult) {
 		super(aTransId);
 		this.result = aResult;
 	}
@@ -110,7 +105,7 @@ public class EPPNameVerificationCreateResp extends EPPResponse {
 	 * Sets the concrete result of the create.
 	 * 
 	 * @param aResult
-	 *            Concrete create result.
+	 *           Concrete create result.
 	 */
 	public void setCreateResult(EPPNameVerificationCreateResult aResult) {
 		this.result = aResult;
@@ -121,19 +116,18 @@ public class EPPNameVerificationCreateResp extends EPPResponse {
 	 * <code>EPPNameVerificationCreateResp</code> instance.
 	 * 
 	 * @param aDocument
-	 *            DOM Document that is being built. Used as an Element factory.
+	 *           DOM Document that is being built. Used as an Element factory.
 	 * 
 	 * @return Element Root DOM Element representing the
 	 *         EPPNameVerificationCreateResp instance.
 	 * 
 	 * @exception EPPEncodeException
-	 *                Unable to encode EPPNameVerificationCreateResp instance.
+	 *               Unable to encode EPPNameVerificationCreateResp instance.
 	 */
 	protected Element doEncode(Document aDocument) throws EPPEncodeException {
 
 		// Create root element
-		Element root = aDocument.createElementNS(
-				EPPNameVerificationMapFactory.NS, ELM_NAME);
+		Element root = aDocument.createElementNS(EPPNameVerificationMapFactory.NS, ELM_NAME);
 
 		// Result
 		EPPUtil.encodeComp(aDocument, root, this.result);
@@ -146,39 +140,33 @@ public class EPPNameVerificationCreateResp extends EPPResponse {
 	 * aElement DOM Element tree.
 	 * 
 	 * @param aElement
-	 *            Root DOM Element to decode
-	 *            <code>EPPNameVerificationCreateResp</code> from.
+	 *           Root DOM Element to decode
+	 *           <code>EPPNameVerificationCreateResp</code> from.
 	 * 
 	 * @exception EPPDecodeException
-	 *                Unable to decode aElement
+	 *               Unable to decode aElement
 	 */
 	protected void doDecode(Element aElement) throws EPPDecodeException {
 		// -- Result
 		// Success?
-		this.result = (EPPNameVerificationCreateResult) EPPUtil.decodeComp(
-				aElement, EPPNameVerificationMapFactory.NS,
-				EPPNameVerificationCreateSuccess.ELM_NAME,
-				EPPNameVerificationCreateSuccess.class);
+		this.result = (EPPNameVerificationCreateResult) EPPUtil.decodeComp(aElement, EPPNameVerificationMapFactory.NS,
+		      EPPNameVerificationCreateSuccess.ELM_NAME, EPPNameVerificationCreateSuccess.class);
 		if (this.result == null) {
 			// Failed?
-			this.result = (EPPNameVerificationCreateResult) EPPUtil.decodeComp(
-					aElement, EPPNameVerificationMapFactory.NS,
-					EPPNameVerificationCreateFailed.ELM_NAME,
-					EPPNameVerificationCreateFailed.class);
+			this.result = (EPPNameVerificationCreateResult) EPPUtil.decodeComp(aElement, EPPNameVerificationMapFactory.NS,
+			      EPPNameVerificationCreateFailed.ELM_NAME, EPPNameVerificationCreateFailed.class);
 		}
 
 		if (this.result == null) {
 			// Pending?
-			this.result = (EPPNameVerificationCreateResult) EPPUtil.decodeComp(
-					aElement, EPPNameVerificationMapFactory.NS,
-					EPPNameVerificationCreatePending.ELM_NAME,
-					EPPNameVerificationCreatePending.class);
+			this.result = (EPPNameVerificationCreateResult) EPPUtil.decodeComp(aElement, EPPNameVerificationMapFactory.NS,
+			      EPPNameVerificationCreatePending.ELM_NAME, EPPNameVerificationCreatePending.class);
 		}
 
 		// Error decoding?
 		if (this.result == null) {
 			throw new EPPDecodeException(
-					"EPPNameVerificationCreateResp.doDecode(): Unable to decode one of the possible create results");
+			      "EPPNameVerificationCreateResp.doDecode(): Unable to decode one of the possible create results");
 		}
 	}
 
@@ -188,11 +176,10 @@ public class EPPNameVerificationCreateResp extends EPPResponse {
 	 * @return clone of <code>EPPNameVerificationCreateResp</code>
 	 * 
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
-		EPPNameVerificationCreateResp clone = (EPPNameVerificationCreateResp) super
-				.clone();
+		EPPNameVerificationCreateResp clone = (EPPNameVerificationCreateResp) super.clone();
 
 		// Result
 		clone.result = (EPPNameVerificationCreateResult) this.result.clone();
@@ -225,7 +212,7 @@ public class EPPNameVerificationCreateResp extends EPPResponse {
 	 * this instance.
 	 * 
 	 * @param aObject
-	 *            Object to compare with.
+	 *           Object to compare with.
 	 * 
 	 * @return {@code true} if this object is the same as the aObject argument;
 	 *         {@code false} otherwise
@@ -251,8 +238,8 @@ public class EPPNameVerificationCreateResp extends EPPResponse {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
