@@ -26,7 +26,8 @@ import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
@@ -39,7 +40,7 @@ import com.verisign.epp.codec.nv.EPPNameVerificationDocument;
 import com.verisign.epp.codec.nv.EPPNameVerificationInfoCmd;
 import com.verisign.epp.codec.nv.EPPNameVerificationInfoResp;
 import com.verisign.epp.codec.nv.EPPRealNameVerification;
-import com.verisign.epp.util.EPPCatFactory;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -77,8 +78,8 @@ public class EPPNameVerificationTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPNameVerificationTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPNameVerificationTst.class);
+	      
 
 	/** EPP Domain associated with test */
 	private EPPNameVerification nameVerification = null;
