@@ -30,9 +30,8 @@ import java.security.cert.Certificate;
 import java.security.cert.PKIXParameters;
 import java.util.Date;
 
-import junit.framework.Assert;
-
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.gen.EPPAuthInfo;
 import com.verisign.epp.codec.gen.EPPDecodeException;
@@ -68,16 +67,16 @@ import com.verisign.epp.framework.EPPHandleEventException;
 import com.verisign.epp.framework.EPPNameVerificationHandler;
 import com.verisign.epp.framework.EPPPollQueueException;
 import com.verisign.epp.framework.EPPPollQueueMgr;
-import com.verisign.epp.util.EPPCatFactory;
+
+import junit.framework.Assert;
 
 /**
  * Stub handler for the Name Verification commands.
  */
 public class NameVerificationHandler extends EPPNameVerificationHandler {
 
-	/** Log4j category for logging */
-	private static Logger cat = Logger.getLogger(NameVerificationHandler.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	/** Category for logging */
+	private static Logger cat = LoggerFactory.getLogger(NameVerificationHandler.class);
 
 	/**
 	 * Private key used for signing
@@ -147,20 +146,18 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	 * Create a signed code from a code value.
 	 * 
 	 * @param aCode
-	 *            Code value to sign
+	 *           Code value to sign
 	 * 
 	 * @return Encoded signed code
 	 * 
 	 * @throws EPPException
-	 *             Error creating the signed code
+	 *            Error creating the signed code
 	 */
-	private EPPEncodedSignedCodeValue createSignedCode(String aCode,
-			String aType) throws EPPException {
+	private EPPEncodedSignedCodeValue createSignedCode(String aCode, String aType) throws EPPException {
 		cat.debug("createSignedCode: enter");
 
 		cat.debug("createSignedCode: code = " + aCode + ", type = " + aType);
-		System.out.println("createSignedCode: code = " + aCode + ", type = "
-				+ aType);
+		System.out.println("createSignedCode: code = " + aCode + ", type = " + aType);
 
 		EPPSignedCode signedCode = null;
 		EPPEncodedSignedCodeValue encodedSignedCodeValue = null;
@@ -172,20 +169,17 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 
 			if (!signedCode.validate(publicKey)) {
 				cat.error("Signed code validation error using public key");
-				throw new EPPException(
-						"Signed code validation error using public key");
+				throw new EPPException("Signed code validation error using public key");
 			}
 
 			if (!signedCode.validate(pkixParameters)) {
 				cat.error("Signed code validation error using PKIX");
-				throw new EPPException(
-						"Signed code validation error using PKIX");
+				throw new EPPException("Signed code validation error using PKIX");
 			}
 
 			encodedSignedCodeValue = new EPPEncodedSignedCodeValue(signedCode);
 
-			cat.debug("createSignedCode: encoded signed code value = ["
-					+ encodedSignedCodeValue + "]");
+			cat.debug("createSignedCode: encoded signed code value = [" + encodedSignedCodeValue + "]");
 		}
 		catch (EPPEncodeException e) {
 			throw new EPPException("EPPEncodeException: " + e);
@@ -199,26 +193,25 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	}
 
 	/**
-	 * Loads the private key used to digitally sign from a Java KeyStore with
-	 * the <code>aKeyAliasName</code> alias and the <code>aPassword</code>
-	 * password to access the Keystore and the key.
+	 * Loads the private key used to digitally sign from a Java KeyStore with the
+	 * <code>aKeyAliasName</code> alias and the <code>aPassword</code> password
+	 * to access the Keystore and the key.
 	 * 
 	 * @param aKeyStoreName
-	 *            Java Keystore to load the key from
+	 *           Java Keystore to load the key from
 	 * @param aKeyAliasName
-	 *            Java Keystore alias of key
+	 *           Java Keystore alias of key
 	 * @param aPassword
-	 *            Password to access Java Keystore and key
+	 *           Password to access Java Keystore and key
 	 * 
 	 * @return Loaded <code>KeyStore.PrivateKeyEntry</code> that can be used to
 	 *         get the private key and it's associated certificate chain.
 	 * 
 	 * @throws Exception
-	 *             Error loading private key
+	 *            Error loading private key
 	 */
-	private static KeyStore.PrivateKeyEntry loadPrivateKeyEntry(
-			String aKeyStoreName, String aKeyAliasName, String aPassword)
-			throws Exception {
+	private static KeyStore.PrivateKeyEntry loadPrivateKeyEntry(String aKeyStoreName, String aKeyAliasName,
+	      String aPassword) throws Exception {
 
 		// Load KeyStore
 		KeyStore keyStore = KeyStore.getInstance(KeyStore.getDefaultType());
@@ -227,9 +220,8 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 
 		// Get Private Key
 		assert keyStore.isKeyEntry(aKeyAliasName);
-		KeyStore.PrivateKeyEntry keyEntry = (KeyStore.PrivateKeyEntry) keyStore
-				.getEntry(aKeyAliasName, new KeyStore.PasswordProtection(
-						aPassword.toCharArray()));
+		KeyStore.PrivateKeyEntry keyEntry = (KeyStore.PrivateKeyEntry) keyStore.getEntry(aKeyAliasName,
+		      new KeyStore.PasswordProtection(aPassword.toCharArray()));
 
 		return keyEntry;
 	}
@@ -240,18 +232,17 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	 * {@link #loadPrivateKeyEntry(String, String, String)}.
 	 * 
 	 * @param aKeyStoreName
-	 *            Java Keystore containing the certificate
+	 *           Java Keystore containing the certificate
 	 * @param aPublicKeyAlias
-	 *            Java Keystore alias of the <code>trustedCertEntry</code>
-	 *            containing the public key
+	 *           Java Keystore alias of the <code>trustedCertEntry</code>
+	 *           containing the public key
 	 * 
 	 * @return Loaded <code>PublicKey</code> instance
 	 * 
 	 * @throws Exception
-	 *             Error loading the public key
+	 *            Error loading the public key
 	 */
-	public static PublicKey loadPublicKey(String aKeyStoreName,
-			String aPublicKeyAlias) throws Exception {
+	public static PublicKey loadPublicKey(String aKeyStoreName, String aPublicKeyAlias) throws Exception {
 
 		// Load KeyStore
 		KeyStore keyStore = KeyStore.getInstance(KeyStore.getDefaultType());
@@ -260,8 +251,8 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 
 		assert keyStore.isCertificateEntry(aPublicKeyAlias);
 
-		KeyStore.TrustedCertificateEntry certEntry = (KeyStore.TrustedCertificateEntry) keyStore
-				.getEntry(aPublicKeyAlias, null);
+		KeyStore.TrustedCertificateEntry certEntry = (KeyStore.TrustedCertificateEntry) keyStore.getEntry(aPublicKeyAlias,
+		      null);
 
 		return certEntry.getTrustedCertificate().getPublicKey();
 	}
@@ -272,15 +263,14 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	 * trusted VSP certificates.
 	 * 
 	 * @param aTrustStoreName
-	 *            Trust store file name
+	 *           Trust store file name
 	 * 
 	 * @return Initialized <code>PKIXParameters</code> instance.
 	 * 
 	 * @throws Exception
-	 *             Error initializing the PKIX parameters
+	 *            Error initializing the PKIX parameters
 	 */
-	public static PKIXParameters loadPKIXParameters(String aTrustStoreName)
-			throws Exception {
+	public static PKIXParameters loadPKIXParameters(String aTrustStoreName) throws Exception {
 
 		KeyStore trustStore = KeyStore.getInstance(KeyStore.getDefaultType());
 		FileInputStream trustStoreFile = new FileInputStream(aTrustStoreName);
@@ -298,8 +288,8 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	public NameVerificationHandler() {
 		// Initialize the PKIX parameters and other DSIG properties
 		try {
-			KeyStore.PrivateKeyEntry keyEntry = loadPrivateKeyEntry(
-					KEYSTORE_FILENAME, KEYSTORE_KEY_ALIAS, KEYSTORE_PASSWORD);
+			KeyStore.PrivateKeyEntry keyEntry = loadPrivateKeyEntry(KEYSTORE_FILENAME, KEYSTORE_KEY_ALIAS,
+			      KEYSTORE_PASSWORD);
 			privateKey = keyEntry.getPrivateKey();
 			certChain = keyEntry.getCertificateChain();
 
@@ -312,24 +302,20 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 		}
 
 		// Initialize the Verification Code Revocation List
-		File verificationCodeRevocationListFile = new File(
-				"verification-code-test-revocation.csv");
+		File verificationCodeRevocationListFile = new File("verification-code-test-revocation.csv");
 
 		if (verificationCodeRevocationListFile.exists()) {
 
 			try {
-				FileInputStream smdRevocationListStream = new FileInputStream(
-						verificationCodeRevocationListFile);
+				FileInputStream smdRevocationListStream = new FileInputStream(verificationCodeRevocationListFile);
 				verificationCodeRevocationList.decode(smdRevocationListStream);
 
 			}
 			catch (FileNotFoundException e) {
-				Assert.fail("Error opening Verification Code Revocation List File: "
-						+ e);
+				Assert.fail("Error opening Verification Code Revocation List File: " + e);
 			}
 			catch (EPPDecodeException e) {
-				Assert.fail("Error decoding Verification Code Revocation List File: "
-						+ e);
+				Assert.fail("Error decoding Verification Code Revocation List File: " + e);
 			}
 		}
 
@@ -339,18 +325,17 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	 * Do any pre-handling of commands.
 	 *
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>NameVerificationHandler</code> This is assumed to be an
-	 *            instance of SessionData here.
+	 *           Any data that a Server needs to send to this
+	 *           <code>NameVerificationHandler</code> This is assumed to be an
+	 *           instance of SessionData here.
 	 *
 	 * @exception EPPHandleEventException
-	 *                Thrown if an error condition occurs. It must contain an
-	 *                <code>EPPEventResponse</code>
+	 *               Thrown if an error condition occurs. It must contain an
+	 *               <code>EPPEventResponse</code>
 	 */
-	protected void preHandleEvent(EPPEvent aEvent, Object aData)
-			throws EPPHandleEventException {
+	protected void preHandleEvent(EPPEvent aEvent, Object aData) throws EPPHandleEventException {
 
 		super.preHandleEvent(aEvent, aData);
 
@@ -361,50 +346,42 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	 * handling of the Name Verification Check Command.
 	 * 
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>NameVerificationHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>NameVerificationHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
 	 */
-	protected EPPEventResponse doNameVerificationCheck(EPPEvent aEvent,
-			Object aData) {
+	protected EPPEventResponse doNameVerificationCheck(EPPEvent aEvent, Object aData) {
 		cat.debug("doNameVerificationCheck: enter");
 
-		EPPNameVerificationCheckCmd theCommand = (EPPNameVerificationCheckCmd) aEvent
-				.getMessage();
+		EPPNameVerificationCheckCmd theCommand = (EPPNameVerificationCheckCmd) aEvent.getMessage();
 
-		EPPTransId theTransId = new EPPTransId(theCommand.getTransId(),
-				"54321-XYZ");
+		EPPTransId theTransId = new EPPTransId(theCommand.getTransId(), "54321-XYZ");
 
-		EPPNameVerificationCheckResp theResp = new EPPNameVerificationCheckResp(
-				theTransId);
+		EPPNameVerificationCheckResp theResp = new EPPNameVerificationCheckResp(theTransId);
 
 		for (String label : theCommand.getLabels()) {
 
 			// ChinaVerificationCodeTst label?
 			if (label.startsWith("cvct")) {
-				theResp.addResult(new EPPNameVerificationCheckResult(label,
-						true));
+				theResp.addResult(new EPPNameVerificationCheckResult(label, true));
 			}
 			else {
 				switch (checkResultCount % 3) {
-				// Available
+					// Available
 					case 0:
-						theResp.addResult(new EPPNameVerificationCheckResult(
-								label, true));
+						theResp.addResult(new EPPNameVerificationCheckResult(label, true));
 						break;
 					// Not Available - Prohibited
 					case 1:
-						theResp.addResult(new EPPNameVerificationCheckResult(
-								label, false, "In Prohibited Lists."));
+						theResp.addResult(new EPPNameVerificationCheckResult(label, false, "In Prohibited Lists."));
 						break;
 					// Not Available - Restricted
 					case 2:
-						EPPNameVerificationCheckResult theCheckResult = new EPPNameVerificationCheckResult(
-								label, false);
+						EPPNameVerificationCheckResult theCheckResult = new EPPNameVerificationCheckResult(label, false);
 						theCheckResult.setRestricted(true);
 						theResp.addResult(theCheckResult);
 						break;
@@ -424,78 +401,60 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	 * handling of the Name Verification Info Command.
 	 * 
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>NameVerificationHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>NameVerificationHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
 	 */
-	protected EPPEventResponse doNameVerificationInfo(EPPEvent aEvent,
-			Object aData) {
+	protected EPPEventResponse doNameVerificationInfo(EPPEvent aEvent, Object aData) {
 		cat.debug("doNameVerificationInfo: enter");
 		EPPNameVerificationInfoResp theResp;
 
-		EPPNameVerificationInfoCmd theCommand = (EPPNameVerificationInfoCmd) aEvent
-				.getMessage();
+		EPPNameVerificationInfoCmd theCommand = (EPPNameVerificationInfoCmd) aEvent.getMessage();
 
-		EPPTransId theTransId = new EPPTransId(theCommand.getTransId(),
-				"54321-XYZ");
+		EPPTransId theTransId = new EPPTransId(theCommand.getTransId(), "54321-XYZ");
 
 		if (theCommand.getInfoType() == EPPNameVerificationInfoCmd.Type.INPUT) {
 
 			// RNV?
 			if (theCommand.getCode().contains("rnv")) {
-				theResp = new EPPNameVerificationInfoResp(
-						theTransId,
-						new EPPNameVerificationInfoInputResult(
-								new EPPRealNameVerification(
-										EPPRealNameVerification.Role.PERSON,
-										"John Xie",
-										"1234567890",
-										EPPRealNameVerification.ProofType.POC,
-										new EPPNameVerificationDocument(
-												EPPNameVerificationDocument.FileType.JPG,
-												"EABQRAQAAAAAAAAAAAAAAAAAAAAD")),
-								new EPPAuthInfo("2fooBAR")));
+				theResp = new EPPNameVerificationInfoResp(theTransId,
+				      new EPPNameVerificationInfoInputResult(
+				            new EPPRealNameVerification(EPPRealNameVerification.Role.PERSON, "John Xie", "1234567890",
+				                  EPPRealNameVerification.ProofType.POC, new EPPNameVerificationDocument(
+				                        EPPNameVerificationDocument.FileType.JPG, "EABQRAQAAAAAAAAAAAAAAAAAAAAD")),
+				            new EPPAuthInfo("2fooBAR")));
 
 			} // DNV
 			else {
-				theResp = new EPPNameVerificationInfoResp(theTransId,
-						new EPPNameVerificationInfoInputResult(
-								new EPPDomainNameVerification("example"),
-								new EPPAuthInfo("2fooBAR")));
+				theResp = new EPPNameVerificationInfoResp(theTransId, new EPPNameVerificationInfoInputResult(
+				      new EPPDomainNameVerification("example"), new EPPAuthInfo("2fooBAR")));
 
 			}
 
 		} // theCommand.getInfoType() ==
-			// EPPNameVerificationInfoCmd.Type.SIGNED_CODE
+		  // EPPNameVerificationInfoCmd.Type.SIGNED_CODE
 		else {
 			try {
 				// RNV?
 				if (theCommand.getCode().contains("rnv")) {
 					theResp = new EPPNameVerificationInfoResp(theTransId,
-							new EPPNameVerificationInfoSignedCodeResult(
-									theCommand.getCode(), "real-name",
-									this.createSignedCode(theCommand.getCode(),
-											"real-name"),
-									EPPNameVerificationStatus.COMPLIANT,
-									new EPPAuthInfo("2fooBAR")));
+					      new EPPNameVerificationInfoSignedCodeResult(theCommand.getCode(), "real-name",
+					            this.createSignedCode(theCommand.getCode(), "real-name"),
+					            EPPNameVerificationStatus.COMPLIANT, new EPPAuthInfo("2fooBAR")));
 				} // DNV
 				else {
 					theResp = new EPPNameVerificationInfoResp(theTransId,
-							new EPPNameVerificationInfoSignedCodeResult(
-									theCommand.getCode(), "domain",
-									this.createSignedCode(theCommand.getCode(),
-											"domain"),
-									EPPNameVerificationStatus.COMPLIANT,
-									new EPPAuthInfo("2fooBAR")));
+					      new EPPNameVerificationInfoSignedCodeResult(theCommand.getCode(), "domain",
+					            this.createSignedCode(theCommand.getCode(), "domain"), EPPNameVerificationStatus.COMPLIANT,
+					            new EPPAuthInfo("2fooBAR")));
 				}
 			}
 			catch (EPPException ex) {
-				cat.error("Error creating the verification code info response:"
-						+ ex);
+				cat.error("Error creating the verification code info response:" + ex);
 				EPPResult theResult = new EPPResult(EPPResult.COMMAND_FAILED);
 				EPPResponse theResponse = new EPPResponse(theTransId, theResult);
 
@@ -508,97 +467,74 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	}
 
 	/**
-	 * Override base handler <code>doNameVerificationCreate</code> method and
-	 * add handling of the Name Verification Create Command.
+	 * Override base handler <code>doNameVerificationCreate</code> method and add
+	 * handling of the Name Verification Create Command.
 	 * 
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>NameVerificationHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>NameVerificationHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
 	 */
-	protected EPPEventResponse doNameVerificationCreate(EPPEvent aEvent,
-			Object aData) {
+	protected EPPEventResponse doNameVerificationCreate(EPPEvent aEvent, Object aData) {
 		cat.debug("doNameVerificationCreate: enter");
 
 		EPPNameVerificationCreateResp theResp;
 
-		EPPNameVerificationCreateCmd theCommand = (EPPNameVerificationCreateCmd) aEvent
-				.getMessage();
+		EPPNameVerificationCreateCmd theCommand = (EPPNameVerificationCreateCmd) aEvent.getMessage();
 
-		EPPTransId theTransId = new EPPTransId(theCommand.getTransId(),
-				"54321-XYZ");
+		EPPTransId theTransId = new EPPTransId(theCommand.getTransId(), "54321-XYZ");
 
 		// DNV?
 		if (theCommand.hasDnv()) {
 
-			cat.info("doNameVerificationCreate: Received DNV create with label = "
-					+ theCommand.getDnv().getName()
-					+ ", rnvCode = "
-					+ theCommand.getDnv().getRnvCode());
+			cat.info("doNameVerificationCreate: Received DNV create with label = " + theCommand.getDnv().getName()
+			      + ", rnvCode = " + theCommand.getDnv().getRnvCode());
 
 			if (theCommand.getDnv().getName().equalsIgnoreCase("PENDING")) {
 				String theCode = VSP_ID + "-" + System.currentTimeMillis();
 
-				EPPNameVerificationPendActionMsg thePollMsg = new EPPNameVerificationPendActionMsg(
-						theTransId,
-						theCode,
-						"domain",
-						EPPNameVerificationStatus.COMPLIANT,
-						"The object has passed verification, signed code was generated.",
-						new Date(System.currentTimeMillis()));
+				EPPNameVerificationPendActionMsg thePollMsg = new EPPNameVerificationPendActionMsg(theTransId, theCode,
+				      "domain", EPPNameVerificationStatus.COMPLIANT,
+				      "The object has passed verification, signed code was generated.",
+				      new Date(System.currentTimeMillis()));
 				try {
-					EPPPollQueueMgr.getInstance().put(null,
-							NameVerificationPollHandler.KIND, thePollMsg, null);
+					EPPPollQueueMgr.getInstance().put(null, NameVerificationPollHandler.KIND, thePollMsg, null);
 				}
 				catch (EPPPollQueueException ex) {
 					cat.error("Error inserting poll queue message: " + ex);
-					EPPResult theResult = new EPPResult(
-							EPPResult.COMMAND_FAILED);
-					EPPResponse theResponse = new EPPResponse(theTransId,
-							theResult);
+					EPPResult theResult = new EPPResult(EPPResult.COMMAND_FAILED);
+					EPPResponse theResponse = new EPPResponse(theTransId, theResult);
 
 					return new EPPEventResponse(theResponse);
 				}
 
-				theResp = new EPPNameVerificationCreateResp(theTransId,
-						new EPPNameVerificationCreatePending(theCode, "domain",
-								EPPNameVerificationStatus.PENDING_COMPLIANT,
-								new Date(System.currentTimeMillis())));
+				theResp = new EPPNameVerificationCreateResp(theTransId, new EPPNameVerificationCreatePending(theCode,
+				      "domain", EPPNameVerificationStatus.PENDING_COMPLIANT, new Date(System.currentTimeMillis())));
 				theResp.setResult(EPPResult.SUCCESS_PENDING);
 			}
 			else if (theCommand.getDnv().getName().equalsIgnoreCase("FAILED")) {
 
-				theResp = new EPPNameVerificationCreateResp(theTransId,
-						new EPPNameVerificationCreateFailed(
-								EPPNameVerificationStatus.NON_COMPLIANT,
-								"The name of the object is not correct."));
+				theResp = new EPPNameVerificationCreateResp(theTransId, new EPPNameVerificationCreateFailed(
+				      EPPNameVerificationStatus.NON_COMPLIANT, "The name of the object is not correct."));
 				theResp.setResult(EPPResult.SUCCESS);
 
 			}
-			else if (theCommand.getDnv().getName()
-					.equalsIgnoreCase("INVALID-TYPE")) {
+			else if (theCommand.getDnv().getName().equalsIgnoreCase("INVALID-TYPE")) {
 
 				try {
 					String theCode = VSP_ID + "-" + System.currentTimeMillis();
 					theResp = new EPPNameVerificationCreateResp(theTransId,
-							new EPPNameVerificationCreateSuccess(theCode,
-									"invalid-type",
-									EPPNameVerificationStatus.COMPLIANT,
-									new Date(System.currentTimeMillis()),
-									this.createSignedCode(theCode,
-											"invalid-type")));
+					      new EPPNameVerificationCreateSuccess(theCode, "invalid-type", EPPNameVerificationStatus.COMPLIANT,
+					            new Date(System.currentTimeMillis()), this.createSignedCode(theCode, "invalid-type")));
 				}
 				catch (EPPException ex) {
-					cat.error("Error creating the DNV verification code create response:"
-							+ ex);
-					EPPResult theResult = new EPPResult(
-							EPPResult.COMMAND_FAILED);
-					EPPResponse theResponse = new EPPResponse(theTransId,
-							theResult);
+					cat.error("Error creating the DNV verification code create response:" + ex);
+					EPPResult theResult = new EPPResult(EPPResult.COMMAND_FAILED);
+					EPPResponse theResponse = new EPPResponse(theTransId, theResult);
 
 					return new EPPEventResponse(theResponse);
 				}
@@ -608,19 +544,13 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 				try {
 					String theCode = VSP_ID + "-" + System.currentTimeMillis();
 					theResp = new EPPNameVerificationCreateResp(theTransId,
-							new EPPNameVerificationCreateSuccess(theCode,
-									"domain",
-									EPPNameVerificationStatus.COMPLIANT,
-									new Date(System.currentTimeMillis()),
-									this.createSignedCode(theCode, "domain")));
+					      new EPPNameVerificationCreateSuccess(theCode, "domain", EPPNameVerificationStatus.COMPLIANT,
+					            new Date(System.currentTimeMillis()), this.createSignedCode(theCode, "domain")));
 				}
 				catch (EPPException ex) {
-					cat.error("Error creating the DNV verification code create response:"
-							+ ex);
-					EPPResult theResult = new EPPResult(
-							EPPResult.COMMAND_FAILED);
-					EPPResponse theResponse = new EPPResponse(theTransId,
-							theResult);
+					cat.error("Error creating the DNV verification code create response:" + ex);
+					EPPResult theResult = new EPPResult(EPPResult.COMMAND_FAILED);
+					EPPResponse theResponse = new EPPResponse(theTransId, theResult);
 
 					return new EPPEventResponse(theResponse);
 				}
@@ -628,33 +558,22 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 		} // RNV
 		else {
 			cat.info("doNameVerificationCreate: Received RNV create with role = "
-					+ theCommand.getRnv().getRole().toString()
-					+ ", name = "
-					+ theCommand.getRnv().getName()
-					+ ", num = "
-					+ theCommand.getRnv().getNum()
-					+ ", proofType = "
-					+ theCommand.getRnv().getProofType().toString());
+			      + theCommand.getRnv().getRole().toString() + ", name = " + theCommand.getRnv().getName() + ", num = "
+			      + theCommand.getRnv().getNum() + ", proofType = " + theCommand.getRnv().getProofType().toString());
 			if (theCommand.getRnv().hasDocuments()) {
-				for (EPPNameVerificationDocument doc : theCommand.getRnv()
-						.getDocuments()) {
-					cat.info("doNameVerificationCreate: doc type = "
-							+ doc.getFileType().toString() + ", content = \""
-							+ doc.getFileContent() + "\"");
+				for (EPPNameVerificationDocument doc : theCommand.getRnv().getDocuments()) {
+					cat.info("doNameVerificationCreate: doc type = " + doc.getFileType().toString() + ", content = \""
+					      + doc.getFileContent() + "\"");
 				}
 			}
 			try {
 				String theCode = VSP_ID + "-" + System.currentTimeMillis();
 				theResp = new EPPNameVerificationCreateResp(theTransId,
-						new EPPNameVerificationCreateSuccess(theCode,
-								"real-name",
-								EPPNameVerificationStatus.COMPLIANT, new Date(
-										System.currentTimeMillis()),
-								this.createSignedCode(theCode, "real-name")));
+				      new EPPNameVerificationCreateSuccess(theCode, "real-name", EPPNameVerificationStatus.COMPLIANT,
+				            new Date(System.currentTimeMillis()), this.createSignedCode(theCode, "real-name")));
 			}
 			catch (EPPException ex) {
-				cat.error("Error creating the RNV verification code create response:"
-						+ ex);
+				cat.error("Error creating the RNV verification code create response:" + ex);
 				EPPResult theResult = new EPPResult(EPPResult.COMMAND_FAILED);
 				EPPResponse theResponse = new EPPResponse(theTransId, theResult);
 
@@ -668,29 +587,26 @@ public class NameVerificationHandler extends EPPNameVerificationHandler {
 	}
 
 	/**
-	 * Override base handler <code>doNameVerificationUpdate</code> method and
-	 * add handling of the Name Verification Update Command.
+	 * Override base handler <code>doNameVerificationUpdate</code> method and add
+	 * handling of the Name Verification Update Command.
 	 * 
 	 * @param aEvent
-	 *            The <code>EPPEvent</code> that is being handled
+	 *           The <code>EPPEvent</code> that is being handled
 	 * @param aData
-	 *            Any data that a Server needs to send to this
-	 *            <code>NameVerificationHandler</code>
+	 *           Any data that a Server needs to send to this
+	 *           <code>NameVerificationHandler</code>
 	 *
 	 * @return EPPEventResponse The response that should be sent back to the
 	 *         client.
 	 */
-	protected EPPEventResponse doNameVerificationUpdate(EPPEvent aEvent,
-			Object aData) {
+	protected EPPEventResponse doNameVerificationUpdate(EPPEvent aEvent, Object aData) {
 		cat.debug("doNameVerificationUpdate: enter");
 
-		EPPNameVerificationUpdateCmd theCommand = (EPPNameVerificationUpdateCmd) aEvent
-				.getMessage();
+		EPPNameVerificationUpdateCmd theCommand = (EPPNameVerificationUpdateCmd) aEvent.getMessage();
 
-		EPPTransId theTransId = new EPPTransId(theCommand.getTransId(),
-				"54321-XYZ");
-		cat.info("doNameVerificationUpdate: code = " + theCommand.getCode()
-				+ ", authInfo = " + theCommand.getAuthInfo().getPassword());
+		EPPTransId theTransId = new EPPTransId(theCommand.getTransId(), "54321-XYZ");
+		cat.info("doNameVerificationUpdate: code = " + theCommand.getCode() + ", authInfo = "
+		      + theCommand.getAuthInfo().getPassword());
 
 		EPPResponse theResp = new EPPResponse(theTransId);
 
