@@ -17,16 +17,16 @@
 
 package com.verisign.epp.codec.whois;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
-import com.verisign.epp.codec.gen.EPPCodec;
 import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * Extension to the domain info command to specify whether or not the whois info
@@ -40,9 +40,9 @@ import com.verisign.epp.util.EPPCatFactory;
 public class EPPWhoisInf implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPWhoisInf.class.getName(), EPPCatFactory.getInstance().getFactory());
+	    private static Logger cat = LoggerFactory.getLogger(EPPWhoisInf.class);
 
 	/**
 	 * Constant for the whois info extension tag
@@ -124,7 +124,6 @@ public class EPPWhoisInf implements EPPCodecComponent {
 
 		Element root = aDocument.createElementNS(EPPWhoisExtFactory.NS, ELM_NAME);
 		root.setAttribute("xmlns:whoisInf", EPPWhoisExtFactory.NS);
-		root.setAttributeNS(EPPCodec.NS_XSI, "xsi:schemaLocation", EPPWhoisExtFactory.NS_SCHEMA);
 
 		EPPUtil.encodeBoolean(aDocument, root, this.flag, EPPWhoisExtFactory.NS, ELM_FLAG);
 
@@ -134,8 +133,8 @@ public class EPPWhoisInf implements EPPCodecComponent {
 	/**
 	 * Decode the EPPIdnLangExtCrete component
 	 * 
-	 * @param aElement
-	 * @throws EPPDecodeException
+	 * @param aElement Element to decode from
+	 * @throws EPPDecodeException On decoding error
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 
